<!DOCTYPE html>
<html lang="ja">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<meta http-equiv="X-UA-Compatible" content="IE=edge" />
<title>{{title}}</title>
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="format-detection" content="telephone=no" />
<style>
	{{style['custom']}}
	{{style['reset']}}
	{{style['kotei']}}
</style>
</head>

<body>
<div id="page_type" style="display: none">single</div>
<a id="pageBottom" href="#footer">↓</a>
<div id="main"></div>
<div class="contents1">
</div>
<div id="novel_contents">
<div id="novel_color">
<p class="novel_subtitle">{{title}}</p>
<div class="novel_writername">
作者：{%- if author[1] %}<a href="{{ author[1] }}">{{ author[0] }}</a>{% else %}{{ author[0] }}{%- endif %}
</div><!--novel_writername-->
<div id="novel_honbun" class="novel_view">
{%- for i in range(0,lines) %}
<p id="L{{ i+1 }}">{{ contents[i] }}</p>
{%- endfor %}
</div>

</div></div>
<br>
<a id="pageTop" href="#main">↑</a>

<!-- フッタここから -->
<div id="footer">
<ul class="undernavi">
<li><a href="https://syosetu.com">小説家になろう</a></li>
<li><a href="https://kakuyomu.jp">カクヨム</a></li>
<li><a href="{{url}}">公式で読む</a></li>
<li id="search">
<form action="https://yomou.syosetu.com/search.php">
<input name="word" size="21" type="text" />
<input value="検索" type="submit" />
</form>
</li>
</ul>
</div><!--footer-->
<!-- フッタここまで -->
{%- for s in script %}
<script id="{{s}}">
{{ script[s] }}
</script>
{%- endfor %}
</body>
</html>
