<a id="pageBottom" href="#footer">↓</a>
<div id="main"></div>
<div id="novel_contents">
<div id="novel_color">
<br>
<p class="novel_title">{{title}}</p>
<div class="novel_writername">
作者：{%- if author[1] %}<a href="{{ author[1] }}">{{ author[0] }}</a>{% else %}{{ author[0] }}{%- endif %}
</div><!--novel_writername-->
<div id="novel_ex">
{{desc|safe}}
</div>
<div class="index_box">
{%- for dex in index %}
{%- if dex['type']=="chapter" %}
 <div class="chapter_title">{{dex['text']}}</div>
{%- elif dex['type']=="episode" %}
<dl class="novel_sublist2">
<dd class="subtitle">
<a href="{{dex['part']}}.html">{{dex['text']}}</a>
</dd>
<dt class="long_update">{{dex['time'].strftime('%Y/%m/%d/ %H:%M')}}</dt>
</dl>
{%- endif %}
{%- endfor %}
</div>
</div></div>

<br>
<a id="pageTop" href="#main">↑</a>

<!-- フッタここから -->
<div id="footer">
<ul class="undernavi">
<li><a href="https://syosetu.com">小説家になろう</a></li>
<li><a href="https://syosetu.com/user/top">ーホーム</a></li>
<li><a href="https://kakuyomy.jp">カクヨム</a></li>
<li><a href="https://kakuyomy.jp/my/antenna/works">ーホーム</a></li>
<li><a href="{{url}}">公式で読む</a></li>
<li id="search">
<form action="https://yomou.syosetu.com/search.php">
<input name="word" size="21" type="text" />
<input value="検索" type="submit" />
</form>
</li>
</ul>
</div><!--footer-->
<!-- フッタここまで -->
