<!DOCTYPE html>
<html lang="ja">
<head>
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, minimum-scale=1.0, maximum-scale=1.0, user-scalable=no, viewport-fit=cover" />

<title>{{ title }}</title>

<link rel="stylesheet" href="static/kakuyomu.css" />
<link rel="icon" sizes="256x256" href="static/app-256.png" class="js-favicon" />
<link rel="apple-touch-icon" href="static/ios-60.png" />
<link rel="shortcut icon" href="static/favicon.ico" class="js-favicon" />
<script src="static/combine.js"></script>
</head>

<body id="page-works-work" class="wrapper isPC">
<div id="page_type" style="display: none">index</div>
<div id="pc">
  <header id="globalHeaderPC">
    <div id="globalHeaderPC-inner">
      <div id="globalHeaderPC-primary">
        <h1 id="globalHeaderPC-logo"><a href="https://kakuyomu.jp">
          <img src="static/kakuyomu-logo.png" alt="カクヨム" />
        </a></h1>
        <nav>
          <ul id="globalHeaderPC-globalNav"><li id="globalHeaderPC-antenna"><a href="https://kakuyomu.jp/my/antenna"><span>マイページ</span></a></li><li><a href="https://kakuyomu.jp/explore"><span>小説を探す</span></a></li><li><a href="https://kakuyomu.jp/official"><span>公式連載</span></a></li><li id="globalHeaderPC-publication"><a href="https://kakuyomu.jp/publication/"><span>書籍化作品</span></a></li>
          </ul>
        </nav>
      </div>
      <nav>
        <div id="globalHeaderPC-search" class="js-global-header-search-container">
          <form method="GET" action="https://kakuyomu.jp/search">
            <input type="text" id="globalHeaderPC-search-input" name="q" placeholder="小説・ユーザーを検索…" autocomplete="off" />
            <button type="submit" id="globalHeaderPC-searchSubmit" aria-label="検索する"><i class="icon-search"></i></button>
          </form>
          <div id="globalHeaderPC-searchingConditions-panel" class="isPanelHidden js-global-header-searching-condition-history-panel"
            data-endpoint-url="https://kakuyomu.jp/my/searching_conditions/recent_fragment">
          </div>
        </div>
      </nav>
    </div>
  </header>

<div id="container">
  <div id="container-inner">
    
<div id="work">
  <header id="workHeader">

    <div id="workHeader-inner">
      <h1 id="workTitle"><a href="{{ url }}">{{ title }}</a></h1>
      <h2 id="workAuthor">
        <span id="workAuthor-label">作者</span>
        <span id="workAuthor-activityName"><a href="{{author[1]}}">{{author[0]}}</a></span>
      </h2>
    </div>

  </header>

  <main id="workMain">

    <div class="widget-internalLinks"></div>

      <section id="description" class="internalLinks-target hasBothCatchphraseAndIntroduction">
          <p id="introduction" class="ui-truncateTextButton js-work-introduction">{{ desc |safe}}</p>
      </section>

    <div id="table-of-contents">

<section class="widget-toc">
  <header>
    <h3 class="heading-level2">目次</h3>

    <div class="widget-toc-workInfo js-chrome-visibility-fix">
	  <p class="widget-toc-workStatus">
        <span>連載</span>
        <span class="js-vertical-composition-item">全{{total}}話</span>
      </p>
    </div>
  </header>

  <div class="widget-toc-main">
    <ol class="widget-toc-items test-toc-items">
{%- for dex in index %}
{%- if dex['type']=="chapter" %}
          <li class="widget-toc-chapter widget-toc-level1 js-vertical-composition-item">
            <span>{{ dex['text'] }}</span>
          </li>
{%- elif dex['type']=="episode" %}
          <li class="widget-toc-episode">
            <a href="{{ dex['part']}}.html" class="widget-toc-episode-episodeTitle">
              <span class="widget-toc-episode-titleLabel js-vertical-composition-item">{{ dex['text'] }}</span>
			  <time class="widget-toc-episode-datePublished" datetime="{{dex['time'].strftime('%Y-%m-%dT%H:%M:%S+09:00')}}">{{dex['time'].strftime('%Y年%m月%d日')}}</time>
            </a>
          </li>
{%- endif %}
{%- endfor %}
          <li class="widget-toc-episode">
              <span class="widget-toc-episode-titleLabel js-vertical-composition-item">&nbsp;</span>
          </li>
    </ol>
  </div>
</section>

</div>
</main>
</div>
</div>
</div>
</div>


<div id="sp">
  <header id="globalHeaderTouch">
    <div id="globalHeaderTouch-siteTitle">
      <div id="globalHeaderTouch-siteTitle-inner">
        <p id="globalHeaderTouch-siteTitle-logo"><a href="https://kakuyomu.jp/">
          <img src="static/kakuyomu-logo.png" alt="カクヨム" />
        </a></p>
      </div>
    </div>

    <nav id="globalHeaderTouch-globalNav">
      <ul>
        <li><a href="https://kakuyomu.jp/">
		  <svg class="globalHeaderTouch-globalNav-positiveImage" xmlns="http://www.w3.org/2000/svg" width="1000" height="1000" viewBox="0 0 1000 1000"><path xmlns="http://www.w3.org/2000/svg" d="M494.45,105,913,512.72V907H649V695.21a148.5,148.5,0,1,0-297,0V907H87V512.49L494.45,105m-.28-42.15L57,500.06V937H382V695.21a118.5,118.5,0,1,1,237,0V937H943V500.06L494.17,62.89Z"/></svg>
		  <svg class="globalHeaderTouch-globalNav-negativeImage" xmlns="http://www.w3.org/2000/svg" width="1000" height="1000" viewBox="0 0 1000 1000"><path xmlns="http://www.w3.org/2000/svg" d="M620,695.21a118.5,118.5,0,1,0-237,0V937H58V500.06L495.17,62.89,944,500.06V937H620Z" fill="#0990cc"/></svg>
          <span>ホーム</span>
        </a></li>
        <li><a href="https://kakuyomu.jp/rankings/all/weekly">
		  <svg class="globalHeaderTouch-globalNav-positiveImage" xmlns="http://www.w3.org/2000/svg" width="1000" height="1000" viewBox="0 0 1000 1000"><title>ranking</title><path d="M297.48,473H388v.73l-73.08,52.8,28.5,87.06-.82.26-73.95-53.57-73.93,53.57-.78-.26,28.77-87.06L150,473.73V473h89.79l28.33-87h1Z"/><line x1="507" y1="513" x2="850" y2="513" fill="none" stroke="#000" stroke-miterlimit="10" stroke-width="30"/><path d="M297.48,219H388v1.05l-73.08,52.8,28.5,87.06-.82.26L268.66,306.6l-73.93,53.57-.78-.26,28.77-87.06L150,220.05V219h89.79l28.33-87h1Z"/><line x1="507" y1="260" x2="850" y2="260" fill="none" stroke="#000" stroke-miterlimit="10" stroke-width="30"/><path d="M297.48,726H388v1.4l-73.08,52.8,28.5,87.06-.82.26-73.95-53.57-73.93,53.57-.78-.26,28.77-87.06L150,727.4V726h89.79l28.33-86h1Z"/><line x1="507" y1="767" x2="850" y2="767" fill="none" stroke="#000" stroke-miterlimit="10" stroke-width="30"/><path d="M953,47V953H47V47H953m30-30H17V983H983V17Z"/></svg>
		  <svg class="globalHeaderTouch-globalNav-negativeImage" xmlns="http://www.w3.org/2000/svg" width="1000" height="1000" viewBox="0 0 1000 1000"><title>ranking-negative</title><rect x="17.44" y="17.44" width="965.11" height="965.11" fill="#0990cc"/><path d="M303.25,467.24H411.43v1.24L324,531.84l34.31,104.47-.93.31-88.71-64.29-88.71,64.29-.93-.31,34.31-104.47-87.47-63.36v-1.24H234l34-103.85h1.24Z" fill="#fff"/><line x1="507" y1="513" x2="850" y2="513" fill="none" stroke="#fff" stroke-miterlimit="10" stroke-width="90"/><path d="M303.25,213.56H411.43v1.24L324,278.16l34.31,104.47-.93.31-88.71-64.29-88.71,64.29-.93-.31,34.31-104.47L125.84,214.8v-1.24H234l34-103.85h1.24Z" fill="#fff"/><line x1="507" y1="260" x2="850" y2="260" fill="none" stroke="#fff" stroke-miterlimit="10" stroke-width="90"/><path d="M303.25,720.91H411.43v1.24L324,785.51,358.27,890l-.93.31L268.64,826l-88.71,64.29L179,890l34.31-104.47-87.47-63.36v-1.24H234l34-103.85h1.24Z" fill="#fff"/><line x1="507" y1="767" x2="850" y2="767" fill="none" stroke="#fff" stroke-miterlimit="10" stroke-width="90"/></svg>
          <span>ランキング</span>
        </a></li>
        <li><a href="https://kakuyomu.jp/official">
		  <svg class="globalHeaderTouch-globalNav-positiveImage" xmlns="http://www.w3.org/2000/svg" width="1000" height="1000" viewBox="0 0 1000 1000"><title>official_1</title><path d="M918.6,50.4a31,31,0,0,1,31,31V918.6a31,31,0,0,1-31,31H81.4a31,31,0,0,1-31-31V81.4a31,31,0,0,1,31-31H918.6m0-32.9H81.4A64.09,64.09,0,0,0,17.5,81.4V918.6a64.09,64.09,0,0,0,63.9,63.9H918.6a64.09,64.09,0,0,0,63.9-63.9V81.4a64.09,64.09,0,0,0-63.9-63.9Z"/><polygon points="287.79 629.09 254.9 629.09 254.9 254.32 424.23 254.32 424.23 287.21 287.79 287.21 287.79 629.09"/><polygon points="744.42 745.86 589.27 745.86 589.27 712.96 711.52 712.96 711.52 371.11 744.42 371.11 744.42 745.86"/></svg>
		  <svg class="globalHeaderTouch-globalNav-negativeImage" xmlns="http://www.w3.org/2000/svg" width="1000" height="1000" viewBox="0 0 1000 1000"><title>official-negative</title><path d="M918.59,17.5H81.41A64.09,64.09,0,0,0,17.5,81.41V918.59A64.09,64.09,0,0,0,81.41,982.5H918.59a64.09,64.09,0,0,0,63.91-63.91V81.41A64.09,64.09,0,0,0,918.59,17.5ZM424.23,308.67h-115V629.09H233.44V232.86H424.23ZM765.88,767.32H589.27V691.5H690.06V371.11h75.82Z" fill="#0990cc"/></svg>
          <span>公式連載</span>
        </a></li>
        <li><a href="https://kakuyomu.jp/my/antenna">
		  <svg class="globalHeaderTouch-globalNav-positiveImage" xmlns="http://www.w3.org/2000/svg" width="1000" height="1000" viewBox="0 0 1000 1000"><title>mypage</title><rect x="122" y="54" width="30" height="892"/><rect x="404" y="54" width="30" height="892"/><rect x="758.6" y="74.51" width="30" height="889" transform="translate(-123.18 266.81) rotate(-18.15)"/></svg>
		  <svg class="globalHeaderTouch-globalNav-negativeImage" xmlns="http://www.w3.org/2000/svg" width="1000" height="1000" viewBox="0 0 1000 1000"><title>mypage-negative</title><rect x="77" y="54" width="120" height="892" fill="#0990cc"/><rect x="359" y="54" width="120" height="892" fill="#0990cc"/><rect x="713.6" y="54.48" width="120" height="889" transform="translate(-116.94 265.81) rotate(-18.15)" fill="#0990cc"/></svg>
          <span>マイページ</span>
        </a></li>
      </ul>
    </nav>
  </header>
<div id="container">
  <div id="container-inner">
    

<div id="work" class="" itemscope itemtype="https://schema.org/CreativeWork">

  <header id="workHeader">
    <div id="workHeader-inner">
      <div id="workHeader-content">
        <h1 id="workTitle">{{title}}</h1>
      </div>
    </div>
  </header>

  <main id="workMain">

    <section id="description" class="internalLinks-target hasBothCatchphraseAndIntroduction">
          <p id="introduction" class="ui-truncateTextButton js-work-introduction">{{desc|safe}}</p>
    </section>

    <div id="table-of-contents">

<section class="widget-toc">
  <header>
    <h3>目次</h3>

    <div class="widget-toc-workInfo js-chrome-visibility-fix">
      <p class="widget-toc-workStatus">
        <span>連載</span>
        <span class="js-vertical-composition-item">全{{total}}話</span>
      </p>
      <p class="widget-toc-date"><time datetime="{{index[-1]['time'].strftime('%Y-%m-%dT%H:%M:%S+09:00')}}"><span>{{index[-1]['time'].strftime('%Y年%m月%d日 %H:%M')}}</span></time> 更新</p>
    </div>
  </header>
  <div class="widget-toc-main">
    <ol class="widget-toc-items test-toc-items">
{%- for dex in index %}
{%- if dex['type']=="chapter" %}
          <li class="widget-toc-chapter widget-toc-level1 js-vertical-composition-item">
            <span>{{ dex['text'] }}</span>
          </li>
{%- elif dex['type']=="episode" %}
          <li class="widget-toc-episode">
            <a href="{{ dex['part']}}.html" class="widget-toc-episode-episodeTitle">
              <span class="widget-toc-episode-titleLabel js-vertical-composition-item">{{ dex['text'] }}</span>
			  <time class="widget-toc-episode-datePublished" datetime="{{dex['time'].strftime('%Y-%m-%dT%H:%M:%S+09:00')}}">{{dex['time'].strftime('%Y年%m月%d日 %H:%M')}}</time>
            </a>
          </li>
{%- endif %}
{%- endfor %}
          <li class="widget-toc-episode">
              <span class="widget-toc-episode-titleLabel js-vertical-composition-item">&nbsp;</span>
          </li>
    </ol>
  </div>
</section>

    </div>
  </main>
</div>
</div>
</div>
</div>

<script src="static/custom.js"></script>

</body>
</html>
