<div id="main_window">
<div id="novel_contents">
<div id="novel_color">

<div class="contents1">
<a href="index.html">{{title}}</a>
<div class="novel_writername">
作者：{%- if author[1] %}<a href="{{ author[1] }}">{{ author[0] }}</a>{% else %}{{ author[0] }}{%- endif %}
</div><!--novel_writername-->
</div><!--contents1-->
</div><!--#novel_color-->

<div class="novel_bn">
<div class="link_prev">
{%- if part!=1 %}
<a rel="prev" href="{{part-1}}.html">&lt;&lt;&nbsp;前へ&nbsp;</a>
{%- endif %}
</div>
<div class="link_back">
<a href="index.html">目次</a>
</div>
<div class="link_next">
{%- if part!=total %}
<a rel="next" href="{{part+1}}.html">&nbsp;次へ&nbsp;&gt;&gt;</a>
{%- endif %}
</div>
</div><!-- novel_bn -->

<div id="novel_no">{{part}}/{{total}}</div>

<div class="novel_subtitle">
{%- if epis[1]['chap'] %}
<div class="chapter_title">{{epis[part]['chap']}}</div>
{%- endif %}
{{subtitle}}
</div>

<div id="novel_honbun" class="novel_view">
{%- for i in range(0,lines) %}
<p id="L{{ i+1 }}">{{ contents[i] }}</p>
{%- endfor %}
</div>

<div class="novel_bn footer">
<div class="link_prev">
{%- if part!=1 %}
<a rel="prev" href="{{part-1}}.html">&lt;&lt;&nbsp;前へ&nbsp;</a>
{%- endif %}
</div>
<div class="link_back">
<a href="index.html">目次</a>
</div>
<div class="link_next">
{%- if part!=total %}
<a rel="next" href="{{part+1}}.html">&nbsp;次へ&nbsp;&gt;&gt;</a>
{%- endif %}
</div>
</div><!-- novel_bn -->

</div><!--novel_contents-->

<!-- フッタここから -->
<div class="upper"><a href="#top">▲ページの上部へ</a></div>
<div id="footer">
<div id="footernavi">
<p>
<a href="https://syosetu.com">小説家になろう</a>
|
<a href="https://kakuyomy.jp">カクヨム</a>
|
<a href="{{url}}">公式で読む</a>
<form action="https://yomou.syosetu.com/search.php">
<input name="word" size="21" type="text" />
<input value="検索" type="submit" />
</form>
</div><!--footernavi-->
</div><!--footer-->
<!-- フッタここまで -->
</div>
