<!DOCTYPE html>
<html lang="ja">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<meta http-equiv="X-UA-Compatible" content="IE=edge" />
<title>{{subtitle}} - {{title}}</title>

<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="format-detection" content="telephone=no" />

<link rel="shortcut icon" href="static/narou.ico" />
<link rel="icon" href="static/narou.ico" />
<link rel="apple-touch-icon-precomposed" href="static/apple-touch-icon-precomposed.png" />

<link rel="stylesheet" type="text/css" href="static/custom.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="static/reset.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="static/kotei.css" media="screen,print" />
</head>
<body>
<div id="page_type" style="display: none">base</div>
{% include "base_body_pc.html" %}
<script src="static/custom.js"></script>
</body>
</html>
