@charset 'utf-8';

/*! normalize.css v2.1.2 | MIT License | git.io/normalize */

aside,details,footer,header,main,nav,section,summary {
  display: block;
}

canvas {
  display: inline-block;
}

[hidden] {
  display: none;
}

html {
  font-family: sans-serif;
  -ms-text-size-adjust: 100%;
  -webkit-text-size-adjust: 100%;
}

body {
  margin: 0;
}

a:focus {
  outline: thin dotted;
}

a:active,a:hover {
  outline: 0;
}

h1 {
  font-size: 2em;
  margin: .67em 0;
}

abbr[title] {
  border-bottom: 1px dotted;
}

b {
  font-weight: 700;
}

hr {
  box-sizing: content-box;
  height: 0;
}

mark {
  background: #ff0;
  color: #000;
}

code,pre {
  font-family: monospace,serif;
  font-size: 1em;
}

pre {
  white-space: pre-wrap;
}

q {
  quotes: "\201C" "\201D" "\2018" "\2019";
}

small {
  font-size: 80%;
}

img {
  border: 0;
}

svg:not(:root) {
  overflow: hidden;
}

legend {
  border: 0;
  padding: 0;
}

button,input,select,textarea {
  font-family: inherit;
  font-size: 100%;
  margin: 0;
}

button,input {
  line-height: normal;
}

button,select {
  text-transform: none;
}

button,html input[type=button],input[type=reset],input[type=submit] {
  -webkit-appearance: button;
  cursor: pointer;
}

button[disabled],html input[disabled] {
  cursor: default;
}

input[type=checkbox],input[type=radio] {
  box-sizing: border-box;
  padding: 0;
}

input[type=search] {
  -webkit-appearance: textfield;
  box-sizing: content-box;
}

input[type=search]::-webkit-search-cancel-button,input[type=search]::-webkit-search-decoration {
  -webkit-appearance: none;
}

button::-moz-focus-inner,input::-moz-focus-inner {
  border: 0;
  padding: 0;
}

textarea {
  overflow: auto;
  vertical-align: top;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

@font-face {
  font-family: dcsymbols;
  src: url(dcsymbols-regular.woff) format('woff'),url(dcsymbols-regular.otf) format('opentype');
  unicode-range: U+2014,U+2015,U+2026;
}

@font-face {
  font-family: dcicons;
  src: url(dcicons-regular.eot);
  src: url(dcicons-regular.eot) format('embedded-opentype'),url(dcicons-regular.otf) format('opentype');
}

i[class^=icon-]:before {
  font-family: dcicons;
  vertical-align: baseline;
  line-height: 1;
  font-style: normal;
  display: inline-block;
}

i[class^=icon-].white {
  color: #fff;
}

.icon-settings:before {
  content: '\f700';
}

.icon-triangle-large-right:before {
  content: '\f702';
}

.icon-triangle-large-bottom:before {
  content: '\f703';
}

.icon-triangle-large-left:before {
  content: '\f704';
}

.icon-triangle-top:before {
  content: '\f705';
}

.icon-triangle-right:before {
  content: '\f706';
}

.icon-triangle-bottom:before {
  content: '\f707';
}

.icon-triangle-left:before {
  content: '\f708';
}

.icon-prev-large:before {
  content: '\f709';
}

.icon-next-large:before {
  content: '\f70a';
}

.icon-prev:before {
  content: '\f70b';
}

.icon-next:before {
  content: '\f70c';
}

.icon-bottom:before {
  content: '\f70d';
}

.icon-up:before {
  content: '\f70e';
}

.icon-expand:before,.icon-sort-enable:before {
  content: '\f70f';
}

.icon-sort-down:before {
  content: '\f710';
}

.icon-sort-up:before {
  content: '\f711';
}

.icon-prev-bold:before {
  content: '\f712';
}

.icon-tag:before {
  content: '\f715';
}

.icon-share:before {
  content: '\f716';
}

.icon-share:before {
  content: '\f719';
}

.icon-search:before {
  content: '\f71a';
}

.icon-date:before {
  content: '\f71b';
}

.icon-check:before {
  content: '\f71c';
}

.icon-star:before {
  content: '\f71d';
}

.icon-close:before,.icon-delete:before {
  content: '\f71e';
}

.icon-menu:before {
  content: '\f71f';
}

.icon-write:before {
  content: '\f720';
}

.icon-key:before {
  content: '\f723';
}

.icon-plus:before {
  content: '\f724';
}

.icon-check-circle:before {
  content: '\f725';
}

.icon-episode:before {
  content: '\f726';
}

.icon-work:before {
  content: '\f727';
}

.icon-invalid:before {
  content: '\f72b';
}

.icon-sidebar:before {
  content: '\f72e';
}

.icon-characterCount:before {
  content: '\f730';
}

.icon-contest:before {
  content: '\f731';
}

.icon-heart:before {
  content: '\f734';
}

.icon-toc:before {
  content: '\f736';
}

.icon-style:before {
  content: '\f737';
}

.icon-review:before {
  content: '\f738';
}

.icon-official:before {
  content: '\f73c';
}

.icon-check-circle2:before {
  content: '\f73d';
}

.icon-heart-negative:before {
  content: '\f741';
}

.icon-info:before {
  content: '\f742';
}

.icon-comment:before {
  content: '\f744';
}

.icon-reply:before {
  content: '\f745';
}

.icon-sort:before {
  content: '\f746';
}

.icon-published:before {
  content: '\f747';
}

.icon-userEvent:before {
  content: '\f749';
}

body {
  background: #fff;
  color: #222;
  line-height: 1.8;
  cursor: default;
  word-wrap: break-word;
  overflow-wrap: break-word;
  box-sizing: border-box;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  -webkit-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
}

body>img[height="1"][width="1"][border="0"] {
  position: fixed;
  left: 0;
  bottom: -1px;
}

.float-parent:after,.float-parent:before {
  content: '';
  display: table;
}

.float-parent:after {
  clear: both;
}

a {
  text-decoration: none;
  color: #0081c2;
}

a:active,a:focus,a:hover {
  color: #0081c2;
  text-decoration: underline;
}

input,textarea {
  outline: 0;
  padding: 7px 10px;
  border: none;
  width: 100%;
  box-sizing: border-box;
  font-size: 1rem;
  border: 2px solid #ccc;
  background: #fff;
  border-radius: 3px;
  color: #222;
  cursor: text;
  -webkit-appearance: none;
}

input::-webkit-input-placeholder,textarea::-webkit-input-placeholder {
  color: #aaa;
}

input:-moz-placeholder,textarea:-moz-placeholder {
  color: #aaa;
  line-height: 1.3em;
}

input::-moz-placeholder,textarea::-moz-placeholder {
  color: #aaa;
  line-height: 1.3em;
}

input:-ms-input-placeholder,textarea:-ms-input-placeholder {
  color: #aaa;
}

input:required,textarea:required {
  box-shadow: none;
}

input:-webkit-autofill,textarea:-webkit-autofill {
  -webkit-box-shadow: inset 0 0 0 1000px #fff;
}

input.isInvalid,textarea.isInvalid {
  border-color: #f23e48;
}

input:hover,textarea:hover {
  border-color: #888;
}

input:focus,textarea:focus {
  border-color: #4baae0;
}

input:focus.isInvalid,textarea:focus.isInvalid {
  border-color: #f23e48!important;
}

input[disabled],textarea[disabled] {
  font-weight: 400;
  cursor: default;
  background: #eee;
  color: #888;
}

input[disabled]:focus,input[disabled]:hover,textarea[disabled]:focus,textarea[disabled]:hover {
  border-color: #ccc;
}

input[type=hidden] {
  width: 1px;
  height: 1px;
}

.a11y-hidden {
  position: absolute;
  width: 1px;
  height: 1px;
  overflow: hidden;
  white-space: nowrap;
  clip: rect(1px,1px,1px,1px);
}

html {
  height: 100%;
}

html.writingDirection-vertical {
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
}

html:not(.writingDirection-vertical) {
  -webkit-writing-mode: horizontal-tb;
  -ms-writing-mode: lr-tb;
  writing-mode: horizontal-tb;
}

body {
  font-size: 14px;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
}

body.isTouch {
  font-size: 13px;
}

.float-right {
  float: right;
}

.float-left {
  float: left;
}

.heading-level2 i,.heading-level3 i,.heading-level4 i,.heading-level5 i,.heading-level6 i {
  font-weight: 400;
}

.heading-level2 {
  font-size: 2em;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,serif;
  letter-spacing: 1px;
  -webkit-transform: scale(1,1.075);
  transform: scale(1,1.075);
}

.heading-level3 {
  font-size: 1.75em;
}

.heading-level4 {
  font-size: 1.2em;
}

.heading-level5 {
  font-size: 1em;
}

.heading-level4-normal {
  font-size: 1.2em;
  font-weight: 400;
}

.heading-level4-normal i {
  font-weight: 400;
}

.heading-level5-normal {
  font-size: 1em;
  font-weight: 400;
}

.heading-level5-normal i {
  font-weight: 400;
}

input[type=button],input[type=checkbox],input[type=radio],input[type=submit] {
  width: auto;
}

.ui-button-default {
  -webkit-transition-property: background,color;
  transition-property: background,color;
  -webkit-transition-duration: .1s;
  transition-duration: .1s;
  -webkit-transition-timing-function: linear;
  transition-timing-function: linear;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 700;
  display: inline-block;
  line-height: 1;
  padding: 8px 10px;
  border-radius: 3px;
  cursor: pointer;
  letter-spacing: .5px;
  white-space: nowrap;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  text-decoration: none!important;
  border: 1px solid #222;
  font-size: 12px;
  background: #ddd;
  border-color: #bbb;
  color: #222;
}

.ui-button-default:focus {
  outline: 0;
}

.ui-button-default img {
  max-height: 12px;
  vertical-align: top;
}

.ui-button-default i[class^=icon] {
  line-height: .5em;
}

.ui-button-default:visited {
  color: #222;
}

.ui-button-default:hover {
  background: #ccc!important;
  border-color: #aaa;
  color: #222;
}

.ui-button-default:focus {
  border-color: #fff;
  color: #222;
  box-shadow: 0 0 5px #666;
}

.ui-button-default[disabled] {
  background: #eee;
  border-color: #ddd;
  color: #aaa;
  text-shadow: none;
  cursor: default;
}

.ui-button-default[disabled]:focus,.ui-button-default[disabled]:hover {
  background: #eee!important;
  border-color: #ddd;
  color: #aaa;
}

.ui-button-white {
  -webkit-transition-property: background,color;
  transition-property: background,color;
  -webkit-transition-duration: .1s;
  transition-duration: .1s;
  -webkit-transition-timing-function: linear;
  transition-timing-function: linear;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 700;
  display: inline-block;
  line-height: 1;
  padding: 8px 10px;
  border-radius: 3px;
  cursor: pointer;
  letter-spacing: .5px;
  white-space: nowrap;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  text-decoration: none!important;
  border: 1px solid #222;
  font-size: 12px;
  background: #fff;
  border-color: #ccc;
  color: #222;
  font-weight: 400;
}

.ui-button-white:focus {
  outline: 0;
}

.ui-button-white img {
  max-height: 12px;
  vertical-align: top;
}

.ui-button-white i[class^=icon] {
  line-height: .5em;
}

.ui-button-white:visited {
  color: #222;
}

.ui-button-white:hover {
  background: #eee!important;
  border-color: #bbb;
  color: #222;
}

.ui-button-white:focus {
  border-color: #bbb;
  color: #222;
  box-shadow: 0 0 5px #ccc;
}

.ui-button-white[disabled] {
  background: #eee;
  border-color: #ddd;
  color: #aaa;
  text-shadow: none;
  cursor: default;
}

.ui-button-white[disabled]:focus,.ui-button-white[disabled]:hover {
  background: #eee!important;
  border-color: #ddd;
  color: #aaa;
}

.ui-button-black {
  -webkit-transition-property: background,color;
  transition-property: background,color;
  -webkit-transition-duration: .1s;
  transition-duration: .1s;
  -webkit-transition-timing-function: linear;
  transition-timing-function: linear;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 700;
  display: inline-block;
  line-height: 1;
  padding: 8px 10px;
  border-radius: 3px;
  cursor: pointer;
  letter-spacing: .5px;
  white-space: nowrap;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  text-decoration: none!important;
  border: 1px solid #222;
  font-size: 12px;
  background: #555;
  border-color: #333;
  color: #fff;
}

.ui-button-black:focus {
  outline: 0;
}

.ui-button-black img {
  max-height: 12px;
  vertical-align: top;
}

.ui-button-black i[class^=icon] {
  line-height: .5em;
}

.ui-button-black:visited {
  color: #fff;
}

.ui-button-black:hover {
  background: #333!important;
  border-color: #222;
  color: #fff;
}

.ui-button-black:focus {
  border-color: #fff;
  color: #fff;
  box-shadow: 0 0 5px #666;
}

.ui-button-black[disabled] {
  background: #eee;
  border-color: #ddd;
  color: #aaa;
  text-shadow: none;
  cursor: default;
}

.ui-button-black[disabled]:focus,.ui-button-black[disabled]:hover {
  background: #eee!important;
  border-color: #ddd;
  color: #aaa;
}

.ui-button-blue {
  -webkit-transition-property: background,color;
  transition-property: background,color;
  -webkit-transition-duration: .1s;
  transition-duration: .1s;
  -webkit-transition-timing-function: linear;
  transition-timing-function: linear;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 700;
  display: inline-block;
  line-height: 1;
  padding: 8px 10px;
  border-radius: 3px;
  cursor: pointer;
  letter-spacing: .5px;
  white-space: nowrap;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  text-decoration: none!important;
  border: 1px solid #222;
  font-size: 12px;
  text-shadow: 0 1px 0 rgba(0,0,0,.2);
  background: #4baae0;
  border-color: #0990cc;
  color: #fff;
}

.ui-button-blue:focus {
  outline: 0;
}

.ui-button-blue img {
  max-height: 12px;
  vertical-align: top;
}

.ui-button-blue i[class^=icon] {
  line-height: .5em;
}

.ui-button-blue:visited {
  color: #fff;
}

.ui-button-blue:hover {
  background: #0990cc!important;
  border-color: #0081c2;
  color: #fff;
}

.ui-button-blue:focus {
  border-color: #fff;
  color: #fff;
  box-shadow: 0 0 5px #0081c2;
}

.ui-button-blue[disabled] {
  background: #eee;
  border-color: #ddd;
  color: #aaa;
  text-shadow: none;
  cursor: default;
}

.ui-button-blue[disabled]:focus,.ui-button-blue[disabled]:hover {
  background: #eee!important;
  border-color: #ddd;
  color: #aaa;
}

.ui-button-yellow {
  -webkit-transition-property: background,color;
  transition-property: background,color;
  -webkit-transition-duration: .1s;
  transition-duration: .1s;
  -webkit-transition-timing-function: linear;
  transition-timing-function: linear;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 700;
  display: inline-block;
  line-height: 1;
  padding: 8px 10px;
  border-radius: 3px;
  cursor: pointer;
  letter-spacing: .5px;
  white-space: nowrap;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  text-decoration: none!important;
  border: 1px solid #222;
  font-size: 12px;
  text-shadow: 0 1px 0 rgba(0,0,0,.2);
  background: #ffb318;
  border-color: #ed9e00;
  color: #fff;
}

.ui-button-yellow:focus {
  outline: 0;
}

.ui-button-yellow img {
  max-height: 12px;
  vertical-align: top;
}

.ui-button-yellow i[class^=icon] {
  line-height: .5em;
}

.ui-button-yellow:visited {
  color: #fff;
}

.ui-button-yellow:hover {
  background: #ed9e00!important;
  border-color: #db9300;
  color: #fff;
}

.ui-button-yellow:focus {
  border-color: #fff;
  color: #fff;
  box-shadow: 0 0 5px #db9300;
}

.ui-button-yellow[disabled] {
  background: #eee;
  border-color: #ddd;
  color: #aaa;
  text-shadow: none;
  cursor: default;
}

.ui-button-yellow[disabled]:focus,.ui-button-yellow[disabled]:hover {
  background: #eee!important;
  border-color: #ddd;
  color: #aaa;
}

.ui-button-red {
  -webkit-transition-property: background,color;
  transition-property: background,color;
  -webkit-transition-duration: .1s;
  transition-duration: .1s;
  -webkit-transition-timing-function: linear;
  transition-timing-function: linear;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 700;
  display: inline-block;
  line-height: 1;
  padding: 8px 10px;
  border-radius: 3px;
  cursor: pointer;
  letter-spacing: .5px;
  white-space: nowrap;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  text-decoration: none!important;
  border: 1px solid #222;
  font-size: 12px;
  text-shadow: 0 1px 0 rgba(0,0,0,.2);
  background: #f23e48;
  border-color: #db2c3d;
  color: #fff;
}

.ui-button-red:focus {
  outline: 0;
}

.ui-button-red img {
  max-height: 12px;
  vertical-align: top;
}

.ui-button-red i[class^=icon] {
  line-height: .5em;
}

.ui-button-red:visited {
  color: #fff;
}

.ui-button-red:hover {
  background: #db2c3d!important;
  border-color: #c11b33;
  color: #fff;
}

.ui-button-red:focus {
  border-color: #fff;
  color: #fff;
  box-shadow: 0 0 5px #c11b33;
}

.ui-button-red[disabled] {
  background: #eee;
  border-color: #ddd;
  color: #aaa;
  text-shadow: none;
  cursor: default;
}

.ui-button-red[disabled]:focus,.ui-button-red[disabled]:hover {
  background: #eee!important;
  border-color: #ddd;
  color: #aaa;
}

.ui-button-silent {
  -webkit-transition-property: background,color;
  transition-property: background,color;
  -webkit-transition-duration: .1s;
  transition-duration: .1s;
  -webkit-transition-timing-function: linear;
  transition-timing-function: linear;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 700;
  display: inline-block;
  line-height: 1;
  padding: 8px 10px;
  border-radius: 3px;
  cursor: pointer;
  letter-spacing: .5px;
  white-space: nowrap;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  text-decoration: none!important;
  border: 1px solid #222;
  font-size: 12px;
  background: 0 0;
  border-color: transparent;
  color: #222;
  -webkit-transition: none;
  transition: none;
  border-radius: 0;
  font-weight: 400;
}

.ui-button-silent:focus {
  outline: 0;
}

.ui-button-silent img {
  max-height: 12px;
  vertical-align: top;
}

.ui-button-silent i[class^=icon] {
  line-height: .5em;
}

.ui-button-silent:visited {
  color: #222;
}

.ui-button-silent:focus,.ui-button-silent:hover {
  color: #0081c2;
}

.ui-button-silent[disabled] {
  color: #ccc;
}

.ui-button-silent[disabled]:focus,.ui-button-silent[disabled]:hover {
  color: #ccc;
}

.ui-button-disabled {
  -webkit-transition-property: background,color;
  transition-property: background,color;
  -webkit-transition-duration: .1s;
  transition-duration: .1s;
  -webkit-transition-timing-function: linear;
  transition-timing-function: linear;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 700;
  display: inline-block;
  line-height: 1;
  padding: 8px 10px;
  border-radius: 3px;
  cursor: pointer;
  letter-spacing: .5px;
  white-space: nowrap;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  text-decoration: none!important;
  border: 1px solid #222;
  font-size: 12px;
  text-shadow: 0 1px 0 rgba(0,0,0,.2);
  background: #eee;
  border-color: #ddd;
  color: #aaa;
  text-shadow: none;
  cursor: default;
}

.ui-button-disabled:focus {
  outline: 0;
}

.ui-button-disabled img {
  max-height: 12px;
  vertical-align: top;
}

.ui-button-disabled i[class^=icon] {
  line-height: .5em;
}

.ui-button-disabled:focus,.ui-button-disabled:hover {
  background: #eee!important;
  border-color: #ddd;
  color: #aaa;
}

.ui-button-blue-wrapper {
  background: 0 0;
  border: none;
}

.ui-button-blue-wrapper:hover .ui-button-blue {
  background: #0990cc!important;
  border-color: #0081c2!important;
  color: #fff!important;
}

.ui-button-blue-wrapper:focus {
  outline: 0;
}

.ui-button-blue-wrapper:focus .ui-button-blue {
  background: #0990cc!important;
  border-color: #fff!important;
  color: #fff!important;
  box-shadow: 0 0 5px #0081c2;
}

.ui-button-blue-wrapper[disabled] .ui-button-blue {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
  text-shadow: none!important;
  cursor: default!important;
}

.ui-button-blue-wrapper[disabled] .ui-button-blue:focus,.ui-button-blue-wrapper[disabled] .ui-button-blue:hover {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
}

.ui-button-yellow-wrapper {
  background: 0 0;
  border: none;
}

.ui-button-yellow-wrapper:hover .ui-button-yellow {
  background: #ed9e00!important;
  border-color: #db9300!important;
  color: #fff!important;
}

.ui-button-yellow-wrapper:focus {
  outline: 0;
}

.ui-button-yellow-wrapper:focus .ui-button-yellow {
  background: #ed9e00!important;
  border-color: #fff!important;
  color: #fff!important;
  box-shadow: 0 0 5px #db9300;
}

.ui-button-yellow-wrapper[disabled] .ui-button-yellow {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
  text-shadow: none!important;
  cursor: default!important;
}

.ui-button-yellow-wrapper[disabled] .ui-button-yellow:focus,.ui-button-yellow-wrapper[disabled] .ui-button-yellow:hover {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
}

.ui-button-silent-wrapper {
  background: 0 0;
  border: none;
}

.ui-button-silent-wrapper:hover .ui-button-silent {
  background: inherit!important;
  border-color: none!important;
  color: #0081c2!important;
}

.ui-button-silent-wrapper:focus {
  outline: 0;
}

.ui-button-silent-wrapper:focus .ui-button-silent {
  background: inherit!important;
  border-color: #fff!important;
  color: #0081c2!important;
  box-shadow: 0 0 5px none;
}

.ui-button-silent-wrapper[disabled] .ui-button-silent {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
  text-shadow: none!important;
  cursor: default!important;
}

.ui-button-silent-wrapper[disabled] .ui-button-silent:focus,.ui-button-silent-wrapper[disabled] .ui-button-silent:hover {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
}

.ui-button-default-wrapper {
  background: 0 0;
  border: none;
}

.ui-button-default-wrapper:hover .ui-button-default {
  background: #ccc!important;
  border-color: #aaa!important;
  color: inherit!important;
}

.ui-button-default-wrapper:focus {
  outline: 0;
}

.ui-button-default-wrapper:focus .ui-button-default {
  background: #ccc!important;
  border-color: #fff!important;
  color: inherit!important;
  box-shadow: 0 0 5px #aaa;
}

.ui-button-default-wrapper[disabled] .ui-button-default {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
  text-shadow: none!important;
  cursor: default!important;
}

.ui-button-default-wrapper[disabled] .ui-button-default:focus,.ui-button-default-wrapper[disabled] .ui-button-default:hover {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
}

.ui-button-white-wrapper {
  background: 0 0;
  border: none;
}

.ui-button-white-wrapper:hover .ui-button-white {
  background: #eee!important;
  border-color: #bbb!important;
  color: #222!important;
}

.ui-button-white-wrapper:focus {
  outline: 0;
}

.ui-button-white-wrapper:focus .ui-button-white {
  background: #eee!important;
  border-color: #fff!important;
  color: #222!important;
  box-shadow: 0 0 5px #bbb;
}

.ui-button-white-wrapper[disabled] .ui-button-white {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
  text-shadow: none!important;
  cursor: default!important;
}

.ui-button-white-wrapper[disabled] .ui-button-white:focus,.ui-button-white-wrapper[disabled] .ui-button-white:hover {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
}

.ui-button-orange {
  -webkit-transition-property: background,color;
  transition-property: background,color;
  -webkit-transition-duration: .1s;
  transition-duration: .1s;
  -webkit-transition-timing-function: linear;
  transition-timing-function: linear;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 700;
  display: inline-block;
  line-height: 1;
  padding: 8px 10px;
  border-radius: 3px;
  cursor: pointer;
  letter-spacing: .5px;
  white-space: nowrap;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  text-decoration: none!important;
  border: 1px solid #222;
  font-size: 12px;
  text-shadow: 0 1px 0 rgba(0,0,0,.2);
  background: #ff9d00;
  border-color: #ff7e00;
  color: #fff;
}

.ui-button-orange:focus {
  outline: 0;
}

.ui-button-orange img {
  max-height: 12px;
  vertical-align: top;
}

.ui-button-orange i[class^=icon] {
  line-height: .5em;
}

.ui-button-orange:visited {
  color: #fff;
}

.ui-button-orange:hover {
  background: #ff7e00;
  border-color: #ff6a00;
  color: #fff;
}

.ui-button-orange:focus {
  border-color: #fff;
  color: #fff;
  box-shadow: 0 0 5px #ff9d00;
}

.ui-button-orange[disabled] {
  background: #eee;
  border-color: #ddd;
  color: #aaa;
  text-shadow: none;
  cursor: default;
}

.ui-button-orange[disabled]:focus,.ui-button-orange[disabled]:hover {
  background: #eee!important;
  border-color: #ddd;
  color: #aaa;
}

.ui-message-notice {
  margin: 1em 0;
  padding: 1em 1.5em;
  line-height: 1.5;
  font-weight: 700;
  background: #e1f1f7;
}

.ui-message-notice.isHidden {
  display: none;
}

.ui-message-notice.isShown {
  display: block;
}

.ui-checkbox {
  width: 24px;
  height: 24px;
  position: relative;
  display: inline-block;
  overflow: hidden;
  vertical-align: middle;
}

.ui-checkbox.ui-checkbox-small {
  width: 20px;
  height: 20px;
}

.ui-checkbox.ui-checkbox-small+.ui-checkbox-label {
  font-size: 1em;
  -webkit-transform: translateY(.1em);
  transform: translateY(.1em);
}

.ui-checkbox.ui-checkbox-small .ui-checkbox-alternate {
  width: 20px;
  height: 20px;
  line-height: 20px;
}

.ui-checkbox.ui-checkbox-small .ui-checkbox-alternate:before {
  width: 16px!important;
  height: 16px!important;
  background-size: contain!important;
}

.ui-checkbox.isDisabled .ui-checkbox-alternate,.ui-checkbox.ui-checkbox-disabled .ui-checkbox-alternate {
  border-color: #ddd!important;
  background: #eee;
}

.ui-checkbox.isDisabled+.ui-checkbox-label,.ui-checkbox.ui-checkbox-disabled+.ui-checkbox-label {
  color: #aaa;
  cursor: default;
}

.ui-checkbox input {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 100;
  width: 100%!important;
  height: 100%!important;
  margin: 0!important;
  opacity: 0;
  cursor: pointer;
}

.ui-checkbox input:checked+.ui-checkbox-alternate {
  border-color: #4baae0;
  background: #f2f1f0;
}

.ui-checkbox input:checked+.ui-checkbox-alternate:before {
  content: '';
  display: block;
  width: 20px;
  height: 20px;
  background: url(/images/common/checkbox-checked.svg?HFJPW5xaqhiR);
  vertical-align: top;
}

.ui-checkbox input:indeterminate+.ui-checkbox-alternate:before {
  content: '';
  display: block;
  width: 20px;
  height: 20px;
  background: url(/images/common/checkbox-indeterminate.svg?fTJHynAkTdh2);
  vertical-align: top;
}

.ui-checkbox input:focus+.ui-checkbox-alternate,.ui-checkbox input:hover+.ui-checkbox-alternate {
  border-color: #888;
}

.ui-checkbox .ui-checkbox-alternate {
  width: 24px;
  height: 24px;
  line-height: 24px;
  display: inline-block;
  text-align: center;
  border-radius: 3px;
  border: 2px solid #ccc;
  background: #fff;
  box-sizing: border-box;
}

.ui-checkbox-label {
  font-size: 1.1em;
  cursor: pointer;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  display: inline-block;
  padding: 0 0 0 8px;
  box-sizing: content-box!important;
  vertical-align: middle;
}

@-webkit-keyframes spin {
  0% {
    -webkit-transform: rotate(0);
    transform: rotate(0);
  }

  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@keyframes spin {
  0% {
    -webkit-transform: rotate(0);
    transform: rotate(0);
  }

  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@-webkit-keyframes spin-left {
  0%, 25% {
    -webkit-transform: rotate(0);
    transform: rotate(0);
  }

  50%, 75% {
    -webkit-transform: rotate(180deg);
    transform: rotate(180deg);
  }

  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@keyframes spin-left {
  0%, 25% {
    -webkit-transform: rotate(0);
    transform: rotate(0);
  }

  50%, 75% {
    -webkit-transform: rotate(180deg);
    transform: rotate(180deg);
  }

  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@-webkit-keyframes spin-right {
  0% {
    -webkit-transform: rotate(0);
    transform: rotate(0);
  }

  25%, 50% {
    -webkit-transform: rotate(180deg);
    transform: rotate(180deg);
  }

  100%, 75% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@keyframes spin-right {
  0% {
    -webkit-transform: rotate(0);
    transform: rotate(0);
  }

  25%, 50% {
    -webkit-transform: rotate(180deg);
    transform: rotate(180deg);
  }

  100%, 75% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

.ui-loading {
  width: 20px;
  height: 20px;
  overflow: hidden;
  position: relative;
  display: inline-block;
  -webkit-animation: 1.25s linear infinite spin;
  animation: 1.25s linear infinite spin;
}

.ui-loading:before {
  content: '';
  display: block;
  background: #fff;
  width: 16px;
  height: 16px;
  position: absolute;
  border-radius: 50%;
  top: 2px;
  left: 2px;
  z-index: 100;
}

.ui-loading-large-beige {
  width: 50px;
  height: 50px;
  overflow: hidden;
  position: relative;
  display: inline-block;
  -webkit-animation: 1.25s linear infinite spin;
  animation: 1.25s linear infinite spin;
}

.ui-loading-large-beige:before {
  content: '';
  display: block;
  background: #f2f1f0;
  width: 40px;
  height: 40px;
  position: absolute;
  border-radius: 50%;
  top: 5px;
  left: 5px;
  z-index: 100;
}

.ui-loading-beige {
  width: 20px;
  height: 20px;
  overflow: hidden;
  position: relative;
  display: inline-block;
  -webkit-animation: 1.25s linear infinite spin;
  animation: 1.25s linear infinite spin;
}

.ui-loading-beige:before {
  content: '';
  display: block;
  background: #f2f1f0;
  width: 16px;
  height: 16px;
  position: absolute;
  border-radius: 50%;
  top: 2px;
  left: 2px;
  z-index: 100;
}

.ui-loading-gray {
  width: 20px;
  height: 20px;
  overflow: hidden;
  position: relative;
  display: inline-block;
  -webkit-animation: 1.25s linear infinite spin;
  animation: 1.25s linear infinite spin;
}

.ui-loading-gray:before {
  content: '';
  display: block;
  background: #eee;
  width: 16px;
  height: 16px;
  position: absolute;
  border-radius: 50%;
  top: 2px;
  left: 2px;
  z-index: 100;
}

.ui-tooltip:focus,.ui-tooltip:hover {
  position: relative;
}

.ui-tooltip:focus:before,.ui-tooltip:hover:before {
  z-index: 90000;
  pointer-events: none;
  display: inline-block!important;
}

.ui-tooltip:focus:after,.ui-tooltip:hover:after {
  content: attr(data-ui-tooltip-label)!important;
  display: inline-block!important;
  background-color: #222;
  font-size: 11px!important;
  font-style: normal;
  text-shadow: none;
  color: #fff!important;
  font-weight: 700;
  padding: 7px 7px;
  line-height: 1;
  position: absolute;
  z-index: 90000;
  max-width: 500px;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  pointer-events: none;
}

.ui-tooltip:focus.ui-tooltip-top:before,.ui-tooltip:hover.ui-tooltip-top:before {
  content: '';
  position: absolute;
  border: 5px solid transparent;
  bottom: -10px;
  left: 50%;
  margin: 0 0 0 -5px;
  border-top-color: #222;
  bottom: auto;
  top: -9px;
}

.ui-tooltip:focus.ui-tooltip-top:after,.ui-tooltip:hover.ui-tooltip-top:after {
  -webkit-transform: translateX(50%);
  transform: translateX(50%);
  bottom: 100%;
  right: 50%;
  margin: 0 0 9px 0;
}

.ui-tooltip:focus.ui-tooltip-right:before,.ui-tooltip:hover.ui-tooltip-right:before {
  content: '';
  position: absolute;
  border: 5px solid transparent;
  top: calc(50% - 5px);
  left: -10px;
  border-right-color: #222;
  left: auto;
  right: -9px;
}

.ui-tooltip:focus.ui-tooltip-right:after,.ui-tooltip:hover.ui-tooltip-right:after {
  -webkit-transform: translateY(50%);
  transform: translateY(50%);
  left: 100%;
  bottom: 50%;
  margin: 0 0 0 9px;
}

.ui-tooltip:focus.ui-tooltip-bottom:before,.ui-tooltip:hover.ui-tooltip-bottom:before {
  content: '';
  position: absolute;
  border: 5px solid transparent;
  top: -5px;
  left: 50%;
  margin: 0 0 0 -5px;
  border-bottom-color: #222;
  top: auto;
  bottom: -9px;
}

.ui-tooltip:focus.ui-tooltip-bottom:after,.ui-tooltip:hover.ui-tooltip-bottom:after {
  -webkit-transform: translateX(50%);
  transform: translateX(50%);
  top: 100%;
  right: 50%;
  margin: 9px 0 0 0;
}

.ui-tooltip:focus.ui-tooltip-left:before,.ui-tooltip:hover.ui-tooltip-left:before {
  content: '';
  position: absolute;
  border: 5px solid transparent;
  top: calc(50% - 5px);
  right: -10px;
  border-left-color: #222;
  left: -9px;
}

.ui-tooltip:focus.ui-tooltip-left:after,.ui-tooltip:hover.ui-tooltip-left:after {
  -webkit-transform: translateY(50%);
  transform: translateY(50%);
  right: 100%;
  bottom: 50%;
  margin: 0 9px 0 0;
}

.ui-tooltip-top-to-bottom:focus:before,.ui-tooltip-top-to-bottom:hover:before {
  top: auto;
  bottom: -9px;
  border-color: transparent;
  border-bottom-color: #222;
}

.ui-tooltip-top-to-bottom:focus:after,.ui-tooltip-top-to-bottom:hover:after {
  bottom: auto;
  top: 100%;
  margin: 9px 0 0;
}

.isTouch .ui-tooltip:after,.isTouch .ui-tooltip:before {
  display: none!important;
}

.ui-contextMenu {
  position: relative;
  outline: 0;
  cursor: pointer;
}

.ui-contextMenu.ui-contextMenu-selector .ui-contextMenu-content {
  top: 100%;
  margin: 0 0 0 -34px;
}

.ui-contextMenu.ui-contextMenu-selector .ui-contextMenu-content li.isActive:first-child a:before {
  top: 6px;
}

.ui-contextMenu.ui-contextMenu-selector .ui-contextMenu-content li.isActive a {
  position: relative;
  color: #0990cc;
  font-weight: 700;
}

.ui-contextMenu.ui-contextMenu-selector .ui-contextMenu-content li.isActive a:before {
  font-family: dcicons;
  content: '\f71C';
  position: absolute;
  top: 2px;
  left: 11px;
  font-size: 14px;
  line-height: 1.5;
  font-weight: 400;
}

.ui-contextMenu.ui-contextMenu-selector .ui-contextMenu-content a {
  padding: 7px 16px 7px 32px!important;
}

.ui-contextMenu:focus .ui-contextMenu-content,.ui-contextMenu:hover .ui-contextMenu-content {
  display: block!important;
}

.ui-contextMenu .ui-contextMenu-content {
  display: none!important;
  position: absolute;
  top: 100%;
  background: #fff;
  border: 1px solid rgba(0,0,0,.3);
  box-shadow: 0 1px 1px rgba(0,0,0,.1);
  z-index: 20000;
  height: auto;
}

.ui-contextMenu .ui-contextMenu-content.ui-contextMenu-content-left {
  left: 0;
}

.ui-contextMenu .ui-contextMenu-content.ui-contextMenu-content-right {
  right: 0;
}

.ui-contextMenu .ui-contextMenu-content ul {
  padding: 0;
  margin: 0;
}

.ui-contextMenu .ui-contextMenu-content ul li {
  list-style-type: none;
}

.ui-contextMenu .ui-contextMenu-content li:first-child a,.ui-contextMenu .ui-contextMenu-content li:first-child button {
  padding-top: 12px!important;
}

.ui-contextMenu .ui-contextMenu-content li:last-child a,.ui-contextMenu .ui-contextMenu-content li:last-child button {
  padding-bottom: 12px!important;
}

.ui-contextMenu .ui-contextMenu-content li.contextMenu-border {
  border-bottom: 1px solid #ccc;
}

.ui-contextMenu .ui-contextMenu-content li.contextMenu-border+li a {
  padding-top: 10px!important;
}

.ui-contextMenu .ui-contextMenu-content li.contextMenu-border a {
  padding-bottom: 10px!important;
}

.ui-contextMenu .ui-contextMenu-content a,.ui-contextMenu .ui-contextMenu-content button {
  font-size: 13px;
  padding: 7px 10px!important;
  color: #222;
  font-weight: 400;
  width: 100%;
  box-sizing: border-box;
  text-align: left;
  line-height: 1!important;
  text-decoration: none;
  display: block;
  background: 0 0;
  border: none;
  white-space: nowrap;
}

.ui-contextMenu .ui-contextMenu-content a.isActive,.ui-contextMenu .ui-contextMenu-content button.isActive {
  background: #f2f1f0;
}

.ui-contextMenu .ui-contextMenu-content a:focus,.ui-contextMenu .ui-contextMenu-content a:hover,.ui-contextMenu .ui-contextMenu-content button:focus,.ui-contextMenu .ui-contextMenu-content button:hover {
  color: #0990cc;
}

.ui-contextMenu .ui-contextMenu-content button[disabled] {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
  text-shadow: none!important;
  cursor: default!important;
}

.ui-contextMenu .ui-contextMenu-content button[disabled]:focus,.ui-contextMenu .ui-contextMenu-content button[disabled]:hover {
  background: #eee!important;
  border-color: #ddd!important;
  color: #aaa!important;
}

.isTouch .ui-contextMenu.ui-contextMenu-selector .ui-contextMenu-content li.isActive:first-child a:before {
  top: 12px;
}

.isTouch .ui-contextMenu.ui-contextMenu-selector .ui-contextMenu-content li.isActive a:before {
  top: 5px;
}

.isTouch .ui-contextMenu.ui-contextMenu-selector .ui-contextMenu-content a {
  padding: 10px 16px 10px 32px!important;
}

.isTouch .ui-contextMenu .ui-contextMenu-content li:first-child a,.isTouch .ui-contextMenu .ui-contextMenu-content li:first-child button {
  padding-top: 17px!important;
}

.isTouch .ui-contextMenu .ui-contextMenu-content li:last-child a,.isTouch .ui-contextMenu .ui-contextMenu-content li:last-child button {
  padding-bottom: 17px!important;
}

.isTouch .ui-contextMenu .ui-contextMenu-content li.contextMenu-border+li a {
  padding-top: 15px!important;
}

.isTouch .ui-contextMenu .ui-contextMenu-content li.contextMenu-border a {
  padding-bottom: 15px!important;
}

.isTouch .ui-contextMenu .ui-contextMenu-content a,.isTouch .ui-contextMenu .ui-contextMenu-content button {
  font-size: 13px;
  padding: 10px 12px!important;
}

.ui-toggleSwitch-label {
  cursor: pointer;
  padding: 0 0 0 4px;
  display: inline-block;
}

.ui-toggleSwitch {
  position: relative;
  width: 36px;
  height: 22px;
  overflow: hidden;
  display: block;
}

.ui-toggleSwitch input {
  border: none;
  background: 0 0;
  position: absolute;
  top: 0;
  left: 0;
  z-index: 3;
  width: 100%;
  height: 22px;
  vertical-align: top;
  text-indent: -9999px;
  overflow: hidden;
  cursor: pointer;
  opacity: 0;
}

.ui-toggleSwitch input:focus+.ui-toggleSwitch-alternate,.ui-toggleSwitch input:hover+.ui-toggleSwitch-alternate {
  background: #aaa;
}

.ui-toggleSwitch input:checked+.ui-toggleSwitch-alternate {
  background: #4baae0;
}

.ui-toggleSwitch input:checked+.ui-toggleSwitch-alternate:after {
  left: 14px;
}

.ui-toggleSwitch input:checked:focus+.ui-toggleSwitch-alternate,.ui-toggleSwitch input:checked:hover+.ui-toggleSwitch-alternate {
  background: #0990cc;
}

.ui-toggleSwitch input[disabled] {
  cursor: default;
}

.ui-toggleSwitch input[disabled]:focus+.ui-toggleSwitch-alternate,.ui-toggleSwitch input[disabled]:hover+.ui-toggleSwitch-alternate {
  background: #ccc;
}

.ui-toggleSwitch input[disabled]:checked:focus+.ui-toggleSwitch-alternate,.ui-toggleSwitch input[disabled]:checked:hover+.ui-toggleSwitch-alternate {
  background: #4baae0;
}

.ui-toggleSwitch .ui-toggleSwitch-alternate {
  position: relative;
  width: 36px;
  height: 22px;
  border-radius: 12px;
  z-index: 0;
  display: block;
  background: #ccc;
  -webkit-transition: all .2s cubic-bezier(.23,1,.32,1);
  transition: all .2s cubic-bezier(.23,1,.32,1);
}

.ui-toggleSwitch .ui-toggleSwitch-alternate:after {
  content: '';
  border-radius: 8px;
  width: 16px;
  height: 16px;
  margin: 3px;
  box-shadow: 0 1px 0 0 rgba(0,0,0,.2);
  display: block;
  background: #fff;
  z-index: 1;
  -webkit-transition: all .2s cubic-bezier(.49,1.47,.82,1);
  transition: all .2s cubic-bezier(.49,1.47,.82,1);
  position: absolute;
  top: 0;
  left: 0;
}

.ui-radiobutton {
  width: 18px;
  height: 18px;
  position: relative;
  display: inline-block;
  overflow: hidden;
  vertical-align: middle;
}

.ui-radiobutton.isDisabled+.ui-radiobutton-label {
  color: #aaa;
  cursor: default;
}

.ui-radiobutton input {
  width: auto;
  position: absolute;
  z-index: 100;
  top: 0;
  left: 0;
  width: 100%!important;
  height: 100%!important;
  margin: 0!important;
  opacity: 0;
  cursor: pointer;
}

.ui-radiobutton input:checked+.ui-radiobutton-alternate {
  border-color: #4baae0;
  background: #4baae0;
}

.ui-radiobutton input:checked+.ui-radiobutton-alternate:before {
  content: '';
  display: block;
  width: 6px;
  height: 6px;
  margin: 4px 0 0 4px;
  background: #fff;
  line-height: 1;
  vertical-align: top;
  border-radius: 50%;
}

.ui-radiobutton input:focus+.ui-radiobutton-alternate,.ui-radiobutton input:hover+.ui-radiobutton-alternate {
  border-color: #666;
}

.ui-radiobutton input:disabled+.ui-radiobutton-alternate {
  border-color: #ddd;
  background: #eee;
}

.ui-radiobutton input:disabled:checked+.ui-radiobutton-alternate {
  border-color: #ddd;
  background: #fff;
}

.ui-radiobutton input:disabled:checked+.ui-radiobutton-alternate:before {
  background: #bbb;
}

.ui-radiobutton input:disabled:focus+.ui-radiobutton-alternate,.ui-radiobutton input:disabled:hover+.ui-radiobutton-alternate {
  border-color: #ddd;
}

.ui-radiobutton .ui-radiobutton-alternate {
  width: 18px;
  height: 18px;
  line-height: 18px;
  display: inline-block;
  text-align: center;
  border-radius: 50%;
  border: 2px solid #ccc;
  box-sizing: border-box;
  background: #fff;
}

.ui-radiobutton-label {
  font-size: 1.1em;
  cursor: pointer;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  padding: 0 0 0 8px;
  display: inline-block;
  box-sizing: content-box!important;
  vertical-align: middle;
}

.ui-toggle.ui-toggle-isShown .ui-toggle-handle:before {
  content: '\f703';
}

.ui-toggle.ui-toggle-isHidden .ui-toggle-body {
  display: none;
}

.ui-toggle .ui-toggle-handle {
  cursor: pointer;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.ui-toggle .ui-toggle-handle:before {
  font-family: dcicons;
  vertical-align: baseline;
  line-height: 1;
  font-style: normal;
  display: inline-block;
}

.ui-toggle .ui-toggle-handle.white {
  color: #fff;
}

.ui-toggle .ui-toggle-handle:before {
  content: '\f702';
}

.ui-toggle .ui-toggle-handle:before {
  width: 20px;
  margin: 0 0 0 -20px;
  text-align: center;
}

.ui-ul {
  padding-left: 0;
  margin: 0;
}

.ui-ul li {
  list-style-type: none;
  margin: 0 0 .5em 0;
  line-height: 1.5;
}

.ui-ul li:before {
  content: '-';
  display: inline-block;
  width: 1em;
  text-align: center;
  margin: 0 0 0 -1em;
  color: #aaa;
}

.ui-ul li a {
  display: inline-block;
}

.ui-input {
  margin: 1em 0;
}

.ui-input-label {
  font-size: 1em;
  font-weight: 400;
  margin: 0;
}

.ui-input-content {
  margin: 0;
}

.isPC .ui-input-description {
  color: #444;
  margin: 0 0 .5em!important;
  line-height: 1.5;
}

.isPC .ui-input-description span {
  display: block;
}

.isTouch .ui-input-description {
  font-size: 12px;
  color: #666;
  margin: 0 0 .25em;
  line-height: 1.4;
}

@-webkit-keyframes keyframes-shakeUpAndDown {
  from, to {
    top: 120%;
  }

  50% {
    top: 140%;
  }
}

@keyframes keyframes-shakeUpAndDown {
  from, to {
    top: 120%;
  }

  50% {
    top: 140%;
  }
}

@-webkit-keyframes keyframes-shakeUpAndDown-next {
  from, to {
    top: 0;
  }

  50% {
    top: 10%;
  }
}

@keyframes keyframes-shakeUpAndDown-next {
  from, to {
    top: 0;
  }

  50% {
    top: 10%;
  }
}

@-webkit-keyframes keyframes-text {
  from, to {
    opacity: 0;
  }

  10% {
    opacity: 0;
  }

  20% {
    opacity: 1;
  }

  90% {
    opacity: 1;
  }
}

@keyframes keyframes-text {
  from, to {
    opacity: 0;
  }

  10% {
    opacity: 0;
  }

  20% {
    opacity: 1;
  }

  90% {
    opacity: 1;
  }
}

@-webkit-keyframes keyframes-cheerMessage {
  from, to {
    opacity: 0;
  }

  10% {
    opacity: 0;
    bottom: 110%;
  }

  17% {
    bottom: 130%;
  }

  20% {
    opacity: 1;
    bottom: 125%;
  }

  90% {
    opacity: 1;
  }
}

@keyframes keyframes-cheerMessage {
  from, to {
    opacity: 0;
  }

  10% {
    opacity: 0;
    bottom: 110%;
  }

  17% {
    bottom: 130%;
  }

  20% {
    opacity: 1;
    bottom: 125%;
  }

  90% {
    opacity: 1;
  }
}

@-webkit-keyframes keyframes-cheerMessage-vertical {
  from, to {
    opacity: 0;
  }

  10% {
    opacity: 0;
    left: 95%;
  }

  17% {
    left: 115%;
  }

  20% {
    opacity: 1;
    left: 110%;
  }

  90% {
    opacity: 1;
  }
}

@keyframes keyframes-cheerMessage-vertical {
  from, to {
    opacity: 0;
  }

  10% {
    opacity: 0;
    left: 95%;
  }

  17% {
    left: 115%;
  }

  20% {
    opacity: 1;
    left: 110%;
  }

  90% {
    opacity: 1;
  }
}

@-webkit-keyframes keyframes-likeMessage {
  from, to {
    opacity: 0;
  }

  10% {
    opacity: 0;
    bottom: 110%;
  }

  17% {
    bottom: 130%;
  }

  20% {
    opacity: 1;
    bottom: 125%;
  }

  90% {
    opacity: 1;
  }
}

@keyframes keyframes-likeMessage {
  from, to {
    opacity: 0;
  }

  10% {
    opacity: 0;
    bottom: 110%;
  }

  17% {
    bottom: 130%;
  }

  20% {
    opacity: 1;
    bottom: 125%;
  }

  90% {
    opacity: 1;
  }
}

@-webkit-keyframes keyframes-pop {
  from, to {
    top: 0;
  }

  10% {
    top: -5px;
  }

  95% {
    top: 1px;
  }

  100% {
    top: 0;
  }
}

@keyframes keyframes-pop {
  from, to {
    top: 0;
  }

  10% {
    top: -5px;
  }

  95% {
    top: 1px;
  }

  100% {
    top: 0;
  }
}

@-webkit-keyframes keyframes-reviewButton-attention {
  from, to {
    -webkit-transform: scale(1);
    transform: scale(1);
  }

  50% {
    -webkit-transform: scale(1.2);
    transform: scale(1.2);
  }
}

@keyframes keyframes-reviewButton-attention {
  from, to {
    -webkit-transform: scale(1);
    transform: scale(1);
  }

  50% {
    -webkit-transform: scale(1.2);
    transform: scale(1.2);
  }
}

@-webkit-keyframes keyframes-from0to100 {
  from {
    width: 0;
  }

  to {
    width: 100%;
  }
}

@keyframes keyframes-from0to100 {
  from {
    width: 0;
  }

  to {
    width: 100%;
  }
}

@-webkit-keyframes keyframes-show1_5s {
  from {
    opacity: 0;
  }

  to {
    opacity: 1;
  }
}

@keyframes keyframes-show1_5s {
  from {
    opacity: 0;
  }

  to {
    opacity: 1;
  }
}

@-webkit-keyframes keyframes-target {
  from {
    background: #f2f1f0;
  }

  to {
    background: 0 0;
  }
}

@keyframes keyframes-target {
  from {
    background: #f2f1f0;
  }

  to {
    background: 0 0;
  }
}

.ui-select {
  position: relative;
  display: inline-block;
  border-radius: 4px;
  z-index: 0;
}

.ui-select:before {
  font-family: dcicons;
  vertical-align: baseline;
  line-height: 1;
  font-style: normal;
  display: inline-block;
}

.ui-select.white {
  color: #fff;
}

.ui-select:before {
  content: '\f70f';
}

.ui-select.ui-select-small select {
  font-size: 12px;
  height: 30px;
  line-height: 30px;
  padding: 0 28px 0 10px;
}

.ui-select:before {
  position: absolute;
  top: 50%;
  right: 0;
  z-index: 0;
  padding: 0 14px 0 0;
  -webkit-transform: translateY(-50%);
  transform: translateY(-50%);
  font-size: .75em;
}

.ui-select:after {
  content: '';
  background: #fff;
  width: 100%;
  height: 100%;
  display: block;
  z-index: -1;
  position: absolute;
  top: 0;
  left: 0;
  border-radius: 4px;
}

.ui-select select {
  -webkit-appearance: button;
  -moz-appearance: button;
  text-overflow: '';
  text-indent: .01px;
  outline: 0;
  color: #222;
  background: 0 0;
  font-size: 1rem;
  border: 2px solid #ccc;
  border-radius: 4px;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  outline: 0!important;
  padding: 7px 28px 7px 10px;
  position: relative;
  z-index: 100;
  width: 100%;
  cursor: pointer;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
}

.ui-select select[disabled=disabled],.ui-select select[readonly=readonly] {
  cursor: default;
}

.ui-select select[disabled=disabled]:focus,.ui-select select[disabled=disabled]:hover,.ui-select select[readonly=readonly]:focus,.ui-select select[readonly=readonly]:hover {
  border-color: #ccc!important;
}

.ui-select select::-ms-expand {
  display: none;
}

.ui-select select:hover {
  border-color: #888!important;
}

.ui-select select:focus {
  border-color: #4baae0!important;
}

.isPC .ui-tab {
  margin: 1em 0 0;
  background: #f7f6f5;
}

.isPC .ui-tab ul {
  padding: 0;
  margin: 0;
  padding: 1em 0 0;
  overflow: hidden;
  overflow-x: auto;
  overflow-y: hidden;
  width: 100%;
  box-sizing: border-box;
  white-space: nowrap;
  -webkit-overflow-scrolling: touch;
}

.isPC .ui-tab ul li {
  list-style-type: none;
}

.isPC .ui-tab ul::-webkit-scrollbar {
  height: 4px;
  background-color: #f7f6f5;
}

.isPC .ui-tab ul::-webkit-scrollbar-thumb {
  background-color: #ccc;
}

.isPC .ui-tab ul::-webkit-scrollbar-thumb:hover {
  background-color: #aaa;
}

.isPC .ui-tab li {
  display: inline-block;
}

.isPC .ui-tab li:first-child {
  margin-left: 1em;
}

.isPC .ui-tab li:focus,.isPC .ui-tab li:hover {
  background: #eae9e8;
}

.isPC .ui-tab li.isActive {
  background: #fff;
  box-shadow: 0 0 10px 0 rgba(0,0,0,.1);
}

.isPC .ui-tab li.isActive a,.isPC .ui-tab li.isActive button {
  font-weight: 700;
}

.isPC .ui-tab a,.isPC .ui-tab button {
  font-size: 1.25em;
  display: block;
  text-decoration: none;
  background: 0 0;
  border: none;
  padding: .5em 1em .25em;
  color: #222;
}

.isTouch .ui-tab {
  background: #f7f6f5;
  margin: 30px 0 0 -15px!important;
  width: calc(100% + 30px);
  box-sizing: border-box;
}

.isTouch .ui-tab:after,.isTouch .ui-tab:before {
  content: '';
  display: table;
}

.isTouch .ui-tab:after {
  clear: both;
}

.isTouch .ui-tab ul {
  padding: 0;
  margin: 0;
  overflow-x: auto;
  overflow-y: hidden;
  width: 100%;
  padding: 0 15px;
  box-sizing: border-box;
  white-space: nowrap;
  -webkit-overflow-scrolling: touch;
}

.isTouch .ui-tab ul li {
  list-style-type: none;
}

.isTouch .ui-tab ul:after,.isTouch .ui-tab ul:before {
  content: '';
  display: table;
}

.isTouch .ui-tab ul:after {
  clear: both;
}

.isTouch .ui-tab ul::-webkit-scrollbar {
  height: 4px;
  background-color: #f7f6f5;
}

.isTouch .ui-tab ul::-webkit-scrollbar-thumb {
  background-color: #ccc;
}

.isTouch .ui-tab ul::-webkit-scrollbar-thumb:hover {
  background-color: #aaa;
}

.isTouch .ui-tab li {
  display: inline-block;
  margin: .5em 0 0 0;
}

.isTouch .ui-tab li:first-child {
  margin-left: 1em;
}

.isTouch .ui-tab li:focus,.isTouch .ui-tab li:hover {
  background: #eae9e8;
}

.isTouch .ui-tab li.isActive {
  background: #fff;
  box-shadow: 0 0 10px 0 rgba(0,0,0,.1);
}

.isTouch .ui-tab li.isActive a,.isTouch .ui-tab li.isActive button {
  font-weight: 700;
}

.isTouch .ui-tab a,.isTouch .ui-tab button {
  display: block;
  text-decoration: none;
  background: 0 0;
  border: none;
  padding: .5em 1em .25em;
  font-size: 1.1em;
  color: #222;
}

.ui-truncateTextButton {
  position: relative;
}

.ui-modal-container {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background: rgba(0,0,0,.3);
  z-index: 30000;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.ui-modal-container.isHidden {
  display: none;
}

.ui-modal-window {
  background: #fff;
  overflow-y: auto;
  overflow-x: hidden;
  -webkit-overflow-scrolling: touch;
  max-height: calc(100% - 16px);
  min-width: 300px;
  border-radius: 4px;
  box-shadow: 0 20px 100px rgba(0,0,0,.3);
}

.ui-modal-window .ui-modal-header {
  padding: 20px 32px 16px;
  background: #f2f1f0;
  text-align: center;
}

.ui-modal-window .ui-modal-header+.ui-modal-body {
  box-shadow: 0 -1px 0 rgba(0,0,0,.1);
  margin-top: 1px;
}

.ui-modal-window .ui-modal-header h3,.ui-modal-window .ui-modal-header h6 {
  font-size: 15px;
  line-height: 1.3;
  font-weight: 400;
  margin: 0;
}

.ui-modal-window .ui-modal-header p {
  font-size: 11.5px;
  color: #666;
  margin: .5em 0 0;
  line-height: 1;
}

.ui-modal-window .ui-tab {
  margin: 0;
  background: #f2f1f0;
  text-align: center;
}

.ui-modal-window .ui-tab ul {
  padding: 0;
}

.ui-modal-window .ui-tab button {
  font-size: 15px;
}

.ui-modal-window .ui-modal-body {
  text-align: left;
  padding: 0 16px;
}

.ui-modal-window .ui-modal-body h3 {
  font-size: 1em;
  margin: 15px 0 7.5px;
}

.ui-modal-window .ui-modal-body p {
  margin: 0;
}

.ui-modal-window .ui-modal-footer {
  margin: 0;
  padding: 0 16px 15px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}

.ui-modal-window .ui-modal-footer button {
  margin: 0 0 0 8px;
}

.isTouch .ui-modal-window .ui-modal-header h3 {
  font-size: 13px;
}

.isTouch .ui-modal-window .ui-modal-footer {
  padding: 9px 10px;
}

.ui-selector.isHidden {
  display: none;
}

.ui-selector:not(.ui-modal-container) {
  position: absolute;
  background: #fff;
  border: 1px solid rgba(0,0,0,.3);
  box-shadow: 0 1px 1px rgba(0,0,0,.1);
  z-index: 20000;
  width: 220px;
}

.ui-selector:not(.ui-modal-container) .ui-selector-header {
  font-size: 11.5px;
  padding: 4px 8px;
}

.ui-selector:not(.ui-modal-container) .ui-selector-items {
  max-height: 250px;
}

.ui-selector:not(.ui-modal-container) .ui-selector-items button {
  padding: 4px 8px 4px 0;
}

.ui-selector.ui-modal-container .ui-selector-window {
  width: 220px;
}

.ui-selector.ui-modal-container .ui-selector-header {
  background: #f2f1f0;
  text-align: center;
  padding: 20px 16px 16px;
  border-bottom: 1px solid #ddd;
  margin: 0 0 8px;
  line-height: 1;
}

.ui-selector.ui-modal-container .ui-selector-items {
  max-height: calc(100vh - 235px);
}

.ui-selector.ui-modal-container .ui-selector-items li:not(:first-child) button::before {
  content: '';
  display: block;
  border-top: 1px solid #ddd;
  position: absolute;
  top: 0;
  left: 44px;
  width: calc(100% - 44px);
  height: 0;
}

.ui-selector.ui-modal-container .ui-selector-items li button {
  padding: 0 8px 0 0;
  position: relative;
  height: 44px;
  line-height: 44px;
}

.ui-selector-search {
  padding: 0 8px 8px;
}

.ui-selector-items {
  border-top: 1px solid #ddd;
  padding: 0;
  padding: 4px 0;
  margin: 0;
  overflow-y: auto;
}

.ui-selector-items li {
  list-style-type: none;
}

.ui-selector-items li.isHidden {
  display: none;
}

.ui-selector-items button {
  border: none;
  background: 0 0;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  width: 100%;
  text-align: left;
}

.ui-selector-items button:enabled:focus,.ui-selector-items button:enabled:hover {
  color: #0990cc;
}

.ui-selector-items svg {
  width: 11px;
  height: 11px;
  margin: 0 15px 0 18px;
}

.isPC #globalHeaderPC {
  position: fixed;
  top: 0;
  left: 0;
  height: 50px;
  background: #fff;
  width: 100%;
  z-index: 10000;
  padding: 0 30px;
  box-sizing: border-box;
  box-shadow: 0 1px 0 rgba(0,0,0,.05);
}

.isPC #globalHeaderPC-inner {
  height: 50px;
  margin: 0 auto;
  max-width: 1125px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  min-width: 1000px;
}

.isPC #globalHeaderPC-inner nav {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.isPC #globalHeaderPC-primary {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.isPC #globalHeaderPC-logo {
  margin: 0 1.5em 0 0!important;
  font-size: 1em;
  margin: 0;
  height: 50px;
  line-height: 50px;
  box-sizing: border-box;
}

.isPC #globalHeaderPC-logo a {
  text-decoration: none;
  display: block;
  line-height: 50px;
  height: 50px;
}

.isPC #globalHeaderPC-logo img {
  max-height: 25px;
  margin: 12.5px 0 0;
}

.isPC #globalHeaderPC-globalNav {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  padding: 0;
  margin: 0;
  font-size: 12.6px;
}

.isPC #globalHeaderPC-globalNav li {
  list-style-type: none;
}

.isPC #globalHeaderPC-globalNav>li {
  margin: 0;
  height: 50px;
  line-height: 50px;
  box-sizing: border-box;
  display: inline-block;
  vertical-align: middle;
}

.isPC #globalHeaderPC-globalNav a {
  display: block;
  padding: 0 1em 0 0;
  line-height: 50px;
  border: none;
  font-size: 12.6px;
  letter-spacing: 0;
}

.isPC #globalHeaderPC-globalNav a:focus,.isPC #globalHeaderPC-globalNav a:hover {
  text-decoration: none;
}

.isPC #globalHeaderPC-globalNav a:focus span,.isPC #globalHeaderPC-globalNav a:hover span {
  border-top-color: #4baae0;
}

.isPC #globalHeaderPC-globalNav a.isActive span {
  border-top-color: #222;
}

.isPC #globalHeaderPC-globalNav span {
  display: block;
  border-top: 4px solid transparent;
  line-height: 46px;
  color: #222;
}

.isPC #globalHeaderPC-search {
  position: relative;
  width: 200px;
  padding: 9px 0 0;
}

.isPC #globalHeaderPC-search form {
  display: block;
  -webkit-transition: all .1s linear;
  transition: all .1s linear;
}

.isPC #globalHeaderPC-search form:after,.isPC #globalHeaderPC-search form:before {
  content: '';
  display: table;
}

.isPC #globalHeaderPC-search form:after {
  clear: both;
}

.isPC #globalHeaderPC-search form:focus button,.isPC #globalHeaderPC-search form:focus input,.isPC #globalHeaderPC-search form:hover button,.isPC #globalHeaderPC-search form:hover input {
  background: #eae9e8;
}

.isPC #globalHeaderPC-search button,.isPC #globalHeaderPC-search input {
  -webkit-transition: all .1s linear;
  transition: all .1s linear;
  background: #f2f1f0;
}

.isPC #globalHeaderPC-search input {
  width: calc(100% - 35px);
  height: 32px;
  font-size: 1em;
  padding-left: 0;
  box-sizing: border-box;
  border: 2px solid transparent;
  border-left: none;
  float: right;
  border-radius: 0;
}

.isPC #globalHeaderPC-search input::-webkit-input-placeholder {
  color: #888;
}

.isPC #globalHeaderPC-search input:-moz-placeholder {
  color: #888;
  line-height: 1.3em;
}

.isPC #globalHeaderPC-search input::-moz-placeholder {
  color: #888;
  line-height: 1.3em;
}

.isPC #globalHeaderPC-search input:-ms-input-placeholder {
  color: #888;
}

.isPC #globalHeaderPC-search input:focus {
  border-top-color: #4baae0!important;
  border-right-color: #4baae0!important;
  border-bottom-color: #4baae0!important;
}

.isPC #globalHeaderPC-search input:focus+button {
  border-bottom-color: #4baae0!important;
  border-left-color: #4baae0!important;
  border-top-color: #4baae0!important;
}

.isPC #globalHeaderPC-search button {
  display: block;
  width: 35px;
  line-height: 1;
  height: 32px;
  text-align: center;
  border: 2px solid transparent;
  border-right: none;
  float: left;
  box-sizing: border-box;
  background: #f2f1f0;
  cursor: pointer;
  border-radius: 0;
}

.isPC #globalHeaderPC-search button:hover {
  color: #0081c2;
}

.isPC #globalHeaderPC-search button i {
  display: inline-block;
  -webkit-transform: translateY(-1.5px);
  transform: translateY(-1.5px);
}

.isPC #globalHeaderPC-searchingConditions-panel {
  position: absolute;
  top: 100%;
  left: 0;
  width: 350px;
  background: #fff;
  border: 1px solid rgba(0,0,0,.3);
  box-shadow: 0 1px 1px rgba(0,0,0,.1);
  box-sizing: border-box;
}

.isPC #globalHeaderPC-searchingConditions-panel.isPanelHidden {
  display: none;
}

.isPC #globalHeaderPC-searchingConditions-panel .widget-searchingConditions {
  margin: 0;
}

.isPC #globalHeaderPC-searchingConditions-panel .widget-searchingConditions div {
  display: block;
}

.isPC #globalHeaderPC-searchingConditions-panel .widget-searchingConditions a {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  padding: 10px 50px 10px 16px;
}

.isPC #globalHeaderPC-searchingConditions-panel .widget-searchingConditions p {
  font-size: .85em;
  margin: 0 0 3px;
  width: 100%;
}

.isPC #globalHeaderPC-searchingConditions-panel .widget-searchingConditions ul {
  font-size: 13px;
  margin: 0;
}

.isPC #globalHeaderPC-searchingConditions-panel .widget-searchingConditions>li {
  border-bottom: none;
  position: relative;
}

.isPC #globalHeaderPC-searchingConditions-panel .widget-searchingConditions>li:not(:first-child):before {
  content: '';
  position: absolute;
  width: calc(100% - 16px);
  top: auto;
  right: 0;
  border-bottom: 1px solid #ddd;
}

.isPC #globalHeaderPC-searchingConditions-panel .widget-searchingConditions button {
  right: 16px;
  background: 0 0;
  width: auto;
  height: auto;
}

.isPC #globalHeaderPC-searchingConditions-panel .widget-searchingConditions-keyword {
  font-size: 14px;
}

.isPC #globalHeaderPC-notification {
  position: relative;
}

.isPC #globalHeaderPC-notification button {
  height: 50px;
  vertical-align: top;
  padding: 0;
  margin: 0 .75em 0 0;
  border-radius: 0;
}

.isPC #globalHeaderPC-notification button:focus,.isPC #globalHeaderPC-notification button:hover {
  background: #f7f6f5;
}

.isPC #globalHeaderPC-notification button span {
  height: auto;
  border: none;
  line-height: 12px;
}

.isPC #globalHeaderPC-notification button img {
  max-height: 18px;
  width: 18px;
  height: 18px;
}

.isPC #globalHeaderPC-notification button img.isHidden {
  display: none;
}

.isPC #globalHeaderPC-info {
  vertical-align: top;
}

.isPC #globalHeaderPC-info i {
  font-size: 1.25em;
  line-height: 1;
}

.isTouch #globalHeaderTouch {
  z-index: 20000;
  background: #fff;
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 80px;
}

.isTouch #globalHeaderTouch-siteTitle {
  border-bottom: 1px solid #ddd;
  height: 35px;
  box-sizing: border-box;
}

.isTouch #globalHeaderTouch-siteTitle-logo a {
  padding: 0 0 0 10px;
  text-decoration: none;
  color: #222;
  font-size: 14px;
  font-weight: 700;
}

.isTouch #globalHeaderTouch-siteTitle-logo img {
  max-height: 16px;
  vertical-align: middle;
  -webkit-transform: translateY(-1px);
  transform: translateY(-1px);
}

.isTouch #globalHeaderTouch-siteTitle-inner {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  margin: 0 auto;
  max-width: 640px;
  padding-left: constant(safe-area-inset-left);
  padding-left: env(safe-area-inset-left);
  padding-right: constant(safe-area-inset-right);
  padding-right: env(safe-area-inset-right);
}

.isTouch #globalHeaderTouch-siteTitle-inner p {
  margin: 0;
  line-height: 35px;
}

.isTouch #globalHeaderTouch-siteTitle-inner a {
  display: block;
}

.isTouch #globalHeaderTouch-siteTitle-controls {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.isTouch #globalHeaderTouch-search a {
  height: 35px;
  vertical-align: top;
}

@media screen and (max-width:340px) {
  .isTouch #globalHeaderTouch-search a {
    padding: 0;
  }
}

.isTouch #globalHeaderTouch-search a img {
  width: 16px;
  height: 16px;
  max-height: none;
}

.isTouch #globalHeaderTouch-search .ui-button-silent {
  vertical-align: top;
  margin: 1px 0 0;
}

.isTouch #globalHeaderTouch-notification button {
  height: 35px;
  vertical-align: top;
  padding: 0 8px;
}

@media screen and (max-width:340px) {
  .isTouch #globalHeaderTouch-notification button {
    padding: 0;
  }
}

.isTouch #globalHeaderTouch-notification button img {
  width: 16px;
  height: 16px;
  max-height: none;
}

.isTouch #globalHeaderTouch-notification button img.isHidden {
  display: none;
}

.isTouch .widget-notification {
  max-height: calc(100vh - 45px);
}

.isTouch #globalHeaderTouch-siteTitle-account {
  margin: 0!important;
}

.isTouch #globalHeaderTouch-siteTitle-account button {
  height: 35px;
  font-size: 11px;
  color: #222;
  vertical-align: top;
  border: none;
  background: 0 0;
  padding: 0 8px;
}

.isTouch #globalHeaderTouch-siteTitle-account i,.isTouch #globalHeaderTouch-siteTitle-account span {
  display: inline-block;
  vertical-align: middle;
}

.isTouch #globalHeaderTouch-siteTitle-account span {
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  max-width: 90px;
}

.isTouch #globalHeaderTouch-siteTitle-account i {
  color: #aaa;
}

.isTouch #globalHeaderTouch-globalNav {
  box-shadow: 0 1px 0 rgba(0,0,0,.1);
}

.isTouch #globalHeaderTouch-globalNav ul {
  padding: 0;
  margin: 0 auto;
  max-width: 640px;
}

.isTouch #globalHeaderTouch-globalNav ul li {
  list-style-type: none;
}

.isTouch #globalHeaderTouch-globalNav ul:after,.isTouch #globalHeaderTouch-globalNav ul:before {
  content: '';
  display: table;
}

.isTouch #globalHeaderTouch-globalNav ul:after {
  clear: both;
}

.isTouch #globalHeaderTouch-globalNav li {
  float: left;
  text-align: center;
  width: 20%;
}

.isTouch #globalHeaderTouch-globalNav li.isActive span {
  color: #0081c2;
}

.isTouch #globalHeaderTouch-globalNav li.isActive .globalHeaderTouch-globalNav-positiveImage {
  display: none;
}

.isTouch #globalHeaderTouch-globalNav li.isActive .globalHeaderTouch-globalNav-negativeImage {
  display: block;
}

.isTouch #globalHeaderTouch-globalNav #globalHeaderTouch-globalNav-others {
  border-left: 1px solid transparent;
  box-sizing: border-box;
}

.isTouch #globalHeaderTouch-globalNav #globalHeaderTouch-globalNav-others.isActive {
  background: #f2f1f0;
  border-left-color: #ddd;
  box-shadow: 1px 0 #ddd,0 1px #f2f1f0;
}

.isTouch #globalHeaderTouch-globalNav #globalHeaderTouch-globalNav-others.isActive span {
  color: #222;
}

.isTouch #globalHeaderTouch-globalNav a,.isTouch #globalHeaderTouch-globalNav button {
  font-size: 10px;
  display: block;
  width: 100%;
  line-height: 1;
  color: #222;
  text-decoration: none;
  padding: 5px 0;
  margin: 0;
  border: none;
  background: 0 0;
}

.isTouch #globalHeaderTouch-globalNav svg {
  width: 20px;
  height: 20px;
  margin: 0 auto 4px;
  vertical-align: top;
}

.isTouch #globalHeaderTouch-globalNav .globalHeaderTouch-globalNav-positiveImage {
  display: block;
}

.isTouch #globalHeaderTouch-globalNav .globalHeaderTouch-globalNav-negativeImage {
  display: none;
}

.isTouch #globalHeaderTouch-globalNav span {
  color: #666;
}

#copyright {
  border-top: 1px solid #ddd;
}

#copyright p {
  margin: 0;
}

#copyright img {
  margin: 0 10px 0 0;
  vertical-align: top;
  display: inline-block;
}

#copyright #copyright-label {
  color: #aaa;
  line-height: 1;
}

.isPC #copyright {
  padding: 10px 0 0;
  margin: 45px 0 0;
}

.isPC #copyright:after,.isPC #copyright:before {
  content: '';
  display: table;
}

.isPC #copyright:after {
  clear: both;
}

.isPC #copyright-label {
  float: right;
}

.isTouch #copyright {
  padding: 15px 16px;
  margin: 8px 0 0;
}

#tab-reading-records {
  margin: 0 0 0 auto;
}

.wrapper.isPC #container {
  width: 1125px;
  margin: 80px auto 30px;
  padding: 0 30px;
}

.wrapper.isTouch #container {
  max-width: 640px;
  margin: 80px auto 0;
  padding: 20px 0;
  padding-bottom: calc(20px + constant(safe-area-inset-bottom));
  padding-bottom: calc(20px + env(safe-area-inset-bottom));
}

.wrapper-dialog.isPC {
  height: 100%;
}

.wrapper-dialog.isPC h1 {
  position: fixed;
  top: 0;
  left: 30px;
  font-size: 1em;
  margin: 0;
  height: 50px;
}

.wrapper-dialog.isPC h1 a {
  text-decoration: none;
  display: block;
  height: 50px;
  line-height: 50px;
}

.wrapper-dialog.isPC h1 img {
  max-height: 25px;
  vertical-align: middle;
}

.wrapper-dialog.isPC #container {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  height: 100%;
  min-width: 500px;
}

.wrapper-dialog.isPC #container-inner {
  width: 465px;
  padding: 42.5px 0;
}

.wrapper-dialog.isPC .ui-input-content {
  position: relative;
}

.wrapper-dialog.isTouch h1 {
  font-size: 1em;
  text-align: center;
  box-shadow: 0 1px 0 rgba(0,0,0,.1);
  margin: 0 0 24px;
  height: 35px;
}

.wrapper-dialog.isTouch h1 a {
  text-decoration: none;
  display: block;
  line-height: 35px;
  height: 35px;
}

.wrapper-dialog.isTouch h1 img {
  max-height: 16px;
  vertical-align: middle;
}

.wrapper-dialog.isTouch #container {
  max-width: 640px;
  margin: 0 auto;
  padding: 0 16px 16px;
  padding-bottom: calc(16px + constant(safe-area-inset-bottom));
  padding-bottom: calc(16px + env(safe-area-inset-bottom));
}

.wrapper-dialog.isTouch .ui-input-content {
  position: relative;
}

.wrapper-user.isPC #container {
  margin: 50px auto 0;
}

.wrapper-user.isPC #main {
  width: 1125px;
  padding: 0 30px 60px;
  margin: 0 auto;
}

.wrapper-user.isTouch #container {
  margin: 80px auto 0;
  max-width: 100%!important;
  padding-bottom: constant(safe-area-inset-bottom);
  padding-bottom: env(safe-area-inset-bottom);
}

.wrapper-user.isTouch #container:after,.wrapper-user.isTouch #container:before {
  content: '';
  display: table;
}

.wrapper-user.isTouch #container:after {
  clear: both;
}

.wrapper-user.isTouch #main {
  max-width: 640px;
  padding: 0;
  margin: 0 auto;
}

.wrapper-user.isTouch .widget-pager p {
  margin-bottom: 24px;
}

.wrapper-contest.isTouch #container {
  margin: 80px auto 24px;
  max-width: 640px;
}

.wrapper-anatanomachi {
  color: #000;
  font: 15px/1.6 "Hiragino Sans","ヒラギノ角ゴシック","Hiragino Kaku Gothic ProN","ヒラギノ角ゴ ProN W3",Meiryo,Helvetica,Arial,sans-serif;
  font-weight: 300;
  margin: 0;
  padding: 0;
}

.wrapper-anatanomachi a {
  color: #000;
  text-decoration: none;
}

.wrapper-anatanomachi a:active,.wrapper-anatanomachi a:hover {
  color: #ff1744;
}

.wrapper-anatanomachi ul {
  margin: 0;
  padding: 0;
  list-style-type: none;
}

.wrapper-anatanomachi .anatanomachi-theme-list {
  border: 2px solid #ff1744;
  border-radius: 4px;
  font-size: 14px;
  padding: 24px 16px 20px;
  margin-bottom: 64px;
  box-sizing: border-box;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-theme-list {
    margin-left: 16px;
    margin-right: 16px;
  }
}

@media (max-width:600px) {
  .wrapper-anatanomachi .anatanomachi-theme-list {
    padding: 12px 16px 8px;
  }
}

.wrapper-anatanomachi .anatanomachi-theme-list-title {
  position: absolute;
  background: #fff url(/images/anatanomachi/sakuhin_yomu.png?w62XVdsuyHxn) center center no-repeat;
  background-size: 123.5px 59.5px;
  width: 160px;
  height: 160px;
  border-radius: 82px;
  margin: -106px 0 0 -40px;
  padding-top: 160px;
  border: 2px solid #ff1744;
  box-sizing: border-box;
  overflow: hidden;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-theme-list-title {
    background-size: 72.64705882px 35px;
    width: 96px;
    height: 96px;
    border-radius: 50px;
    margin: -60px 0 0 -30px;
    padding-top: 96px;
  }
}

@media (max-width:600px) {
  .wrapper-anatanomachi .anatanomachi-theme-list-title {
    border: none;
    width: auto;
    height: auto;
    overflow: auto;
    padding: 0 8px;
    margin: -22px 0 0 -8px;
    background: #fff;
    font-size: 14px;
    font-weight: 600;
    color: #ff1744;
  }
}

.wrapper-anatanomachi .anatanomachi-theme-list-container {
  padding-bottom: 10px;
}

.wrapper-anatanomachi .anatanomachi-theme-list-container:after,.wrapper-anatanomachi .anatanomachi-theme-list-container:before {
  content: '';
  display: table;
}

.wrapper-anatanomachi .anatanomachi-theme-list-container:after {
  clear: both;
}

.wrapper-anatanomachi .anatanomachi-theme-list h4 {
  clear: both;
  font-size: 12px;
  font-weight: 300;
  color: #fff;
  background: #ff1744;
  text-align: right;
  width: 152px;
  margin: 4px 0 0;
  padding: 2px 4px 0;
  box-sizing: border-box;
  float: left;
}

@media (max-width:600px) {
  .wrapper-anatanomachi .anatanomachi-theme-list h4 {
    width: auto;
    padding: 0;
    margin: 8px 0 0;
    background: 0 0;
    color: #ff1744;
    border-bottom: 1px solid #ff1744;
    float: none;
    text-align: left;
  }
}

.wrapper-anatanomachi .anatanomachi-theme-list ul {
  float: right;
  width: calc(100% - 168px);
  margin: 0;
  padding: 4px 0;
}

@media (max-width:600px) {
  .wrapper-anatanomachi .anatanomachi-theme-list ul {
    float: none;
    width: auto;
    padding: 8px 0;
  }
}

.wrapper-anatanomachi .anatanomachi-theme-list li {
  display: inline-block;
  margin-right: 1em;
}

.wrapper-anatanomachi .anatanomachi-theme-list p {
  clear: both;
  border-top: 1px solid #ccc;
  margin: 0;
  padding: 4px 0 0 168px;
}

@media (max-width:600px) {
  .wrapper-anatanomachi .anatanomachi-theme-list p {
    padding: 4px 0 0;
    text-align: center;
  }
}

.wrapper-anatanomachi .anatanomachi-theme-list p a {
  display: inline-block;
  padding: 8px 0;
}

.wrapper-anatanomachi .anatanomachi-container {
  border-top: 5px solid #2792ca;
}

.wrapper-anatanomachi .anatanomachi-container header {
  border-bottom: 1px solid #ccc;
  padding: 14px 0;
  text-align: center;
  line-height: 1;
}

.wrapper-anatanomachi .anatanomachi-container h1 {
  display: inline-block;
  width: 95%;
  max-width: 980px;
  padding: 0;
  margin: 0;
}

.wrapper-anatanomachi .anatanomachi-content-wrapper {
  max-width: 980px;
  margin: 16px auto 0;
}

.wrapper-anatanomachi .anatanomachi-content-wrapper:after,.wrapper-anatanomachi .anatanomachi-content-wrapper:before {
  content: '';
  display: table;
}

.wrapper-anatanomachi .anatanomachi-content-wrapper:after {
  clear: both;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-content-wrapper {
    margin-top: 0;
    background: url(/images/anatanomachi/japan_min.png?XwV4GGJeeE7y) center top 5px no-repeat;
    background-size: 288.5px 241px;
  }
}

.wrapper-anatanomachi .anatanomachi-nav {
  float: left;
  width: 180px;
  text-align: center;
  margin-top: 16px;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-nav {
    margin-top: 0;
    float: none;
    width: auto;
  }
}

.wrapper-anatanomachi .anatanomachi-nav h2 {
  margin: 0;
  padding: 0;
}

.wrapper-anatanomachi .anatanomachi-nav h2 a {
  display: block;
  background: url(/images/anatanomachi/anatano_machino_monogatari_min.png?Ek65soTJ0yy1) center center no-repeat;
  width: 262px;
  height: 280px;
  padding-top: 280px;
  overflow: hidden;
  box-sizing: border-box;
  margin: 0 0 24px -41px;
  background-size: contain;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-nav h2 a {
    background-image: url(/images/anatanomachi/anatano_machino_monogatari_h.png?nBT2oEt_K_vf);
    width: 450px;
    max-width: 80%;
    height: 180px;
    padding-top: 180px;
    margin: 0 auto -20px;
  }
}

.wrapper-anatanomachi .anatanomachi-nav .anatanomachi-nav-result-link {
  display: inline-block;
  border: 2px solid #ff1744;
  padding: 2px;
  border-radius: 9px;
  margin: 0 0 16px;
}

.wrapper-anatanomachi .anatanomachi-nav .anatanomachi-nav-result-link a {
  font-weight: 600;
}

.wrapper-anatanomachi .anatanomachi-nav .anatanomachi-nav-result-link a {
  display: block;
  color: #fff;
  font-size: 10px;
  background: #ff1744;
  border-radius: 6px;
  padding: 8px 20px;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-nav .anatanomachi-nav-result-link a {
    font-size: 14px;
  }
}

.wrapper-anatanomachi .anatanomachi-nav .anatanomachi-nav-result-link a:hover {
  background: #ff4a6d;
}

.wrapper-anatanomachi .anatanomachi-nav-description {
  font-size: 11px;
  color: #999;
  margin: 0;
  padding: 0 8px;
}

.wrapper-anatanomachi .anatanomachi-nav-description br {
  display: block;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-nav-description br {
    display: none;
  }
}

.wrapper-anatanomachi .anatanomachi-nav-description a {
  color: #0081c2;
  text-decoration: underline;
}

.wrapper-anatanomachi .anatanomachi-nav-description a:hover {
  color: #f23e48;
}

.wrapper-anatanomachi .anatanomachi-top-link {
  font-size: 11px;
}

.wrapper-anatanomachi .anatanomachi-top-link:hover::before {
  border-right-color: #ff1744;
}

.wrapper-anatanomachi .anatanomachi-top-link::before {
  display: inline-block;
  content: "";
  border: 3px solid transparent;
  border-right-width: 5px;
  border-right-color: #000;
  margin: 0 4px 1px -3px;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-top-link {
    display: none;
  }
}

.wrapper-anatanomachi .anatanomachi-content {
  float: right;
  width: 760px;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-content {
    float: none;
    width: auto;
  }
}

.wrapper-anatanomachi .anatanomachi-content-title {
  color: #ff1744;
  font-size: 24px;
  margin: 48px 0 24px;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .anatanomachi-content-title {
    margin-top: 32px;
    padding-left: 16px;
    padding-right: 16px;
  }
}

.wrapper-anatanomachi footer {
  width: 980px;
  max-width: 100%;
  margin: 80px auto 0;
  padding-bottom: 32px;
}

.wrapper-anatanomachi footer:before {
  content: "";
  position: absolute;
  display: block;
  border-top: 1px solid #ccc;
  width: 100%;
  left: 0;
  margin-top: 24px;
}

@media (max-width:980px) {
  .wrapper-anatanomachi footer:before {
    display: none;
  }
}

.wrapper-anatanomachi .copyright {
  display: inline;
  font-size: 10px;
  color: #999;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .copyright {
    padding: 0 16px;
  }
}

.wrapper-anatanomachi .links {
  margin: 48px 0 0;
}

@media (max-width:980px) {
  .wrapper-anatanomachi .links {
    padding: 0 16px;
  }
}

.wrapper-anatanomachi .links li {
  display: inline-block;
  font-size: 16px;
  font-weight: 700;
  margin-right: 24px;
}

@media (max-width:600px) {
  .wrapper-anatanomachi .links li {
    margin-right: 0;
    margin-bottom: 8px;
    font-size: 14px;
    display: block;
  }
}

.wrapper-anatanomachi .links li:last-child {
  margin-right: 0;
}

.wrapper-anatanomachi .links li a {
  color: #202a63;
}

.wrapper-anatanomachi .links li a:hover {
  opacity: .8;
}

.wrapper-anatanomachi .links img {
  width: auto;
  height: 18px;
}

@media (max-width:600px) {
  .wrapper-anatanomachi .links img {
    height: 16px;
  }
}

.wrapper-antenna.isPC #container {
  width: 1125px;
  margin: 110px auto 0;
  padding: 0 30px;
}

.wrapper-antenna.isTouch #container {
  max-width: 640px;
  margin: 80px auto 0;
  padding-bottom: calc(20px + constant(safe-area-inset-bottom));
  padding-bottom: calc(20px + env(safe-area-inset-bottom));
}

.wrapper-antenna.isTouch #globalHeaderTouch {
  position: relative;
}

.wrapper-antenna.isTouch #container {
  margin: 0 auto;
}

.wrapper-guide.isPC #container {
  margin: 100px 0 0;
}

.wrapper-guide.isPC #signup {
  margin: 50px 0;
  text-align: center;
}

.wrapper-guide.isPC #signup header {
  margin: 0 0 30px;
}

.wrapper-guide.isPC #signup header h2,.wrapper-guide.isPC #signup header p {
  text-align: center;
  margin: 0;
}

.wrapper-guide.isPC #signup header h2 {
  text-align: center;
  font-size: 30px;
  font-weight: 400;
  letter-spacing: 4px;
}

.wrapper-guide.isPC #signup header p {
  font-size: 18px;
  color: #666;
  margin: 0;
}

.wrapper-guide.isPC #signup header p span {
  display: block;
}

.wrapper-guide.isPC #pager {
  width: 1125px;
  margin: 0 auto 1px;
  padding: 0 30px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.wrapper-guide.isPC #pager p {
  margin: 0;
  width: 50%;
}

.wrapper-guide.isPC #pager a {
  display: block;
  padding: 30px;
  text-decoration: none;
  font-size: 18px;
  font-weight: 700;
}

.wrapper-guide.isPC #pager a i {
  font-weight: 400;
}

.wrapper-guide.isPC #pager-prev a {
  border-top: 1px solid #ddd;
  color: #222;
}

.wrapper-guide.isPC #pager-prev a:focus,.wrapper-guide.isPC #pager-prev a:hover {
  background: #f2f1f0;
  border-top-color: #ddd;
}

.wrapper-guide.isPC #pager-next {
  text-align: right;
}

.wrapper-guide.isPC #pager-next a {
  border-top: 1px solid #4baae0;
}

.wrapper-guide.isPC #pager-next a:focus,.wrapper-guide.isPC #pager-next a:hover {
  background: #4baae0;
  color: #fff;
  border-top-color: #0990cc;
}

.wrapper-guide.isTouch #container {
  max-width: 640px;
  margin: 0 auto;
}

.wrapper-guide.isTouch #container:after,.wrapper-guide.isTouch #container:before {
  content: '';
  display: table;
}

.wrapper-guide.isTouch #container:after {
  clear: both;
}

.wrapper-guide.isTouch #signup {
  text-align: center;
  margin: 24px auto;
  max-width: 640px;
  padding: 0 16px;
  box-sizing: border-box;
}

.wrapper-guide.isTouch #signup header {
  margin: 0 16px 24px;
}

.wrapper-guide.isTouch #signup header h2,.wrapper-guide.isTouch #signup header p {
  text-align: center;
  margin: 0;
}

.wrapper-guide.isTouch #signup header h2 {
  text-align: center;
  font-size: 18px;
  font-weight: 400;
  letter-spacing: 4px;
  line-height: 1.5;
}

.wrapper-guide.isTouch #signup header p {
  font-size: 13px;
  color: #666;
  margin: 0;
}

.wrapper-guide.isTouch #pager {
  max-width: 640px;
  margin: 0 auto 1px;
  border-top: 1px solid #ddd;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

.wrapper-guide.isTouch #pager p {
  margin: 0;
}

.wrapper-guide.isTouch #pager a {
  display: block;
  text-decoration: none;
  font-weight: 700;
}

.wrapper-guide.isTouch #pager a i {
  font-weight: 400;
}

.wrapper-guide.isTouch #pager-prev a {
  color: #222;
  padding: 16px 0 16px 16px;
}

.wrapper-guide.isTouch #pager-next {
  text-align: right;
}

.wrapper-guide.isTouch #pager-next a {
  padding: 16px 16px 16px 0;
}

.wrapper-official.isPC #container {
  width: 1125px;
  padding: 0 30px;
  margin: 130px auto 30px;
}

.wrapper-official.isTouch #container {
  max-width: 640px;
  margin: 80px auto 16px;
}

.wrapper-official.isTouch #container:after,.wrapper-official.isTouch #container:before {
  content: '';
  display: table;
}

.wrapper-official.isTouch #container:after {
  clear: both;
}

.wrapper-userEvent #userEvent-title {
  margin: 0 0 .25em;
  font-size: 28px;
  line-height: 1.2;
}

.wrapper-userEvent #userEvent-title a {
  color: #222;
}

.wrapper-userEvent #userEvent-title a:focus,.wrapper-userEvent #userEvent-title a:hover {
  color: #0990cc;
}

.wrapper-userEvent #userEvent-meta {
  color: #666;
  padding: 0;
  margin: 0;
}

.wrapper-userEvent #userEvent-meta li {
  list-style-type: none;
}

.wrapper-userEvent #userEvent-meta li {
  display: inline-block;
  margin: 0 16px 0 0;
}

.wrapper-userEvent #userEvent-meta a {
  color: #666;
}

.wrapper-userEvent #userEvent-meta a:focus,.wrapper-userEvent #userEvent-meta a:hover {
  color: #0990cc;
}

.wrapper-userEvent #userEvent-editButton {
  margin: 0 0 15px;
  background: #faf7f0;
  border-top: 1px solid #ecdcc1;
  border-bottom: 1px solid #f5eddf;
}

.wrapper-userEvent #userEvent-editButton-inner {
  width: 1125px;
  margin: 0 auto;
  padding: 8px 30px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  color: #8e6938;
  font-weight: 700;
}

.wrapper-userEvent #userEvent-editButton-inner p {
  margin: 0;
}

.wrapper-userEvent.isPC #container {
  margin-top: 100px;
}

.wrapper-userEvent.isTouch #container {
  max-width: 100%!important;
  margin: 80px auto 16px;
}

.wrapper-userEvent.isTouch #userEvent-editButton {
  margin: 0;
}

.wrapper-userEvent.isTouch #userEvent-editButton-inner {
  width: 100%;
  max-width: 640px;
  padding: 8px 10px;
  box-sizing: border-box;
}

.wrapper-userEvent.isTouch #userEvent-editButton-inner .ui-button-default {
  font-size: 12px;
}

.wrapper-userEvent.isTouch #userEvent-editButton-inner p {
  font-size: 11px;
  line-height: 1.3;
}

.wrapper-userEvent.isTouch #userEvent-editButton-inner p:first-child {
  margin: 0 10px 0 0;
}

.wrapper-userEvent.isTouch #userEvent-applyButton {
  max-width: 640px;
  margin: 0 auto;
}

.wrapper-userEvent.isTouch #userEvent-title {
  font-size: 18px;
}

.wrapper-userEvent.isTouch #userEvent-meta {
  font-size: 12px;
}

.wrapper-userEvent.isTouch #userEvent-applyButton {
  padding: 0 16px 16px;
  text-align: center;
}

.wrapper-userEvent.isTouch #userEvent-applyButton .widget-event-applyButton-button {
  margin: 0;
}

.wrapper-userEvent.isTouch #userEvent-applyButton .ui-button-disabled {
  width: 100%;
  padding: 1em 0;
}

.wrapper-userEvent.isTouch #userEvent-applyButton-message {
  color: #666;
  margin: 1em 0 0;
  font-size: 11px;
}

.wrapper-userEvent.isTouch #userEvent-applyButton-message span {
  display: inline-block;
}

.wrapper-userEvent.isTouch #userEvent-aside h2,.wrapper-userEvent.isTouch #userEvent-aside h3 {
  font-size: 11px;
  font-weight: 700;
  margin: 0 0 8px;
  padding: 0 16px 8px!important;
  border-bottom: 1px solid #ddd;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  box-sizing: border-box;
}

.wrapper-userEvent.isTouch #userEvent-aside header {
  margin: 16px 16px 8px;
}

.isPC .works-editButton-edit {
  font-size: 1.25em;
  padding: 0 .5em;
  color: #444;
  -webkit-transition: all .1s linear;
  transition: all .1s linear;
}

.isPC .works-editButton-edit:focus,.isPC .works-editButton-edit:hover {
  color: #222;
}

.widget-my-rewards-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  border-bottom: 1px solid #ddd;
  margin: 0 0 15px;
}

.widget-my-rewards-header h1 {
  padding: 0 0 14px;
}

.widget-my-rewards-header div {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.widget-my-rewards-header p a {
  text-decoration: none;
  padding: 0 14px 24px;
  display: inline-block;
}

.widget-my-rewards-header p a:focus svg path,.widget-my-rewards-header p a:hover svg path {
  fill: #0990cc;
}

.widget-my-rewards-header p svg {
  width: 16px;
  height: 16px;
  vertical-align: middle;
}

.widget-my-rewards-header p svg path {
  fill: #666;
}

.isTouch .widget-my-rewards-header div {
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: reverse;
  -webkit-flex-direction: row-reverse;
  -ms-flex-direction: row-reverse;
  flex-direction: row-reverse;
  width: 100%;
}

.isTouch .widget-my-rewards-header p {
  height: 44px;
  line-height: 44px!important;
}

.isTouch .widget-my-rewards-header p a {
  padding: 0 14px;
}

.isTouch .widget-my-rewards-header li:first-child a {
  padding-left: 15px;
}

.isTouch .widget-my-rewards-header li a span {
  height: 44px;
  line-height: 44px;
}

.isPC .widget-work {
  padding: 15px 0;
  border-bottom: 1px solid #ddd;
  position: relative;
}

.isPC .widget-work:after,.isPC .widget-work:before {
  content: '';
  display: table;
}

.isPC .widget-work:after {
  clear: both;
}

.isPC .widget-work .float-left {
  width: calc(100% - (300px + 30px));
  padding: 0 0 0 40px;
  box-sizing: border-box;
}

.isPC .widget-work .float-right {
  width: 300px;
}

.isTouch .widget-work {
  border-bottom: 1px solid #ddd;
  padding: 14px 16px 14px 56px;
  margin-left: 16px;
  position: relative;
}

.isTouch .widget-work:after,.isTouch .widget-work:before {
  content: '';
  display: table;
}

.isTouch .widget-work:after {
  clear: both;
}

.isTouch .widget-work .float-left,.isTouch .widget-work .float-right {
  width: 100%;
  float: none;
}

.isTouch .widget-work .widget-work-reviews .widget-catchphrase {
  border-bottom: 1px dotted #ddd;
  width: calc(100% + 16px);
  padding: 0 16px 4px 0;
  box-sizing: border-box;
}

.isTouch .widget-work .widget-work-reviews .widget-catchphrase:last-child {
  margin-bottom: 12px;
}

.isTouch .widget-work .widget-work-reviews .widget-catchphrase+.widget-catchphrase {
  padding: 4px 16px 4px 0;
}

.isTouch .widget-work .widget-work-reviews .widget-catchphrase-title {
  font-size: 13px;
}

.isTouch .widget-work h3,.isTouch .widget-work p {
  margin: 0;
  line-height: 1.5;
}

.isTouch .widget-work .widget-work-title {
  font-size: 11px;
  font-weight: 400;
  margin-bottom: 4px;
}

.isTouch .widget-work .widget-work-title a {
  text-decoration: none;
}

.isTouch .widget-work .widget-work-titleLabel {
  color: #222;
}

.isTouch .widget-work .widget-work-author {
  font-weight: 400;
  color: #999;
}

.isTouch .widget-work .widget-work-meta {
  color: #888;
  font-size: 13px;
  line-height: 1.25;
}

.isTouch .widget-work .widget-work-meta:after,.isTouch .widget-work .widget-work-meta:before {
  content: '';
  display: table;
}

.isTouch .widget-work .widget-work-meta:after {
  clear: both;
}

.isTouch .widget-work .widget-work-meta a {
  color: #888;
}

.isTouch .widget-work .widget-work-meta a:hover {
  color: #0081c2;
}

.isTouch .widget-work .widget-work-meta i {
  color: #aaa;
}

.isTouch .widget-work .widget-work-meta>span {
  padding: 0 14px 0 0;
  position: relative;
  float: left;
}

.isTouch .widget-work .widget-work-meta>span:after {
  content: '';
  display: inline-block;
  position: absolute;
  right: 5px;
  top: 50%;
  margin: -2px 0 0;
  width: 4px;
  height: 4px;
  background: #ddd;
  border-radius: 50%;
}

.isTouch .widget-work .widget-work-meta>span:last-child:after {
  display: none;
  padding: 0;
}

.isTouch .widget-work .widget-work-introduction {
  font-size: 11px;
  margin-bottom: 6px;
}

.isTouch .widget-work .widget-work-introduction a {
  color: #999;
}

.isTouch .widget-work .widget-work-summary {
  margin: 8px 0 0;
}

.isTouch .widget-work .widget-work-tags {
  font-size: 11px;
  display: block;
  position: relative;
  padding-left: 16px;
  font-weight: 400;
}

.isTouch .widget-work .widget-work-tags a:first-child:before,.isTouch .widget-work .widget-work-tags span:first-child:before {
  content: "-";
  color: #999;
  display: inline;
  position: absolute;
  left: 0;
}

.isTouch .widget-work .widget-work-tags a {
  color: #222;
  text-decoration: none;
}

.isTouch .widget-work .widget-work-tags a:after {
  content: " / ";
  color: #ccc;
}

.isTouch .widget-work .widget-work-tags a:last-child:after {
  display: none;
}

.isTouch .widget-work .widget-work-tags a:hover {
  color: #0081c2;
}

.isPC #widget-user-header #user-profile {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  padding: 30px 0;
}

.isPC #widget-user-header #user-description {
  max-width: 600px;
}

.isPC #widget-user-header #user-meta {
  color: #666;
  line-height: 1;
  margin: 0 0 30px;
}

.isPC #widget-user-header #user-meta p {
  display: inline-block;
  margin: 0;
  padding: 0 0 0 30px;
  position: relative;
}

.isPC #widget-user-header #user-meta p:before {
  content: '';
  display: block;
  width: 6px;
  height: 6px;
  border-radius: 50%;
  position: absolute;
  top: 50%;
  left: 12px;
  margin: -3px 0 0 0;
  background: #ddd;
}

.isPC #widget-user-header #user-meta p:first-child {
  margin: 0;
  padding: 0;
}

.isPC #widget-user-header #user-meta p:first-child:before {
  display: none;
}

.isPC #widget-user-header #user-meta a {
  color: #666;
}

.isPC #widget-user-header #user-meta a:hover {
  color: #0081c2;
}

.isTouch #widget-user-header #user-profile {
  margin: 16px 16px 0;
}

.isTouch #widget-user-header #user-profile-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

.isTouch #widget-user-header #user-description {
  margin: 12px 0 0;
}

.isTouch #widget-user-header #user-meta {
  line-height: 1.5;
  font-size: 12px;
}

.isTouch #widget-user-header #user-meta p {
  margin: 0;
}

.isTouch #widget-user-header #user-meta a {
  color: #999;
  margin: 0;
}

.isPC .widget-catchphrase {
  line-height: 1.4;
}

.isPC .widget-catchphrase:first-child {
  padding: 5px 0 10px;
  border-bottom: 1px solid #eee;
}

.isPC .widget-catchphrase:last-child {
  padding: 10px 0 0;
  border: none;
}

.isPC .widget-catchphrase h4,.isPC .widget-catchphrase p {
  margin: 0;
}

.isPC .widget-catchphrase .widget-catchphrase-title {
  font-size: 1.5em;
  line-height: 1.2;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  display: inline;
  letter-spacing: -.25px;
}

.isPC .widget-catchphrase .widget-catchphrase-title a {
  text-decoration: none;
}

.isPC .widget-catchphrase .widget-catchphrase-author {
  position: relative;
  -webkit-transform: translateY(-.275em);
  transform: translateY(-.275em);
  display: inline-block;
  font-size: .85em;
}

.isPC .widget-catchphrase .widget-catchphrase-author a {
  text-decoration: none;
}

.isPC .widget-catchphrase .widget-catchphrase-author a:hover {
  border-bottom: 1px solid #aaa;
}

.isPC .widget-catchphrase .widget-catchphrase-author-dash {
  position: relative;
  width: 2.25em;
  height: 1em;
  display: inline-block;
}

.isPC .widget-catchphrase .widget-catchphrase-author-dash:before {
  content: '';
  position: absolute;
  top: 50%;
  left: 0;
  width: 2em;
  height: 0;
  display: inline-block;
  margin: 1px 0 0;
  border-top: 1px solid;
}

.isTouch .widget-catchphrase {
  line-height: 1.3;
}

.isTouch .widget-catchphrase:first-child {
  border-top: none;
  padding-top: 0;
}

.isTouch .widget-catchphrase:last-child {
  padding-bottom: 0;
}

.isTouch .widget-catchphrase h4,.isTouch .widget-catchphrase p {
  margin: 0;
}

.isTouch .widget-catchphrase .widget-catchphrase-title {
  font-size: 15px;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  font-weight: 700;
  display: inline;
}

.isTouch .widget-catchphrase .widget-catchphrase-title a {
  text-decoration: none;
}

.isTouch .widget-catchphrase .widget-catchphrase-author {
  position: relative;
  padding: 0;
  -webkit-transform: translateY(-.275em);
  transform: translateY(-.275em);
  display: inline;
  font-size: 11px;
}

.isTouch .widget-catchphrase .widget-catchphrase-author a {
  text-decoration: none;
}

.isTouch .widget-catchphrase .widget-catchphrase-author-dash {
  position: relative;
  width: 2.25em;
  height: 1em;
  display: inline-block;
}

.isTouch .widget-catchphrase .widget-catchphrase-author-dash:before {
  content: '';
  position: absolute;
  top: 50%;
  left: 0;
  width: 2em;
  height: 0;
  display: inline-block;
  border-top: 1px solid;
}

.isTouch .widget-catchphrase .widget-catchphrase-author-reviewCount {
  display: none;
}

@media all and (-ms-high-contrast:none) {
  ::-ms-backdrop {
    opacity: .3;
  }
}

@media all and (-ms-high-contrast:none) {
  ::-ms-backdrop {
    opacity: .8;
  }
}

.isPC .widget-works-work-navigation {
  max-width: 1125px;
  margin: 140px auto 0;
}

.isPC .widget-works-work-navigation dd,.isPC .widget-works-work-navigation dt {
  float: left;
  margin: 0;
}

.isPC .widget-works-work-navigation #workTitle {
  margin: 0;
  line-height: 1.3;
}

.isPC .widget-works-work-navigation #workTitle a {
  color: #222;
}

.isPC .widget-works-work-navigation #workTitle a:hover {
  color: #0081c2;
}

.isPC .widget-works-work-navigation #workTitle {
  line-height: 1.2;
  font-size: 1.75em;
}

.isPC .widget-works-work-navigation .ui-tab li:first-child {
  margin-left: .25em;
}

.isTouch .widget-works-work-navigation {
  padding: 0 16px;
}

.isTouch .widget-works-work-navigation #workTitle {
  margin: 0;
  line-height: 1.3;
}

.isTouch .widget-works-work-navigation #workTitle a {
  color: #222;
}

.isTouch .widget-works-work-navigation #workTitle a:hover {
  color: #0081c2;
}

.isTouch .widget-works-work-navigation #workTitle {
  line-height: 1.2;
  font-size: 16px;
  margin: 8px 0 4px;
}

.isTouch .widget-works-work-navigation .ui-tab {
  margin-top: 16px!important;
}

.isTouch .widget-works-work-navigation .ui-tab li:first-child {
  margin: 0;
}

.isTouch .widget-works-work-navigation .ui-tab li:first-child a {
  padding-left: 0;
}

.widget-episode {
  margin: 30px auto 60px;
  font-size: 17.5px;
  text-align: center;
}

@media screen and (max-width:640px) {
  .widget-episode {
    font-size: 16px;
  }
}

.widget-episode-inner {
  text-align: left;
  display: inline-block;
  max-width: 665px;
}

@media screen and (max-width:705px) {
  .widget-episode-inner {
    max-width: 100%;
  }
}

.widget-episodeTitle {
  font-size: 1.75em;
  color: #0081c2;
  vertical-align: top;
  line-height: 1.3em;
  font-weight: 400;
  background: #fff;
  margin: 0 auto 1em;
  max-width: 665px;
}

.widget-episodeTitle::-webkit-input-placeholder {
  color: #4baae0;
}

.widget-episodeTitle:-moz-placeholder {
  color: #4baae0;
  line-height: 1.3em;
}

.widget-episodeTitle::-moz-placeholder {
  color: #4baae0;
  line-height: 1.3em;
}

.widget-episodeTitle:-ms-input-placeholder {
  color: #4baae0;
}

@media screen and (max-width:640px) {
  .widget-episodeTitle {
    padding: 0 0 10px;
  }
}

.widget-episodeBody {
  line-height: 1.8;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,'HGS明朝B','HG明朝B',dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  font-size: 1em;
  padding: 15px 0 0;
}

.widget-episodeBody p {
  margin: 0;
}

.isTouch .widget-episode {
  font-size: 16px;
}

.writingDirection-vertical .widget-episode {
  margin: auto 30px auto 60px;
  font-size: 17.5px;
  text-align: center;
}

.writingDirection-vertical .widget-episode-inner {
  max-width: 100%;
  max-height: 665px;
}

@media screen and (max-height:745px) {
  .writingDirection-vertical .widget-episode-inner {
    max-height: 100%;
  }
}

.writingDirection-vertical .widget-episodeBody {
  padding: 0 15px 0 0;
}

.widget-episodeStatusLabel-published {
  font-weight: 700;
  font-size: 10px;
  width: 55px;
  border-radius: 2px;
  display: inline-block;
  text-align: center;
  background: #4baae0;
  color: #fff;
  vertical-align: top;
  height: 16px;
  line-height: 16px;
}

.widget-episodeStatusLabel-draft {
  font-weight: 700;
  font-size: 10px;
  width: 55px;
  border-radius: 2px;
  display: inline-block;
  text-align: center;
  background: #eee;
  color: #999;
  vertical-align: top;
  height: 16px;
  line-height: 16px;
}

.widget-episodeStatusLabel-reserved {
  font-weight: 700;
  font-size: 10px;
  width: 55px;
  border-radius: 2px;
  display: inline-block;
  text-align: center;
  background: #ffb318;
  color: #fff;
  vertical-align: top;
  height: 16px;
  line-height: 16px;
}

.widget-episodeStatusLabel-hidden {
  font-weight: 700;
  font-size: 10px;
  width: 55px;
  border-radius: 2px;
  display: inline-block;
  text-align: center;
  background: #f23e48;
  color: #fff;
  vertical-align: top;
  height: 16px;
  line-height: 16px;
}

.isPC .widget-pager {
  margin: 0 0 30px;
}

.isPC .widget-pager:after,.isPC .widget-pager:before {
  content: '';
  display: table;
}

.isPC .widget-pager:after {
  clear: both;
}

.isPC .widget-pager p {
  width: 50%;
  box-sizing: border-box;
  padding: 0 30px;
}

.isPC .widget-pager a {
  font-size: 1.25em;
  line-height: 1.3;
  font-weight: 700;
}

.isPC .widget-pager a i {
  font-weight: 400;
  margin: 0 .5em;
}

.isTouch .widget-pager:after,.isTouch .widget-pager:before {
  content: '';
  display: table;
}

.isTouch .widget-pager:after {
  clear: both;
}

.isTouch .widget-pager p {
  box-sizing: border-box;
  margin: 1em 0;
}

.isTouch .widget-pager a {
  font-size: 15px;
  line-height: 1.3;
  font-weight: 700;
}

.isTouch .widget-pager a i {
  font-weight: 400;
  margin: 0 .5em;
}

.isPC .widget-antenna-signUp-message {
  margin: 0 0 15px 0;
  padding: 20px 20px 20px 0;
  background: #f2f1f0;
  position: relative;
  border: 2px solid #ddd;
}

.isPC .widget-antenna-signUp-message:after,.isPC .widget-antenna-signUp-message:before {
  content: '';
  display: table;
}

.isPC .widget-antenna-signUp-message:after {
  clear: both;
}

.isPC .widget-antenna-signUp-message-icon {
  font-size: 4.5em;
  color: #ccc;
  line-height: 1;
  margin: 0;
  width: 110px;
  padding: 0 0 0 10px;
  float: left;
  text-align: center;
}

.isPC .widget-antenna-signUp-message-body {
  width: calc(100% - 120px);
  float: right;
}

.isPC .widget-antenna-signUp-message-body h3,.isPC .widget-antenna-signUp-message-body p {
  line-height: 1.5;
  margin: 0;
}

.isPC .widget-antenna-signUp-message-body h3 {
  font-size: 1.5em;
}

.isPC .widget-antenna-signUp-message-body a {
  text-decoration: underline;
}

.isPC .widget-antenna-signUp-message-body .widget-antenna-signUp-message-button {
  margin: 1em 0 0;
}

.isPC .widget-antenna-signUp-message-body .ui-button-blue {
  color: #fff;
  font-size: 1.25em;
}

.isTouch .widget-antenna-signUp-message {
  z-index: 30000;
  margin: 0;
  padding: 16px 16px 16px 0;
  background: #f2f1f0;
  position: relative;
  border: 2px solid #4baae0;
  position: fixed;
  bottom: 20px;
  left: 50%;
  -webkit-transform: translateX(-50%);
  transform: translateX(-50%);
  width: calc(100% - 40px);
  box-sizing: border-box;
  max-width: 600px;
}

.isTouch .widget-antenna-signUp-message:after,.isTouch .widget-antenna-signUp-message:before {
  content: '';
  display: table;
}

.isTouch .widget-antenna-signUp-message:after {
  clear: both;
}

.isTouch .widget-antenna-signUp-message-icon {
  font-size: 1.5em;
  color: #888;
  line-height: 1;
  margin: 0;
  width: 50px;
  padding: 0 0 0 10px;
  float: left;
  text-align: center;
}

.isTouch .widget-antenna-signUp-message-body {
  width: calc(100% - 60px);
  float: right;
}

.isTouch .widget-antenna-signUp-message-body h3,.isTouch .widget-antenna-signUp-message-body p {
  line-height: 1.5;
  margin: 0;
}

.isTouch .widget-antenna-signUp-message-body h3 {
  font-size: 1.1em;
}

.isTouch .widget-antenna-signUp-message-body .widget-antenna-signUp-message-message {
  font-size: .9em;
  margin: .5em 0 0;
}

.isTouch .widget-antenna-signUp-message-body .widget-antenna-signUp-message-button {
  margin: 1em 0 0;
}

.isTouch .widget-antenna-signUp-message-body .ui-button-blue {
  color: #fff;
  font-size: 1.1em;
}

.isPC .widget-workTitle {
  position: relative;
}

.isPC .widget-workTitle:last-child {
  padding-bottom: 0;
}

.isPC .widget-workTitle .widget-workTitle-title {
  margin: 0 0 .25em;
  font-size: 1.25em;
  line-height: 1.2;
  width: 100%;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  font-weight: 400;
  color: #888;
}

.isPC .widget-workTitle .widget-workTitle-title a {
  text-decoration: none;
  border-bottom: 1px solid transparent;
  display: inline-block;
}

.isPC .widget-workTitle .widget-workTitle-title a:focus,.isPC .widget-workTitle .widget-workTitle-title a:hover {
  border-bottom-color: #4baae0!important;
  color: #0081c2;
}

.isPC .widget-workTitle .widget-workTitle-titleLabel {
  color: #222;
  font-weight: 700;
}

.isPC .widget-workTitle .widget-workTitle-author {
  font-weight: 400;
  color: #555;
}

.isPC .widget-workTitle .widget-workTitle-author .icon-official {
  color: #bbb;
}

.isPC .widget-workTitle .widget-workTitle-meta {
  margin: 0;
  color: #666;
  font-size: .9em;
  line-height: 1.25;
}

.isPC .widget-workTitle .widget-workTitle-meta:after,.isPC .widget-workTitle .widget-workTitle-meta:before {
  content: '';
  display: table;
}

.isPC .widget-workTitle .widget-workTitle-meta:after {
  clear: both;
}

.isPC .widget-workTitle .widget-workTitle-meta a {
  color: #888;
}

.isPC .widget-workTitle .widget-workTitle-meta a:hover {
  color: #0081c2;
}

.isPC .widget-workTitle .widget-workTitle-meta i {
  color: #aaa;
}

.isPC .widget-workTitle .widget-workTitle-meta>span,.isPC .widget-workTitle .widget-workTitle-meta>time {
  padding: 0 14px 0 0;
  position: relative;
  float: left;
}

.isPC .widget-workTitle .widget-workTitle-meta>span:after,.isPC .widget-workTitle .widget-workTitle-meta>time:after {
  content: '';
  display: inline-block;
  position: absolute;
  right: 5px;
  top: 50%;
  margin: -2px 0 0;
  width: 4px;
  height: 4px;
  background: #ddd;
  border-radius: 50%;
}

.isPC .widget-workTitle .widget-workTitle-meta>span:last-child:after,.isPC .widget-workTitle .widget-workTitle-meta>time:last-child:after {
  display: none;
  padding: 0;
}

.isTouch .widget-workTitle {
  position: relative;
}

.isTouch .widget-workTitle .widget-workTitle-title {
  margin: 0 0 6px;
  font-size: 13px;
  line-height: 1.3;
}

.isTouch .widget-workTitle .widget-workTitle-title a {
  text-decoration: none;
}

.isTouch .widget-workTitle .widget-workTitle-title a:hover {
  border-bottom: 1px solid #aaa;
}

.isTouch .widget-workTitle .widget-workTitle-titleLabel {
  color: #222;
}

.isTouch .widget-workTitle .widget-workTitle-author {
  font-weight: 400;
  color: #666;
}

.isTouch .widget-workTitle .widget-workTitle-author a {
  color: #666;
}

.isTouch .widget-workTitle .widget-workTitle-author .icon-official {
  color: #bbb;
}

.isTouch .widget-workTitle .widget-workTitle-meta {
  margin: 0;
  color: #666;
  font-size: 11px;
  line-height: 1.3;
}

.isTouch .widget-workTitle .widget-workTitle-meta:after,.isTouch .widget-workTitle .widget-workTitle-meta:before {
  content: '';
  display: table;
}

.isTouch .widget-workTitle .widget-workTitle-meta:after {
  clear: both;
}

.isTouch .widget-workTitle .widget-workTitle-meta a {
  color: #666;
}

.isTouch .widget-workTitle .widget-workTitle-meta a:hover {
  color: #0081c2;
}

.isTouch .widget-workTitle .widget-workTitle-meta i {
  color: #666;
}

.isTouch .widget-workTitle .widget-workTitle-meta>span,.isTouch .widget-workTitle .widget-workTitle-meta>time {
  padding: 0 14px 0 0;
  position: relative;
  float: left;
}

.isTouch .widget-workTitle .widget-workTitle-meta>span:after,.isTouch .widget-workTitle .widget-workTitle-meta>time:after {
  content: '';
  display: inline-block;
  position: absolute;
  right: 5px;
  top: 50%;
  margin: -2px 0 0;
  width: 4px;
  height: 4px;
  background: #ddd;
  border-radius: 50%;
}

.isTouch .widget-workTitle .widget-workTitle-meta>span:last-child:after,.isTouch .widget-workTitle .widget-workTitle-meta>time:last-child:after {
  display: none;
  padding: 0;
}

.isPC .widget-official .widget-official-header h3,.isPC .widget-official .widget-official-header p {
  margin: 0;
  line-height: 1.3;
}

.isPC .widget-official .float-left {
  width: 70px;
}

.isPC .widget-official .float-right {
  float: right;
  width: calc(100% - 85px);
}

.isPC .widget-official .widget-official-header-logo {
  width: 70px;
  height: 70px;
  text-align: center;
}

.isPC .widget-official .widget-official-header-logo a {
  display: block;
}

.isPC .widget-official .widget-official-header-logo img {
  max-width: 100%;
  max-height: 100%;
  vertical-align: top;
  border: 1px solid #ddd;
  box-sizing: border-box;
}

.isPC .widget-official .widget-official-header-right:after,.isPC .widget-official .widget-official-header-right:before {
  content: '';
  display: table;
}

.isPC .widget-official .widget-official-header-right:after {
  clear: both;
}

.isPC .widget-official .widget-official-header-name {
  float: left;
  margin: 0 0 .5em!important;
  width: calc(100% - 125px);
}

.isPC .widget-official .widget-official-header-name a {
  display: block;
  text-decoration: none;
}

.isPC .widget-official .widget-official-header-profile {
  font-size: .95em;
  line-height: 1.4!important;
  color: #555;
}

.isTouch .widget-official .widget-official-header {
  margin-left: 16px;
}

.isTouch .widget-official .widget-official-header h3,.isTouch .widget-official .widget-official-header p {
  margin: 0;
  line-height: 1.3;
}

.isTouch .widget-official .float-left {
  width: 72px;
  float: left;
}

.isTouch .widget-official .float-right {
  float: right;
  width: calc(100% - 88px);
}

.isTouch .widget-official .widget-official-header-logo {
  width: 100%;
}

.isTouch .widget-official .widget-official-header-logo img {
  max-width: 100%;
  max-height: 100%;
}

.isTouch .widget-official .widget-official-header-right:after,.isTouch .widget-official .widget-official-header-right:before {
  content: '';
  display: table;
}

.isTouch .widget-official .widget-official-header-right:after {
  clear: both;
}

.isTouch .widget-official .widget-official-header-name {
  padding-right: 16px;
}

.isTouch .widget-official .widget-official-header-name a {
  display: block;
  text-decoration: none;
}

.isTouch .widget-official .widget-official-header-profile {
  font-size: 12px;
  line-height: 1.5!important;
  color: #999;
  padding-right: 16px;
}

.isPC .widget-official-item .widget-official-item-content {
  margin: 15px 0 0 85px;
}

.isPC .widget-official-item .widget-workTitle {
  border-top: 1px solid #eee;
  padding: 10px 0 10px 0;
}

.isPC .widget-official-item .widget-workTitle-author {
  display: none;
}

.isPC .widget-official-content-recent:after,.isPC .widget-official-content-recent:before {
  content: '';
  display: table;
}

.isPC .widget-official-content-recent:after {
  clear: both;
}

.isPC .widget-official-content-recent .widget-official-item {
  float: left;
  width: calc(33.33333% - 30px);
  margin: 30px 0 0 45px;
}

.isPC .widget-official-content-recent .widget-official-item:nth-child(3n+1) {
  margin-left: 0;
  clear: both;
}

.isPC .widget-official-content-recent .widget-official-item-content ul {
  padding: 0;
  margin-bottom: 0;
}

.isPC .widget-official-content-recent .widget-official-item-content ul li {
  list-style-type: none;
}

.isPC .widget-official-content-recent .widget-workTitle-title {
  font-size: 1.1em;
}

.isTouch .widget-official-item {
  margin-bottom: 16px;
}

.isTouch .widget-official-item .widget-official-item-content {
  margin: 16px 0 0 16px;
}

.isTouch .widget-official-item .widget-official-item-content .widget-workTitle {
  border-top: 1px solid #ddd;
  padding: 12px 16px 10px 0;
  margin: 0 0 0 88px;
}

.isTouch .widget-official-item .widget-official-item-content .widget-workTitle .widget-workTitle-title {
  margin-bottom: 4px;
}

.isTouch .widget-official-item .widget-workTitle-author {
  display: none;
}

.isTouch .widget-official-content-recent .widget-official-item-content ul {
  padding: 0;
  margin-bottom: 0;
}

.isTouch .widget-official-content-recent .widget-official-item-content ul li {
  list-style-type: none;
}

.isTouch .widget-official-content-recent .widget-official-item-content li {
  position: relative;
  margin: 0 0 .5em;
}

.isPC .widget-official-publication ul {
  padding: 0;
  margin: 0;
}

.isPC .widget-official-publication ul li {
  list-style-type: none;
}

.isPC .widget-official-publication ul a {
  display: block;
  padding: 14px 0;
  color: #222;
  text-decoration: none;
}

.isPC .widget-official-publication ul a:after,.isPC .widget-official-publication ul a:before {
  content: '';
  display: table;
}

.isPC .widget-official-publication ul a:after {
  clear: both;
}

.isPC .widget-official-publication ul a:focus h3,.isPC .widget-official-publication ul a:hover h3 {
  text-decoration: underline;
}

.isPC .widget-official-publication ul div {
  width: calc(100% - 116px);
  float: right;
}

.isPC .widget-official-publication ul h3,.isPC .widget-official-publication ul p {
  margin: 0;
  line-height: 1.3;
}

.isPC .widget-official-publication ul h3 {
  font-size: 13px;
  margin: 8px 0;
}

.isPC .widget-official-publication ul p {
  font-size: 11.5px;
  color: #666;
  margin: 2.5px 0 0;
}

.isPC .widget-official-publication ul img {
  max-width: 100%;
  vertical-align: top;
  border: 1px solid #222;
}

.isTouch .widget-official-publication ul {
  padding: 0;
  margin: 0;
  padding: 2px 0 0;
}

.isTouch .widget-official-publication ul li {
  list-style-type: none;
}

.isTouch .widget-official-publication li:nth-child(1),.isTouch .widget-official-publication li:nth-child(2) {
  float: left;
  width: calc(50% - 1px);
}

.isTouch .widget-official-publication li:nth-child(1) a,.isTouch .widget-official-publication li:nth-child(2) a {
  padding: 0 0 14px;
}

.isTouch .widget-official-publication li:nth-child(1) img,.isTouch .widget-official-publication li:nth-child(2) img {
  max-height: 170px;
}

@media screen and (max-width:420px) {
  .isTouch .widget-official-publication li:nth-child(1) img,  .isTouch .widget-official-publication li:nth-child(2) img {
    max-height: 133px;
  }
}

.isTouch .widget-official-publication li:nth-child(1) div,.isTouch .widget-official-publication li:nth-child(2) div {
  margin: 8px 12px 0 16px;
}

.isTouch .widget-official-publication li:nth-child(1) {
  margin: 0 2px 0 0;
}

.isTouch .widget-official-publication li:nth-child(3),.isTouch .widget-official-publication li:nth-child(4),.isTouch .widget-official-publication li:nth-child(5),.isTouch .widget-official-publication li:nth-child(6) {
  margin: 0 0 0 16px;
  border-bottom: 1px solid #ddd;
}

.isTouch .widget-official-publication li:nth-child(3) a,.isTouch .widget-official-publication li:nth-child(4) a,.isTouch .widget-official-publication li:nth-child(5) a,.isTouch .widget-official-publication li:nth-child(6) a {
  padding: 14px 16px 14px 0;
}

.isTouch .widget-official-publication li:nth-child(3) img,.isTouch .widget-official-publication li:nth-child(4) img,.isTouch .widget-official-publication li:nth-child(5) img,.isTouch .widget-official-publication li:nth-child(6) img {
  max-width: 46px;
}

.isTouch .widget-official-publication li:nth-child(3) div,.isTouch .widget-official-publication li:nth-child(4) div,.isTouch .widget-official-publication li:nth-child(5) div,.isTouch .widget-official-publication li:nth-child(6) div {
  margin: 0 0 0 60px;
}

.isTouch .widget-official-publication li:nth-child(3) {
  clear: both;
  border-top: 1px solid #ddd;
}

.isTouch .widget-official-publication li a {
  display: block;
  position: relative;
  min-height: 60px;
  color: #222;
  text-decoration: none;
}

.isTouch .widget-official-publication li h3,.isTouch .widget-official-publication li p {
  margin: 0;
  line-height: 1.3;
}

.isTouch .widget-official-publication li h3 {
  font-size: 13px;
  margin: 8px 0;
}

.isTouch .widget-official-publication li p {
  font-size: 11.5px;
  color: #666;
  margin: 2.5px 0 0;
}

.isTouch .widget-official-publication li img {
  vertical-align: top;
  border: 1px solid #222;
  box-sizing: border-box;
}

.widget-shareButtons>div,.widget-shareButtons>iframe {
  margin: 0 5px 0 0;
}

.widget-shareButtons>div:last-child,.widget-shareButtons>iframe:last-child {
  margin: 0;
}

.widget-shareButtons>div {
  vertical-align: top;
  display: inline-block!important;
}

.widget-shareButtons>div>span {
  vertical-align: top!important;
}

.widget-feedList .heading-level5 {
  margin: 0;
}

.isPC .widget-feedList-list {
  padding: 0;
  margin: 0;
}

.isPC .widget-feedList-list li {
  list-style-type: none;
}

.isPC .widget-feedList-list li {
  border-bottom: 1px solid #ddd;
}

.isPC .widget-feedList-list a {
  display: block;
  padding: 10px 0;
  line-height: 1.5;
}

.isPC .widget-feedList-list a:focus,.isPC .widget-feedList-list a:hover {
  text-decoration: none;
}

.isPC .widget-feedList-list a:focus h3,.isPC .widget-feedList-list a:hover h3 {
  text-decoration: underline;
}

.isPC .widget-feedList-list time {
  color: #888;
  line-height: 1;
}

.isPC .widget-feedList-list h3 {
  margin: 0;
  font-size: 1em;
  line-height: 1.5;
  color: #222;
}

.isTouch .widget-feedList-list {
  padding: 0;
  margin: 0;
}

.isTouch .widget-feedList-list li {
  list-style-type: none;
}

.isTouch .widget-feedList-list li {
  border-bottom: 1px solid #ddd;
  margin: 0 0 0 16px;
}

.isTouch .widget-feedList-list a {
  display: block;
  line-height: 1.5;
  padding: 10px 16px 10px 0;
}

.isTouch .widget-feedList-list a:focus,.isTouch .widget-feedList-list a:hover {
  text-decoration: none;
}

.isTouch .widget-feedList-list a:focus h3,.isTouch .widget-feedList-list a:hover h3 {
  text-decoration: underline;
}

.isTouch .widget-feedList-list time {
  color: #888;
  line-height: 1;
  font-size: 11px;
}

.isTouch .widget-feedList-list h3 {
  margin: 0;
  font-size: 13px;
  line-height: 1.5;
  color: #222;
}

.isPC .widget-event-applyButton {
  background: #f2f1f0;
  padding: 15px;
}

.isPC .widget-event-applyButton h4 {
  margin: 0;
  line-height: 1.3;
  font-size: 1.1em;
}

.isPC .widget-event-applyButton-alternate,.isPC .widget-event-applyButton-button {
  text-align: center;
}

.isPC .widget-event-applyButton-description {
  line-height: 1.5;
  margin: .5em 0 0;
  font-size: .9em;
  color: #444;
}

.isPC .widget-event-applyButton-button {
  margin: .5em 0;
}

.isPC .widget-event-applyButton-button .ui-button-blue {
  width: 100%;
  box-sizing: border-box;
  font-size: 1.1em;
  padding: .75em 0;
}

.isPC .widget-event-applyButton-alternate {
  margin: 0;
  font-size: .9em;
}

.isPC .widget-event-applyButton-message {
  background: #fff;
  text-align: center;
  padding: .75em 1em;
  line-height: 1.3;
  margin: .5em 0 0;
}

.isPC .widget-event-applyButton-message p {
  margin: .5em 0 0;
}

.isTouch .widget-event-applyButton {
  background: #f2f1f0;
  padding: 15px;
}

.isTouch .widget-event-applyButton h4 {
  margin: 0;
  line-height: 1.3;
  font-size: 1em;
}

.isTouch .widget-event-applyButton-alternate,.isTouch .widget-event-applyButton-button {
  text-align: center;
}

.isTouch .widget-event-applyButton-description {
  line-height: 1.5;
  margin: .5em 0 0;
  font-size: 11px;
  color: #444;
}

.isTouch .widget-event-applyButton-button {
  margin: .5em 0;
}

.isTouch .widget-event-applyButton-button .ui-button-blue,.isTouch .widget-event-applyButton-button .ui-button-default {
  width: 100%;
  box-sizing: border-box;
  font-size: 1em;
  padding: 1em 0;
}

.isTouch .widget-event-applyButton-alternate {
  margin: 0;
  font-size: 11px;
}

.isTouch .widget-event-applyButton-message {
  background: #fff;
  text-align: center;
  padding: .75em 1em;
  line-height: 1.3;
  margin: .5em 0 0;
}

.isTouch .widget-event-applyButton-message p {
  margin: .5em 0 0;
}

.widget-displaySetting h4 {
  margin: 15px 0 7.5px;
  font-size: 11.5px!important;
  font-weight: 400;
  line-height: 1;
}

.widget-displaySetting ul {
  margin: 0;
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,'HGS明朝B','HG明朝B',dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

.widget-displaySetting li {
  list-style-type: none;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  border: solid #ddd;
  border-width: 1px 0 1px 1px;
}

.widget-displaySetting li:first-child {
  border-radius: 3px 0 0 3px;
}

.widget-displaySetting li:last-child {
  border-width: 1px;
  border-radius: 0 3px 3px 0;
}

.widget-displaySetting li:hover {
  border-color: #222!important;
}

.widget-displaySetting li:hover+li {
  border-left-color: #222;
}

.widget-displaySetting li:hover+li.isActive {
  border-left-color: #222!important;
}

.widget-displaySetting li.isActive {
  border-color: #4baae0!important;
}

.widget-displaySetting li.isActive+li {
  border-left-color: #4baae0;
}

.widget-displaySetting li label {
  display: block;
  text-align: center;
  cursor: pointer;
  height: 45px;
  line-height: 45px;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  white-space: nowrap;
}

.widget-displaySetting li input {
  position: absolute;
  top: 0;
  left: 0;
  opacity: 0;
}

.widget-displaySetting-fontSize ul {
  font-size: 17.5px;
}

.widget-displaySetting-fontSize-small label {
  font-size: .88em;
}

.widget-displaySetting-fontSize-medium label {
  font-size: 1em;
}

.widget-displaySetting-fontSize-large label {
  font-size: 1.15em;
}

.widget-displaySetting-fontSize-xLarge label {
  font-size: 1.3em;
}

.widget-displaySetting-bgColor-white {
  padding: 1px;
}

.widget-displaySetting-bgColor-white label {
  background: #fff;
  color: #222;
}

.widget-displaySetting-bgColor-black {
  padding: 1px;
}

.widget-displaySetting-bgColor-black label {
  background: #171b1d;
  color: #f0f0f0;
}

.widget-displaySetting-bgColor-kinari {
  padding: 1px;
}

.widget-displaySetting-bgColor-kinari label {
  background: #f7f6eb;
  color: #292826;
}

.widget-displaySetting-bgColor-blue {
  padding: 1px;
}

.widget-displaySetting-bgColor-blue label {
  background: #dfecf4;
  color: #262829;
}

.widget-displaySetting-fontFamily-serif {
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,'HGS明朝B','HG明朝B',dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

.widget-displaySetting-fontFamily-sans {
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

.widget-displaySetting-fontFamily-warning {
  font-size: 11px;
  color: #666;
  margin: 0;
  line-height: 1.3;
}

.widget-displaySetting-fontFamily-warning.isHidden {
  display: none;
}

.widget-notification {
  margin: 0 auto;
  padding: 0;
  max-height: calc(75vh - 50px);
  max-width: 640px;
  overflow-y: auto;
  overflow-x: hidden;
  white-space: normal;
  -webkit-overflow-scrolling: touch;
}

.widget-notification .widget-notification-item {
  list-style-type: none;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.widget-notification .widget-notification-item:first-child .widget-notification-content {
  border: none;
}

.widget-notification .widget-notification-item.isUnread a {
  background: #ebf3f9;
}

.widget-notification .widget-notification-item:focus a,.widget-notification .widget-notification-item:hover a {
  background: #fafaf9;
}

.widget-notification .widget-notification-item p {
  margin: 0;
}

.widget-notification .widget-notification-item-main {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  display: -webkit-box!important;
  display: -webkit-flex!important;
  display: -ms-flexbox!important;
  display: flex!important;
  color: #222;
  padding: 0 0 12px!important;
  line-height: 1.4!important;
}

.widget-notification .widget-notification-kind-icon {
  text-align: right;
  margin: 0 8px 0 0!important;
  padding: 14px 0 0;
}

.widget-notification .widget-notification-kind-icon img {
  max-width: 24px;
  max-height: none!important;
}

.widget-notification .widget-notification-content {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  border-top: 1px solid #ddd;
  padding: 14px 16px 0 0;
}

.widget-notification .widget-notification-meta {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  font-size: 11px;
  color: #666;
}

.widget-notification .widget-notification-meta p {
  margin: 0 0 0 .75em!important;
  min-width: 0;
}

.widget-notification .widget-notification-meta p:first-child {
  margin: 0!important;
}

.widget-notification .widget-notification-body,.widget-notification .widget-notification-subtitle,.widget-notification .widget-notification-title {
  margin: 4px 0 0!important;
}

.widget-notification .widget-notification-title {
  font-weight: 700;
  font-size: 14px;
}

.widget-notification .widget-notification-subtitle {
  font-size: 11px;
  color: #666;
}

.widget-notification .widget-notification-body {
  font-size: 13px;
}

.isPC .widget-notification-kind-icon {
  width: 48px;
}

.isTouch .widget-notification-kind-icon {
  width: 68px;
}

.isTouch .widget-notification-item:last-child {
  margin: 0 0 88px;
  position: relative;
}

.isTouch .widget-notification-item:last-child:before {
  content: '';
  display: block;
  border-top: 1px solid #ddd;
  position: absolute;
  right: 0;
  bottom: 0;
  width: calc(100% - 70px);
  height: 0;
}

.isPC .widget-internalLinks {
  border-top: 1px solid #888;
  font-size: 1.25em;
}

.isPC .widget-internalLinks ul {
  padding: 0;
  margin: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.isPC .widget-internalLinks ul li {
  list-style-type: none;
}

.isPC .widget-internalLinks li {
  margin: 0 0 0 1em;
  height: 60px;
  line-height: 60px;
}

.isPC .widget-internalLinks li:first-child {
  margin: 0;
}

.isPC .widget-internalLinks li.isActive {
  font-weight: 700;
}

.isPC .widget-internalLinks li.isActive a {
  color: #222;
  border-top-color: #222;
}

.isPC .widget-internalLinks a {
  display: block;
  text-decoration: none;
  border-top: 3px solid transparent;
  color: #666;
}

.isPC .widget-internalLinks a:focus,.isPC .widget-internalLinks a:hover {
  border-top-color: #4baae0;
}

.isPC .widget-internalLinks .icon-bottom {
  display: none;
}

.isTouch .widget-internalLinks {
  border-bottom: 1px solid #ddd;
  font-size: 12px;
}

.isTouch .widget-internalLinks ul {
  padding: 0;
  margin: 0 16px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.isTouch .widget-internalLinks ul li {
  list-style-type: none;
}

.isTouch .widget-internalLinks li {
  line-height: 1.5;
}

.isTouch .widget-internalLinks li.isActive a {
  color: #0081c2;
}

.isTouch .widget-internalLinks li:last-child a {
  padding: 8px 0;
}

.isTouch .widget-internalLinks a {
  display: block;
  text-decoration: none;
  padding: 8px 12px 8px 0;
  font-weight: 700;
  color: #222;
}

.isTouch .widget-internalLinks-count {
  font-weight: 400;
  color: #666;
}

.widget-meta {
  padding: 0;
  margin: 0;
  font-size: 11.5px;
  color: #666;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

.widget-meta li {
  list-style-type: none;
}

.widget-meta li {
  position: relative;
  padding: 0 14px 0 0;
}

.widget-meta li:after {
  content: '';
  display: inline-block;
  position: absolute;
  right: 5px;
  top: 50%;
  margin: -2px 0 0;
  width: 4px;
  height: 4px;
  background: #ddd;
  border-radius: 50%;
}

.widget-meta li:last-child {
  padding: 0;
}

.widget-meta li:last-child:after {
  display: none;
}

.widget-meta time {
  margin: 0;
}

.widget-meta a {
  color: #666;
}

.widget-meta a:focus,.widget-meta a:hover {
  color: #0081c2;
}

.widget-multiple-panel.isHidden {
  display: none;
}

.widget-followingLabel-createPopup-container {
  position: relative;
}

.widget-followingLabel-createPopup {
  background: #fff;
  border: 1px solid rgba(0,0,0,.3);
  box-shadow: 0 1px 1px rgba(0,0,0,.1);
  width: 220px;
  height: auto;
  line-height: 1.8;
}

.widget-followingLabel-createPopup.isHidden {
  display: none;
}

.widget-followingLabel-createPopup p {
  margin: 0!important;
}

.widget-followingLabel-createPopup-header {
  font-size: 11.5px;
  padding: 4px 8px;
}

.widget-followingLabel-createPopup-content {
  padding: 0 8px;
}

.widget-followingLabel-createPopup-footer {
  padding: 8px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: reverse;
  -webkit-flex-direction: row-reverse;
  -ms-flex-direction: row-reverse;
  flex-direction: row-reverse;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

.widget-followingLabel-createPopup-footer button {
  width: calc(50% - 4.5px);
}

.isPC .widget-followingLabel-createPopup {
  position: absolute;
  z-index: 20000;
}

.isTouch .widget-followingLabel-createPopup-header {
  padding: 20px 16px 16px;
  line-height: 1;
  background: #f2f1f0;
  text-align: center;
  margin: 0 0 10px!important;
  font-size: 13px;
  box-shadow: 0 1px 0 rgba(0,0,0,.1);
}

.isTouch .widget-followingLabel-createPopup-content {
  padding: 0 10px;
}

.isTouch .widget-followingLabel-createPopup-footer {
  padding: 9px 10px;
}

.widget-followingLabel-applyPopup-container {
  position: relative;
}

.widget-followingLabel-applyPopup {
  position: absolute;
  background: #fff;
  border: 1px solid rgba(0,0,0,.3);
  box-shadow: 0 1px 1px rgba(0,0,0,.1);
  z-index: 20000;
  width: 220px;
  height: auto;
  line-height: 1.8;
}

.widget-followingLabel-applyPopup.isHidden {
  display: none;
}

.widget-followingLabel-applyPopup p {
  margin: 0!important;
}

.widget-followingLabel-applyPopup-header {
  font-size: 11.5px;
  padding: 4px 8px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

.widget-followingLabel-applyPopup-header button {
  padding: 0;
  color: #0990cc;
  border: none;
  font-size: 11.5px;
}

.widget-followingLabel-applyPopup-header button:focus,.widget-followingLabel-applyPopup-header button:hover {
  color: #0081c2;
}

.widget-followingLabel-applyPopup-header button:focus svg circle,.widget-followingLabel-applyPopup-header button:focus svg line,.widget-followingLabel-applyPopup-header button:hover svg circle,.widget-followingLabel-applyPopup-header button:hover svg line {
  stroke: #0081c2;
}

.widget-followingLabel-applyPopup-header span,.widget-followingLabel-applyPopup-header svg {
  vertical-align: middle;
}

.widget-followingLabel-applyPopup-header svg {
  width: 11px;
  height: 11px;
  vertical-align: middle;
}

.widget-followingLabel-applyPopup-header svg circle,.widget-followingLabel-applyPopup-header svg line {
  stroke: #0990cc;
}

.widget-followingLabel-applyPopup-search {
  padding: 0 8px 8px;
}

.widget-followingLabel-applyPopup-content {
  padding: 0;
  padding: 8px;
  margin: 0;
  overflow-x: hidden;
  overflow-y: auto;
  -webkit-overflow-scrolling: touch;
  border-top: 1px solid #ddd;
  max-height: 200px;
}

.widget-followingLabel-applyPopup-content li {
  list-style-type: none;
}

.widget-followingLabel-applyPopup-content::-webkit-scrollbar {
  border-right: 5px solid #fff;
  width: 15px;
  background: #fff;
}

.widget-followingLabel-applyPopup-content::-webkit-scrollbar:hover {
  border-right-color: #f7f6f5;
}

.widget-followingLabel-applyPopup-content::-webkit-scrollbar-thumb {
  border-right: 5px solid #ddd;
  -webkit-transition: all .1s linear;
  transition: all .1s linear;
}

.widget-followingLabel-applyPopup-content::-webkit-scrollbar-thumb:hover {
  border-right-color: #bbb;
}

.widget-followingLabel-applyPopup-content-item {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.widget-followingLabel-applyPopup-content-item.isHidden {
  display: none;
}

.widget-followingLabel-applyPopup-content-item .ui-checkbox {
  padding: 2px 0;
  -webkit-align-self: flex-start;
  -ms-flex-item-align: start;
  align-self: flex-start;
}

.widget-followingLabel-applyPopup-content-item .ui-checkbox-label {
  padding: 2px 0 2px 8px;
  box-sizing: border-box!important;
  font-size: 14px;
  line-height: 1.4;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

.widget-followingLabel-applyPopup-footer {
  text-align: right;
  padding: 8px 4px;
  border-top: 1px solid #ddd;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.widget-followingLabel-applyPopup-footer button {
  width: 100%;
  box-sizing: border-box;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  margin: 0 4px;
  -webkit-font-feature-settings: 'palt';
  font-feature-settings: 'palt';
  letter-spacing: 1px;
}

.widget-followingLabel-applyPopup-footer button img,.widget-followingLabel-applyPopup-footer button span {
  vertical-align: top;
}

.widget-followingLabel-applyPopup-footer .ui-toggleSwitch {
  margin: 0 0 0 4px;
}

.widget-followingLabel-applyPopup-footer .ui-toggleSwitch-label {
  font-size: 12px;
  margin: 0 1em 0 0;
}

.widget-bar {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  line-height: 10px;
}

.widget-bar span {
  height: 10px;
  display: inline-block;
  vertical-align: top;
}

.widget-bar-gray {
  padding: 0 0 0 1px;
  box-sizing: border-box;
}

.widget-bar-gray span {
  width: 100%;
  background-image: -webkit-repeating-linear-gradient(left,#fff 0,#fff 1px,#aaa 0,#aaa 3px);
  background-image: repeating-linear-gradient(90deg,#fff 0,#fff 1px,#aaa 0,#aaa 3px);
}

.widget-bar-blue {
  padding: 0 0 0 1px;
  box-sizing: border-box;
}

.widget-bar-blue span {
  width: 100%;
  background-image: -webkit-repeating-linear-gradient(left,#fff 0,#fff 1px,#4baae0 0,#4baae0 3px);
  background-image: repeating-linear-gradient(90deg,#fff 0,#fff 1px,#4baae0 0,#4baae0 3px);
}

.widget-searchingConditions {
  padding: 0;
  margin: 0;
}

.widget-searchingConditions li {
  list-style-type: none;
}

.widget-searchingConditions>li {
  position: relative;
  border-bottom: 1px solid #ddd;
}

.widget-searchingConditions a {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: baseline;
  -webkit-align-items: baseline;
  -ms-flex-align: baseline;
  align-items: baseline;
  min-height: 62px;
  box-sizing: border-box;
  padding: 10px 50px 10px 0;
}

.widget-searchingConditions a:focus,.widget-searchingConditions a:hover {
  background: #fafaf9;
  text-decoration: none;
}

.widget-searchingConditions p {
  display: inline;
  color: #222;
  margin: 0;
}

.widget-searchingConditions button {
  position: absolute;
  top: 0;
  right: 0;
  padding: 10px 0 8px 8px;
}

.widget-searchingConditions ul {
  padding: 0;
  line-height: 1.5;
}

.widget-searchingConditions ul li {
  list-style-type: none;
}

.widget-searchingConditions ul li {
  color: #222;
  display: inline;
}

.widget-searchingConditions ul li span {
  display: inline-block;
}

.widget-searchingConditions ul li span:not(:last-child) {
  margin: 0 .5em 0 0;
}

.widget-searchingConditions ul .widget-searchingConditions-keyword {
  display: block;
}

.widget-searchingConditions .icon-history svg {
  width: 16px;
  height: 16px;
  margin: 0 .25em 0 0;
}

.widget-searchingConditions-time {
  line-height: 1.3;
  width: 120px;
}

.widget-searchingConditions-time time {
  font-size: 13px;
  font-weight: 700;
  vertical-align: top;
}

.widget-searchingConditions-main {
  margin: 0;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

.isPC .widget-searchingConditions {
  width: 100%;
}

.isPC .widget-searchingConditions li:last-child {
  border-bottom: none;
}

.isPC .widget-searchingConditions button svg {
  width: 24px;
  height: 24px;
}

.isPC .widget-searchingConditions a:focus,.isPC .widget-searchingConditions a:hover {
  background: #fafaf9;
}

.isTouch .widget-searchingConditions {
  margin: 0 0 0 16px;
}

.isTouch .widget-searchingConditions p {
  font-size: .9em;
}

@media screen and (max-width:340px) {
  .isTouch .widget-searchingConditions a {
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -webkit-flex-direction: column;
    -ms-flex-direction: column;
    flex-direction: column;
  }
}

.isTouch .widget-searchingConditions button {
  padding: 10px 16px 3px 8px;
}

.isTouch .widget-searchingConditions svg {
  width: 16px;
  height: 16px;
}

.isTouch .widget-searchingConditions-listItem time {
  font-size: 11px;
}

#page-settings-loyalty-entered #container-inner {
  text-align: center;
  box-sizing: border-box;
}

#page-settings-loyalty-entered #icon {
  margin: 0;
}

#page-settings-loyalty-entered i {
  font-size: 5em;
  line-height: 1;
  color: #0990cc;
}

@media screen and (max-width:640px) {
  #page-settings-loyalty-entered i {
    font-size: 4em;
  }
}

#page-settings-loyalty-entered h2 {
  font-size: 1.25em;
  font-weight: 400;
  line-height: 1.5;
}

@media screen and (max-width:640px) {
  #page-settings-loyalty-entered h2 {
    font-size: 1.1em;
    font-weight: 700;
  }
}

#page-settings-loyalty-entered h2 span {
  display: block;
}

@media screen and (max-width:640px) {
  #page-settings-loyalty-entered h2 span {
    display: inline;
  }
}

#page-settings-loyalty-entered #button {
  margin: 1em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-author-links a:focus svg,#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-author-links a:hover svg {
  fill: #0081c2;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-author-links svg {
  width: 13px;
  height: 13px;
  vertical-align: middle;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-author-links svg {
  fill: #0990cc;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader {
  -webkit-transition-property: top,width,padding-right;
  transition-property: top,width,padding-right;
  -webkit-transition-duration: .3s;
  transition-duration: .3s;
  -webkit-transition-timing-function: cubic-bezier(.23,1,.32,1);
  transition-timing-function: cubic-bezier(.23,1,.32,1);
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain {
  -webkit-transition-property: margin;
  transition-property: margin;
  -webkit-transition-duration: .3s;
  transition-duration: .3s;
  -webkit-transition-timing-function: cubic-bezier(.23,1,.32,1);
  transition-timing-function: cubic-bezier(.23,1,.32,1);
}

#page-works-episodes-episode.writingDirection-horizontal #contentAside {
  -webkit-transition-property: right;
  transition-property: right;
  -webkit-transition-duration: .3s;
  transition-duration: .3s;
  -webkit-transition-timing-function: cubic-bezier(.23,1,.32,1);
  transition-timing-function: cubic-bezier(.23,1,.32,1);
}

#page-works-episodes-episode.writingDirection-horizontal #content {
  height: 100%;
  position: relative;
}

@media screen and (max-width:700px) {
  #page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #worksEpisodesEpisodeHeader-inner {
    display: block;
  }

  #page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #worksEpisodesEpisodeHeader-inner:after,  #page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #worksEpisodesEpisodeHeader-inner:before {
    content: '';
    display: table;
  }

  #page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #worksEpisodesEpisodeHeader-inner:after {
    clear: both;
  }

  #page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #worksEpisodesEpisodeHeader-workInfo {
    display: none;
  }

  #page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #worksEpisodesEpisodeHeader-tools {
    width: 130px;
    float: right;
  }

  #page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #worksEpisodesEpisodeHeader-logo {
    display: none;
  }
}

#page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #worksEpisodesEpisodeHeader {
  width: calc(100% - 330px);
  top: 0!important;
}

#page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #contentMain {
  margin: 0 330px 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #content.contentAside-isShown #contentAside {
  right: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader {
  position: fixed;
  top: -50px;
  left: 0;
  height: 50px;
  line-height: 50px;
  width: 100%;
  box-shadow: 0 1px 0 0 rgba(0,0,0,.05);
  z-index: 10000;
  box-sizing: border-box;
  padding-left: constant(safe-area-inset-left);
  padding-left: env(safe-area-inset-left);
  padding-right: constant(safe-area-inset-right);
  padding-right: env(safe-area-inset-right);
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader.isShown {
  top: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-inner {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-inner h1,#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-inner h2,#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-inner p,#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-inner ul {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-closeButton svg,#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools svg {
  vertical-align: top;
  width: 50px;
  height: 50px;
  max-height: 50px;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-workInfo {
  width: calc(50% - 60px);
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-closeButton {
  width: 55px;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-closeButton:after {
  right: 40%;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-closeButton a {
  display: block;
  font-size: 1.3em;
  height: 50px;
  width: 50px;
  line-height: 50px;
  color: #222;
  position: relative;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-closeButton a:before {
  display: block;
  content: '';
  position: absolute;
  top: 14px;
  right: 0;
  height: calc(100% - 28px);
  width: 0;
  border-left: 1px solid #eee;
}

@media screen and (max-width:640px) {
  #page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-closeButton a:before {
    display: none;
  }
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-closeButton a:focus svg,#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-closeButton a:hover svg {
  fill: #0081c2!important;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-breadcrumbs {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  padding: 0;
  white-space: nowrap;
  line-height: 1.4;
  padding-left: 15px;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-breadcrumbs li {
  list-style-type: none;
}

@media screen and (max-width:640px) {
  #page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-breadcrumbs {
    display: none;
  }
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-breadcrumbs li {
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-breadcrumbs h1 {
  font-weight: 400;
  font-size: 12px;
  margin-top: 2px;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-breadcrumbs h2 {
  font-weight: 400;
  color: #888;
  font-size: 11px;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-breadcrumbs a,#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-breadcrumbs a>span,#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-breadcrumbs h2>span {
  width: 100%;
  display: block;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-logo {
  width: 100px;
  text-align: center;
  height: 50px;
  line-height: 50px;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-logo a {
  display: inline-block;
  text-decoration: none;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-logo img {
  vertical-align: middle;
  max-width: 100px;
  margin: -2px 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-logo img[id*=vertical] {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools {
  width: calc(50% - 60px);
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools p {
  width: 50px;
  height: 50px;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper {
  color: #aaa;
  height: 50px;
  line-height: 50px;
  box-sizing: border-box;
  display: inline-block;
  vertical-align: top;
  padding: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper.isActive .ui-button-silent {
  border: 1px solid #4baae0;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper.isActive .ui-button-silent svg {
  fill: #4baae0;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper.isActive:hover .ui-button-silent {
  border-color: #0990cc;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper.isActive:hover .ui-button-silent svg {
  fill: #0990cc;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper:focus svg,#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper:hover svg {
  fill: #0990cc;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-tools .ui-button-silent {
  display: block;
  height: 50px;
  width: 50px;
  line-height: 50px;
  vertical-align: top;
  box-sizing: border-box;
  padding: 0;
  border: none;
}

#page-works-episodes-episode.writingDirection-horizontal #sidebar-button {
  padding: 8px 12px 8px 8px!important;
}

#page-works-episodes-episode.writingDirection-horizontal #sidebar-button .ui-button-silent {
  width: 34px;
  height: 34px;
}

#page-works-episodes-episode.writingDirection-horizontal #sidebar-button svg {
  width: 32px;
  height: 32px;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain {
  padding: 50px 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-inner {
  margin: 0;
  padding: 0 20px;
  box-sizing: border-box;
  position: relative;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-inner .widget-episode {
  margin: 0 auto;
  padding: 0 0 60px;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-inner .widget-episodeBody {
  padding: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header {
  text-align: center;
  overflow: hidden;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header .chapterTitle {
  max-width: 665px;
  line-height: 1.2;
  margin: 3rem auto 2rem;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header .chapterTitle+.chapterTitle {
  margin-top: 2rem;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header .chapterTitle.level1 {
  font-size: 2.75em;
  color: #888;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header .chapterTitle.level2 {
  position: relative;
  padding: 0 2em;
  box-sizing: border-box;
  font-size: 1.75em;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header .chapterTitle.level2>span {
  position: relative;
  z-index: 1;
  padding: 0 .5em;
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header .chapterTitle.level2:before {
  content: '';
  position: absolute;
  top: 50%;
  left: 0;
  width: 100%;
  height: 0;
  border-top: 1px solid;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header .widget-episodeTitle {
  margin: 2rem auto 60px;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header-cover {
  padding: 120px 60px 60px;
  overflow: hidden;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header-cover p {
  margin: 0;
  line-height: 1.2;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header-cover #contentMain-header-workTitle {
  font-weight: 700;
  font-size: 3em;
  max-width: 665px;
  margin: 0 auto;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header-cover #contentMain-header-author {
  font-size: 2em;
  color: #888;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-nextEpisode a,#page-works-episodes-episode.writingDirection-horizontal #contentMain-previousEpisode a {
  display: block;
  text-align: center;
  text-decoration: none;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-previousEpisode a {
  padding: 13px 10px;
  font-size: .9em;
  line-height: 1.3;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-previousEpisode-inner>span {
  vertical-align: top;
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-previousEpisode-inner .contentMain-pagerDash {
  width: 2em;
  height: 1em;
  display: inline-block;
  overflow: hidden;
  text-indent: -5em;
  position: relative;
  margin: 0 .3em 0 .25em;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-previousEpisode-inner .contentMain-pagerDash:before {
  content: '';
  display: block;
  position: absolute;
  top: 50%;
  left: 0;
  width: 100%;
  height: 0;
  border-top: 1px solid;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-previousEpisode-inner .contentMain-pagerEpisodeTitle {
  overflow: hidden;
  max-width: calc(100% - 150px);
  text-align: left;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-nextEpisode a {
  padding: 30px;
  line-height: 1.4;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-nextEpisode a:focus i,#page-works-episodes-episode.writingDirection-horizontal #contentMain-nextEpisode a:hover i {
  color: #0990cc;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-readNextEpisode .contentMain-pagerRelation {
  margin: 0 auto 1em;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-readNextEpisode .contentMain-chapterTitle {
  display: block;
  margin: 1em auto;
  font-size: 12px;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-readNextEpisode .contentMain-chapterTitle .level1+.level2:before {
  font-family: dcicons;
  content: '\f70a';
  display: inline-block;
  margin: 0 8px;
  opacity: .5;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-readNextEpisode .contentMain-pagerEpisodeTitle {
  font-size: 1.5em;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-readNextEpisode .contentMain-pagerEpisodeTitle>span {
  text-align: left;
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-readNextEpisode .contentMain-pagerArrow {
  margin: 1em auto 0;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-readNextEpisode svg {
  width: 38px;
  height: 38px;
  fill: #4baae0;
}

#page-works-episodes-episode.writingDirection-horizontal .contentMain-nextEpisode-inner>span {
  display: block;
  max-width: 608px;
  margin: 0 auto;
}

#page-works-episodes-episode.writingDirection-horizontal #contentAside {
  overflow-y: auto;
  width: 330px;
  height: 100%;
  position: fixed;
  top: 0;
  right: -330px;
  box-sizing: border-box;
  border-left: 1px solid;
  z-index: 10000;
  -webkit-overflow-scrolling: touch;
}

#page-works-episodes-episode.writingDirection-horizontal #contentAside .ui-loading-large-beige {
  position: absolute;
  top: 50%;
  left: 50%;
  margin: -25px 0 0 -25px;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionHeader {
  padding: 15px;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionHeader h3,#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionHeader h4 {
  line-height: 1.2;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionHeader h3 a:hover,#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionHeader h4 a:hover {
  color: #0081c2;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionHeader h3 {
  margin: .5em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionHeader h4 {
  font-weight: 400;
  margin: .25em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #contentAside-buttons {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  margin: 1em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #contentAside-buttons>div,#page-works-episodes-episode.writingDirection-horizontal #contentAside-buttons>p {
  width: calc(50% - 2px);
}

#page-works-episodes-episode.writingDirection-horizontal #contentAside-buttons p {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #contentAside-buttons a,#page-works-episodes-episode.writingDirection-horizontal #contentAside-buttons button {
  text-align: center;
  box-sizing: border-box;
  width: 100%;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody {
  margin: 0 0 60px;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody header {
  border-bottom: 1px solid;
  margin: 0 0 1em;
  padding: 0 15px .25em;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody header:after,#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody header:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody header:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody header h3 {
  float: left;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  font-size: .9em;
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc {
  padding: 0;
  margin: 0 0 45px;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc header {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc header:after,#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc header:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc header:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc h3 {
  float: none;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-workInfo {
  font-size: .85em;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-workInfo:after,#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-workInfo:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-workInfo:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-workInfo p {
  display: inline-block;
  margin: 0 0 0 .5em;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-workInfo p:first-child {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-workStatus {
  float: left;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-date {
  float: right;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items {
  list-style-type: none;
  margin: 0;
  padding: 0;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #222;
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:after,#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #aaa;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:focus,#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:hover {
  color: #0081c2;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a>span {
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items li {
  line-height: 1.2;
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items li:after,#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items li:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items li:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items li:first-child.widget-toc-chapter {
  border-top: none!important;
  margin-top: 0!important;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter {
  position: relative;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  margin: 16px 0 0 0;
  font-size: 1em;
  background: #eae9e8;
  border-top: 1px solid #ddd;
  color: #888;
  text-align: center;
  letter-spacing: .5px;
  padding: 24px 16px 8px;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1+ol {
  margin-top: 1em;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  margin: 24px 0 0 16px;
  padding: 0 16px 8px 0;
  font-size: .85em;
  letter-spacing: .5px;
  border-bottom: 1px solid #ddd;
  color: #666;
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-bottom: 1px solid #ddd;
  position: relative;
  margin: 0 0 0 16px;
  padding: 1px 0;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode-datePublished {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode-episodeTitle {
  padding: 1em 65px 1em 0;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeInfo {
  font-size: 11px;
  padding: 0 16px 8px;
  margin: 0;
  border-bottom: 1px solid;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeInfo:after,#page-works-episodes-episode.writingDirection-horizontal #episodeInfo:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeInfo:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeInfo dd,#page-works-episodes-episode.writingDirection-horizontal #episodeInfo dt {
  margin: 0 0 .5em;
  padding: 0;
  line-height: 1.3;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeInfo dt {
  width: 7em;
  float: left;
  clear: both;
  font-weight: 700;
  font-size: .95em;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeInfo dd {
  width: calc(100% - 7em);
  float: right;
}

#page-works-episodes-episode.writingDirection-horizontal #displaySetting-modalContainer .ui-tab.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal #displaySetting-modalContainer .ui-tab li {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #displaySetting-modalContainer .ui-modal-footer {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  padding: 15px 16px;
  padding-bottom: calc(15px + constant(safe-area-inset-bottom));
  padding-bottom: calc(15px + env(safe-area-inset-bottom));
}

#page-works-episodes-episode.writingDirection-horizontal #displaySetting-modalContainer .ui-modal-footer div {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #displaySetting-modalContainer .ui-modal-footer p {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #displaySetting,#page-works-episodes-episode.writingDirection-horizontal #readSetting {
  width: 272px;
  height: 309px;
  margin: 1em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #displaySetting.isHidden,#page-works-episodes-episode.writingDirection-horizontal #readSetting.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal #readSetting section {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-horizontal #readSetting header {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  margin: 0 16px 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #readSetting header h4 {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #readSetting header p {
  line-height: 1.4;
  font-size: 12px;
  color: #666;
}

#page-works-episodes-episode.writingDirection-horizontal #readSetting .ui-toggleSwitch {
  margin: .25em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-links {
  padding: 2em 16px 1em;
  line-height: 1.5;
  text-align: center;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-links p {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-links a {
  padding: 0 1em;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-links a:first-child {
  padding: 0 1em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-links a:last-child {
  padding: 0 0 0 1em;
}

@media screen and (max-width:360px) {
  #page-works-episodes-episode.writingDirection-horizontal #episodeFooter-links .label-touch-omit {
    display: none;
  }
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #contentMain-inner,#page-works-episodes-episode.writingDirection-horizontal.isPC #contentMain-nextEpisode,#page-works-episodes-episode.writingDirection-horizontal.isPC #contentMain-previousEpisode,#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter {
  min-width: 740px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC .episodeFooter-section-inner {
  margin: 0 auto;
  max-width: 665px;
  padding: 45px 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode-episodeTitle {
  padding-right: 16px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action {
  margin: 0 0 1em -14px;
  width: calc(100% + 13px);
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action:after,#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action.isRecommendCheerAction {
  margin-top: 126px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action i {
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action .ui-button-silent.isOpen {
  color: #0081c2;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action .ui-button-silent.isOpen .icon-up {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action .ui-button-silent.isOpen .icon-bottom {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action .ui-button-silent .icon-up {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action .ui-button-silent .icon-bottom {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-left {
  float: left;
  position: relative;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-right {
  float: right;
  position: relative;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton-container {
  display: inline-block;
  vertical-align: bottom;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton-container div {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton-container button {
  vertical-align: bottom;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton {
  font-size: 1.2em;
  position: relative;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton:focus,#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton:hover {
  background: 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton i {
  font-size: 1.1em;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton .icon-heart-negative {
  color: #f23e48;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton .isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-action-cheerButton #episodeFooter-action-cheerButton-cheer {
  color: #0990cc;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-share {
  position: absolute;
  bottom: 100%;
  right: 0;
  box-shadow: 0 1px 1px rgba(0,0,0,.1);
  background: #fff;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-share:after,#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-share:before {
  content: '';
  left: auto!important;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-share:before {
  content: '';
  position: absolute;
  border: 8px solid transparent;
  left: 50%;
  margin: 0 0 0 -8px;
  border-top-color: #ccc;
  right: 30px;
  bottom: -16px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-share:after {
  content: '';
  position: absolute;
  border: 8px solid transparent;
  bottom: -16px;
  left: 50%;
  margin: 0 0 0 -8px;
  border-top-color: #fff;
  right: 30px;
  bottom: -14px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-share.isHidden {
  right: 9999px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-share.isShown {
  right: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-share-inner {
  padding: 15px 15px 5px;
  white-space: nowrap;
  max-width: calc(100vw - 45px);
  overflow-x: auto;
  -webkit-overflow-scrolling: touch;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-share-inner:before {
  content: '';
  display: block;
  width: 15px;
  height: 100%;
  position: absolute;
  top: 0;
  right: 0;
  background: -moz-linear-gradient(left,rgba(255,255,255,0),rgba(255,255,255,.95));
  background: -webkit-gradient(linear,left top,right top,from(rgba(255,255,255,0)),to(rgba(255,255,255,.95)));
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers .ui-loading {
  margin: 30px auto;
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers h4,#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers li {
  border-bottom: 1px solid;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers h4 {
  font-size: 11px;
  margin: 0;
  padding: 0 0 8px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers ul {
  padding: 0;
  margin: 0 0 30px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers ul li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers li {
  padding: 8px 0;
  list-style-type: none;
  font-size: .8em;
  line-height: 1.5;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers template {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-cheers-isEmpty {
  font-size: .8rem;
  color: #888;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-work-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-work-header h3 {
  line-height: 1.3;
  margin: 0 30px 0 0;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-work-header-workTitle {
  font-size: 16px;
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-work-header-author {
  margin: 4px 0 0;
  font-size: 14px;
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-work-header-author a {
  text-decoration: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-signUp-balloon {
  padding: 1em 4em;
  display: inline-block;
  line-height: 1.5;
  position: relative;
  box-sizing: border-box;
  text-align: center;
  margin: 8px 0 10px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-signUp-balloon h3,#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-signUp-balloon p {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-signUp-balloon h3 {
  font-size: 1.5em;
  margin: .25em 0 .5em;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-signUp-balloon .signUp-balloon-button {
  margin: 1em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-signUp-balloon .signUp-balloon-button a {
  display: block;
  font-size: 1.1em;
  padding: .75em 0;
  max-width: 300px;
  margin: .5em auto;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-info h3 {
  font-weight: 400;
  font-size: 11.5px;
  margin: 0 0 4px;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  margin: 0 0 16px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-name {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  margin: 0 16px 0 0;
  line-height: 1.3;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-name a {
  display: inline-block;
  text-decoration: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-name span {
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-name span:focus,#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-name span:hover {
  text-decoration: underline;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-links {
  margin: 0;
  padding: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-links li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-links li {
  display: inline-block;
  margin: 0 .75em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-links li span {
  vertical-align: middle;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-news {
  margin: 30px auto 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-news h5 {
  font-size: 11px;
  margin: 0;
  padding: 0 0 8px;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-news ul {
  padding: 0;
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-news ul li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-news ul a {
  text-decoration: none;
  padding: 5px 10% 5px 110px;
  position: relative;
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-news ul h6,#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-news ul p {
  margin: 0;
  line-height: 1.5;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-news ul h6 {
  font-size: 1em;
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-horizontal.isPC #episodeFooter-author-news ul p {
  font-size: .85em;
  position: absolute;
  top: 6px;
  left: 0;
  width: 90px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #content.contentAside-isShown #worksEpisodesEpisodeHeader {
  width: calc(100% - 250px);
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #content.contentAside-isShown #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-logo,#page-works-episodes-episode.writingDirection-horizontal.isTouch #content.contentAside-isShown #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-workInfo {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #content.contentAside-isShown #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-tools {
  width: 100%;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #content.contentAside-isShown #contentMain {
  margin: 0 250px 0 0;
  margin: 0 calc(250px + constant(safe-area-inset-right)) 0 0;
  margin: 0 calc(250px + env(safe-area-inset-right)) 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentAside {
  width: 250px;
  width: calc(250px + constant(safe-area-inset-right));
  width: calc(250px + env(safe-area-inset-right));
  right: -250px;
  right: calc(-1 * (250px + constant(safe-area-inset-right)));
  right: calc(-1 * (250px + env(safe-area-inset-right)));
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch .contentAside-sectionHeader {
  padding-right: calc(16px + constant(safe-area-inset-right))!important;
  padding-right: calc(16px + env(safe-area-inset-right))!important;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeInfo,#page-works-episodes-episode.writingDirection-horizontal.isTouch .widget-toc header,#page-works-episodes-episode.writingDirection-horizontal.isTouch .widget-toc-chapter {
  padding-right: 16px!important;
  padding-right: calc(16px + constant(safe-area-inset-right))!important;
  padding-right: calc(16px + env(safe-area-inset-right))!important;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch .widget-toc-episode {
  padding-right: constant(safe-area-inset-right)!important;
  padding-right: env(safe-area-inset-right)!important;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentAside-buttons {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentAside-buttons p {
  width: 100%;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentAside-buttons p+p {
  margin: 8px 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #displaySetting-modalContainer .ui-tab {
  margin: 0!important;
  width: 100%;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #displaySetting-modalContainer .ui-tab li {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-previousEpisode {
  min-width: 320px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-inner {
  min-width: 320px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-inner .widget-episode {
  padding: 0 0 30px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-header .chapterTitle.level1 {
  font-size: 1.75em;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-header .widget-episodeTitle {
  font-size: 1.25em;
  margin: 2rem auto 45px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-header-cover {
  padding: 120px 0 60px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-header-cover #contentMain-header-workTitle {
  font-size: 1.75em;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-header-cover #contentMain-header-author {
  font-size: 1.25em;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-nextEpisode .contentMain-pagerEpisodeTitle {
  font-size: 1.25em;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-relatedWork {
  border-top: 1px solid;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-relatedWork.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-relatedWork-inner {
  max-width: 665px;
  margin: 0 auto;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #contentMain-relatedWork-inner h3 {
  margin: 0;
  font-size: 11px;
  padding: 14px 16px 8px;
  border-bottom: 1px solid;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter {
  min-width: 320px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch .episodeFooter-section-inner {
  margin: 0 auto;
  max-width: 640px;
  padding: 24px 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action {
  margin: 0 0 1em;
  width: 100%;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action:after,#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-left:after,#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-left:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-left:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-right {
  margin: 0 0 10px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-cheerButton-container {
  width: 50%;
  font-size: 15px;
  text-align: center;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-cheerButton {
  font-size: 1.2em;
  position: relative;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-cheerButton:focus,#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-cheerButton:hover {
  background: 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-cheerButton i {
  font-size: 1.1em;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-cheerButton .icon-heart-negative {
  color: #f23e48;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-cheerButton .isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-action-cheerButton #episodeFooter-action-cheerButton-cheer {
  color: #0990cc;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-share {
  position: absolute;
  bottom: 100%;
  right: 0;
  box-shadow: 0 1px 1px rgba(0,0,0,.1);
  background: #fff;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-share:after,#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-share:before {
  content: '';
  left: auto!important;
  right: auto!important;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-share:before {
  content: '';
  position: absolute;
  border: 8px solid transparent;
  left: 50%;
  margin: 0 0 0 -8px;
  border-top-color: #ccc;
  right: 30px;
  bottom: -16px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-share:after {
  content: '';
  position: absolute;
  border: 8px solid transparent;
  bottom: -16px;
  left: 50%;
  margin: 0 0 0 -8px;
  border-top-color: #fff;
  right: 30px;
  bottom: -14px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-share.isHidden {
  right: 9999px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-share.isShown {
  right: 50%;
  -webkit-transform: translateX(50%);
  transform: translateX(50%);
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-share-inner {
  padding: 15px 15px 5px;
  white-space: nowrap;
  max-width: calc(100vw - 45px);
  overflow-x: auto;
  -webkit-overflow-scrolling: touch;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-share-inner:before {
  content: '';
  display: block;
  width: 15px;
  height: 100%;
  position: absolute;
  top: 0;
  right: 0;
  background: -moz-linear-gradient(left,rgba(255,255,255,0),rgba(255,255,255,.95));
  background: -webkit-gradient(linear,left top,right top,from(rgba(255,255,255,0)),to(rgba(255,255,255,.95)));
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers .ui-loading {
  margin: 24px auto;
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers h4,#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers li {
  border-bottom: 1px solid;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers h4 {
  font-size: 11px;
  margin: 0;
  padding: 0 0 8px 16px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers ul {
  padding: 0;
  margin: 0 0 2em;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers ul li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers li {
  list-style-type: none;
  line-height: 1.5;
  font-size: 13px;
  margin: 0 0 0 16px;
  padding: 8px 16px 8px 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers template {
  display: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-cheers-isEmpty {
  font-size: .8rem;
  color: #888;
  margin-left: 16px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-work {
  margin: 0 16px;
  border-top: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-work .episodeFooter-section-inner {
  margin: 0 auto;
  max-width: 604px;
  padding: 16px;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-work-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-work-header h3 {
  line-height: 1.3;
  margin: 0 16px 0 0;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-work-header h3 span {
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-work-header-workTitle {
  font-size: 13px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-work-header-author {
  margin: 4px 0 0;
  font-size: 11px;
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-work-header-author a {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-signUp-balloon {
  padding: 1em;
  display: inline-block;
  line-height: 1.5;
  position: relative;
  margin: 12px 0 0 -16px;
  box-sizing: border-box;
  border: none;
  text-align: center;
  width: calc(100% + 32px);
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-signUp-balloon h3,#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-signUp-balloon p {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-signUp-balloon h3 {
  margin: .25em 0 .5em;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-signUp-balloon p {
  font-size: .9em;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-signUp-balloon .signUp-balloon-button {
  margin: 1em 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-signUp-balloon .signUp-balloon-button a {
  display: block;
  font-size: 1.1em;
  padding: .75em 0;
  max-width: 300px;
  margin: .5em auto;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author {
  border: none!important;
  margin: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-info {
  padding: 0 16px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-info h3 {
  font-weight: 400;
  font-size: 11px;
  margin: 0 0 5px;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-header:after,#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-header:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-header:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-name {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  line-height: 1.3;
  margin: 0 16px 0 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-name a {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-name span {
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-links {
  margin: 0;
  padding: 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-links li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-links li span {
  vertical-align: middle;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-news {
  margin: 24px auto 0;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-news h5 {
  font-size: 11px;
  margin: 0;
  padding: 0 0 8px 16px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-news ul {
  padding: 0;
  margin: 0 0 0 16px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-news ul li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-news ul a {
  text-decoration: none;
  padding: 5px 16px 5px 90px;
  position: relative;
  display: block;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-news ul h6,#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-news ul p {
  margin: 0;
  line-height: 1.5;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-news ul h6 {
  font-size: 1em;
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch #episodeFooter-author-news ul p {
  font-size: .85em;
  position: absolute;
  top: 6px;
  left: 0;
  width: 90px;
}

#page-works-episodes-episode.writingDirection-horizontal.isTouch .contentAside-sectionBody header h3 {
  margin: 0;
  padding: 0!important;
  width: 100%!important;
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical {
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  height: 100%;
  min-width: 100%;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-author-links a:focus svg,#page-works-episodes-episode.writingDirection-vertical #episodeFooter-author-links a:hover svg {
  fill: #0081c2;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-author-links svg {
  width: 13px;
  height: 13px;
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg);
  vertical-align: middle;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-author-links svg {
  fill: #0990cc;
}

#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop,#page-works-episodes-episode.writingDirection-vertical i[class^=icon-] {
  -ms-writing-mode: lr-tb;
  writing-mode: horizontal-tb;
}

#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  -ms-writing-mode: lr-tb;
  writing-mode: horizontal-tb;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-action-cheerButton-container,#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  -ms-flex-align: center;
  align-items: center;
}

#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  position: static!important;
}

#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  position: static!important;
}

#page-works-episodes-episode.writingDirection-vertical _:-ms-lang(x)::backdrop {
  position: static!important;
  width: 17px;
}

#page-works-episodes-episode.writingDirection-vertical _:-ms-lang(x)::backdrop {
  position: static!important;
  width: 17px;
}

#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-links a+a,#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  margin: .5em 0 0 0!important;
  padding: .5em 0 0 0!important;
}

#page-works-episodes-episode.writingDirection-vertical _:-ms-lang(x)::backdrop {
  transform: translateX(0)!important;
  right: -10px!important;
}

#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  transform: translateX(0)!important;
  right: -10px!important;
}

#page-works-episodes-episode.writingDirection-vertical _:-ms-lang(x)::backdrop {
  transform: translateX(13px)!important;
}

#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  transform: translateX(13px)!important;
}

#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  position: static;
  transform: none;
}

#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical _:-ms-lang(x)::backdrop {
  position: static;
  transform: none;
}

#page-works-episodes-episode.writingDirection-vertical _:-ms-lang(x)::backdrop {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical .ui-loading,#page-works-episodes-episode.writingDirection-vertical .ui-loading-large-beige {
  -webkit-writing-mode: horizontal-tb;
  -ms-writing-mode: lr-tb;
  writing-mode: horizontal-tb;
}

#page-works-episodes-episode.writingDirection-vertical time>span {
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  text-orientation: sideways;
  display: inline-block;
  vertical-align: bottom;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain,#page-works-episodes-episode.writingDirection-vertical #contentMain-inner {
  height: 100%;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader {
  -webkit-transition-property: right,height,padding-bottom;
  transition-property: right,height,padding-bottom;
  -webkit-transition-duration: .3s;
  transition-duration: .3s;
  -webkit-transition-timing-function: cubic-bezier(.23,1,.32,1);
  transition-timing-function: cubic-bezier(.23,1,.32,1);
}

#page-works-episodes-episode.writingDirection-vertical #contentMain {
  -webkit-transition-property: margin;
  transition-property: margin;
  -webkit-transition-duration: .3s;
  transition-duration: .3s;
  -webkit-transition-timing-function: cubic-bezier(.23,1,.32,1);
  transition-timing-function: cubic-bezier(.23,1,.32,1);
}

#page-works-episodes-episode.writingDirection-vertical #contentAside {
  -webkit-transition-property: bottom;
  transition-property: bottom;
  -webkit-transition-duration: .3s;
  transition-duration: .3s;
  -webkit-transition-timing-function: cubic-bezier(.23,1,.32,1);
  transition-timing-function: cubic-bezier(.23,1,.32,1);
}

#page-works-episodes-episode.writingDirection-vertical #content {
  height: 100%;
  position: relative;
}

@media screen and (max-height:700px) {
  #page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #worksEpisodesEpisodeHeader-inner {
    display: block;
  }

  #page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #worksEpisodesEpisodeHeader-inner:after,  #page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #worksEpisodesEpisodeHeader-inner:before {
    content: '';
    display: table;
  }

  #page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #worksEpisodesEpisodeHeader-inner:after {
    clear: both;
  }

  #page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #worksEpisodesEpisodeHeader-workInfo {
    display: none;
  }

  #page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #worksEpisodesEpisodeHeader-tools {
    height: 130px;
    float: right;
  }
}

#page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #worksEpisodesEpisodeHeader-logo {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #worksEpisodesEpisodeHeader {
  height: calc(100% - 300px);
  right: 0!important;
}

#page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #worksEpisodesEpisodeHeader-tools {
  height: 100px;
}

#page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #contentMain {
  margin: 0 0 300px 0;
}

#page-works-episodes-episode.writingDirection-vertical #content.contentAside-isShown #contentAside {
  bottom: 0;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader {
  position: fixed;
  top: 0;
  right: -51px;
  right: calc(-50px - constant(safe-area-inset-right) - 1px);
  right: calc(-50px - env(safe-area-inset-right) - 1px);
  width: 50px;
  width: calc(50px + constant(safe-area-inset-right));
  width: calc(50px + env(safe-area-inset-right));
  line-height: 50px;
  height: 100%;
  box-shadow: -1px 0 0 0 rgba(0,0,0,.05);
  z-index: 10000;
  box-sizing: border-box;
  padding-right: constant(safe-area-inset-right);
  padding-right: env(safe-area-inset-right);
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader.isShown {
  right: 0;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader .ui-tooltip-bottom:before {
  left: auto;
  right: 100%;
  bottom: auto;
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg);
  margin: -10px 0 0;
  top: 50%;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader .ui-tooltip-bottom:after {
  top: 50%;
  right: 100%;
  margin: 0 10px 0 0;
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  -webkit-transform: translateY(-50%);
  transform: translateY(-50%);
  max-height: 500px;
  max-width: 100%;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-inner {
  width: 50px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-inner h1,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-inner h2,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-inner p,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-inner ul {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-closeButton svg,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools svg {
  vertical-align: top;
  width: 50px;
  height: 50px;
  max-height: 50px;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-workInfo {
  height: calc(100% - 130px - 130px);
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-closeButton {
  width: 50px;
  height: 55px;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-closeButton a {
  display: block;
  font-size: 1.3em;
  text-align: center;
  width: 50px;
  height: 50px;
  line-height: 50px;
  position: relative;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-closeButton a:before {
  display: block;
  content: '';
  position: absolute;
  left: 14px;
  bottom: 0;
  width: calc(100% - 28px);
  height: 0;
  border-top: 1px solid;
}

@media screen and (max-height:640px) {
  #page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-closeButton a:before {
    display: none;
  }
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-closeButton a:focus svg,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-closeButton a:hover svg {
  fill: #0081c2!important;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-height: 0;
  padding: 0;
  white-space: nowrap;
  line-height: 1.4;
  padding-top: 15px;
  width: 50px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-box-align: start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs li {
  list-style-type: none;
}

@media screen and (max-height:640px) {
  #page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs {
    display: none;
  }
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs li {
  display: block;
  width: 1em;
  height: 100%;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs h1 {
  font-weight: 400;
  font-size: 12px;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs h2 {
  font-weight: 400;
  color: #888;
  font-size: 11px;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs a,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs a>span,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs h2>span {
  height: 100%;
  display: block;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-logo {
  -webkit-box-ordinal-group: 2;
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
  height: 130px;
  text-align: center;
  width: 50px;
  line-height: 50px;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-logo a {
  display: inline-block;
  text-decoration: none;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-logo img {
  max-height: 100px;
  margin: 0 15px;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-logo img[id*=horizontal] {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools {
  height: 130px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools p {
  width: 50px;
  height: 50px;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper {
  font-size: 28px;
  width: 50px;
  line-height: 50px;
  box-sizing: border-box;
  vertical-align: top;
  padding: 0;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper.isActive .ui-button-silent {
  border: 1px solid #4baae0;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper.isActive .ui-button-silent svg {
  fill: #4baae0;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper.isActive:hover .ui-button-silent {
  border-color: #0990cc;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper.isActive:hover .ui-button-silent svg {
  fill: #0990cc;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper:focus svg,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools .ui-button-silent-wrapper:hover svg {
  fill: #0990cc;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-tools .ui-button-silent {
  display: block;
  padding: 0;
  width: 50px;
  height: 50px;
  line-height: 50px;
  vertical-align: top;
  box-sizing: border-box;
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical #sidebar-button {
  padding: 8px!important;
}

#page-works-episodes-episode.writingDirection-vertical #sidebar-button .ui-button-silent {
  width: 34px;
  height: 34px;
}

#page-works-episodes-episode.writingDirection-vertical #sidebar-button svg {
  width: 32px;
  height: 32px;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain {
  padding: 0 50px 0 0;
  padding: 0 calc(50px + constant(safe-area-inset-right)) 0 0;
  padding: 0 calc(50px + env(safe-area-inset-right)) 0 0;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-inner {
  margin: 0;
  padding: 40px 0;
  box-sizing: border-box;
  position: relative;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-inner .widget-episode {
  margin: 0 auto;
  padding: 0 0 0 60px;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-inner .widget-episodeBody {
  padding: 0;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header-cover {
  margin: auto 60px;
  padding: 60px;
  overflow: hidden;
  border-top: 1px solid;
  border-bottom: 1px solid;
  max-height: 665px;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header-cover p {
  margin: 0;
  line-height: 1.2;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header-cover #contentMain-header-workTitle {
  font-weight: 700;
  font-size: 2.5em;
  max-height: 665px;
  margin: -2px 0 0 4px;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header-cover #contentMain-header-author {
  font-size: 1.5em;
  color: #888;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header {
  overflow: hidden;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header .chapterTitle {
  line-height: 1.2;
  max-height: 665px;
  margin: auto 3rem auto 2rem;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header .chapterTitle+.chapterTitle {
  margin-right: 2rem;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header .chapterTitle.level1 {
  font-size: 2em;
  padding-top: 35px;
  color: #888;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header .chapterTitle.level2 {
  position: relative;
  font-size: 1.75em;
  padding-top: calc(35px - .5em);
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header .chapterTitle.level2>span {
  position: relative;
  z-index: 1;
  padding: .5em 0;
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header .chapterTitle.level2:before {
  content: '';
  position: absolute;
  right: 50%;
  top: 0;
  height: 100%;
  width: 0;
  border-right: 1px solid;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header .widget-episodeTitle {
  margin: auto 2rem auto 60px;
  max-height: 665px;
  padding-top: 35px;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-nextEpisode,#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode {
  height: 100%;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-nextEpisode a,#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode a {
  display: block;
  text-decoration: none;
  height: 100%;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode a {
  padding: 10px 16px 10px 13px;
  font-size: 11.5px;
  line-height: 1.3;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode-inner {
  max-height: 665px;
  height: 100%;
  margin: auto 0;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode-inner>span {
  vertical-align: middle;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode-inner .contentMain-pagerRelation {
  margin: 35px 0 0;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode-inner .contentMain-pagerDash {
  height: 2em;
  width: 1em;
  display: inline-block;
  overflow: hidden;
  text-indent: -5em;
  position: relative;
  margin: .3em 0 .25em;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode-inner .contentMain-pagerDash:before {
  content: '';
  display: block;
  position: absolute;
  right: 50%;
  top: 0;
  height: 100%;
  width: 0;
  border-right: 1px solid;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode-inner .contentMain-pagerEpisodeTitle {
  overflow: hidden;
  max-height: calc(100% - 150px);
  text-align: left;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-nextEpisode a {
  padding: 30px 30px 30px 80px;
  line-height: 1.4;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-nextEpisode a:focus i,#page-works-episodes-episode.writingDirection-vertical #contentMain-nextEpisode a:hover i {
  color: #0990cc;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-readNextEpisode .contentMain-pagerRelation {
  margin: 0 0 0 1em;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-readNextEpisode .contentMain-chapterTitle {
  display: block;
  margin: 0 1em;
  font-size: 12px;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-readNextEpisode .contentMain-chapterTitle .level1+.level2:before {
  font-family: dcicons;
  content: '\f70a';
  display: inline-block;
  margin: 0 8px;
  opacity: .5;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-readNextEpisode .contentMain-pagerEpisodeTitle {
  font-size: 1.5em;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-readNextEpisode .contentMain-pagerArrow {
  margin: 0 1em 0 0;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-readNextEpisode svg {
  width: 38px;
  height: 38px;
  fill: #4baae0;
}

#page-works-episodes-episode.writingDirection-vertical .contentMain-nextEpisode-inner {
  display: block;
  max-height: 665px;
  height: 100%;
  padding: 24px 0;
  margin: auto 0;
  box-sizing: border-box;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-align: end;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
}

#page-works-episodes-episode.writingDirection-vertical .contentMain-nextEpisode-inner>span {
  display: block;
  max-height: 530px;
  height: 100%;
}

#page-works-episodes-episode.writingDirection-vertical .contentMain-nextEpisode-inner svg {
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg);
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-relatedWork {
  border-right: 1px solid;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-relatedWork.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-relatedWork-inner {
  max-height: 665px;
  margin: auto 0;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-relatedWork-inner h3 {
  margin: 0;
  font-size: 11px;
  padding: 16px 14px 16px 8px;
  border-left: 1px solid;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-relatedWork-inner .widget-catchphrase {
  margin: 0 0 0 .5em;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-relatedWork-inner .widget-catchphrase-author-dash {
  width: 1em;
  height: 2.25em;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-relatedWork-inner .widget-catchphrase-author-dash::before {
  top: 0;
  left: auto;
  right: 50%;
  width: 0;
  height: 2em;
  border-top: none;
  border-right: 1px solid;
}

#page-works-episodes-episode.writingDirection-vertical #contentAside {
  overflow-x: auto;
  width: 100%;
  height: 300px;
  position: fixed;
  right: 0;
  bottom: -300px;
  box-sizing: border-box;
  border-top: 1px solid;
  z-index: 10000;
  -webkit-overflow-scrolling: touch;
  padding-right: constant(safe-area-inset-right);
  padding-right: env(safe-area-inset-right);
  padding-bottom: constant(safe-area-inset-bottom);
  padding-bottom: env(safe-area-inset-bottom);
}

#page-works-episodes-episode.writingDirection-vertical #contentAside .ui-loading-large-beige {
  position: absolute;
  top: 50%;
  left: 50%;
  margin: -25px 0 0 -25px;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionHeader {
  padding: 15px;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionHeader h3,#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionHeader h4 {
  line-height: 1.2;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionHeader h3 a:focus,#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionHeader h3 a:hover,#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionHeader h4 a:focus,#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionHeader h4 a:hover {
  color: #0081c2;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionHeader h3 {
  margin: 0 .5em 0 0;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionHeader h4 {
  font-weight: 400;
  margin: 0 .25em 0 0;
}

#page-works-episodes-episode.writingDirection-vertical #contentAside-buttons {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-vertical #contentAside-buttons p {
  height: calc(50% - 2px);
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical #contentAside-buttons a,#page-works-episodes-episode.writingDirection-vertical #contentAside-buttons button {
  height: 100%;
  text-align: center;
}

#page-works-episodes-episode.writingDirection-vertical #contentAside-buttons a {
  box-sizing: border-box;
  width: 38px;
  line-height: 18px;
  padding: 10px 10px 8px;
}

#page-works-episodes-episode.writingDirection-vertical #contentAside-buttons button {
  width: 38px;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody {
  margin: 0 0 0 60px;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody header {
  border-left: 1px solid;
  margin: 0 0 0 1em;
  padding: 15px 0 15px 8px;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody header:after,#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody header:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody header:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody header h3 {
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  font-size: .9em;
  margin: 0;
  border-bottom: none;
  padding: 0!important;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc {
  padding: 0;
  margin: 0 0 0 45px;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc:before {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc header {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc h3 {
  -webkit-transform: scale(1);
  transform: scale(1);
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc h3 a {
  font-weight: 400;
  color: #888;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-workInfo {
  font-size: 11.5px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-workInfo p {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-workInfo p:first-child {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items {
  list-style-type: none;
  margin: 0;
  padding: 0;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #222;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:after,#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #aaa;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:focus,#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:hover {
  color: #0081c2;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a>span {
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items li {
  line-height: 1.2;
  clear: both;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items li:after,#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items li:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items li:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items li:first-child.widget-toc-chapter {
  border-top: none!important;
  margin-top: 0!important;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter {
  position: relative;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  margin: 16px 0 0 0;
  font-size: 1em;
  background: #eae9e8;
  border-top: 1px solid #ddd;
  color: #888;
  text-align: center;
  letter-spacing: .5px;
  padding: 24px 16px 8px;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1+ol {
  margin-top: 1em;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  margin: 24px 0 0 16px;
  padding: 0 16px 8px 0;
  font-size: .85em;
  letter-spacing: .5px;
  border-bottom: 1px solid #ddd;
  color: #666;
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-bottom: 1px solid #ddd;
  position: relative;
  margin: 0 0 0 16px;
  padding: 1px 0;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode-datePublished {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode-episodeTitle {
  padding: 1em 65px 1em 0;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border: none;
  border-left: 1px solid;
  margin: 16px 0 0;
  padding: 0 1px;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode:first-child.widget-toc-chapter.widget-toc-level1 {
  margin: 0;
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode-episodeTitle {
  padding: 0 1em 65px;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  text-align: left;
  padding: 16px 24px 16px 12px;
  border-top: none;
  margin: 0 16px 0 0;
  border-right: 1px solid;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  margin: 16px 24px 0 0;
  border: none;
  border-left: 1px solid;
  padding: 0 0 16px 12px;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter:first-child {
  margin: 0!important;
  border-right: none!important;
}

#page-works-episodes-episode.writingDirection-vertical #episodeInfo {
  font-size: 11px;
  padding: 16px 0 16px 8px;
  margin: 0;
  border-left: 1px solid;
}

#page-works-episodes-episode.writingDirection-vertical #episodeInfo:after,#page-works-episodes-episode.writingDirection-vertical #episodeInfo:before {
  content: '';
  display: table;
}

#page-works-episodes-episode.writingDirection-vertical #episodeInfo:after {
  clear: both;
}

#page-works-episodes-episode.writingDirection-vertical #episodeInfo dd,#page-works-episodes-episode.writingDirection-vertical #episodeInfo dt {
  margin: 0 0 0 .5em;
  padding: 0;
  line-height: 1.3;
}

#page-works-episodes-episode.writingDirection-vertical #episodeInfo dt {
  height: 7em;
  float: left;
  clear: both;
  font-weight: 700;
  font-size: .95em;
}

#page-works-episodes-episode.writingDirection-vertical #episodeInfo dd {
  height: calc(100% - 7em);
  float: right;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-modal-window {
  overflow-y: hidden;
  overflow-x: auto;
  height: 100%;
  max-height: 500px;
  min-width: 1px;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-modal-header {
  padding: 53px 1em 1em 0;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-modal-header h3 {
  text-align: left;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-tab {
  width: auto;
  margin: 0!important;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-tab.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-tab ul {
  padding: 0 10px 0 0;
  overflow-x: hidden;
  overflow-y: auto;
  text-align: left;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-tab li {
  margin: 0;
  vertical-align: bottom;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-tab li:first-child {
  margin-top: 35px;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-tab li.isActive {
  box-shadow: 5px 0 10px 0 rgba(0,0,0,.1);
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-tab button {
  padding: 1em .5em 1em .25em;
  width: 35px;
  height: 100px;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-tab button span {
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-modal-body {
  padding: 16px 0;
  padding-bottom: calc(1em + constant(safe-area-inset-bottom));
  padding-bottom: calc(1em + env(safe-area-inset-bottom));
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting {
  -webkit-columns: 2;
  columns: 2;
  -webkit-column-gap: 32px;
  column-gap: 32px;
  position: relative;
  width: 176px;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting section {
  overflow: hidden;
  padding-left: 1px;
  -webkit-column-break-inside: avoid;
  break-inside: avoid;
  padding: 0 15px 0 0;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting section:last-child {
  margin-left: 1px;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting h4 {
  margin: 0 0 0 7.5px;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting li {
  border-width: 1px 1px 0 1px;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting li:first-child {
  border-radius: 3px 3px 0 0;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting li:last-child {
  border-width: 1px;
  border-radius: 0 0 3px 3px;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting li:hover+li {
  border-color: #ddd;
  border-top-color: #222;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting li:hover+li.isActive {
  border-left-color: #4baae0!important;
  border-top-color: #222!important;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting li.isActive+li {
  border-color: #ddd;
  border-top-color: #4baae0;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .widget-displaySetting li label {
  height: auto;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-modal-footer {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  padding: 16px 0 16px 15px;
  padding-bottom: calc(16px + constant(safe-area-inset-bottom));
  padding-bottom: calc(16px + env(safe-area-inset-bottom));
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-modal-footer div {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-height: 0;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-modal-footer button {
  width: 35px;
  height: 50px;
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting-modalContainer .ui-modal-footer button span {
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting,#page-works-episodes-episode.writingDirection-vertical #readSetting {
  width: 176px;
}

#page-works-episodes-episode.writingDirection-vertical #displaySetting.isHidden,#page-works-episodes-episode.writingDirection-vertical #readSetting.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical #readSetting section {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

#page-works-episodes-episode.writingDirection-vertical #readSetting header {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  margin: 0 1em 16px 0;
}

#page-works-episodes-episode.writingDirection-vertical #readSetting header h4 {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical #readSetting header p {
  line-height: 1.4;
  font-size: 12px;
  color: #666;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-action-left .ui-tooltip-top:before {
  left: 100%;
  bottom: auto;
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg);
  margin: -10px 0 0;
  top: 50%;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-action-left .ui-tooltip-top:after {
  top: 50%;
  left: 100%;
  right: auto;
  bottom: auto;
  margin: 0 0 0 10px;
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  -webkit-transform: translateY(-50%);
  transform: translateY(-50%);
  max-height: 500px;
  max-width: 100%;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-links {
  text-align: center;
  border: none;
  line-height: 1.5;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-links p {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-links a {
  padding: 1em 0;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-links a:first-child {
  padding: 0 0 1em;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-links a:last-child {
  padding: 1em 0 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #contentMain-inner,#page-works-episodes-episode.writingDirection-vertical.isPC #contentMain-nextEpisode,#page-works-episodes-episode.writingDirection-vertical.isPC #contentMain-previousEpisode,#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter {
  min-height: 590px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC .episodeFooter-section {
  padding: 40px 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC .episodeFooter-section-inner {
  margin: auto 0;
  max-height: 665px;
  padding: 0 45px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author,#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-work {
  padding: 40px 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #displaySetting-modalContainer .ui-modal-header {
  padding: 53px 1em 1em;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action {
  margin: 0 0 0 60px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action.isRecommendCheerAction {
  margin-right: 100px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action i {
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action .ui-button-silent {
  padding: 16px 32px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action .ui-button-silent.isOpen {
  color: #0081c2;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action .ui-button-silent.isOpen .icon-up {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action .ui-button-silent.isOpen .icon-bottom {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action .ui-button-silent .icon-up {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action .ui-button-silent .icon-bottom {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-left {
  position: relative;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-left i:before {
  display: inline;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-right {
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  border-left: 1px solid;
  padding: 0 0 16px 12px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton-container {
  border-left: 1px solid;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  width: 89px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton-container>div {
  min-height: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-height: 0;
  font-size: 1.2em;
  text-align: left;
  height: 100%;
  max-height: 100%;
  width: 89px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton:focus,#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton:hover {
  background: 0 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton-inner {
  height: 100%;
  width: 100%;
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton-inner i {
  font-size: 1.1em;
  margin: -3px 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton-inner .icon-heart-negative {
  color: #f23e48;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton-inner .isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton-inner span {
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-action-cheerButton-inner #episodeFooter-action-cheerButton-cheer {
  color: #0990cc;
}

@media screen and (max-height:735px) {
  #page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers {
    margin: 24px 0;
  }
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers .ui-loading {
  margin: auto 30px;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers h4,#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers li {
  border-left: 1px solid;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers h4 {
  font-size: 11px;
  margin: 0;
  padding: 0 0 0 8px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers ul {
  padding: 0;
  margin: 0 0 0 30px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers ul li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers li {
  padding: 0 8px;
  list-style-type: none;
  font-size: .8em;
  line-height: 1.5;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers template {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-cheers-isEmpty {
  font-size: .8rem;
  color: #888;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-work-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-work-header h3 {
  line-height: 1.3;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-height: 0;
  margin: 0 0 30px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-work-header-workTitle {
  font-size: 16px;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-work-header-author {
  margin: 0 4px 0 0;
  font-size: 14px;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-work-header-author a {
  text-decoration: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-signUp-balloon {
  padding: 4em 1.5em 4em 1em;
  display: inline-block;
  line-height: 1.5;
  position: relative;
  box-sizing: border-box;
  margin: 0 8px 0 10px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-signUp-balloon-inner {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-height: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-signUp-balloon-inner h3,#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-signUp-balloon-inner p {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-signUp-balloon-inner h3 {
  font-size: 1.5em;
  margin: 0 .25em 0 .5em;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-signUp-balloon-inner .signUp-balloon-button {
  margin: 0 1em 0 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-signUp-balloon-inner .signUp-balloon-button a {
  display: block;
  font-size: 1.1em;
  padding: 0 .75em;
  margin: 0 .5em;
  max-height: 300px;
  text-align: center;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-signUp-balloon-inner .signUp-duration {
  max-height: 300px;
  text-align: center;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author {
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-info h3 {
  font-weight: 400;
  font-size: 11.5px;
  margin: 0 0 0 4px;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  margin: 0 0 0 10px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-name {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  margin: 0 0 16px 0;
  line-height: 1.3;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-name a {
  display: inline-block;
  text-decoration: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-name span {
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-name span:focus,#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-name span:hover {
  text-decoration: underline;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-links {
  margin: 0;
  padding: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-links li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-links li {
  display: inline-block;
  margin: 0 0 .75em 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-links li span {
  vertical-align: middle;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news {
  margin: auto 30px auto 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news h5 {
  font-size: 11px;
  margin: 0;
  padding: 0 0 0 8px;
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news ul {
  padding: 0;
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news ul li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news ul a {
  text-decoration: none;
  padding: 110px 5px 10% 5px;
  position: relative;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news ul h6,#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news ul p {
  margin: 0;
  line-height: 1.5;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news ul h6 {
  font-size: 1em;
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news ul p {
  font-size: .85em;
  position: absolute;
  right: 6px;
  top: 0;
  height: 90px;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author-news li {
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-links {
  padding: 16px 2em 16px 1em;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-inner {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-align: end;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
  max-height: 665px;
  height: 100%;
  margin: auto 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch .episodeFooter-section {
  height: 100%;
  padding: 40px 0;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch .episodeFooter-section-inner {
  margin: auto 0;
  padding: 16px 45px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #contentMain-previousEpisode a {
  padding-top: 40px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #contentMain-nextEpisode a {
  padding-top: 40px;
  padding-bottom: 40px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #contentMain-nextEpisode-ad {
  display: block;
  padding: 40px 0 40px 30px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #contentMain-nextEpisode-inner {
  padding: 35px 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #displaySetting-modalContainer .ui-modal-window {
  max-width: 330px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode-episodeTitle {
  padding-bottom: 65px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action {
  margin: 0 0 0 45px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action.isRecommendCheerAction {
  margin-right: 100px;
}

@media screen and (max-height:540px) {
  #page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action.isRecommendCheerAction {
    margin-right: 155px;
  }
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action i {
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action .ui-button-silent {
  padding: 16px 32px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action .ui-button-silent.isOpen {
  color: #0081c2;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action .ui-button-silent.isOpen .icon-up {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action .ui-button-silent.isOpen .icon-bottom {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action .ui-button-silent .icon-up {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action .ui-button-silent .icon-bottom {
  display: inline-block;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-left {
  position: relative;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-left i:before {
  display: inline;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-right {
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  border-left: 1px solid;
  padding: 0 0 0 12px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton-container {
  border-left: 1px solid;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  width: 89px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton-container>div {
  min-height: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-height: 0;
  font-size: 1.2em;
  text-align: left;
  height: 100%;
  width: 89px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton:focus,#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton:hover {
  background: 0 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton-inner {
  height: 100%;
  width: 100%;
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton-inner i {
  font-size: 1.1em;
  margin: -3px 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton-inner .icon-heart-negative {
  color: #f23e48;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton-inner .isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton-inner span {
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-action-cheerButton-inner #episodeFooter-action-cheerButton-cheer {
  color: #0990cc;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers.isHidden {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers .ui-loading {
  margin: auto 24px;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers h4,#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers li {
  border-left: 1px solid;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers h4 {
  font-size: 11px;
  margin: 0;
  padding: 0 0 0 8px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers ul {
  padding: 0;
  margin: 0 0 0 2em;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers ul li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers li {
  padding: 0 8px;
  list-style-type: none;
  font-size: .8em;
  line-height: 1.5;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers template {
  display: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-cheers-isEmpty {
  font-size: .8rem;
  color: #888;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-work {
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-work .episodeFooter-section-inner {
  padding: 16px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-work-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-work-header h3 {
  line-height: 1.3;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-height: 0;
  margin: 0 0 30px 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-work-header-workTitle {
  font-size: 13px;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-work-header-author {
  margin: 0 4px 0 0;
  font-size: 11px;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-work-header-author a {
  text-decoration: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon {
  padding: 4em 1.5em 4em 1em;
  display: inline-block;
  line-height: 1.5;
  position: relative;
  box-sizing: border-box;
  margin: 0 8px 0 10px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

@media screen and (max-height:640px) {
  #page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon {
    padding: 3em 1em 1em 1em;
  }
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon-inner {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-height: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon-inner h3,#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon-inner p {
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon-inner h3 {
  font-size: 15px;
  margin: 0 .25em 0 .5em;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon-inner .signUp-balloon-button {
  margin: 0 1em 0 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon-inner .signUp-balloon-button a {
  font-size: 1.1em;
  padding: 1em .75em;
  margin: 0 .5em;
  max-height: 300px;
  text-align: center;
  height: 100%;
  box-sizing: border-box;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon-inner .signUp-balloon-button a>span {
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon-inner .signUp-balloon-button a>span+span {
  margin: 0 4px 0 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-signUp-balloon-inner .signUp-duration {
  max-height: 300px;
  text-align: center;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author {
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-info h3 {
  font-weight: 400;
  font-size: 11px;
  margin: 0 0 0 4px;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-name {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  margin: 0 0 16px 0;
  line-height: 1.3;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-name a {
  display: inline-block;
  text-decoration: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-name span {
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-name span:focus,#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-name span:hover {
  text-decoration: underline;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-links {
  margin: 0;
  padding: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-links li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-links li {
  display: inline-block;
  margin: 0 0 .75em 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-links li span {
  vertical-align: middle;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news {
  margin: auto 30px auto 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news h5 {
  font-size: 11px;
  margin: 0;
  padding: 0 0 0 8px;
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news ul {
  padding: 0;
  margin: 0;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news ul li {
  list-style-type: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news ul a {
  text-decoration: none;
  padding: 110px 5px 10% 5px;
  position: relative;
  display: block;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news ul h6,#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news ul p {
  margin: 0;
  line-height: 1.5;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news ul h6 {
  font-size: 1em;
  font-weight: 400;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news ul p {
  font-size: .85em;
  position: absolute;
  right: 6px;
  top: 0;
  height: 90px;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-author-news li {
  border: none;
}

#page-works-episodes-episode.writingDirection-vertical.isTouch #episodeFooter-links {
  padding: 0 2em 0 1em!important;
  margin: 24px 0!important;
  height: calc(100% - 48px);
  max-height: 482px!important;
}

#page-works-episodes-episode {
  color: #222;
  background: #f2f1f0;
}

#page-works-episodes-episode #contentMain-header .chapterTitle.level2 span,#page-works-episodes-episode #contentMain-inner,#page-works-episodes-episode #episodeFooter,#page-works-episodes-episode #worksEpisodesEpisodeHeader,#page-works-episodes-episode .widget-episodeTitle {
  background: #fff;
}

#page-works-episodes-episode .ui-loading-large-beige:before {
  background: #f2f1f0;
}

#page-works-episodes-episode .ui-loading:before {
  background: #fff;
}

#page-works-episodes-episode #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a,#page-works-episodes-episode #worksEpisodesEpisodeHeader .float-left li a,#page-works-episodes-episode #worksEpisodesEpisodeHeader .ui-button-silent {
  color: #222;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:before {
  border-left-color: #ddd;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:before {
  border-top-color: #ddd;
}

#page-works-episodes-episode #worksEpisodesEpisodeHeader-breadcrumbs h1 a {
  color: #222;
}

#page-works-episodes-episode #worksEpisodesEpisodeHeader-breadcrumbs h1 a:focus,#page-works-episodes-episode #worksEpisodesEpisodeHeader-breadcrumbs h1 a:hover {
  color: #0081c2;
}

#page-works-episodes-episode #worksEpisodesEpisodeHeader-logo,#page-works-episodes-episode #worksEpisodesEpisodeHeader-tools {
  background: #fff;
}

#page-works-episodes-episode #contentMain-header .widget-episodeTitle {
  color: #222;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-header .chapterTitle.level2:before {
  border-top-color: #bcbfbf!important;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header .chapterTitle.level2:before {
  border-right-color: #bcbfbf!important;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-header-cover {
  border-top-color: #ddd!important;
  border-bottom-color: #ddd!important;
}

#page-works-episodes-episode #contentMain-nextEpisode,#page-works-episodes-episode #contentMain-previousEpisode {
  background: #f2f1f0;
}

#page-works-episodes-episode #contentMain-nextEpisode a,#page-works-episodes-episode #contentMain-previousEpisode a {
  background: #f2f1f0;
}

#page-works-episodes-episode #contentMain-nextEpisode a:focus,#page-works-episodes-episode #contentMain-nextEpisode a:hover,#page-works-episodes-episode #contentMain-previousEpisode a:focus,#page-works-episodes-episode #contentMain-previousEpisode a:hover {
  background: #eae9e8;
}

#page-works-episodes-episode #contentMain-nextEpisode .contentMain-chapterTitle {
  color: #222;
}

#page-works-episodes-episode.writingDirection-horizontal .contentMain-pagerDash:before {
  border-top-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-vertical .contentMain-pagerDash:before {
  border-right-color: #ddd!important;
}

#page-works-episodes-episode .contentMain-pagerRelation {
  color: #666!important;
}

#page-works-episodes-episode .contentMain-pagerEpisodeTitle {
  color: #222;
}

#page-works-episodes-episode #contentMain-relatedWork {
  background: #eae9e8;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-relatedWork {
  border-top-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-horizontal #contentMain-relatedWork h3 {
  border-bottom-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-relatedWork {
  border-right-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-relatedWork h3 {
  border-left-color: #ddd!important;
}

#page-works-episodes-episode #contentAside {
  background: #f2f1f0;
}

#page-works-episodes-episode #contentAside::-webkit-scrollbar {
  width: 8px;
  background-color: #f2f1f0;
}

#page-works-episodes-episode #contentAside::-webkit-scrollbar:hover {
  background-color: #ddd;
}

#page-works-episodes-episode #contentAside::-webkit-scrollbar-thumb {
  background-color: #aaa;
}

#page-works-episodes-episode #contentAside::-webkit-scrollbar-thumb:hover {
  background-color: #222;
}

#page-works-episodes-episode #contentAside .widget-toc-workInfo {
  color: #666;
}

#page-works-episodes-episode.writingDirection-horizontal #contentAside {
  border-left-color: #ddd;
}

#page-works-episodes-episode.writingDirection-horizontal #contentAside::-webkit-scrollbar {
  width: 8px;
}

#page-works-episodes-episode.writingDirection-vertical #contentAside {
  border-top-color: #ddd;
}

#page-works-episodes-episode.writingDirection-vertical #contentAside::-webkit-scrollbar {
  height: 8px;
}

#page-works-episodes-episode .contentAside-sectionHeader h3 a,#page-works-episodes-episode .contentAside-sectionHeader h4 a {
  color: #222;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody header {
  border-bottom-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  background: #eae9e8;
  border-top-color: #ddd!important;
  color: #666;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  background: #f2f1f0;
  color: #666;
  border-bottom-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-bottom-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #222;
}

#page-works-episodes-episode.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #666;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeInfo {
  border-bottom-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody header {
  border-left-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  background: #eae9e8;
  border-right-color: #ddd!important;
  color: #666;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  background: #f2f1f0;
  color: #666;
  border-left-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-left-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #222;
}

#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #666;
}

#page-works-episodes-episode.writingDirection-vertical #episodeInfo {
  border-left-color: #ddd!important;
}

#page-works-episodes-episode #episodeFooter-share {
  border: 1px solid #ddd;
}

#page-works-episodes-episode.isPC.writingDirection-horizontal #episodeFooter-work {
  border-top: 1px solid #ddd;
}

#page-works-episodes-episode.isPC.writingDirection-horizontal #episodeFooter-links {
  border-top: 1px solid #ddd;
}

#page-works-episodes-episode.isPC.writingDirection-vertical #episodeFooter-work {
  border-right: 1px solid #ddd;
}

#page-works-episodes-episode.isPC.writingDirection-vertical #episodeFooter-links {
  border-right: 1px solid #ddd;
}

#page-works-episodes-episode.isTouch.writingDirection-horizontal #episodeFooter-links {
  border-top: 1px solid #ddd;
}

#page-works-episodes-episode.isTouch.writingDirection-vertical #episodeFooter-links {
  border-right: 1px solid #ddd;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-action-cheerButton-container,#page-works-episodes-episode.writingDirection-vertical #episodeFooter-action-right {
  border-left-color: #ddd!important;
}

#page-works-episodes-episode #episodeFooter-action-cheerButton:disabled #episodeFooter-action-cheerButton-cheer {
  color: #ccc!important;
}

#page-works-episodes-episode #episodeFooter-cheers li {
  color: #666;
}

#page-works-episodes-episode #episodeFooter-cheers a {
  color: #222;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-cheers h4,#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-cheers li {
  border-bottom-color: #ddd!important;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-cheers h4,#page-works-episodes-episode.writingDirection-vertical #episodeFooter-cheers li {
  border-left-color: #ddd!important;
}

#page-works-episodes-episode.isTouch #episodeFooter-work .episodeFooter-section-inner {
  border: 3px double #ddd;
}

#page-works-episodes-episode #episodeFooter-work-header-workTitle a {
  color: #222;
}

#page-works-episodes-episode #episodeFooter-work-header-workTitle a:focus,#page-works-episodes-episode #episodeFooter-work-header-workTitle a:hover {
  color: #0990cc;
}

#page-works-episodes-episode #episodeFooter-signUp-balloon {
  background: #f2f1f0;
  border: 1px solid #ddd;
  color: #222;
}

#page-works-episodes-episode #episodeFooter-signUp-balloon .signUp-duration {
  color: #666;
}

#page-works-episodes-episode #episodeFooter-author h3 {
  color: #666;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-author {
  border-top: 1px solid #ddd;
}

#page-works-episodes-episode.writingDirection-vertical.isPC #episodeFooter-author {
  border-right: 1px solid #ddd!important;
}

#page-works-episodes-episode #episodeFooter-author-links a {
  color: #222;
}

#page-works-episodes-episode #episodeFooter-author-links a:focus,#page-works-episodes-episode #episodeFooter-author-links a:hover {
  color: #0990cc;
}

#page-works-episodes-episode #episodeFooter-author-news ul a:focus h6,#page-works-episodes-episode #episodeFooter-author-news ul a:hover h6 {
  text-decoration: underline;
  color: #0081c2;
}

#page-works-episodes-episode #episodeFooter-author-news ul h6 {
  color: #222;
}

#page-works-episodes-episode #episodeFooter-author-news ul p {
  color: #666;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-author-news h5 {
  border-bottom: 1px solid #ddd;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-author-news ul li {
  border-bottom: 1px solid #ddd;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-author-news h5 {
  border-left: 1px solid #ddd!important;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-author-news ul li {
  border-left: 1px solid #ddd!important;
}

#page-works-episodes-episode #episodeFooter-links a {
  color: #222;
}

#page-works-episodes-episode #episodeFooter-links a:focus,#page-works-episodes-episode #episodeFooter-links a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.writingDirection-horizontal #episodeFooter-links a+a {
  border-left: 1px solid #ddd;
}

#page-works-episodes-episode.writingDirection-vertical #episodeFooter-links a+a {
  border-top: 1px solid #ddd;
}

#page-works-episodes-episode.writingDirection-horizontal #worksEpisodesEpisodeHeader-logo-horizontal-white {
  display: none!important;
}

#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-logo-vertical-white {
  display: none!important;
}

#page-works-episodes-episode.colorTheme-black {
  color: #f0f0f0;
  background: #484b4d;
}

#page-works-episodes-episode.colorTheme-black #contentMain-header .chapterTitle.level2 span,#page-works-episodes-episode.colorTheme-black #contentMain-inner,#page-works-episodes-episode.colorTheme-black #episodeFooter,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader,#page-works-episodes-episode.colorTheme-black .widget-episodeTitle {
  background: #171b1d;
}

#page-works-episodes-episode.colorTheme-black .ui-loading-large-beige:before {
  background: #484b4d;
}

#page-works-episodes-episode.colorTheme-black .ui-loading:before {
  background: #171b1d;
}

#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .float-left li a,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .ui-button-silent {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:before {
  border-left-color: #686b6c;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:before {
  border-top-color: #686b6c;
}

#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader-breadcrumbs h1 a {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader-breadcrumbs h1 a:focus,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader-breadcrumbs h1 a:hover {
  color: #0081c2;
}

#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader-logo,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader-tools {
  background: #171b1d;
}

#page-works-episodes-episode.colorTheme-black #contentMain-header .widget-episodeTitle {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #contentMain-header .chapterTitle.level2:before {
  border-top-color: #8b8888!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #contentMain-header .chapterTitle.level2:before {
  border-right-color: #8b8888!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #contentMain-header-cover {
  border-top-color: #686b6c!important;
  border-bottom-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black #contentMain-nextEpisode,#page-works-episodes-episode.colorTheme-black #contentMain-previousEpisode {
  background: #484b4d;
}

#page-works-episodes-episode.colorTheme-black #contentMain-nextEpisode a,#page-works-episodes-episode.colorTheme-black #contentMain-previousEpisode a {
  background: #484b4d;
}

#page-works-episodes-episode.colorTheme-black #contentMain-nextEpisode a:focus,#page-works-episodes-episode.colorTheme-black #contentMain-nextEpisode a:hover,#page-works-episodes-episode.colorTheme-black #contentMain-previousEpisode a:focus,#page-works-episodes-episode.colorTheme-black #contentMain-previousEpisode a:hover {
  background: #585b5d;
}

#page-works-episodes-episode.colorTheme-black #contentMain-nextEpisode .contentMain-chapterTitle {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal .contentMain-pagerDash:before {
  border-top-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical .contentMain-pagerDash:before {
  border-right-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black .contentMain-pagerRelation {
  color: #b0b0b0!important;
}

#page-works-episodes-episode.colorTheme-black .contentMain-pagerEpisodeTitle {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black #contentMain-relatedWork {
  background: #585b5d;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #contentMain-relatedWork {
  border-top-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #contentMain-relatedWork h3 {
  border-bottom-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #contentMain-relatedWork {
  border-right-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #contentMain-relatedWork h3 {
  border-left-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black #contentAside {
  background: #484b4d;
}

#page-works-episodes-episode.colorTheme-black #contentAside::-webkit-scrollbar {
  width: 8px;
  background-color: #484b4d;
}

#page-works-episodes-episode.colorTheme-black #contentAside::-webkit-scrollbar:hover {
  background-color: #686b6c;
}

#page-works-episodes-episode.colorTheme-black #contentAside::-webkit-scrollbar-thumb {
  background-color: #aaa;
}

#page-works-episodes-episode.colorTheme-black #contentAside::-webkit-scrollbar-thumb:hover {
  background-color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black #contentAside .widget-toc-workInfo {
  color: #b0b0b0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #contentAside {
  border-left-color: #686b6c;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #contentAside::-webkit-scrollbar {
  width: 8px;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #contentAside {
  border-top-color: #686b6c;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #contentAside::-webkit-scrollbar {
  height: 8px;
}

#page-works-episodes-episode.colorTheme-black .contentAside-sectionHeader h3 a,#page-works-episodes-episode.colorTheme-black .contentAside-sectionHeader h4 a {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal .contentAside-sectionBody header {
  border-bottom-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  background: #585b5d;
  border-top-color: #686b6c!important;
  color: #b0b0b0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  background: #484b4d;
  color: #b0b0b0;
  border-bottom-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-bottom-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #b0b0b0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #episodeInfo {
  border-bottom-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical .contentAside-sectionBody header {
  border-left-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  background: #585b5d;
  border-right-color: #686b6c!important;
  color: #b0b0b0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  background: #484b4d;
  color: #b0b0b0;
  border-left-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-left-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #b0b0b0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeInfo {
  border-left-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-share {
  border: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.isPC.writingDirection-horizontal #episodeFooter-work {
  border-top: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.isPC.writingDirection-horizontal #episodeFooter-links {
  border-top: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.isPC.writingDirection-vertical #episodeFooter-work {
  border-right: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.isPC.writingDirection-vertical #episodeFooter-links {
  border-right: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.isTouch.writingDirection-horizontal #episodeFooter-links {
  border-top: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.isTouch.writingDirection-vertical #episodeFooter-links {
  border-right: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeFooter-action-cheerButton-container,#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeFooter-action-right {
  border-left-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-action-cheerButton:disabled #episodeFooter-action-cheerButton-cheer {
  color: #6f6f6f!important;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-cheers li {
  color: #b0b0b0;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-cheers a {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #episodeFooter-cheers h4,#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #episodeFooter-cheers li {
  border-bottom-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeFooter-cheers h4,#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeFooter-cheers li {
  border-left-color: #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.isTouch #episodeFooter-work .episodeFooter-section-inner {
  border: 3px double #686b6c;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-work-header-workTitle a {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-work-header-workTitle a:focus,#page-works-episodes-episode.colorTheme-black #episodeFooter-work-header-workTitle a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-signUp-balloon {
  background: #484b4d;
  border: 1px solid #686b6c;
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-signUp-balloon .signUp-duration {
  color: #b0b0b0;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-author h3 {
  color: #b0b0b0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #episodeFooter-author {
  border-top: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical.isPC #episodeFooter-author {
  border-right: 1px solid #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-author-links a {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-author-links a:focus,#page-works-episodes-episode.colorTheme-black #episodeFooter-author-links a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-author-news ul a:focus h6,#page-works-episodes-episode.colorTheme-black #episodeFooter-author-news ul a:hover h6 {
  text-decoration: underline;
  color: #0081c2;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-author-news ul h6 {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-author-news ul p {
  color: #b0b0b0;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #episodeFooter-author-news h5 {
  border-bottom: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #episodeFooter-author-news ul li {
  border-bottom: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeFooter-author-news h5 {
  border-left: 1px solid #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeFooter-author-news ul li {
  border-left: 1px solid #686b6c!important;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-links a {
  color: #f0f0f0;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-links a:focus,#page-works-episodes-episode.colorTheme-black #episodeFooter-links a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #episodeFooter-links a+a {
  border-left: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeFooter-links a+a {
  border-top: 1px solid #686b6c;
}

#page-works-episodes-episode.colorTheme-black [class^=ui-button] {
  border: none;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #worksEpisodesEpisodeHeader-logo-horizontal-default {
  display: none!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #worksEpisodesEpisodeHeader-logo-horizontal-white {
  display: inline-block!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #worksEpisodesEpisodeHeader-logo-vertical-default {
  display: none!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #worksEpisodesEpisodeHeader-logo-vertical-white {
  display: inline-block!important;
}

#page-works-episodes-episode.colorTheme-black .ui-modal-container {
  background: rgba(255,255,255,.3);
}

#page-works-episodes-episode.colorTheme-black .ui-modal-window {
  color: #222;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #worksEpisodesEpisodeHeader {
  box-shadow: 0 1px 0 0 rgba(255,255,255,.3);
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #worksEpisodesEpisodeHeader {
  box-shadow: -1px 0 0 0 rgba(255,255,255,.3);
}

#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:focus,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:hover,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .float-left li a:focus,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .float-left li a:hover,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .float-right .ui-button-silent-wrapper:focus,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .float-right .ui-button-silent-wrapper:hover,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .ui-button-silent:focus,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .ui-button-silent:hover {
  color: #4baae0;
}

#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .ui-tooltip:focus:before,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .ui-tooltip:hover:before {
  border-bottom-color: #fff;
}

#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .ui-tooltip:focus:after,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader .ui-tooltip:hover:after {
  background-color: #fff;
  color: #222!important;
}

#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader-closeButton svg,#page-works-episodes-episode.colorTheme-black #worksEpisodesEpisodeHeader-tools svg {
  fill: #fff;
}

#page-works-episodes-episode.colorTheme-black .widget-episodeBody a {
  color: #4baae0;
}

#page-works-episodes-episode.colorTheme-black #contentMain-relatedWork {
  background: #ddd;
}

#page-works-episodes-episode.colorTheme-black #contentMain-relatedWork h3 {
  color: #222;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #contentMain-relatedWork h3 {
  border-bottom-color: #bbb!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #contentMain-relatedWork h3 {
  border-left-color: #bbb!important;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-action-cheerButton-container .ui-tooltip:focus:before,#page-works-episodes-episode.colorTheme-black #episodeFooter-action-cheerButton-container .ui-tooltip:hover:before {
  border-top-color: #fff;
  border-bottom-color: transparent;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-action-cheerButton-container .ui-tooltip:focus:after,#page-works-episodes-episode.colorTheme-black #episodeFooter-action-cheerButton-container .ui-tooltip:hover:after {
  background-color: #fff;
  color: #222!important;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-links a {
  color: #222;
}

#page-works-episodes-episode.colorTheme-black #episodeFooter-links a:focus,#page-works-episodes-episode.colorTheme-black #episodeFooter-links a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #episodeFooter-links {
  border-top-color: #bbb!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-horizontal #episodeFooter-links a+a {
  border-left-color: #bbb!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeFooter-links {
  border-right-color: #bbb!important;
}

#page-works-episodes-episode.colorTheme-black.writingDirection-vertical #episodeFooter-links a+a {
  border-top-color: #bbb!important;
}

#page-works-episodes-episode.colorTheme-black .contentAside-sectionHeader h3 a:focus,#page-works-episodes-episode.colorTheme-black .contentAside-sectionHeader h3 a:hover,#page-works-episodes-episode.colorTheme-black .contentAside-sectionHeader h4 a:focus,#page-works-episodes-episode.colorTheme-black .contentAside-sectionHeader h4 a:hover {
  color: #4baae0;
}

#page-works-episodes-episode.colorTheme-black #contentAside-buttons a {
  background: #bbb;
  color: #222;
  border: 1px solid #aaa;
}

#page-works-episodes-episode.colorTheme-black #contentAside-buttons a:active,#page-works-episodes-episode.colorTheme-black #contentAside-buttons a:focus,#page-works-episodes-episode.colorTheme-black #contentAside-buttons a:hover {
  background: #999;
  color: #fff;
}

#page-works-episodes-episode.colorTheme-kinari {
  color: #292826;
  background: #ebe9dd;
}

#page-works-episodes-episode.colorTheme-kinari #contentMain-header .chapterTitle.level2 span,#page-works-episodes-episode.colorTheme-kinari #contentMain-inner,#page-works-episodes-episode.colorTheme-kinari #episodeFooter,#page-works-episodes-episode.colorTheme-kinari #worksEpisodesEpisodeHeader,#page-works-episodes-episode.colorTheme-kinari .widget-episodeTitle {
  background: #f7f6eb;
}

#page-works-episodes-episode.colorTheme-kinari .ui-loading-large-beige:before {
  background: #ebe9dd;
}

#page-works-episodes-episode.colorTheme-kinari .ui-loading:before {
  background: #f7f6eb;
}

#page-works-episodes-episode.colorTheme-kinari #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a,#page-works-episodes-episode.colorTheme-kinari #worksEpisodesEpisodeHeader .float-left li a,#page-works-episodes-episode.colorTheme-kinari #worksEpisodesEpisodeHeader .ui-button-silent {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:before {
  border-left-color: #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:before {
  border-top-color: #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari #worksEpisodesEpisodeHeader-breadcrumbs h1 a {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari #worksEpisodesEpisodeHeader-breadcrumbs h1 a:focus,#page-works-episodes-episode.colorTheme-kinari #worksEpisodesEpisodeHeader-breadcrumbs h1 a:hover {
  color: #0081c2;
}

#page-works-episodes-episode.colorTheme-kinari #worksEpisodesEpisodeHeader-logo,#page-works-episodes-episode.colorTheme-kinari #worksEpisodesEpisodeHeader-tools {
  background: #f7f6eb;
}

#page-works-episodes-episode.colorTheme-kinari #contentMain-header .widget-episodeTitle {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #contentMain-header .chapterTitle.level2:before {
  border-top-color: #c4c1b0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #contentMain-header .chapterTitle.level2:before {
  border-right-color: #c4c1b0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #contentMain-header-cover {
  border-top-color: #d0cdc0!important;
  border-bottom-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari #contentMain-nextEpisode,#page-works-episodes-episode.colorTheme-kinari #contentMain-previousEpisode {
  background: #ebe9dd;
}

#page-works-episodes-episode.colorTheme-kinari #contentMain-nextEpisode a,#page-works-episodes-episode.colorTheme-kinari #contentMain-previousEpisode a {
  background: #ebe9dd;
}

#page-works-episodes-episode.colorTheme-kinari #contentMain-nextEpisode a:focus,#page-works-episodes-episode.colorTheme-kinari #contentMain-nextEpisode a:hover,#page-works-episodes-episode.colorTheme-kinari #contentMain-previousEpisode a:focus,#page-works-episodes-episode.colorTheme-kinari #contentMain-previousEpisode a:hover {
  background: #e4e1d1;
}

#page-works-episodes-episode.colorTheme-kinari #contentMain-nextEpisode .contentMain-chapterTitle {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal .contentMain-pagerDash:before {
  border-top-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical .contentMain-pagerDash:before {
  border-right-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari .contentMain-pagerRelation {
  color: #6a6968!important;
}

#page-works-episodes-episode.colorTheme-kinari .contentMain-pagerEpisodeTitle {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari #contentMain-relatedWork {
  background: #e4e1d1;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #contentMain-relatedWork {
  border-top-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #contentMain-relatedWork h3 {
  border-bottom-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #contentMain-relatedWork {
  border-right-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #contentMain-relatedWork h3 {
  border-left-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari #contentAside {
  background: #ebe9dd;
}

#page-works-episodes-episode.colorTheme-kinari #contentAside::-webkit-scrollbar {
  width: 8px;
  background-color: #ebe9dd;
}

#page-works-episodes-episode.colorTheme-kinari #contentAside::-webkit-scrollbar:hover {
  background-color: #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari #contentAside::-webkit-scrollbar-thumb {
  background-color: #aaa;
}

#page-works-episodes-episode.colorTheme-kinari #contentAside::-webkit-scrollbar-thumb:hover {
  background-color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari #contentAside .widget-toc-workInfo {
  color: #6a6968;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #contentAside {
  border-left-color: #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #contentAside::-webkit-scrollbar {
  width: 8px;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #contentAside {
  border-top-color: #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #contentAside::-webkit-scrollbar {
  height: 8px;
}

#page-works-episodes-episode.colorTheme-kinari .contentAside-sectionHeader h3 a,#page-works-episodes-episode.colorTheme-kinari .contentAside-sectionHeader h4 a {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal .contentAside-sectionBody header {
  border-bottom-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  background: #e4e1d1;
  border-top-color: #d0cdc0!important;
  color: #6a6968;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  background: #ebe9dd;
  color: #6a6968;
  border-bottom-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-bottom-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #6a6968;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #episodeInfo {
  border-bottom-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical .contentAside-sectionBody header {
  border-left-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  background: #e4e1d1;
  border-right-color: #d0cdc0!important;
  color: #6a6968;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  background: #ebe9dd;
  color: #6a6968;
  border-left-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-left-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #6a6968;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #episodeInfo {
  border-left-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-share {
  border: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.isPC.writingDirection-horizontal #episodeFooter-work {
  border-top: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.isPC.writingDirection-horizontal #episodeFooter-links {
  border-top: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.isPC.writingDirection-vertical #episodeFooter-work {
  border-right: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.isPC.writingDirection-vertical #episodeFooter-links {
  border-right: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.isTouch.writingDirection-horizontal #episodeFooter-links {
  border-top: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.isTouch.writingDirection-vertical #episodeFooter-links {
  border-right: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #episodeFooter-action-cheerButton-container,#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #episodeFooter-action-right {
  border-left-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-action-cheerButton:disabled #episodeFooter-action-cheerButton-cheer {
  color: #bdbdbd!important;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-cheers li {
  color: #6a6968;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-cheers a {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #episodeFooter-cheers h4,#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #episodeFooter-cheers li {
  border-bottom-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #episodeFooter-cheers h4,#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #episodeFooter-cheers li {
  border-left-color: #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.isTouch #episodeFooter-work .episodeFooter-section-inner {
  border: 3px double #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-work-header-workTitle a {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-work-header-workTitle a:focus,#page-works-episodes-episode.colorTheme-kinari #episodeFooter-work-header-workTitle a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-signUp-balloon {
  background: #ebe9dd;
  border: 1px solid #d0cdc0;
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-signUp-balloon .signUp-duration {
  color: #6a6968;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-author h3 {
  color: #6a6968;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #episodeFooter-author {
  border-top: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical.isPC #episodeFooter-author {
  border-right: 1px solid #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-author-links a {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-author-links a:focus,#page-works-episodes-episode.colorTheme-kinari #episodeFooter-author-links a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-author-news ul a:focus h6,#page-works-episodes-episode.colorTheme-kinari #episodeFooter-author-news ul a:hover h6 {
  text-decoration: underline;
  color: #0081c2;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-author-news ul h6 {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-author-news ul p {
  color: #6a6968;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #episodeFooter-author-news h5 {
  border-bottom: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #episodeFooter-author-news ul li {
  border-bottom: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #episodeFooter-author-news h5 {
  border-left: 1px solid #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #episodeFooter-author-news ul li {
  border-left: 1px solid #d0cdc0!important;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-links a {
  color: #292826;
}

#page-works-episodes-episode.colorTheme-kinari #episodeFooter-links a:focus,#page-works-episodes-episode.colorTheme-kinari #episodeFooter-links a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-horizontal #episodeFooter-links a+a {
  border-left: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-kinari.writingDirection-vertical #episodeFooter-links a+a {
  border-top: 1px solid #d0cdc0;
}

#page-works-episodes-episode.colorTheme-blue {
  color: #262829;
  background: #c9ddeb;
}

#page-works-episodes-episode.colorTheme-blue #contentMain-header .chapterTitle.level2 span,#page-works-episodes-episode.colorTheme-blue #contentMain-inner,#page-works-episodes-episode.colorTheme-blue #episodeFooter,#page-works-episodes-episode.colorTheme-blue #worksEpisodesEpisodeHeader,#page-works-episodes-episode.colorTheme-blue .widget-episodeTitle {
  background: #dfecf4;
}

#page-works-episodes-episode.colorTheme-blue .ui-loading-large-beige:before {
  background: #c9ddeb;
}

#page-works-episodes-episode.colorTheme-blue .ui-loading:before {
  background: #dfecf4;
}

#page-works-episodes-episode.colorTheme-blue #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a,#page-works-episodes-episode.colorTheme-blue #worksEpisodesEpisodeHeader .float-left li a,#page-works-episodes-episode.colorTheme-blue #worksEpisodesEpisodeHeader .ui-button-silent {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:before {
  border-left-color: #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #worksEpisodesEpisodeHeader #worksEpisodesEpisodeHeader-closeButton a:before {
  border-top-color: #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue #worksEpisodesEpisodeHeader-breadcrumbs h1 a {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue #worksEpisodesEpisodeHeader-breadcrumbs h1 a:focus,#page-works-episodes-episode.colorTheme-blue #worksEpisodesEpisodeHeader-breadcrumbs h1 a:hover {
  color: #0081c2;
}

#page-works-episodes-episode.colorTheme-blue #worksEpisodesEpisodeHeader-logo,#page-works-episodes-episode.colorTheme-blue #worksEpisodesEpisodeHeader-tools {
  background: #dfecf4;
}

#page-works-episodes-episode.colorTheme-blue #contentMain-header .widget-episodeTitle {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #contentMain-header .chapterTitle.level2:before {
  border-top-color: #9cb2c4!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #contentMain-header .chapterTitle.level2:before {
  border-right-color: #9cb2c4!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #contentMain-header-cover {
  border-top-color: #adc1ce!important;
  border-bottom-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue #contentMain-nextEpisode,#page-works-episodes-episode.colorTheme-blue #contentMain-previousEpisode {
  background: #c9ddeb;
}

#page-works-episodes-episode.colorTheme-blue #contentMain-nextEpisode a,#page-works-episodes-episode.colorTheme-blue #contentMain-previousEpisode a {
  background: #c9ddeb;
}

#page-works-episodes-episode.colorTheme-blue #contentMain-nextEpisode a:focus,#page-works-episodes-episode.colorTheme-blue #contentMain-nextEpisode a:hover,#page-works-episodes-episode.colorTheme-blue #contentMain-previousEpisode a:focus,#page-works-episodes-episode.colorTheme-blue #contentMain-previousEpisode a:hover {
  background: #b7d2e4;
}

#page-works-episodes-episode.colorTheme-blue #contentMain-nextEpisode .contentMain-chapterTitle {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal .contentMain-pagerDash:before {
  border-top-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical .contentMain-pagerDash:before {
  border-right-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue .contentMain-pagerRelation {
  color: #68696a!important;
}

#page-works-episodes-episode.colorTheme-blue .contentMain-pagerEpisodeTitle {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue #contentMain-relatedWork {
  background: #b7d2e4;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #contentMain-relatedWork {
  border-top-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #contentMain-relatedWork h3 {
  border-bottom-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #contentMain-relatedWork {
  border-right-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #contentMain-relatedWork h3 {
  border-left-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue #contentAside {
  background: #c9ddeb;
}

#page-works-episodes-episode.colorTheme-blue #contentAside::-webkit-scrollbar {
  width: 8px;
  background-color: #c9ddeb;
}

#page-works-episodes-episode.colorTheme-blue #contentAside::-webkit-scrollbar:hover {
  background-color: #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue #contentAside::-webkit-scrollbar-thumb {
  background-color: #aaa;
}

#page-works-episodes-episode.colorTheme-blue #contentAside::-webkit-scrollbar-thumb:hover {
  background-color: #262829;
}

#page-works-episodes-episode.colorTheme-blue #contentAside .widget-toc-workInfo {
  color: #68696a;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #contentAside {
  border-left-color: #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #contentAside::-webkit-scrollbar {
  width: 8px;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #contentAside {
  border-top-color: #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #contentAside::-webkit-scrollbar {
  height: 8px;
}

#page-works-episodes-episode.colorTheme-blue .contentAside-sectionHeader h3 a,#page-works-episodes-episode.colorTheme-blue .contentAside-sectionHeader h4 a {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal .contentAside-sectionBody header {
  border-bottom-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  background: #b7d2e4;
  border-top-color: #adc1ce!important;
  color: #68696a;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  background: #c9ddeb;
  color: #68696a;
  border-bottom-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-bottom-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #68696a;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #episodeInfo {
  border-bottom-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical .contentAside-sectionBody header {
  border-left-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  background: #b7d2e4;
  border-right-color: #adc1ce!important;
  color: #68696a;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  background: #c9ddeb;
  color: #68696a;
  border-left-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items .widget-toc-episode {
  border-left-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-items a:visited {
  color: #68696a;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #episodeInfo {
  border-left-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-share {
  border: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.isPC.writingDirection-horizontal #episodeFooter-work {
  border-top: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.isPC.writingDirection-horizontal #episodeFooter-links {
  border-top: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.isPC.writingDirection-vertical #episodeFooter-work {
  border-right: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.isPC.writingDirection-vertical #episodeFooter-links {
  border-right: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.isTouch.writingDirection-horizontal #episodeFooter-links {
  border-top: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.isTouch.writingDirection-vertical #episodeFooter-links {
  border-right: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #episodeFooter-action-cheerButton-container,#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #episodeFooter-action-right {
  border-left-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-action-cheerButton:disabled #episodeFooter-action-cheerButton-cheer {
  color: #bdbdbd!important;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-cheers li {
  color: #68696a;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-cheers a {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #episodeFooter-cheers h4,#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #episodeFooter-cheers li {
  border-bottom-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #episodeFooter-cheers h4,#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #episodeFooter-cheers li {
  border-left-color: #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.isTouch #episodeFooter-work .episodeFooter-section-inner {
  border: 3px double #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-work-header-workTitle a {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-work-header-workTitle a:focus,#page-works-episodes-episode.colorTheme-blue #episodeFooter-work-header-workTitle a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-signUp-balloon {
  background: #c9ddeb;
  border: 1px solid #adc1ce;
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-signUp-balloon .signUp-duration {
  color: #68696a;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-author h3 {
  color: #68696a;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #episodeFooter-author {
  border-top: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical.isPC #episodeFooter-author {
  border-right: 1px solid #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-author-links a {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-author-links a:focus,#page-works-episodes-episode.colorTheme-blue #episodeFooter-author-links a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-author-news ul a:focus h6,#page-works-episodes-episode.colorTheme-blue #episodeFooter-author-news ul a:hover h6 {
  text-decoration: underline;
  color: #0081c2;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-author-news ul h6 {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-author-news ul p {
  color: #68696a;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #episodeFooter-author-news h5 {
  border-bottom: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #episodeFooter-author-news ul li {
  border-bottom: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #episodeFooter-author-news h5 {
  border-left: 1px solid #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #episodeFooter-author-news ul li {
  border-left: 1px solid #adc1ce!important;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-links a {
  color: #262829;
}

#page-works-episodes-episode.colorTheme-blue #episodeFooter-links a:focus,#page-works-episodes-episode.colorTheme-blue #episodeFooter-links a:hover {
  color: #0990cc;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-horizontal #episodeFooter-links a+a {
  border-left: 1px solid #adc1ce;
}

#page-works-episodes-episode.colorTheme-blue.writingDirection-vertical #episodeFooter-links a+a {
  border-top: 1px solid #adc1ce;
}

#page-works-episodes-episode.fontFamily-sans .widget-episodeBody {
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-works-episodes-episode.fontFamily-sans #displaySetting-modalContainer ul {
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-works-episodes-episode.isPC.fontSize-small.writingDirection-horizontal .widget-episodeBody {
  font-size: 15.4px!important;
}

@media screen and (max-width:640px) {
  #page-works-episodes-episode.isPC.fontSize-small.writingDirection-horizontal .widget-episodeBody {
    font-size: 14.08px!important;
  }
}

#page-works-episodes-episode.isPC.fontSize-small.writingDirection-vertical .widget-episodeBody {
  font-size: 15.4px!important;
}

#page-works-episodes-episode.isTouch.fontSize-small .widget-episodeBody {
  font-size: 14.08px!important;
}

#page-works-episodes-episode.isPC.fontSize-medium.writingDirection-horizontal .widget-episodeBody {
  font-size: 17.5px!important;
}

@media screen and (max-width:640px) {
  #page-works-episodes-episode.isPC.fontSize-medium.writingDirection-horizontal .widget-episodeBody {
    font-size: 16px!important;
  }
}

#page-works-episodes-episode.isPC.fontSize-medium.writingDirection-vertical .widget-episodeBody {
  font-size: 17.5px!important;
}

#page-works-episodes-episode.isTouch.fontSize-medium .widget-episodeBody {
  font-size: 16px!important;
}

#page-works-episodes-episode.isPC.fontSize-large.writingDirection-horizontal .widget-episodeBody {
  font-size: 20.125px!important;
}

@media screen and (max-width:640px) {
  #page-works-episodes-episode.isPC.fontSize-large.writingDirection-horizontal .widget-episodeBody {
    font-size: 18.4px!important;
  }
}

#page-works-episodes-episode.isPC.fontSize-large.writingDirection-vertical .widget-episodeBody {
  font-size: 20.125px!important;
}

#page-works-episodes-episode.isTouch.fontSize-large .widget-episodeBody {
  font-size: 18.4px!important;
}

#page-works-episodes-episode.isPC.fontSize-xLarge.writingDirection-horizontal .widget-episodeBody {
  font-size: 22.75px!important;
}

@media screen and (max-width:640px) {
  #page-works-episodes-episode.isPC.fontSize-xLarge.writingDirection-horizontal .widget-episodeBody {
    font-size: 20.8px!important;
  }
}

#page-works-episodes-episode.isPC.fontSize-xLarge.writingDirection-vertical .widget-episodeBody {
  font-size: 22.75px!important;
}

#page-works-episodes-episode.isTouch.fontSize-xLarge .widget-episodeBody {
  font-size: 20.8px!important;
}

#page-works-episodes-episode.writingDirection-vertical .tatechuyoko1 {
  -webkit-text-combine: horizontal;
  -ms-text-combine-horizontal: all;
  text-combine-upright: all;
}

#page-works-episodes-episode.writingDirection-vertical .tatechuyoko1,#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  -webkit-text-combine: none;
  -ms-text-combine-horizontal: none;
  text-combine-upright: none;
  -ms-writing-mode: lr-tb;
  writing-mode: horizontal-tb;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-vertical .tatechuyoko1,#page-works-episodes-episode.writingDirection-vertical _:-ms-lang(x)::backdrop {
  -webkit-text-combine: none;
  -ms-text-combine-horizontal: none;
  text-combine-upright: none;
  -ms-writing-mode: lr-tb;
  writing-mode: horizontal-tb;
  line-height: 1;
}

#page-works-episodes-episode.writingDirection-vertical #contentMain-nextEpisode .contentMain-pagerEpisodeTitle .tatechuyoko1,#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode .contentMain-pagerEpisodeTitle .tatechuyoko1,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs .tatechuyoko1,#page-works-episodes-episode.writingDirection-vertical .chapterTitle .tatechuyoko1,#page-works-episodes-episode.writingDirection-vertical .widget-episodeTitle .tatechuyoko1 {
  font-family: dcsymbols,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-works-episodes-episode.writingDirection-vertical.fontFamily-sans .widget-episodeBody .tatechuyoko1 {
  font-family: dcsymbols,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-works-episodes-episode.writingDirection-vertical .tatechuyoko2,#page-works-episodes-episode.writingDirection-vertical .tatechuyoko3 {
  -webkit-text-combine: horizontal;
  -ms-text-combine-horizontal: all;
  text-combine-upright: all;
}

#page-works-episodes-episode.writingDirection-vertical #contentAside #episodeInfo .tatechuyoko3,#page-works-episodes-episode.writingDirection-vertical #contentMain-previousEpisode .contentMain-pagerEpisodeTitle .tatechuyoko3,#page-works-episodes-episode.writingDirection-vertical #worksEpisodesEpisodeHeader-breadcrumbs .tatechuyoko3,#page-works-episodes-episode.writingDirection-vertical .contentAside-sectionBody .widget-toc .widget-toc-workInfo .tatechuyoko3 {
  -webkit-text-combine: none;
  -ms-text-combine-horizontal: none;
  text-combine-upright: none;
}

#page-works-episodes-episode.writingDirection-vertical .leaderMarks,#page-works-episodes-episode.writingDirection-vertical _:lang(x)::-ms-backdrop {
  transform: translateX(-.4em);
}

#page-works-episodes-episode.writingDirection-vertical .leaderMarks,#page-works-episodes-episode.writingDirection-vertical _:-ms-lang(x)::backdrop {
  display: inline-block;
  transform: translateX(-.4em);
}

#page-my-dashboard #dashboard-primary {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  margin: 0 30px 0 0;
}

@media screen and (max-width:1000px) {
  #page-my-dashboard #dashboard-primary {
    margin: 0;
  }
}

#page-my-dashboard #dashboard-primary section {
  margin: 30px 0;
  border: 1px solid #ddd;
  border-radius: 4px;
  box-shadow: 0 1px 0 rgba(0,0,0,.05);
}

#page-my-dashboard #dashboard-primary section:first-child {
  margin-top: 0;
}

#page-my-dashboard #dashboard-primary header {
  background: #f2f1f0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  border-radius: 4px 4px 0 0;
}

#page-my-dashboard #dashboard-primary h2 {
  font-size: 12px;
  width: 100%;
  line-height: 1.3;
  margin: 0;
}

#page-my-dashboard #dashboard-primary h2 button {
  padding: 8px 12px;
  width: 100%;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

#page-my-dashboard #dashboard-primary h2 button.isPanelShown svg {
  -webkit-transform: translateY(1px) rotate(180deg);
  transform: translateY(1px) rotate(180deg);
}

#page-my-dashboard #dashboard-primary h2 svg {
  width: 14px;
  height: 14.34px;
  margin: 0 10px 0 0;
  -webkit-transform: translateY(-1px);
  transform: translateY(-1px);
}

#page-my-dashboard #dashboard-primary h2 span {
  font-weight: 700;
}

#page-my-dashboard #dashboard-primary footer {
  border-top: 1px solid #ddd;
  line-height: 1;
}

#page-my-dashboard #dashboard-primary footer p {
  margin: 0;
}

#page-my-dashboard #dashboard-primary footer a,#page-my-dashboard #dashboard-primary footer span {
  padding: 1em 0;
  display: block;
  text-align: center;
}

#page-my-dashboard #dashboard-primary footer a {
  color: #222;
}

#page-my-dashboard #dashboard-primary footer a:focus,#page-my-dashboard #dashboard-primary footer a:hover {
  color: #0081c2;
}

#page-my-dashboard #dashboard-primary footer span {
  color: #999;
}

#page-my-dashboard .news-title {
  font-size: 15px;
  line-height: 1.3;
  font-weight: 700;
}

#page-my-dashboard .news-title a {
  color: #222;
}

#page-my-dashboard .news-title a:focus,#page-my-dashboard .news-title a:hover {
  color: #0081c2;
}

#page-my-dashboard .news-isHidden {
  line-height: 1.3;
  margin: 0 0 8px!important;
}

#page-my-dashboard .news-isHidden span {
  color: #fff;
  background: #f23e48;
  font-weight: 700;
  padding: 2px 3px 2px 4px;
  line-height: 1;
  border-radius: 2px;
  letter-spacing: 1px;
  box-sizing: border-box;
  font-size: 10px;
}

#page-my-dashboard #information .heading-level5 {
  margin: 0;
}

#page-my-dashboard.isPC #dashboard-container {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

@media screen and (max-width:1000px) {
  #page-my-dashboard.isPC #dashboard-container {
    display: block;
  }
}

#page-my-dashboard.isTouch #main {
  max-width: 100%;
}

#page-my-dashboard.isTouch #dashboard-primary {
  max-width: 800px;
  padding: 16px 16px 0;
  margin: 0 auto;
}

#page-my-dashboard.isTouch #dashboard-primary section {
  margin: 0 0 16px;
}

#page-my-dashboard.isTouch #information .heading-level5 {
  font-size: 11px;
  font-weight: 700;
  margin: 0 0 8px;
  padding: 0 16px 8px!important;
  border-bottom: 1px solid #ddd;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  box-sizing: border-box;
  margin: 0;
}

#page-my-dashboard.isTouch #information {
  margin: 8px 0 0;
}

#page-my-works.isPC #content:before {
  display: none;
}

#page-my-works.isPC #content _:lang(x)::-ms-backdrop,#page-my-works.isPC #content:before {
  display: block;
}

#page-my-works-edit.isPC #main {
  padding: 0 34px;
}

#page-my-works-edit.isTouch #workStatus {
  margin: 0 0 1em;
}

#page-my-works-edit.isTouch #workStatus label {
  height: 44px;
  line-height: 44px;
}

#page-my-news .news {
  padding: 14px 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  border-bottom: 1px solid #ddd;
}

#page-my-news .news-title {
  font-size: 15px;
  line-height: 1.3;
  font-weight: 700;
}

#page-my-news .news-title a {
  color: #222;
}

#page-my-news .news-title a:focus,#page-my-news .news-title a:hover {
  color: #0081c2;
}

#page-my-news .news-isHidden {
  line-height: 1.3;
  margin: 0 0 8px!important;
}

#page-my-news .news-isHidden span {
  color: #fff;
  background: #f23e48;
  font-weight: 700;
  padding: 2px 3px 2px 4px;
  line-height: 1;
  border-radius: 2px;
  letter-spacing: 1px;
  box-sizing: border-box;
  font-size: 10px;
}

#page-my-news.isTouch .news {
  padding: 14px 16px;
}

#page-my-news-edit #input-body {
  font-size: 1.1em;
  height: calc(100vh - 485px);
  min-height: 320px;
}

#page-my-news-edit #input-image {
  display: none;
}

#page-my-news-edit #upload.isHidden {
  display: none;
}

#page-my-news-edit #upload {
  position: relative;
  text-align: center;
  line-height: 1.4;
  padding: 24px;
}

#page-my-news-edit #upload button {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border: 1px dashed #bbb;
}

#page-my-news-edit #upload p {
  margin: 0 0 8px;
}

#page-my-news-edit #upload span {
  display: inline-block;
}

#page-my-news-edit #upload ul {
  padding: 0;
  font-size: 11.5px;
  color: #666;
  margin: 0;
}

#page-my-news-edit #upload ul li {
  list-style-type: none;
}

#page-my-news-edit.isPC #main {
  padding: 0 34px;
}

#page-my-news-edit.isPC #upload {
  height: 144px;
}

@media screen and (max-width:1255px) {
  #page-my-news-edit.isPC #upload {
    height: 163px;
  }
}

@media screen and (max-width:980px) {
  #page-my-news-edit.isPC #upload {
    height: 182px;
  }
}

@media screen and (max-width:920px) {
  #page-my-news-edit.isPC #upload {
    height: 144px;
  }
}

#page-my-news-edit.isPC #upload button:focus,#page-my-news-edit.isPC #upload button:hover {
  border-color: #666;
}

#page-my-news-edit.isTouch #main {
  padding: 14px 16px 0;
  padding-right: calc(16px + constant(safe-area-inset-right));
  padding-right: calc(16px + env(safe-area-inset-right));
  padding-left: calc(16px + constant(safe-area-inset-left));
  padding-left: calc(16px + env(safe-area-inset-left));
  padding-bottom: constant(safe-area-inset-bottom);
  padding-bottom: env(safe-area-inset-bottom);
}

#page-my-news-edit.isTouch #input-body {
  height: calc(100vh - 475px);
}

#page-my-news-edit.isTouch #upload {
  height: 118px;
}

#page-my-news-edit.isTouch #upload {
  padding: 16px 0 15px;
}

#page-my-news-edit.isTouch #upload p {
  margin: 0 0 4px;
}

#page-my-events.isPC #main h2 {
  font-size: 18px;
  line-height: 1.3;
}

#page-my-events.isPC #contests {
  margin: 30px 0 0;
}

#page-my-events.isPC #contests section {
  margin: 0 0 30px;
}

#page-my-events.isPC #contests section:not(:first-child) h2 {
  font-weight: 400;
}

#page-my-events.isPC #contests .sectionHeader {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-my-events.isPC #contests .sectionHeader a {
  color: #222;
}

#page-my-events.isPC #contests .sectionHeader a:focus,#page-my-events.isPC #contests .sectionHeader a:hover {
  color: #0081c2;
}

#page-my-events.isPC #contests .sectionHeader a i {
  color: #0990cc;
}

#page-my-events.isPC .contest {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  position: relative;
  padding: 0 0 28px;
}

@media screen and (max-width:1000px) {
  #page-my-events.isPC .contest {
    display: block;
  }
}

#page-my-events.isPC .contest:before {
  content: '';
  display: block;
  position: absolute;
  top: 0;
  left: 230px;
  width: calc(100% - 230px);
  height: 0;
  border-top: 1px solid #ddd;
}

@media screen and (max-width:1000px) {
  #page-my-events.isPC .contest:before {
    left: 165px;
    width: calc(100% - 165px);
  }
}

#page-my-events.isPC .contest:last-child {
  border-bottom: 1px solid #ddd;
}

@media screen and (max-width:1000px) {
  #page-my-events.isPC .contest .contest-button {
    display: none;
  }
}

#page-my-events.isTouch #main {
  padding: 14px 0 24px;
  padding-right: constant(safe-area-inset-right);
  padding-right: env(safe-area-inset-right);
  padding-left: constant(safe-area-inset-left);
  padding-left: env(safe-area-inset-left);
  padding-bottom: calc(24px + constant(safe-area-inset-bottom));
  padding-bottom: calc(24px + env(safe-area-inset-bottom));
}

#page-my-events.isTouch #contests {
  margin: 48px 0 0;
}

#page-my-events.isTouch #contests section {
  margin: 0 0 24px;
}

#page-my-events.isTouch #contests .sectionHeader {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  font-size: 11px;
  font-weight: 700;
  margin: 0 0 8px;
  padding: 0 16px 8px!important;
  border-bottom: 1px solid #ddd;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  box-sizing: border-box;
}

#page-my-events.isTouch #contests .sectionHeader h2,#page-my-events.isTouch #contests .sectionHeader p {
  margin: 0;
}

#page-my-events.isTouch #contests .sectionHeader h2 {
  font-size: 11px;
}

#page-my-events.isTouch #contests .sectionHeader p {
  font-weight: 400;
}

#page-my-events.isTouch #contests .sectionHeader a {
  color: #222;
}

#page-my-events.isTouch #contests .sectionHeader a:focus,#page-my-events.isTouch #contests .sectionHeader a:hover {
  color: #0081c2;
}

#page-my-events.isTouch #contests .sectionHeader a i {
  color: #0990cc;
}

#page-my-events.isTouch .contest {
  padding: 14px 16px 14px 0;
  margin: 0 0 0 16px;
  border-bottom: 1px solid #ddd;
}

#page-my-reactions.isPC #content:before {
  display: none;
}

#page-my-reactions.isPC #content _:lang(x)::-ms-backdrop,#page-my-reactions.isPC #content:before {
  display: block;
}

#page-my-rewards.isTouch #main {
  padding: 16px 16px 0;
}

#page-my-rewards-withdrawal #withdrawal-kr {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  border: 5px solid #f2f1f0;
  padding: 35px 0;
  margin: 25px 0 30px;
}

#page-my-rewards-withdrawal #withdrawal-kr-inner {
  position: relative;
  width: 80%;
  max-width: 300px;
}

#page-my-rewards-withdrawal #withdrawal-kr-inner:before {
  content: '';
  position: absolute;
  top: 46px;
  left: calc(50% - 9px);
  width: 23px;
  height: 1px;
  -webkit-transform: rotate(-60deg);
  transform: rotate(-60deg);
  background: #666;
}

#page-my-rewards-withdrawal #withdrawal-kr-inner p {
  margin: 0;
}

#page-my-rewards-withdrawal #withdrawal-kr-textArea {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-my-rewards-withdrawal #withdrawal-kr-textArea div {
  width: calc(50% - 10px);
  text-align: center;
}

#page-my-rewards-withdrawal #withdrawal-kr-textArea input {
  font-size: 30px;
  font-weight: 700;
  text-align: center;
  line-height: 40px;
  border: none;
  border-bottom: 1px solid #bbb;
  border-radius: 0;
  padding: 0 0 5px;
}

#page-my-rewards-withdrawal #withdrawal-kr-textArea input:hover {
  border-color: #888;
}

#page-my-rewards-withdrawal #withdrawal-kr-textArea input:focus {
  border-color: #4baae0;
}

#page-my-rewards-withdrawal .withdrawal-kr-label {
  color: #666;
}

#page-my-rewards-withdrawal #withdrawal-range-bar {
  margin: 13px 0 0;
  position: relative;
}

#page-my-rewards-withdrawal #withdrawal-range-bar input {
  height: 5px;
  border: none;
  border-radius: 3px;
  background: #f2f1f0;
  padding: 0;
}

#page-my-rewards-withdrawal #withdrawal-range-bar input[type=range]::-webkit-slider-thumb {
  -webkit-appearance: none;
  cursor: pointer;
  background: #4baae0;
  border: 1px solid #4baae0;
  border-radius: 50%;
  width: 15px;
  height: 15px;
  z-index: 1;
}

#page-my-rewards-withdrawal #withdrawal-range-bar input[type=range]::-moz-range-thumb {
  cursor: pointer;
  background: #4baae0;
  border: 1px solid #4baae0;
  border-radius: 50%;
  width: 15px;
  height: 15px;
  z-index: 1;
}

#page-my-rewards-withdrawal #withdrawal-range-bar input[type=range]::-ms-fill-lower {
  background: #4baae0;
}

#page-my-rewards-withdrawal #withdrawal-range-bar input[type=range]::-ms-fill-upper {
  background: #f2f1f0;
}

#page-my-rewards-withdrawal #withdrawal-range-bar input[type=range]::-ms-thumb {
  background: #0081c2;
  width: 15px;
}

#page-my-rewards-withdrawal #withdrawal-range-bar input[type=range]::-ms-tooltip {
  display: none;
}

#page-my-rewards-withdrawal #withdrawal-range-bar input[type=range]::-ms-track {
  border: none;
}

#page-my-rewards-withdrawal #withdrawal-range-bar div {
  position: absolute;
  top: 12px;
  left: 0;
  height: 5px;
  border-radius: 3px;
  background: #4baae0;
  pointer-events: none;
}

#page-my-rewards-withdrawal #withdrawal-range-bar p {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  font-size: 12px;
  color: #666;
  line-height: 1;
  margin: 3px 0 0;
}

#page-my-rewards-withdrawal #withdrawal-details div {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  border-top: 1px solid #ddd;
  padding: 8px 0;
}

#page-my-rewards-withdrawal #withdrawal-details div:last-child {
  border-bottom: 1px solid #ddd;
}

#page-my-rewards-withdrawal #edit-bank-link {
  padding: 0 0 0 2px;
}

@media screen and (max-width:360px) {
  #page-my-rewards-withdrawal.isTouch #withdrawal-kr-inner:before {
    top: 43px;
    width: 20px;
  }

  #page-my-rewards-withdrawal.isTouch #withdrawal-kr-textArea input {
    font-size: 25px;
  }
}

#page-my-rewards-histories #histories-list {
  padding: 0;
  margin: 0;
}

#page-my-rewards-histories #histories-list li {
  list-style-type: none;
}

#page-my-rewards-histories #histories-list li {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  border-bottom: 1px solid #ddd;
  padding: 14px 8px 14px 0;
}

#page-my-rewards-histories #histories-list div {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-my-rewards-histories #histories-list p {
  margin: 0;
}

#page-my-rewards-histories #histories-list .histories-transaction {
  line-height: 1.4;
}

#page-my-rewards-histories #histories-list #histories-labels {
  position: -webkit-sticky;
  position: sticky;
  top: 50px;
  width: 100%;
  font-size: 12px;
  font-weight: 700;
  box-shadow: 0 1px 0 rgba(0,0,0,.1);
  border: none;
  background: #fff;
  padding: 2px 8px 6px 0;
}

#page-my-rewards-histories .histories-outline {
  -webkit-box-align: baseline;
  -webkit-align-items: baseline;
  -ms-flex-align: baseline;
  align-items: baseline;
}

#page-my-rewards-histories.isPC .histories-time {
  width: 130px;
  white-space: nowrap;
}

#page-my-rewards-histories.isPC #histories-labels .histories-transaction {
  line-height: inherit;
}

#page-my-rewards-histories.isPC .histories-transaction {
  width: calc(100% - 130px);
}

#page-my-rewards-histories.isTouch #histories-list {
  padding: 0 0 0 15px;
}

#page-my-rewards-histories.isTouch #histories-list li {
  -webkit-box-align: end;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
  padding-right: 0;
}

@media screen and (max-width:800px) {
  #page-my-rewards-histories.isTouch #histories-list li {
    padding: 8px 14px 8px 0;
  }
}

#page-my-rewards-histories.isTouch #histories-list p {
  line-height: 1.5;
}

#page-my-rewards-histories.isTouch #histories-list #histories-labels {
  top: 44px;
  padding: 4px 0 8px 0;
}

@media screen and (max-width:800px) {
  #page-my-rewards-histories.isTouch #histories-list #histories-labels {
    top: 80px;
    padding: 8px 14px 8px 0;
  }
}

#page-my-rewards-histories.isTouch #histories-list #histories-labels p {
  font-size: 11.5px;
}

#page-my-rewards-histories.isTouch .histories-outline {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}

#page-my-rewards-histories.isTouch .histories-time {
  font-size: 11.5px;
  color: #666;
}

#page-my-works-episodes-edit {
  background: #fff;
}

#page-my-works-episodes-edit.isSeamlessScrollMode {
  overflow-y: scroll;
}

#page-my-works-episodes-edit .icon-white {
  display: none;
}

#page-my-works-episodes-edit #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit #contentMain-preview .episodeBody div {
  background: #fff;
  color: #222;
}

#page-my-works-episodes-edit #contentMain-episode .episodeTitle input,#page-my-works-episodes-edit #contentMain-preview .episodeTitle span {
  background: #fff;
  color: #222;
}

#page-my-works-episodes-edit #redoButton img,#page-my-works-episodes-edit #saveButton img,#page-my-works-episodes-edit #undoButton img,#page-my-works-episodes-edit #updateButton img {
  height: 12px;
  width: 12px;
}

@media screen and (max-width:340px) {
  #page-my-works-episodes-edit #redoButton img,  #page-my-works-episodes-edit #saveButton img,  #page-my-works-episodes-edit #undoButton img,  #page-my-works-episodes-edit #updateButton img {
    height: 11px;
    width: 11px;
  }
}

#page-my-works-episodes-edit #redoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit #redoButton[disabled] .ui-button-default,#page-my-works-episodes-edit #saveButton[disabled] .ui-button-blue,#page-my-works-episodes-edit #saveButton[disabled] .ui-button-default,#page-my-works-episodes-edit #undoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit #undoButton[disabled] .ui-button-default,#page-my-works-episodes-edit #updateButton[disabled] .ui-button-blue,#page-my-works-episodes-edit #updateButton[disabled] .ui-button-default {
  background: #f2f1f0!important;
  color: #aaa!important;
  border-color: #ddd!important;
}

#page-my-works-episodes-edit #redoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit #redoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit #redoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit #redoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit #saveButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit #saveButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit #saveButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit #saveButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit #undoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit #undoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit #undoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit #undoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit #updateButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit #updateButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit #updateButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit #updateButton[disabled] .ui-button-default:hover {
  background: #f2f1f0!important;
  border-color: #ddd!important;
}

#page-my-works-episodes-edit #redoButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit #saveButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit #undoButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit #updateButton[disabled] .ui-loading-gray:before {
  background: #f2f1f0!important;
}

#page-my-works-episodes-edit #redoButton .ui-button-default,#page-my-works-episodes-edit #saveButton .ui-button-default,#page-my-works-episodes-edit #undoButton .ui-button-default,#page-my-works-episodes-edit #updateButton .ui-button-default {
  background: #ddd!important;
  color: #222!important;
  border-color: #bbb!important;
}

#page-my-works-episodes-edit #redoButton .ui-button-default:focus,#page-my-works-episodes-edit #redoButton .ui-button-default:hover,#page-my-works-episodes-edit #saveButton .ui-button-default:focus,#page-my-works-episodes-edit #saveButton .ui-button-default:hover,#page-my-works-episodes-edit #undoButton .ui-button-default:focus,#page-my-works-episodes-edit #undoButton .ui-button-default:hover,#page-my-works-episodes-edit #updateButton .ui-button-default:focus,#page-my-works-episodes-edit #updateButton .ui-button-default:hover {
  background: #ccc!important;
  border-color: #aaa!important;
}

#page-my-works-episodes-edit #redoButton .ui-loading-gray:before,#page-my-works-episodes-edit #saveButton .ui-loading-gray:before,#page-my-works-episodes-edit #undoButton .ui-loading-gray:before,#page-my-works-episodes-edit #updateButton .ui-loading-gray:before {
  background: #ddd!important;
}

#page-my-works-episodes-edit #undoButton:disabled+#redoButton:disabled .ui-button-default:before {
  border-left-color: #ddd;
}

#page-my-works-episodes-edit #redoButton .ui-button-default:before {
  border-left: 1px solid #bbb;
}

#page-my-works-episodes-edit #contentAside {
  background: #f2f1f0;
}

#page-my-works-episodes-edit #contentAside-inner {
  border-top: 1px solid #ddd;
}

#page-my-works-episodes-edit #contentAside-inner::-webkit-scrollbar {
  width: 8px;
  background-color: #f2f1f0;
}

#page-my-works-episodes-edit #contentAside-inner::-webkit-scrollbar:hover {
  background-color: #ddd;
}

#page-my-works-episodes-edit #contentAside-inner::-webkit-scrollbar-thumb {
  background-color: #aaa;
}

#page-my-works-episodes-edit #contentAside-inner::-webkit-scrollbar-thumb:hover {
  background-color: #222;
}

#page-my-works-episodes-edit #contentAside-inner h3 i {
  color: #666;
}

#page-my-works-episodes-edit #contentAside-inner h4 {
  color: #222;
}

#page-my-works-episodes-edit #contentAside-inner p {
  color: #666;
}

#page-my-works-episodes-edit .notation-label {
  color: #222;
}

#page-my-works-episodes-edit .notation-sample {
  border-left: 1px solid #ddd;
}

#page-my-works-episodes-edit .widget-displaySetting {
  background: #fff;
  color: #222;
}

#page-my-works-episodes-edit .widget-displaySetting li {
  border-color: #ddd;
}

#page-my-works-episodes-edit .widget-displaySetting li:hover {
  border-color: #222!important;
}

#page-my-works-episodes-edit .widget-displaySetting li:hover+li {
  border-left-color: #222!important;
}

#page-my-works-episodes-edit .widget-displaySetting li:hover.isActive+li {
  border-left-color: #4baae0!important;
}

#page-my-works-episodes-edit .widget-displaySetting li.isActive {
  border-color: #4baae0!important;
}

#page-my-works-episodes-edit .widget-displaySetting li.isActive+li {
  border-left-color: #4baae0;
}

#page-my-works-episodes-edit #contentMain-preview-loading .ui-loading:before {
  background: #fff;
}

#page-my-works-episodes-edit.colorTheme-black {
  background: #171b1d;
}

#page-my-works-episodes-edit.colorTheme-black #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.colorTheme-black #contentMain-preview .episodeBody div {
  background: #171b1d;
  color: #f0f0f0;
}

#page-my-works-episodes-edit.colorTheme-black #contentMain-episode .episodeTitle input,#page-my-works-episodes-edit.colorTheme-black #contentMain-preview .episodeTitle span {
  background: #171b1d;
  color: #f0f0f0;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton img,#page-my-works-episodes-edit.colorTheme-black #saveButton img,#page-my-works-episodes-edit.colorTheme-black #undoButton img,#page-my-works-episodes-edit.colorTheme-black #updateButton img {
  height: 12px;
  width: 12px;
}

@media screen and (max-width:340px) {
  #page-my-works-episodes-edit.colorTheme-black #redoButton img,  #page-my-works-episodes-edit.colorTheme-black #saveButton img,  #page-my-works-episodes-edit.colorTheme-black #undoButton img,  #page-my-works-episodes-edit.colorTheme-black #updateButton img {
    height: 11px;
    width: 11px;
  }
}

#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-default {
  background: #484b4d!important;
  color: #aaa!important;
  border-color: #65696b!important;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-default:hover {
  background: #484b4d!important;
  border-color: #65696b!important;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-loading-gray:before {
  background: #484b4d!important;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton .ui-button-default,#page-my-works-episodes-edit.colorTheme-black #saveButton .ui-button-default,#page-my-works-episodes-edit.colorTheme-black #undoButton .ui-button-default,#page-my-works-episodes-edit.colorTheme-black #updateButton .ui-button-default {
  background: #65696b!important;
  color: #f0f0f0!important;
  border-color: #65696b!important;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #redoButton .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-black #saveButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #saveButton .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-black #undoButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #undoButton .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-black #updateButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #updateButton .ui-button-default:hover {
  background: #585b5d!important;
  border-color: #585b5d!important;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-black #saveButton .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-black #undoButton .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-black #updateButton .ui-loading-gray:before {
  background: #65696b!important;
}

#page-my-works-episodes-edit.colorTheme-black #undoButton:disabled+#redoButton:disabled .ui-button-default:before {
  border-left-color: #65696b;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton .ui-button-default:before {
  border-left: 1px solid #65696b;
}

#page-my-works-episodes-edit.colorTheme-black #contentAside {
  background: #484b4d;
}

#page-my-works-episodes-edit.colorTheme-black #contentAside-inner {
  border-top: 1px solid #686b6c;
}

#page-my-works-episodes-edit.colorTheme-black #contentAside-inner::-webkit-scrollbar {
  width: 8px;
  background-color: #484b4d;
}

#page-my-works-episodes-edit.colorTheme-black #contentAside-inner::-webkit-scrollbar:hover {
  background-color: #686b6c;
}

#page-my-works-episodes-edit.colorTheme-black #contentAside-inner::-webkit-scrollbar-thumb {
  background-color: #aaa;
}

#page-my-works-episodes-edit.colorTheme-black #contentAside-inner::-webkit-scrollbar-thumb:hover {
  background-color: #f0f0f0;
}

#page-my-works-episodes-edit.colorTheme-black #contentAside-inner h3 i {
  color: #b0b0b0;
}

#page-my-works-episodes-edit.colorTheme-black #contentAside-inner h4 {
  color: #f0f0f0;
}

#page-my-works-episodes-edit.colorTheme-black #contentAside-inner p {
  color: #b0b0b0;
}

#page-my-works-episodes-edit.colorTheme-black .notation-label {
  color: #f0f0f0;
}

#page-my-works-episodes-edit.colorTheme-black .notation-sample {
  border-left: 1px solid #686b6c;
}

#page-my-works-episodes-edit.colorTheme-black .widget-displaySetting {
  background: #171b1d;
  color: #f0f0f0;
}

#page-my-works-episodes-edit.colorTheme-black .widget-displaySetting li {
  border-color: #686b6c;
}

#page-my-works-episodes-edit.colorTheme-black .widget-displaySetting li:hover {
  border-color: #f0f0f0!important;
}

#page-my-works-episodes-edit.colorTheme-black .widget-displaySetting li:hover+li {
  border-left-color: #f0f0f0!important;
}

#page-my-works-episodes-edit.colorTheme-black .widget-displaySetting li:hover.isActive+li {
  border-left-color: #4baae0!important;
}

#page-my-works-episodes-edit.colorTheme-black .widget-displaySetting li.isActive {
  border-color: #4baae0!important;
}

#page-my-works-episodes-edit.colorTheme-black .widget-displaySetting li.isActive+li {
  border-left-color: #4baae0;
}

#page-my-works-episodes-edit.colorTheme-black #contentMain-preview-loading .ui-loading:before {
  background: #171b1d;
}

#page-my-works-episodes-edit.colorTheme-black .icon-black {
  display: none;
}

#page-my-works-episodes-edit.colorTheme-black .icon-white {
  display: inline;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-default {
  border-color: #484b4d!important;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #redoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #saveButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #undoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-black #updateButton[disabled] .ui-button-default:hover {
  border-color: #484b4d!important;
}

#page-my-works-episodes-edit.colorTheme-black #redoButton .ui-button-default:before {
  border-left: 1px solid #171b1d;
}

#page-my-works-episodes-edit.colorTheme-black .ui-tooltip:after {
  background: #ddd;
  color: #222!important;
}

#page-my-works-episodes-edit.colorTheme-black .ui-tooltip-top:before {
  border-top-color: #ddd;
}

#page-my-works-episodes-edit.colorTheme-black .ui-tooltip-bottom:before {
  border-bottom-color: #ddd;
}

#page-my-works-episodes-edit.colorTheme-kinari {
  background: #f7f6eb;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.colorTheme-kinari #contentMain-preview .episodeBody div {
  background: #f7f6eb;
  color: #292826;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentMain-episode .episodeTitle input,#page-my-works-episodes-edit.colorTheme-kinari #contentMain-preview .episodeTitle span {
  background: #f7f6eb;
  color: #292826;
}

#page-my-works-episodes-edit.colorTheme-kinari #redoButton img,#page-my-works-episodes-edit.colorTheme-kinari #saveButton img,#page-my-works-episodes-edit.colorTheme-kinari #undoButton img,#page-my-works-episodes-edit.colorTheme-kinari #updateButton img {
  height: 12px;
  width: 12px;
}

@media screen and (max-width:340px) {
  #page-my-works-episodes-edit.colorTheme-kinari #redoButton img,  #page-my-works-episodes-edit.colorTheme-kinari #saveButton img,  #page-my-works-episodes-edit.colorTheme-kinari #undoButton img,  #page-my-works-episodes-edit.colorTheme-kinari #updateButton img {
    height: 11px;
    width: 11px;
  }
}

#page-my-works-episodes-edit.colorTheme-kinari #redoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-kinari #redoButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-kinari #saveButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-kinari #saveButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-kinari #undoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-kinari #undoButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-kinari #updateButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-kinari #updateButton[disabled] .ui-button-default {
  background: #ebe9dd!important;
  color: #aaa!important;
  border-color: #e4e1d1!important;
}

#page-my-works-episodes-edit.colorTheme-kinari #redoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-kinari #redoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-kinari #redoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-kinari #redoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-kinari #saveButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-kinari #saveButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-kinari #saveButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-kinari #saveButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-kinari #undoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-kinari #undoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-kinari #undoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-kinari #undoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-kinari #updateButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-kinari #updateButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-kinari #updateButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-kinari #updateButton[disabled] .ui-button-default:hover {
  background: #ebe9dd!important;
  border-color: #e4e1d1!important;
}

#page-my-works-episodes-edit.colorTheme-kinari #redoButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-kinari #saveButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-kinari #undoButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-kinari #updateButton[disabled] .ui-loading-gray:before {
  background: #ebe9dd!important;
}

#page-my-works-episodes-edit.colorTheme-kinari #redoButton .ui-button-default,#page-my-works-episodes-edit.colorTheme-kinari #saveButton .ui-button-default,#page-my-works-episodes-edit.colorTheme-kinari #undoButton .ui-button-default,#page-my-works-episodes-edit.colorTheme-kinari #updateButton .ui-button-default {
  background: #e4e1d1!important;
  color: #292826!important;
  border-color: #d0cbb3!important;
}

#page-my-works-episodes-edit.colorTheme-kinari #redoButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-kinari #redoButton .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-kinari #saveButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-kinari #saveButton .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-kinari #undoButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-kinari #undoButton .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-kinari #updateButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-kinari #updateButton .ui-button-default:hover {
  background: #d8d4c0!important;
  border-color: #c9c3a7!important;
}

#page-my-works-episodes-edit.colorTheme-kinari #redoButton .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-kinari #saveButton .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-kinari #undoButton .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-kinari #updateButton .ui-loading-gray:before {
  background: #e4e1d1!important;
}

#page-my-works-episodes-edit.colorTheme-kinari #undoButton:disabled+#redoButton:disabled .ui-button-default:before {
  border-left-color: #e4e1d1;
}

#page-my-works-episodes-edit.colorTheme-kinari #redoButton .ui-button-default:before {
  border-left: 1px solid #d0cbb3;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentAside {
  background: #ebe9dd;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentAside-inner {
  border-top: 1px solid #d0cdc0;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentAside-inner::-webkit-scrollbar {
  width: 8px;
  background-color: #ebe9dd;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentAside-inner::-webkit-scrollbar:hover {
  background-color: #d0cdc0;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentAside-inner::-webkit-scrollbar-thumb {
  background-color: #aaa;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentAside-inner::-webkit-scrollbar-thumb:hover {
  background-color: #292826;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentAside-inner h3 i {
  color: #6a6968;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentAside-inner h4 {
  color: #292826;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentAside-inner p {
  color: #6a6968;
}

#page-my-works-episodes-edit.colorTheme-kinari .notation-label {
  color: #292826;
}

#page-my-works-episodes-edit.colorTheme-kinari .notation-sample {
  border-left: 1px solid #d0cdc0;
}

#page-my-works-episodes-edit.colorTheme-kinari .widget-displaySetting {
  background: #f7f6eb;
  color: #292826;
}

#page-my-works-episodes-edit.colorTheme-kinari .widget-displaySetting li {
  border-color: #d0cdc0;
}

#page-my-works-episodes-edit.colorTheme-kinari .widget-displaySetting li:hover {
  border-color: #292826!important;
}

#page-my-works-episodes-edit.colorTheme-kinari .widget-displaySetting li:hover+li {
  border-left-color: #292826!important;
}

#page-my-works-episodes-edit.colorTheme-kinari .widget-displaySetting li:hover.isActive+li {
  border-left-color: #4baae0!important;
}

#page-my-works-episodes-edit.colorTheme-kinari .widget-displaySetting li.isActive {
  border-color: #4baae0!important;
}

#page-my-works-episodes-edit.colorTheme-kinari .widget-displaySetting li.isActive+li {
  border-left-color: #4baae0;
}

#page-my-works-episodes-edit.colorTheme-kinari #contentMain-preview-loading .ui-loading:before {
  background: #f7f6eb;
}

#page-my-works-episodes-edit.colorTheme-blue {
  background: #dfecf4;
}

#page-my-works-episodes-edit.colorTheme-blue #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.colorTheme-blue #contentMain-preview .episodeBody div {
  background: #dfecf4;
  color: #262829;
}

#page-my-works-episodes-edit.colorTheme-blue #contentMain-episode .episodeTitle input,#page-my-works-episodes-edit.colorTheme-blue #contentMain-preview .episodeTitle span {
  background: #dfecf4;
  color: #262829;
}

#page-my-works-episodes-edit.colorTheme-blue #redoButton img,#page-my-works-episodes-edit.colorTheme-blue #saveButton img,#page-my-works-episodes-edit.colorTheme-blue #undoButton img,#page-my-works-episodes-edit.colorTheme-blue #updateButton img {
  height: 12px;
  width: 12px;
}

@media screen and (max-width:340px) {
  #page-my-works-episodes-edit.colorTheme-blue #redoButton img,  #page-my-works-episodes-edit.colorTheme-blue #saveButton img,  #page-my-works-episodes-edit.colorTheme-blue #undoButton img,  #page-my-works-episodes-edit.colorTheme-blue #updateButton img {
    height: 11px;
    width: 11px;
  }
}

#page-my-works-episodes-edit.colorTheme-blue #redoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-blue #redoButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-blue #saveButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-blue #saveButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-blue #undoButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-blue #undoButton[disabled] .ui-button-default,#page-my-works-episodes-edit.colorTheme-blue #updateButton[disabled] .ui-button-blue,#page-my-works-episodes-edit.colorTheme-blue #updateButton[disabled] .ui-button-default {
  background: #c9ddeb!important;
  color: #aaa!important;
  border-color: #b7d2e4!important;
}

#page-my-works-episodes-edit.colorTheme-blue #redoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-blue #redoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-blue #redoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-blue #redoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-blue #saveButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-blue #saveButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-blue #saveButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-blue #saveButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-blue #undoButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-blue #undoButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-blue #undoButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-blue #undoButton[disabled] .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-blue #updateButton[disabled] .ui-button-blue:focus,#page-my-works-episodes-edit.colorTheme-blue #updateButton[disabled] .ui-button-blue:hover,#page-my-works-episodes-edit.colorTheme-blue #updateButton[disabled] .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-blue #updateButton[disabled] .ui-button-default:hover {
  background: #c9ddeb!important;
  border-color: #b7d2e4!important;
}

#page-my-works-episodes-edit.colorTheme-blue #redoButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-blue #saveButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-blue #undoButton[disabled] .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-blue #updateButton[disabled] .ui-loading-gray:before {
  background: #c9ddeb!important;
}

#page-my-works-episodes-edit.colorTheme-blue #redoButton .ui-button-default,#page-my-works-episodes-edit.colorTheme-blue #saveButton .ui-button-default,#page-my-works-episodes-edit.colorTheme-blue #undoButton .ui-button-default,#page-my-works-episodes-edit.colorTheme-blue #updateButton .ui-button-default {
  background: #b7d2e4!important;
  color: #262829!important;
  border-color: #96b7cd!important;
}

#page-my-works-episodes-edit.colorTheme-blue #redoButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-blue #redoButton .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-blue #saveButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-blue #saveButton .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-blue #undoButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-blue #undoButton .ui-button-default:hover,#page-my-works-episodes-edit.colorTheme-blue #updateButton .ui-button-default:focus,#page-my-works-episodes-edit.colorTheme-blue #updateButton .ui-button-default:hover {
  background: #abc6d7!important;
  border-color: #8eb1c5!important;
}

#page-my-works-episodes-edit.colorTheme-blue #redoButton .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-blue #saveButton .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-blue #undoButton .ui-loading-gray:before,#page-my-works-episodes-edit.colorTheme-blue #updateButton .ui-loading-gray:before {
  background: #b7d2e4!important;
}

#page-my-works-episodes-edit.colorTheme-blue #undoButton:disabled+#redoButton:disabled .ui-button-default:before {
  border-left-color: #b7d2e4;
}

#page-my-works-episodes-edit.colorTheme-blue #redoButton .ui-button-default:before {
  border-left: 1px solid #96b7cd;
}

#page-my-works-episodes-edit.colorTheme-blue #contentAside {
  background: #c9ddeb;
}

#page-my-works-episodes-edit.colorTheme-blue #contentAside-inner {
  border-top: 1px solid #adc1ce;
}

#page-my-works-episodes-edit.colorTheme-blue #contentAside-inner::-webkit-scrollbar {
  width: 8px;
  background-color: #c9ddeb;
}

#page-my-works-episodes-edit.colorTheme-blue #contentAside-inner::-webkit-scrollbar:hover {
  background-color: #adc1ce;
}

#page-my-works-episodes-edit.colorTheme-blue #contentAside-inner::-webkit-scrollbar-thumb {
  background-color: #aaa;
}

#page-my-works-episodes-edit.colorTheme-blue #contentAside-inner::-webkit-scrollbar-thumb:hover {
  background-color: #262829;
}

#page-my-works-episodes-edit.colorTheme-blue #contentAside-inner h3 i {
  color: #68696a;
}

#page-my-works-episodes-edit.colorTheme-blue #contentAside-inner h4 {
  color: #262829;
}

#page-my-works-episodes-edit.colorTheme-blue #contentAside-inner p {
  color: #68696a;
}

#page-my-works-episodes-edit.colorTheme-blue .notation-label {
  color: #262829;
}

#page-my-works-episodes-edit.colorTheme-blue .notation-sample {
  border-left: 1px solid #adc1ce;
}

#page-my-works-episodes-edit.colorTheme-blue .widget-displaySetting {
  background: #dfecf4;
  color: #262829;
}

#page-my-works-episodes-edit.colorTheme-blue .widget-displaySetting li {
  border-color: #adc1ce;
}

#page-my-works-episodes-edit.colorTheme-blue .widget-displaySetting li:hover {
  border-color: #262829!important;
}

#page-my-works-episodes-edit.colorTheme-blue .widget-displaySetting li:hover+li {
  border-left-color: #262829!important;
}

#page-my-works-episodes-edit.colorTheme-blue .widget-displaySetting li:hover.isActive+li {
  border-left-color: #4baae0!important;
}

#page-my-works-episodes-edit.colorTheme-blue .widget-displaySetting li.isActive {
  border-color: #4baae0!important;
}

#page-my-works-episodes-edit.colorTheme-blue .widget-displaySetting li.isActive+li {
  border-left-color: #4baae0;
}

#page-my-works-episodes-edit.colorTheme-blue #contentMain-preview-loading .ui-loading:before {
  background: #dfecf4;
}

#page-my-works-episodes-edit.fontFamily-sans #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.fontFamily-sans #contentMain-preview .episodeBody div,#page-my-works-episodes-edit.fontFamily-sans .widget-displaySetting ul {
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif!important;
}

#page-my-works-episodes-edit.isPC.fontSize-small.writingDirection-horizontal #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isPC.fontSize-small.writingDirection-horizontal #contentMain-preview .episodeBody div {
  font-size: 15.4px!important;
}

@media screen and (max-width:640px) {
  #page-my-works-episodes-edit.isPC.fontSize-small.writingDirection-horizontal #contentMain-episode .episodeBody textarea,  #page-my-works-episodes-edit.isPC.fontSize-small.writingDirection-horizontal #contentMain-preview .episodeBody div {
    font-size: 14.08px!important;
  }
}

#page-my-works-episodes-edit.isPC.fontSize-small.writingDirection-vertical #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isPC.fontSize-small.writingDirection-vertical #contentMain-preview .episodeBody div {
  font-size: 15.4px!important;
}

#page-my-works-episodes-edit.isTouch.fontSize-small #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isTouch.fontSize-small #contentMain-preview .episodeBody div {
  font-size: 14.08px!important;
}

#page-my-works-episodes-edit.isPC.fontSize-medium.writingDirection-horizontal #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isPC.fontSize-medium.writingDirection-horizontal #contentMain-preview .episodeBody div {
  font-size: 17.5px!important;
}

@media screen and (max-width:640px) {
  #page-my-works-episodes-edit.isPC.fontSize-medium.writingDirection-horizontal #contentMain-episode .episodeBody textarea,  #page-my-works-episodes-edit.isPC.fontSize-medium.writingDirection-horizontal #contentMain-preview .episodeBody div {
    font-size: 16px!important;
  }
}

#page-my-works-episodes-edit.isPC.fontSize-medium.writingDirection-vertical #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isPC.fontSize-medium.writingDirection-vertical #contentMain-preview .episodeBody div {
  font-size: 17.5px!important;
}

#page-my-works-episodes-edit.isTouch.fontSize-medium #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isTouch.fontSize-medium #contentMain-preview .episodeBody div {
  font-size: 16px!important;
}

#page-my-works-episodes-edit.isPC.fontSize-large.writingDirection-horizontal #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isPC.fontSize-large.writingDirection-horizontal #contentMain-preview .episodeBody div {
  font-size: 20.125px!important;
}

@media screen and (max-width:640px) {
  #page-my-works-episodes-edit.isPC.fontSize-large.writingDirection-horizontal #contentMain-episode .episodeBody textarea,  #page-my-works-episodes-edit.isPC.fontSize-large.writingDirection-horizontal #contentMain-preview .episodeBody div {
    font-size: 18.4px!important;
  }
}

#page-my-works-episodes-edit.isPC.fontSize-large.writingDirection-vertical #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isPC.fontSize-large.writingDirection-vertical #contentMain-preview .episodeBody div {
  font-size: 20.125px!important;
}

#page-my-works-episodes-edit.isTouch.fontSize-large #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isTouch.fontSize-large #contentMain-preview .episodeBody div {
  font-size: 18.4px!important;
}

#page-my-works-episodes-edit.isPC.fontSize-xLarge.writingDirection-horizontal #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isPC.fontSize-xLarge.writingDirection-horizontal #contentMain-preview .episodeBody div {
  font-size: 22.75px!important;
}

@media screen and (max-width:640px) {
  #page-my-works-episodes-edit.isPC.fontSize-xLarge.writingDirection-horizontal #contentMain-episode .episodeBody textarea,  #page-my-works-episodes-edit.isPC.fontSize-xLarge.writingDirection-horizontal #contentMain-preview .episodeBody div {
    font-size: 20.8px!important;
  }
}

#page-my-works-episodes-edit.isPC.fontSize-xLarge.writingDirection-vertical #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isPC.fontSize-xLarge.writingDirection-vertical #contentMain-preview .episodeBody div {
  font-size: 22.75px!important;
}

#page-my-works-episodes-edit.isTouch.fontSize-xLarge #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.isTouch.fontSize-xLarge #contentMain-preview .episodeBody div {
  font-size: 20.8px!important;
}

#page-my-works-episodes-edit #content {
  height: 100%;
  position: relative;
}

#page-my-works-episodes-edit #content.contentAside-isShown #contentAside {
  left: 0;
}

#page-my-works-episodes-edit #content.contentAside-isShown #contentMain {
  width: calc(100% - 250px);
  width: calc(100% - (250px + constant(safe-area-inset-left)));
  width: calc(100% - (250px + env(safe-area-inset-left)));
  margin: 0 0 0 250px;
  margin: 0 0 0 calc(250px + constant(safe-area-inset-left));
  margin: 0 0 0 calc(250px + env(safe-area-inset-left));
}

#page-my-works-episodes-edit #content.contentAside-isShown #contentMain-inner {
  min-width: 240px;
}

#page-my-works-episodes-edit.writingDirection-vertical.isPreview #content.contentAside-isShown #episode-preview-content {
  width: calc(100vw - (250px + 25px));
  width: calc(100vw - (250px + 25px + constant(safe-area-inset-left)));
  width: calc(100vw - (250px + 25px + env(safe-area-inset-left)));
}

#page-my-works-episodes-edit #contentAside {
  -webkit-transition: all .3s cubic-bezier(.23,1,.32,1);
  transition: all .3s cubic-bezier(.23,1,.32,1);
}

#page-my-works-episodes-edit #contentAside {
  width: 250px;
  width: calc(250px + constant(safe-area-inset-left));
  width: calc(250px + env(safe-area-inset-left));
  height: 100%;
  position: fixed;
  top: 0;
  left: -250px;
  left: calc(-1 * (250px + constant(safe-area-inset-left)));
  left: calc(-1 * (250px + env(safe-area-inset-left)));
  box-sizing: border-box;
}

#page-my-works-episodes-edit #contentAside-inner {
  padding: 8px 15px 0;
  padding: 8px 15px constant(safe-area-inset-bottom) calc(15px + constant(safe-area-inset-left));
  padding: 8px 15px env(safe-area-inset-bottom) calc(15px + env(safe-area-inset-left));
  overflow-y: auto;
  box-sizing: border-box;
  width: 100%;
  height: calc(100% - 50px);
  -webkit-overflow-scrolling: touch;
}

#page-my-works-episodes-edit #contentAside-inner section {
  line-height: 1.4;
  margin: 1.5em 0 0;
}

#page-my-works-episodes-edit #contentAside-inner section:first-child {
  margin: .5em 0 0;
}

#page-my-works-episodes-edit #contentAside-inner h3,#page-my-works-episodes-edit #contentAside-inner h4,#page-my-works-episodes-edit #contentAside-inner ol {
  margin: 0;
}

#page-my-works-episodes-edit #contentAside-inner h3 {
  font-weight: 400;
  font-size: 1.2em;
  line-height: 1.2;
  margin: .5em 0 0;
}

#page-my-works-episodes-edit #contentAside-inner h3 i {
  width: 1.25em;
  display: inline-block;
  margin: 0 0 0 -1.25em;
}

#page-my-works-episodes-edit #contentAside-inner h4 {
  margin: 0 0 .5em;
  font-size: 13px;
}

#page-my-works-episodes-edit #contentAside-inner h4:after,#page-my-works-episodes-edit #contentAside-inner h4:before {
  content: '';
  display: table;
}

#page-my-works-episodes-edit #contentAside-inner h4:after {
  clear: both;
}

#page-my-works-episodes-edit #contentAside-inner h4 a {
  float: right;
  font-weight: 400;
}

#page-my-works-episodes-edit #contentAside-inner p {
  font-weight: 400;
  line-height: 1.4;
  font-size: 12px;
  margin: .5em 0 0;
}

#page-my-works-episodes-edit #contentAside-inner ul {
  margin: .5em 0 1em;
  padding: 0;
}

#page-my-works-episodes-edit #contentAside-inner ul li {
  list-style-type: none;
}

#page-my-works-episodes-edit #contentAside-inner li {
  margin: 0 0 .5em;
}

#page-my-works-episodes-edit .contentAside-pane.isHidden {
  display: none!important;
}

#page-my-works-episodes-edit #undoButton .ui-button-default {
  border-radius: 3px 0 0 3px;
  border-right: 0;
}

#page-my-works-episodes-edit #redoButton .ui-button-default {
  border-radius: 0 3px 3px 0;
  border-left: 0;
  position: relative;
}

#page-my-works-episodes-edit #redoButton .ui-button-default:before {
  position: absolute;
  top: -1px;
  left: 0;
  content: '';
  display: block;
  width: 0;
  height: 30px;
  z-index: 1;
}

@media screen and (max-width:340px) {
  #page-my-works-episodes-edit #redoButton .ui-button-default:before {
    height: 29px;
  }
}

#page-my-works-episodes-edit #saveButton.isLoading #saveButton-icon,#page-my-works-episodes-edit #saveButton.isLoading #saveButton-text {
  display: none;
}

#page-my-works-episodes-edit #saveButton.isLoading .ui-loading-gray {
  display: block;
}

#page-my-works-episodes-edit #saveButton.isChecking #saveButton-text {
  display: none;
}

#page-my-works-episodes-edit #saveButton.isChecking #saveButton-icon {
  display: block;
}

#page-my-works-episodes-edit #saveButton .ui-button-default {
  width: 57px;
  height: 30px;
  box-sizing: border-box;
}

@media screen and (max-width:340px) {
  #page-my-works-episodes-edit #saveButton .ui-button-default {
    height: 29px;
  }
}

#page-my-works-episodes-edit #saveButton #saveButton-icon {
  display: none;
  position: relative;
}

#page-my-works-episodes-edit #saveButton #saveButton-icon svg {
  width: 16px;
  height: 16px;
  -webkit-transform: translateY(-.2em);
  transform: translateY(-.2em);
}

#page-my-works-episodes-edit #saveButton #saveButton-icon svg path {
  stroke: #0990cc;
}

#page-my-works-episodes-edit #saveButton .ui-loading-gray {
  display: none;
  margin: -4px auto 0;
}

#page-my-works-episodes-edit #updateButton {
  padding-right: 10px!important;
}

#page-my-works-episodes-edit #contentMain {
  overflow: hidden;
}

#page-my-works-episodes-edit #workTitle {
  max-width: 825px;
  margin: 0 auto;
}

#page-my-works-episodes-edit #workTitle-inner {
  margin: 0;
  padding: 0 80px 10px;
  font-size: 12px;
  line-height: 1.5;
  color: #999;
}

@media screen and (max-width:640px) {
  #page-my-works-episodes-edit #workTitle-inner {
    font-size: 11px;
    padding: 0 20px 10px;
  }
}

#page-my-works-episodes-edit #workTitle-episodeNumber {
  margin: 0 0 0 .4em;
}

#page-my-works-episodes-edit #workTitle-episodeNumber i {
  color: #888;
  margin: 0 .25em 0 0;
}

#page-my-works-episodes-edit #contentMain-episode,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview {
  max-width: 825px;
  margin: 0 auto;
  position: relative;
  min-height: 30px;
}

@media screen and (max-width:640px) {
  #page-my-works-episodes-edit #contentMain-episode,  #page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview {
    font-size: 1.1em;
  }
}

#page-my-works-episodes-edit #contentMain-episode.isHidden,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview.isHidden {
  display: none;
}

#page-my-works-episodes-edit #contentMain-episode .episodeTitle,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeTitle {
  line-height: 1;
  margin: 0;
}

#page-my-works-episodes-edit #contentMain-episode .episodeTitle input,#page-my-works-episodes-edit #contentMain-episode .episodeTitle>span,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeTitle input,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeTitle>span {
  padding: 0 80px;
  font-size: 24.5px;
  vertical-align: top;
  line-height: 1.3em;
  font-weight: 400;
}

@media screen and (max-width:640px) {
  #page-my-works-episodes-edit #contentMain-episode .episodeTitle input,  #page-my-works-episodes-edit #contentMain-episode .episodeTitle>span,  #page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeTitle input,  #page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeTitle>span {
    padding: 0 20px 10px;
  }
}

#page-my-works-episodes-edit #contentMain-episode .episodeTitle>span,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeTitle>span {
  display: block;
  text-align: center;
}

#page-my-works-episodes-edit #contentMain-episode .episodeBody,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody {
  margin: 0;
  font-size: 17.5px;
}

#page-my-works-episodes-edit #contentMain-episode .episodeBody div,#page-my-works-episodes-edit #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody div,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody textarea {
  line-height: 1.8;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,'HGS明朝B','HG明朝B',dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-my-works-episodes-edit #contentMain-episode .episodeBody textarea,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody textarea {
  padding: 30px 80px 110px;
}

@media screen and (max-width:640px) {
  #page-my-works-episodes-edit #contentMain-episode .episodeBody textarea,  #page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody textarea {
    padding: 20px 20px 110px;
  }
}

#page-my-works-episodes-edit #contentMain-episode .episodeBody div,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody div {
  max-width: 665px;
  margin: 0 auto;
  padding: 20px 20px 110px;
}

#page-my-works-episodes-edit #contentMain-episode .episodeBody p,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody p {
  margin: 0;
}

#page-my-works-episodes-edit #contentMain-episode .episodeBody #episodeBody-input,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody #episodeBody-input {
  min-height: 400px;
  height: calc(100vh - (50px * 2 + 104px));
  overflow-y: scroll;
  -webkit-overflow-scrolling: touch;
  resize: vertical;
}

#page-my-works-episodes-edit #contentMain-episode .episodeBody #episodeBody-input.isSeamlessScrollMode,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody #episodeBody-input.isSeamlessScrollMode {
  display: block;
  min-height: 0;
  padding-right: 110px;
  resize: none;
}

#page-my-works-episodes-edit #contentMain-episode .episodeBody #episodeBody-input.isSeamlessScrollMode.isOverflowClippedByContent,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview .episodeBody #episodeBody-input.isSeamlessScrollMode.isOverflowClippedByContent {
  padding-bottom: 15px;
}

#page-my-works-episodes-edit #contentMain-episode input,#page-my-works-episodes-edit #contentMain-episode textarea,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview input,#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview textarea {
  border: none;
}

#page-my-works-episodes-edit #contentMain-episode {
  padding: 110px 0 0;
}

@media screen and (max-width:640px) {
  #page-my-works-episodes-edit #contentMain-episode {
    padding: 74px 0 0;
  }
}

#page-my-works-episodes-edit.writingDirection-horizontal.isPreview .episodeBody {
  text-align: center;
}

#page-my-works-episodes-edit.writingDirection-horizontal.isPreview .episodeBody div {
  display: inline-block;
  text-align: left;
  padding-top: 60px!important;
}

#page-my-works-episodes-edit.writingDirection-horizontal #contentMain-preview {
  padding: 107px 0 0;
}

#page-my-works-episodes-edit.writingDirection-vertical .tatechuyoko1 {
  -webkit-text-combine: horizontal;
  -ms-text-combine-horizontal: all;
  text-combine-upright: all;
}

#page-my-works-episodes-edit.writingDirection-vertical .tatechuyoko1,#page-my-works-episodes-edit.writingDirection-vertical _:lang(x)::-ms-backdrop {
  -webkit-text-combine: none;
  -ms-text-combine-horizontal: none;
  text-combine-upright: none;
  -ms-writing-mode: lr-tb;
  writing-mode: horizontal-tb;
  line-height: 1;
}

#page-my-works-episodes-edit.writingDirection-vertical .tatechuyoko1,#page-my-works-episodes-edit.writingDirection-vertical _:-ms-lang(x)::backdrop {
  -webkit-text-combine: none;
  -ms-text-combine-horizontal: none;
  text-combine-upright: none;
  -ms-writing-mode: lr-tb;
  writing-mode: horizontal-tb;
  line-height: 1;
}

#page-my-works-episodes-edit.writingDirection-vertical .episodeTitle .tatechuyoko1 {
  font-family: dcsymbols,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-my-works-episodes-edit.writingDirection-vertical.fontFamily-sans .episodeBody .tatechuyoko1 {
  font-family: dcsymbols,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-my-works-episodes-edit.writingDirection-vertical .tatechuyoko2,#page-my-works-episodes-edit.writingDirection-vertical .tatechuyoko3 {
  -webkit-text-combine: horizontal;
  -ms-text-combine-horizontal: all;
  text-combine-upright: all;
}

#page-my-works-episodes-edit.writingDirection-vertical .leaderMarks,#page-my-works-episodes-edit.writingDirection-vertical _:lang(x)::-ms-backdrop {
  transform: translateX(-.4em);
}

#page-my-works-episodes-edit.writingDirection-vertical .leaderMarks,#page-my-works-episodes-edit.writingDirection-vertical _:-ms-lang(x)::backdrop {
  display: inline-block;
  transform: translateX(-.4em);
}

#page-my-works-episodes-edit.writingDirection-vertical #contentMain-preview {
  width: 100%;
  height: 100%;
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  position: relative;
}

#page-my-works-episodes-edit.writingDirection-vertical #contentMain-preview.isHidden {
  display: none;
}

#page-my-works-episodes-edit.writingDirection-vertical #episode-preview-content {
  max-width: initial;
  width: calc(100vw - 25px);
  height: calc(100% - 50px);
  overflow-x: auto;
  overflow-y: hidden;
  padding: 50px 32px 0 0;
  -webkit-overflow-scrolling: touch;
  box-sizing: border-box;
  margin: 0 25px 0 0;
}

#page-my-works-episodes-edit.writingDirection-vertical #episode-preview-content .episodeBody,#page-my-works-episodes-edit.writingDirection-vertical #episode-preview-content .episodeTitle {
  max-height: 665px;
}

#page-my-works-episodes-edit.writingDirection-vertical #episode-preview-content .episodeTitle {
  line-height: 1;
  margin: auto 0 auto 60px;
  font-size: 24.5px;
  padding: 80px 0;
  display: block;
}

#page-my-works-episodes-edit.writingDirection-vertical #episode-preview-content .episodeTitle>span {
  font-size: 1em;
  vertical-align: top;
  line-height: 1.3em;
  font-weight: 400;
  padding: 35px 0 0;
  display: block;
}

#page-my-works-episodes-edit.writingDirection-vertical #episode-preview-content .episodeBody {
  margin: auto 0;
  padding: 40px 0 40px 60px;
  text-align: center;
}

#page-my-works-episodes-edit.writingDirection-vertical #episode-preview-content .episodeBody div {
  display: inline-block;
  text-align: left;
  line-height: 1.8;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,'HGS明朝B','HG明朝B',dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  max-height: 100%;
}

#page-my-works-episodes-edit.writingDirection-vertical #episode-preview-content p {
  margin: 0;
}

#page-my-works-episodes-edit #contentMain-preview-loading {
  position: absolute;
  top: 80px;
  left: 50%;
  z-index: 100;
  -webkit-transform: translateX(-50%);
  transform: translateX(-50%);
  -webkit-writing-mode: horizontal-tb;
  -ms-writing-mode: lr-tb;
  writing-mode: horizontal-tb;
}

#page-my-works-episodes-edit #contentMain-preview-loading.isHidden {
  display: none;
}

#page-my-works-episodes-edit .widget-displaySetting {
  margin: 8px 0 0;
  background: #fff;
  padding: 8px;
  border-radius: 3px;
  box-shadow: 0 0 1px rgba(0,0,0,.1);
}

#page-my-works-episodes-edit .widget-displaySetting h4 {
  font-size: 12px!important;
  margin: 8px 0 4px!important;
}

#page-my-works-episodes-edit .widget-displaySetting li,#page-my-works-episodes-edit .widget-displaySetting section,#page-my-works-episodes-edit .widget-displaySetting ul {
  margin: 0!important;
}

#page-my-works-episodes-edit .widget-displaySetting section:first-of-type h3 {
  margin-top: 0!important;
}

#page-my-works-episodes-edit.isPC #contentAside-tools {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  height: 100%;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}

#page-my-works-episodes-edit.isPC #contentAside-tools #contentAside-tools-top {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
}

@media screen and (max-height:800px) {
  #page-my-works-episodes-edit.isPC #contentAside-tools {
    display: block;
  }
}

#page-my-works-episodes-edit.isTouch.writingDirection-horizontal.isPreview .episodeTitle>span {
  font-size: 16.25px!important;
}

#page-my-works-episodes-edit.isTouch.writingDirection-horizontal.isPreview .episodeBody div {
  padding-top: 45px!important;
}

@media screen and (max-width:705px) {
  #page-my-works-episodes-edit.isTouch.writingDirection-horizontal.isPreview .episodeBody div {
    max-width: 100%!important;
    box-sizing: border-box;
  }
}

#page-my-works-episodes-edit.isTouch.writingDirection-vertical.isPreview .episodeTitle {
  padding: 0 0 10px!important;
}

#page-my-works-episodes-edit.isTouch.writingDirection-vertical.isPreview .episodeTitle>span {
  font-size: 22.75px!important;
}

@media screen and (max-height:845px) {
  #page-my-works-episodes-edit.isTouch.writingDirection-vertical.isPreview .episodeBody {
    max-height: 100%!important;
    box-sizing: border-box;
  }
}

#page-my-works-episodes-edit.isTouch #contentMain-episode .episodeTitle input {
  font-size: 16.25px;
}

#page-my-works-episodes-published #container {
  max-width: 400px;
  margin: 0 auto;
  padding: 0 15px;
}

#page-my-works-episodes-published #container:after,#page-my-works-episodes-published #container:before {
  content: '';
  display: table;
}

#page-my-works-episodes-published #container:after {
  clear: both;
}

#page-my-works-episodes-published #container header {
  margin: 60px 0 0;
  text-align: center;
}

#page-my-works-episodes-published #container header i {
  font-size: 5em;
  line-height: 1;
  color: #4baae0;
  margin: 0 0 10px 10px;
  display: block;
}

#page-my-works-episodes-published #container header h2 {
  line-height: 1.3;
}

#page-my-works-episodes-published #container header p {
  margin: 0;
}

#page-my-works-episodes-published #workInfo {
  text-align: center;
  margin: 1em 0 45px;
}

#page-my-works-episodes-published #workInfo h3,#page-my-works-episodes-published #workInfo p {
  font-size: 14px;
  line-height: 1.5;
}

#page-my-works-episodes-published #workInfo h3 {
  font-weight: 400;
  color: #666;
  margin: 0;
}

#page-my-works-episodes-published #workInfo a {
  color: #222;
  text-decoration: none;
  border-bottom: 1px solid #eee;
}

#page-my-works-episodes-published #workInfo a:focus,#page-my-works-episodes-published #workInfo a:hover {
  color: #0990cc!important;
  border-bottom-color: #0990cc;
}

#page-my-works-episodes-published #workInfo p {
  margin: .25em 0 0;
}

#page-my-works-episodes-published #workInfo-workTitle {
  font-weight: 700;
}

#page-my-works-episodes-published #workInfo-author {
  color: #666;
}

#page-my-works-episodes-published #buttons {
  padding: 0;
  text-align: center;
  margin: 0 0 45px;
}

#page-my-works-episodes-published #buttons li {
  list-style-type: none;
}

#page-my-works-episodes-published #buttons li {
  display: inline-block;
  margin: 0 2px;
}

#page-my-works-episodes-published #share {
  text-align: center;
}

#page-my-works-episodes-published #share h3 {
  border-bottom: 1px solid #ddd;
}

#page-my-works-episodes-published #share h4,#page-my-works-episodes-published #share p {
  margin: 0;
}

#page-my-works-episodes-published #share h4 {
  font-weight: 400;
}

#page-my-works-episodes-published #share input {
  font-size: 14px;
}

#page-my-works-episodes-published #share section {
  margin: 0 0 .75em;
}

#page-my-works-episodes-published #share-actions {
  margin: .5em 0 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: reverse;
  -webkit-flex-direction: row-reverse;
  -ms-flex-direction: row-reverse;
  flex-direction: row-reverse;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  line-height: 1;
  text-align: center;
}

#page-my-works-episodes-published #share-actions p:not(:first-child) {
  border-right: 1px solid #ddd;
  padding: 0 .75em 0 0;
  margin: 0 .75em 0 0;
}

#page-my-works-episodes-published #share-actions p a,#page-my-works-episodes-published #share-actions p button {
  padding: 0;
  font-weight: 400;
  color: #0990cc;
  border: none;
}

#page-my-works-episodes-published #share-actions p a:focus,#page-my-works-episodes-published #share-actions p a:hover,#page-my-works-episodes-published #share-actions p button:focus,#page-my-works-episodes-published #share-actions p button:hover {
  color: #0081c2;
  text-decoration: underline!important;
}

#page-my-works-episodes-published #share-actions .isPanelHidden .icon-up {
  display: none;
}

#page-my-works-episodes-published #share-actions .isPanelShown .icon-bottom {
  display: none;
}

#page-my-works-episodes-published.isTouch #container {
  max-width: 400px!important;
}

#page-my-works-episodes-published.isTouch #container header {
  margin: 45px 0 0;
}

#page-my-works-episodes-published.isTouch #container header i {
  font-size: 3em;
}

#page-my-works-episodes-published.isTouch #container header h2 {
  font-size: 18px;
}

#page-my-works-episodes-published.isTouch #workInfo h3,#page-my-works-episodes-published.isTouch #workInfo p {
  font-size: 11px;
}

#page-my-works-episodes-published.isTouch #buttons {
  font-size: 14px;
}

#page-my-works-episodes-published.isTouch #buttons:after,#page-my-works-episodes-published.isTouch #buttons:before {
  content: '';
  display: table;
}

#page-my-works-episodes-published.isTouch #buttons:after {
  clear: both;
}

#page-my-works-episodes-published.isTouch #buttons li {
  float: left;
  width: calc(33.333333% - 6px);
  display: block;
  margin: 0 0 0 9px;
}

#page-my-works-episodes-published.isTouch #buttons li:first-child {
  margin: 0;
}

#page-my-works-episodes-published.isTouch #buttons a {
  width: 100%;
  padding-left: 0;
  padding-right: 0;
  box-sizing: border-box;
}

#page-my-works-episodes-published.isTouch #share {
  text-align: left;
}

#page-my-works-episodes-published.isTouch #share h3 {
  font-size: 11px;
  font-weight: 700;
  margin: 0 0 1em -15px;
  width: calc(100% + 30px);
  padding: 0 16px 8px!important;
  border-bottom: 1px solid #ddd;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  box-sizing: border-box;
  -webkit-transform: scale(1,1);
  transform: scale(1,1);
}

#page-my-works-episodes-published.isTouch #share h3 h3 {
  margin: 0;
}

#page-my-works-episodes-published.isTouch #share-actions {
  display: block;
  text-align: left;
  width: calc(100% + 15px);
}

#page-my-works-episodes-published.isTouch #share-actions p {
  border: none;
  padding: 0;
  margin: 0;
  border-top: 1px solid #ddd;
}

#page-my-works-episodes-published.isTouch #share-actions a,#page-my-works-episodes-published.isTouch #share-actions button {
  display: block;
  padding: 10px 0;
  width: 100%;
  text-align: left;
}

#page-my-collections .ui-message-notice a,#page-my-collections .ui-message-notice span {
  display: inline-block;
}

#page-my-collections .collection {
  padding: 14px 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  border-bottom: 1px solid #ddd;
}

#page-my-collections .collection-title {
  font-size: 15px;
  line-height: 1.3;
  font-weight: 700;
}

#page-my-collections .collection-title a {
  color: #222;
}

#page-my-collections .collection-title a:focus,#page-my-collections .collection-title a:hover {
  color: #0081c2;
}

#page-my-collections.isTouch .ui-message-notice {
  margin: 10px;
}

#page-my-collections.isTouch .collection {
  padding: 14px 16px;
}

#page-my-antenna-users.isPC main {
  margin: 0 0 0 10px;
}

#page-my-collections-edit #input-description {
  height: 10em;
}

#page-my-collections-edit.isPC #main {
  padding: 0 34px;
}

#page-my-collections-edit.isTouch #main {
  padding: 14px 16px 0;
  padding-bottom: env(safe-area-inset-bottom);
}

#page-my-collections-edit.isTouch .ui-input-content {
  margin: 12px 0 0;
}

#page-top #container {
  margin-top: 80px;
  width: 1120px;
  padding: 0 35px 0 30px;
}

#page-top #information {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  margin: 10px 0 0;
}

#page-top #information-box {
  margin: 0 30px 0 0;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
}

#page-top #blog {
  width: 200px;
  min-width: 200px;
  background: #f2f1f0;
  position: relative;
}

#page-top #blog h2 {
  background: #222;
  color: #fff;
  font-size: 12px;
  display: inline-block;
  position: absolute;
  top: -6px;
  left: 7px;
  line-height: 1;
  padding: 4px 6px;
  margin: 0;
}

#page-top #blog ul {
  padding: 0;
  margin: 15px 15px 0;
}

#page-top #blog ul li {
  list-style-type: none;
}

#page-top #blog li {
  padding: 10px 0;
  border-bottom: 1px solid #ddd;
}

#page-top #blog li a {
  text-decoration: none;
  display: block;
}

#page-top #blog time {
  display: block;
}

#page-top #blog time {
  color: #888;
  font-size: 11px;
  line-height: 1.5;
}

#page-top #blog p {
  margin: 10px 15px 15px;
  line-height: 1;
  font-size: 12px;
  text-align: center;
}

#page-top #rankings {
  width: 200px;
}

#page-top #explore section {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  border-top: 1px solid #ddd;
  padding: 15px 0 30px;
}

#page-top #explore h3 {
  font-size: 1em;
  font-weight: 400;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,serif;
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  margin: .3em 1.25em 0 0;
  line-height: 1;
  color: #aaa;
  letter-spacing: 3px;
  max-width: 1em;
}

#page-top #explore ul {
  padding: 0;
  margin: 0;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  line-height: 1.3;
}

#page-top #explore ul li {
  list-style-type: none;
}

#page-top #explore ul a {
  color: #222;
  padding: 3px 0;
  display: block;
}

#page-top #shareButtons {
  border-top: 1px solid #ddd;
  margin: 30px 0 0;
  padding: 10px 0 0;
}

#page-top #kakuyomu-guide {
  border-top: 1px solid #ddd;
  border-bottom: 1px solid #ddd;
  padding: 15px 0;
}

#page-top #rankings ul {
  padding: 0;
  margin: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-top #rankings ul li {
  list-style-type: none;
}

#page-top #rankings ul li.isActive button {
  border-top-color: #ddd;
  border-left-color: #ddd;
  border-right-color: #ddd;
  border-bottom-color: #fff;
}

#page-top #rankings ul li:not(.isActive) span {
  display: none;
}

#page-top #rankings ul button {
  background: 0 0;
  width: 100%;
  padding: .25em .4em;
  display: block;
  border: 1px solid transparent;
  box-sizing: border-box;
  margin: 0 0 -1px;
  position: relative;
  z-index: 10;
}

#page-top #publication {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  margin: 0 0 30px;
  border-top: 2px solid #ddd;
  border-bottom: 2px solid #ddd;
  padding: 30px 0;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-top #publication-header p {
  color: #555;
  margin: 1em 0 0;
  line-height: 1.5;
}

#page-top #publication-header p span {
  display: block;
}

#page-top #publication-header a {
  color: #222;
}

#page-top #publication-header a:focus,#page-top #publication-header a:hover {
  color: #0990cc;
}

#page-top #publication-content {
  padding: 0;
  width: calc(100% - 190px);
  margin: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-top #publication-content li {
  list-style-type: none;
}

#page-top #publication-content li {
  width: 33.333333%;
  padding: 0 0 0 40px;
}

#page-top #publication-content li p {
  margin: 0;
}

#page-top #publication-content a {
  display: block;
  color: #222;
  text-decoration: none;
}

#page-top #publication-content a:after,#page-top #publication-content a:before {
  content: '';
  display: table;
}

#page-top #publication-content a:after {
  clear: both;
}

#page-top .publication-content-info {
  float: right;
  width: calc(100% - 75px);
}

#page-top .publication-content-info h3,#page-top .publication-content-info p {
  line-height: 1.3;
}

#page-top .publication-content-info h3 {
  margin: 5px 0 0;
  font-size: 13px;
}

#page-top .publication-content-catchphrase {
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  font-size: 11px;
}

#page-top .publication-content-author {
  font-size: 11px;
  color: #888;
  margin: 5px 0!important;
}

#page-top #aside {
  width: 200px;
  float: right;
}

#page-top #features {
  border-top: 2px solid #ddd;
  padding: 30px 0 0;
  margin: 30px 0 15px;
}

#page-top #features ul {
  padding: 0;
  margin: 15px 0 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-top #features ul li {
  list-style-type: none;
}

#page-top #features li {
  width: calc(25% - 11.25px);
}

#page-top #features h3,#page-top #features p,#page-top #features ul {
  line-height: 1.5;
}

#page-top #features h3 {
  font-size: 13px;
  line-height: 1.3;
  margin: 0 0 4px;
}

#page-top #features li a {
  color: #222;
  text-decoration: none;
}

#page-top #features li a:focus h3,#page-top #features li a:hover h3 {
  color: #0990cc;
  text-decoration: underline;
}

#page-top #features li p {
  font-size: 11.5px;
  color: #666;
  margin: 0;
}

#page-top #features li p:after,#page-top #features li p:before {
  content: '';
  display: table;
}

#page-top #features li p:after {
  clear: both;
}

#page-top #features li span,#page-top #features li time {
  display: block;
  padding: 0 13px 0 0;
  position: relative;
  float: left;
  color: #888;
}

#page-top #features li span:after,#page-top #features li time:after {
  content: '';
  display: inline-block;
  position: absolute;
  right: 5px;
  top: 50%;
  margin: -2px 0 0;
  width: 4px;
  height: 4px;
  background: #ccc;
  border-radius: 50%;
}

#page-top #features li span:last-child:after,#page-top #features li time:last-child:after {
  display: none;
  padding: 0;
}

#page-top .features-image {
  width: 100%;
  height: 88px;
  background-size: auto 88px;
  background-position: center center;
  margin: 0 0 8px;
}

#page-contests-default.isPC #container-inner .sectionHeader {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  -webkit-box-align: end;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
  margin: 0 0 25px;
}

#page-contests-default.isPC #container-inner .sectionHeader p {
  margin: 0;
}

#page-contests-default.isPC #container-inner .sectionHeader a {
  color: #222;
}

#page-contests-default.isPC #container-inner .sectionHeader a:focus,#page-contests-default.isPC #container-inner .sectionHeader a:hover {
  color: #0081c2;
}

#page-contests-default.isPC #container-inner .sectionHeader i {
  color: #0990cc;
}

#page-contests-contest-works.isPC #filter-categories ul,#page-contests-contest-works.isPC .widget-internalLinks {
  width: 1125px;
  padding: 0 30px;
  margin: 0 auto;
}

#page-contests-contest-works.isPC .widget-internalLinks {
  border-top: 1px solid #ddd;
  padding: 0;
}

#page-contests-contest-works.isPC .widget-internalLinks ul {
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

#page-contests-contest-works.isPC .internalLinks-target {
  margin-top: -100px!important;
  padding-top: 100px!important;
}

#page-contests-contest-works.isPC #result {
  overflow: hidden;
  min-width: 1185px;
}

#page-contests-contest-works.isPC #result-background {
  background: #f2f1f0;
  padding: 30px 0 60px;
}

#page-contests-contest-works.isPC #result-inner {
  width: 800px;
  margin: 0 auto;
  padding: 0 30px;
  background: #fff;
}

#page-contests-contest-works.isPC #result-inner:after,#page-contests-contest-works.isPC #result-inner:before {
  content: '';
  display: table;
}

#page-contests-contest-works.isPC #result-inner:after {
  clear: both;
}

#page-contests-contest-works.isPC #filter ul {
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  padding: 0 30px;
}

#page-contests-contest-works.isPC #filter ul li {
  list-style-type: none;
}

#page-contests-contest-works.isPC #filter-categories {
  background: #f2f1f0;
  height: 50px;
  box-shadow: 0 1px 0 rgba(0,0,0,.1),inset 0 1px 0 rgba(0,0,0,.05);
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: end;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
}

#page-contests-contest-works.isPC #filter-categories+#filter-list {
  border: none;
  padding-top: 0!important;
}

#page-contests-contest-works.isPC #filter-categories ul {
  padding: 0 30px;
  margin: 0 auto -1px;
  box-sizing: content-box;
}

#page-contests-contest-works.isPC #filter-categories a {
  font-size: 14px;
  padding: 8px 13px 12px;
}

#page-contests-contest-works.isPC #filter-list {
  border-top: 1px solid #ddd;
  margin: 0;
  padding: 0;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  height: 60px;
  line-height: 60px;
  box-sizing: border-box;
}

#page-contests-contest-works.isPC #filter-list li {
  margin: 0 8px!important;
}

#page-contests-contest-works.isPC #filter-list li.isActive a {
  font-weight: 700;
  color: #222;
}

#page-contests-contest-works.isPC #filter-list li a {
  display: block;
}

#page-contests-contest-works.isTouch .widget-internalLinks {
  margin: 16px 0 0;
}

#page-contests-contest-works.isTouch .widget-internalLinks ul {
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

#page-contests-contest-works.isTouch .widget-internalLinks li.isActive a {
  color: #222;
}

#page-contests-contest-works.isTouch .internalLinks-target {
  margin-top: -80px!important;
  padding-top: 80px!important;
}

#page-contests-contest-works.isTouch #filter {
  background: #f2f1f0;
  padding: 12px 12px 0;
}

#page-contests-contest-works.isTouch #filter select {
  height: 37px;
  line-height: 37px;
}

#page-contests-contest-works.isTouch #filter-categories,#page-contests-contest-works.isTouch #filter-list {
  width: 100%;
}

#page-contests-contest-works.isTouch #filter-categories+#filter-list {
  margin: 8px 0 0;
}

#page-contests-contest-detail.isPC #contest-body {
  border: 5px solid #f2f1f0;
  margin: 0;
  padding: 45px 30px 30px;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-contests-contest-detail.isPC #contest-body h2 {
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  margin: 0 0 .5em;
  text-align: center;
  font-size: 1.85em;
  line-height: 1.5;
  color: #0081c2;
}

#page-contests-contest-detail.isPC #contest-body h2+p {
  color: #444;
  margin: 0 30px;
  font-size: 15px;
  line-height: 1.7;
}

#page-contests-contest-detail.isPC #contest-body h2 span {
  display: inline-block;
}

#page-contests-contest-detail.isPC #contest-body h3 {
  margin: 2em 0 0;
  font-size: 1.25em;
  border-bottom: 1px solid #ddd;
}

#page-contests-contest-detail.isPC #contest-body h4 {
  margin: 2em 0 0;
  line-height: 1.3;
}

#page-contests-contest-detail.isPC #contest-body ul {
  padding: 0 0 0 1.5em;
}

#page-contests-contest-detail.isPC #contest-body table {
  border: solid #ddd;
  border-width: 1px 0 0 1px;
  width: 100%;
  margin: 1em 0;
  line-height: 1.5;
}

#page-contests-contest-detail.isPC #contest-body td,#page-contests-contest-detail.isPC #contest-body th {
  border: solid #ddd;
  border-width: 0 1px 1px 0;
  padding: 10px 13px;
}

#page-contests-contest-detail.isPC #contest-body th {
  text-align: left;
  background: #f2f1f0;
}

#page-contests-contest-detail.isPC #contest-body dt {
  font-weight: 700;
}

#page-contests-contest-detail.isPC #contest-body dd {
  margin: 0 0 0 30px!important;
  padding-left: 10px!important;
  border-left: 5px solid #eee;
}

#page-contests-contest-detail.isTouch #contest-body {
  margin: 24px 16px;
}

#page-contests-contest-detail.isTouch #contest-body h2 {
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  margin: 0 0 16px;
  line-height: 1.5;
  color: #0081c2;
  font-size: 18px;
  text-align: left;
}

#page-contests-contest-detail.isTouch #contest-body h2+p {
  color: #444;
  line-height: 1.7;
  margin: 0;
  font-size: 14px;
}

#page-contests-contest-detail.isTouch #contest-body h2 span {
  display: inline-block;
}

#page-contests-contest-detail.isTouch #contest-body h2 br {
  display: none;
}

#page-contests-contest-detail.isTouch #contest-body h3 {
  border-bottom: 1px solid #ddd;
  font-size: 11px;
  margin: 24px 0 8px -16px;
  width: 100%;
  padding: 0 16px 8px;
}

#page-contests-contest-detail.isTouch #contest-body p,#page-contests-contest-detail.isTouch #contest-body ul {
  line-height: 1.7;
}

#page-contests-contest-detail.isTouch #contest-body ul {
  padding: 0 0 0 1.5em;
}

#page-contests-contest-detail.isTouch #contest-body table {
  border: solid #ddd;
  border-width: 1px 0 0 1px;
  width: 100%;
  margin: 16px 0;
  line-height: 1.5;
}

#page-contests-contest-detail.isTouch #contest-body td,#page-contests-contest-detail.isTouch #contest-body th {
  border: solid #ddd;
  border-width: 0 1px 1px 0;
  padding: 8px 10px;
}

#page-contests-contest-detail.isTouch #contest-body th {
  text-align: left;
  background: #f2f1f0;
}

#page-contests-contest-detail.isTouch #contest-body dt {
  font-weight: 700;
}

#page-contests-contest-detail.isTouch #contest-body dd {
  margin: 0 0 0 24px!important;
  padding-left: 10px!important;
  border-left: 5px solid #eee;
}

#page-works-work #container {
  max-width: 100%!important;
  width: 100%!important;
  padding: 0;
  margin: 0;
  min-width: 1125px;
}

#page-works-work #workHeader {
  max-width: 1125px;
  padding: 0 30px;
  margin: 120px auto 0;
  position: relative;
}

#page-works-work #workHeader dd,#page-works-work #workHeader dt {
  float: left;
  margin: 0;
}

#page-works-work #workHeader #workTitle {
  margin: 0;
  line-height: 1.3;
}

#page-works-work #workHeader #workTitle a {
  color: #222;
}

#page-works-work #workHeader #workTitle a:hover {
  color: #0081c2;
}

#page-works-work #workHeader #workTitle {
  font-size: 2.5em;
  line-height: 1.2;
}

#page-works-work #workHeader .ui-tab li:first-child {
  margin: 0;
}

#page-works-work #workMain {
  width: 1125px;
  padding: 0 30px;
  margin: 0 auto 60px;
}

#page-works-work #author-information .heading-level2,#page-works-work #reviews .heading-level2,#page-works-work #work-information .heading-level2 {
  font-size: 1.5em;
}

#page-works-work .widget-internalLinks {
  margin: 80px 0 40px;
}

#page-works-work .internalLinks-target {
  margin-top: -60px!important;
  padding-top: 60px!important;
}

#page-works-work #description {
  margin: 0 0 80px;
  width: 100%;
  min-height: 150px;
}

#page-works-work #description:after,#page-works-work #description:before {
  content: '';
  display: table;
}

#page-works-work #description:after {
  clear: both;
}

#page-works-work #description+#table-of-contents {
  border-top: 1px solid #ccc;
  padding: 60px 0 0;
}

#page-works-work #description.hasBothCatchphraseAndIntroduction {
  display: table;
  table-layout: fixed;
}

#page-works-work #description.hasBothCatchphraseAndIntroduction p {
  display: table-cell;
  width: 50%;
  margin: 0;
  vertical-align: middle;
  box-sizing: border-box;
}

#page-works-work #description.hasBothCatchphraseAndIntroduction #catchphrase {
  padding: 0 5% 0 2%;
  border-right: 10px solid #f5f5f5;
}

#page-works-work #description.hasBothCatchphraseAndIntroduction #introduction {
  padding: 0 2% 0 5%;
}

#page-works-work #description #catchphrase {
  line-height: 1.2;
  margin: 0 0 30px;
  text-align: center;
  box-sizing: border-box;
}

#page-works-work #description #catchphrase-body {
  font-size: 2.5em;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-works-work #description #catchphrase-author {
  font-size: .9em;
  line-height: 1;
  display: block;
  margin: 1em 0 0;
  font-weight: 700;
}

#page-works-work #description #catchphrase-author span {
  vertical-align: middle;
}

#page-works-work #description #introduction {
  font-size: 1.1em;
}

#page-works-work .widget-toc {
  min-height: 200px;
  margin: 0 0 60px;
}

#page-works-work .widget-toc:after,#page-works-work .widget-toc:before {
  content: '';
  display: table;
}

#page-works-work .widget-toc:after {
  clear: both;
}

#page-works-work .widget-toc header {
  float: left;
  width: calc(33.33333333% - 26px);
}

#page-works-work .widget-toc header h3,#page-works-work .widget-toc header p {
  margin: 0;
}

#page-works-work .widget-toc h3 {
  line-height: 1.4;
}

#page-works-work .widget-toc .widget-toc-date,#page-works-work .widget-toc .widget-toc-workStatus {
  color: #888;
}

#page-works-work .widget-toc .widget-toc-date {
  font-size: .9em;
  line-height: 1.4;
}

#page-works-work .widget-toc .widget-toc-main {
  width: calc(66.6666666% - 14px);
  float: right;
}

#page-works-work .widget-toc .widget-toc-items {
  line-height: 1.5;
  padding: 0;
  margin: 0;
}

#page-works-work .widget-toc .widget-toc-items:after,#page-works-work .widget-toc .widget-toc-items:before {
  content: '';
  display: table;
}

#page-works-work .widget-toc .widget-toc-items:after {
  clear: both;
}

#page-works-work .widget-toc .widget-toc-items li {
  list-style-type: none;
}

#page-works-work .widget-toc .widget-toc-items li:after,#page-works-work .widget-toc .widget-toc-items li:before {
  content: '';
  display: table;
}

#page-works-work .widget-toc .widget-toc-items li:after {
  clear: both;
}

#page-works-work .widget-toc .widget-toc-items li:first-child.widget-toc-chapter {
  margin-top: 0!important;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-chapter {
  position: relative;
  line-height: 1.2;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level1 {
  margin: 2em 0 .35em;
  font-size: 2.5em;
  color: #888;
  font-weight: 400;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2 {
  margin: 2em 0 1em;
  font-size: 1.25em;
  font-weight: 700;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-chapter.widget-toc-level2:before {
  content: '';
  position: absolute;
  display: block;
  top: 50%;
  left: 0;
  width: 100%;
  height: 0;
  border-top: 1px solid #444;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-chapter span {
  background: #fff;
  position: relative;
  z-index: 1;
  display: inline-block;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode {
  position: relative;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a {
  display: block;
  padding: 3px 0;
  color: #222;
  position: relative;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:after,#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:before {
  content: '';
  display: table;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:after {
  clear: both;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:before {
  content: '';
  position: absolute;
  display: block;
  top: 1em;
  left: 0;
  width: 100%;
  height: 0;
  border-top: 1px dotted #aaa;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:visited {
  color: #aaa;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:focus,#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:hover {
  color: #0990cc;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:focus:before,#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:hover:before {
  border-top-color: #222;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:focus .widget-toc-episode-titleLabel,#page-works-work .widget-toc .widget-toc-items .widget-toc-episode a:hover .widget-toc-episode-titleLabel {
  text-decoration: underline;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode-datePublished,#page-works-work .widget-toc .widget-toc-items .widget-toc-episode-titleLabel {
  background: #fff;
  position: relative;
  z-index: 1;
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode-titleLabel {
  float: left;
  font-size: 1.1em;
  font-weight: 400;
  max-width: calc(100% - 120px);
}

#page-works-work .widget-toc .widget-toc-items .widget-toc-episode-datePublished {
  float: right;
  color: #777;
}

#page-works-work #reviews h3 {
  margin-top: 0;
}

#page-works-work #work-information h3 {
  margin-top: 0;
}

#page-works-work #work-information header {
  max-width: 66.666666%;
}

#page-works-work #work-information header h4,#page-works-work #work-information header h5 {
  line-height: 1.5;
  margin: 0;
}

#page-works-work #work-information header h4 a,#page-works-work #work-information header h5 a {
  color: #222;
  text-decoration: none;
  border-bottom: 1px solid #eee;
}

#page-works-work #work-information header h4 a:hover,#page-works-work #work-information header h5 a:hover {
  border-bottom-color: #aaa;
}

#page-works-work #work-information-main {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  position: relative;
}

#page-works-work #work-information-main p {
  margin: 1.5em 0 0;
}

#page-works-work #work-information-main p a {
  color: #444;
}

#page-works-work #work-information-main p a:hover {
  color: #0081c2;
}

#page-works-work #author-information-inner {
  width: 1125px;
  margin: 0 auto;
  padding: 0 30px 60px;
}

#page-works-work #author-information-inner h3 {
  margin-top: 0;
}

#page-works-work #author-information-title {
  font-size: 1em;
  font-weight: 400;
  color: #888;
  line-height: 1;
  margin: 30px 0 1em;
}

#page-works-work #author-information-table {
  margin: 30px 0 0;
}

#page-works-work #author-information-table:after,#page-works-work #author-information-table:before {
  content: '';
  display: table;
}

#page-works-work #author-information-table:after {
  clear: both;
}

#page-works-work #author-information-table>section {
  float: left;
  width: calc(33.3333333% - 26.6666666px);
  margin: 0 0 15px 40px;
}

#page-works-work #author-information-table>section:nth-child(1) {
  margin: 0 0 15px;
}

#page-works-work #author-information-profile-inner header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-work #author-information-name {
  margin: 0;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
}

#page-works-work #author-information-name span {
  display: block;
}

#page-works-work #author-information-news {
  margin: 30px 0 0;
}

#page-works-work #author-information-news .author-information-see-more {
  font-size: .9em;
}

#page-works-work #author-information-news-list {
  padding: 0;
  margin: 0;
}

#page-works-work #author-information-news-list li {
  list-style-type: none;
}

#page-works-work #author-information-news-list li {
  border-bottom: 1px solid #ddd;
}

#page-works-work #author-information-news-list a {
  text-decoration: none;
  padding: 5px 0 5px 90px;
  position: relative;
  display: block;
}

#page-works-work #author-information-news-list a:hover h5 {
  text-decoration: underline;
  color: #0081c2;
}

#page-works-work #author-information-news-list h5,#page-works-work #author-information-news-list p {
  margin: 0;
  line-height: 1.5;
}

#page-works-work #author-information-news-list h5 {
  font-size: 1em;
  color: #222;
  font-weight: 400;
}

#page-works-work #author-information-news-list p {
  font-size: .85em;
  color: #888;
  position: absolute;
  top: 6px;
  left: 0;
  width: 90px;
}

#page-works-work #author-information-other-works .widget-catchphrase-author,#page-works-work #author-information-reviews .widget-catchphrase-author {
  display: none;
}

#page-works-reviews-edit.isTouch #container {
  padding-bottom: constant(safe-area-inset-bottom);
  padding-bottom: env(safe-area-inset-bottom);
}

#page-works-reviews-review.isPC #work-buttons {
  padding: 0;
  margin: 16px 0 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-reviews-review.isPC #work-buttons li {
  list-style-type: none;
}

#page-works-reviews-review.isPC #work-buttons li {
  width: calc(50% - 4px);
}

#page-works-reviews-review.isPC #work-buttons a,#page-works-reviews-review.isPC #work-buttons button {
  width: 100%;
}

#page-works-reviews-review.isPC #work-buttons a {
  height: 33px;
  line-height: 33px;
  box-sizing: border-box;
  font-size: 15px;
  padding: 0;
  text-align: center;
}

#page-works-reviews-review.isPC .widget-pager {
  margin: 30px 0;
}

#page-works-reviews-review.isTouch #work-buttons {
  padding: 0;
  margin: 16px auto 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  max-width: 370px;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-works-reviews-review.isTouch #work-buttons li {
  list-style-type: none;
}

#page-works-reviews-review.isTouch #work-buttons li {
  width: calc(50% - 4px);
}

#page-works-reviews-review.isTouch #work-buttons a {
  width: 100%;
}

#page-works-reviews-review.isTouch #work-buttons a {
  box-sizing: border-box;
  text-align: center;
}

#page-works-reviews-review.isTouch .widget-pager p {
  margin: 0;
}

#page-users-user #collections header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-users-user #collections header h4 {
  margin: 0;
}

#page-users-user #collections header a {
  margin: 0 0 0 1em;
}

#page-users-user #collections>ul {
  padding: 0;
}

#page-users-user #collections>ul li {
  list-style-type: none;
}

#page-users-user #collections .collection a {
  position: relative;
  border: 1px solid #ddd;
  text-decoration: none;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  color: #222;
}

#page-users-user #collections .collection a:focus,#page-users-user #collections .collection a:hover {
  border-color: #bbb;
}

#page-users-user #collections .collection-color {
  position: absolute;
  top: -1px;
  left: 15px;
  width: 80px;
  height: 7px;
}

#page-users-user #collections .collection-summary {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
}

#page-users-user #collections .collection-title {
  font-size: 18px;
  line-height: 1.3;
  margin: 0;
}

#page-users-user #collections .collection-meta {
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  color: #666;
  margin: 4px 0 0;
}

#page-users-user #collections .collection-meta li {
  list-style-type: none;
}

#page-users-user #collections .collection-meta li {
  position: relative;
  padding: 0 14px 0 0;
}

#page-users-user #collections .collection-meta li:after {
  content: '';
  display: inline-block;
  position: absolute;
  right: 5px;
  top: 50%;
  margin: -2px 0 0;
  width: 4px;
  height: 4px;
  background: #ddd;
  border-radius: 50%;
}

#page-users-user #collections .collection-meta li:last-child {
  padding: 0;
}

#page-users-user #collections .collection-meta li:last-child:after {
  display: none;
}

#page-users-user #collections .collection-description {
  font-size: 12px;
  line-height: 1.5;
  color: #666;
}

#page-users-user.isPC #main {
  margin-bottom: 60px;
}

#page-users-user.isPC .heading-level3 {
  margin: 0;
  line-height: 1.2;
}

#page-users-user.isPC .heading-level3 span {
  display: inline-block;
}

#page-users-user.isPC #collections {
  margin: 0 0 15px 0;
  padding: 0 0 25px 0;
  border-bottom: 1px solid #ddd;
}

#page-users-user.isPC #collections>ul {
  display: -ms-grid;
  display: grid;
  -ms-grid-columns: 1fr 1fr;
  grid-template-columns: 1fr 1fr;
  gap: 15px;
}

#page-users-user.isPC #collections .collection a {
  padding: 19px 15px 15px;
  height: 100%;
  box-sizing: border-box;
}

#page-users-user.isPC #collections .collection-summary {
  min-width: 0;
  margin: 0 15px 0 0;
}

#page-users-user.isPC #collections .collection-meta {
  font-size: 12px;
}

#page-users-user.isPC #collections .collection-description {
  width: 50%;
}

#page-users-user.isTouch .heading-level3 {
  margin: 0;
  line-height: 1.2;
  font-size: 11px;
}

#page-users-user.isTouch .heading-level3 span {
  display: inline-block;
}

#page-users-user.isTouch #collections {
  margin: 0 0 24px;
}

#page-users-user.isTouch #collections header {
  margin: 0 16px;
  font-size: 11px;
}

#page-users-user.isTouch #collections header h4 {
  font-weight: 700;
}

#page-users-user.isTouch #collections>ul {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow-x: auto;
  overflow-y: hidden;
  -webkit-scroll-snap-type: x mandatory;
  -ms-scroll-snap-type: x mandatory;
  scroll-snap-type: x mandatory;
}

#page-users-user.isTouch #collections .collection {
  scroll-snap-align: start;
  padding: 0 0 0 16px;
}

#page-users-user.isTouch #collections .collection:last-child {
  padding-right: 16px;
}

#page-users-user.isTouch #collections .collection a {
  padding: 19px 15px 12px;
  box-sizing: border-box;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  height: 100%;
  width: 288px;
}

@media screen and (max-width:640px) {
  #page-users-user.isTouch #collections .collection a {
    width: calc((100vw - 16px * 4)/ 2);
  }
}

#page-users-user.isTouch #collections .collection-title {
  font-size: 14px;
}

#page-users-user.isTouch #collections .collection-meta {
  font-size: 11.5px;
}

#page-users-user.isTouch #collections .collection-summary {
  margin: 0 0 15px;
}

#page-users-works.isPC .widget-work .float-left {
  padding-left: 165px;
}

#page-users-works.isTouch .widget-catchphrase-author {
  display: none;
}

#page-users-works.isTouch .widget-catchphrase {
  margin: 0 0 .25em;
  border: none;
  padding-bottom: 0;
}

#page-users-works.isTouch .widget-catchphrase:nth-child(2) {
  display: none;
}

#page-users-works.isTouch .widget-catchphrase-title {
  font-size: 11.5px;
}

#page-users-works.isTouch .widget-work {
  padding-left: 56px;
}

#page-users-collections .collection {
  border-bottom: 1px solid #ddd;
}

#page-users-collections .collection-summary {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  text-decoration: none;
  position: relative;
}

#page-users-collections .collection-color {
  position: absolute;
  top: 0;
  width: 80px;
  height: 7px;
}

#page-users-collections .collection-body {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  color: #666;
}

#page-users-collections .collection-body h2 {
  color: #222;
  margin: 0;
  line-height: 1.3;
}

#page-users-collections .collection-body p {
  line-height: 1.5;
  color: #444;
}

#page-users-collections .collection-body time {
  line-height: 1.3;
  display: block;
}

#page-users-collections .collection-workList {
  margin: 20px 0;
  padding: 0;
}

#page-users-collections .collection-workList a {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  color: #222;
  text-decoration: none;
}

#page-users-collections .collection-workList a:focus,#page-users-collections .collection-workList a:hover {
  color: #0990cc;
}

#page-users-collections .collection-workList a:focus .collection-work-title-order,#page-users-collections .collection-workList a:hover .collection-work-title-order {
  color: #666;
}

#page-users-collections .collection-workList a:focus .collection-work-title-titleLabel,#page-users-collections .collection-workList a:hover .collection-work-title-titleLabel {
  text-decoration: underline;
}

#page-users-collections .collection-work-color {
  display: inline-block;
  width: 30px;
  height: 7px;
  margin: 0 8px 0 0;
}

#page-users-collections .collection-work-title {
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  max-width: calc(100% - 40px);
}

#page-users-collections .collection-work-title-order {
  color: #666;
}

#page-users-collections .collection-work-omit {
  margin: 0 0 0 38px;
}

#page-users-collections .collection-work-omit i {
  font-size: 10px;
  color: #999;
  display: inline-block;
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg);
}

#page-users-collections.isPC .collection {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-users-collections.isPC .collection-summary {
  padding: 24px 0 18px;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-users-collections.isPC .collection-color {
  left: 165px;
}

#page-users-collections.isPC .collection-body {
  padding: 0 60px 0 0;
}

#page-users-collections.isPC .collection-body h2 {
  font-size: 18px;
}

#page-users-collections.isPC .collection-body h2:focus,#page-users-collections.isPC .collection-body h2:hover {
  color: #0081c2;
  text-decoration: underline;
}

#page-users-collections.isPC .collection-body p {
  font-size: 13px;
  margin: .5em 0 0;
}

#page-users-collections.isPC .collection-body time {
  font-size: 13px;
  margin: .7em 0 0;
}

#page-users-collections.isPC .collection-workList {
  width: 300px;
  font-size: 13px;
}

#page-users-collections.isTouch .collection-summary {
  padding: 20px 16px 15px 0;
}

#page-users-collections.isTouch .collection-color {
  left: 60px;
}

#page-users-collections.isTouch .collection-body h2 {
  font-size: 15px;
}

#page-users-collections.isTouch .collection-body p {
  font-size: 12px;
}

#page-users-collections.isTouch .collection-body time {
  font-size: 12px;
  margin: 1em 0 0;
}

#page-users-collections.isTouch .collection-workList {
  font-size: 12px;
  border-top: 1px dotted #ddd;
  margin: 0 0 30px 60px;
  padding: 8px 16px 0 0;
}

#page-users-collections-show #collection {
  margin: 2px 0 0;
}

#page-users-collections-show #collection-color {
  width: 80px;
  height: 7px;
}

#page-users-collections-show #collection-body h1 {
  margin: 0;
  line-height: 1.3;
}

#page-users-collections-show #collection-body h1 a {
  color: #222;
}

#page-users-collections-show #collection-description {
  line-height: 1.5;
}

#page-users-collections-show #collection-workList {
  border-top: 1px solid #ddd;
  margin: 8px 0 0;
}

#page-users-collections-show #collection-workList ul {
  padding: 0;
  margin: 0;
}

#page-users-collections-show #collection-workList ul li {
  list-style-type: none;
}

#page-users-collections-show #collection-workList .widget-work {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-users-collections-show #collection-workList .widget-work .float-left {
  padding: 0;
}

#page-users-collections-show.isPC #collection header {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-users-collections-show.isPC #collection header+#collection-workList {
  margin: 30px 0 0;
}

#page-users-collections-show.isPC #collection-color {
  margin: 0 0 30px 165px;
}

#page-users-collections-show.isPC #collection-body {
  margin: 0 330px 0 0;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-users-collections-show.isPC #collection-description {
  font-size: 1.1em;
  margin: 30px 0 15px;
}

#page-users-collections-show.isPC #collection-workList li {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-users-collections-show.isPC #collection-workList .collection-workList-item-number {
  width: 145px;
  margin: 15px 20px 0 0;
  text-align: right;
  color: #666;
}

#page-users-collections-show.isTouch #collection header {
  margin: 0 16px;
}

#page-users-collections-show.isTouch #collection header+#collection-workList {
  margin: 24px 0 0;
}

#page-users-collections-show.isTouch #collection .widget-meta {
  margin: 4px 0 0;
}

#page-users-collections-show.isTouch #collection-color {
  margin: 0 0 16px 16px;
}

#page-users-collections-show.isTouch #collection-body h1 {
  font-size: 15px;
}

#page-users-collections-show.isTouch #collection-description {
  margin: 15px 0;
}

#page-users-collections-show.isTouch #collection-workList li {
  position: relative;
}

#page-users-collections-show.isTouch #collection-workList .collection-workList-item-number {
  position: absolute;
  top: 10px;
  left: 16px;
  color: #666;
}

#page-users-news-entry.isPC #write-a-comment {
  height: 70px;
}

#page-users-news-entry.isPC .widget-pager {
  margin: 30px 0 0;
}

#page-users-news-entry.isPC aside h3 {
  margin: 0;
  padding: 0;
  border-bottom: 1px solid #ddd;
}

#page-users-news-entry.isPC aside li {
  margin: 0 0 12px;
}

#page-users-news-entry.isPC aside h4,#page-users-news-entry.isPC aside p {
  margin: 0;
  line-height: 1.5;
}

#page-users-news-entry.isPC aside h4 {
  margin: 0 4px 0 0;
  color: #222;
}

#page-users-news-entry.isPC aside p {
  color: #666;
  font-size: 11.5px;
}

#page-users-news-entry.isPC aside a {
  display: block;
  color: #222;
  text-decoration: none;
}

#page-users-news-entry.isPC aside a:hover {
  color: #0081c2;
}

#page-users-news-entry.isPC aside a:hover h4 {
  text-decoration: underline;
}

#page-users-news-entry.isTouch .widget-shareButtons {
  margin: 16px 16px 0;
}

#page-users-news-entry.isTouch .widget-pager a {
  font-size: 13px;
}

#page-users-news-entry.isTouch aside p {
  margin: 0 16px 24px;
}

#page-users-news-entry.isTouch aside p a {
  display: block;
  margin: 8px 0 0;
  font-size: 11px;
}

#page-users-news-entry.isTouch aside p a i {
  color: #4baae0;
  padding-right: 4px;
}

#page-users-news-entry.isTouch aside h3 {
  font-size: 11px;
  font-weight: 700;
  margin: 0 0 8px;
  padding: 0 16px 8px!important;
  border-bottom: 1px solid #ddd;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  box-sizing: border-box;
  margin: 0;
}

#page-users-news-entry.isTouch aside ul {
  margin: 0 0 24px;
  padding: 0;
}

#page-users-news-entry.isTouch aside li {
  margin: 0 0 0 16px;
}

#page-users-news-entry.isTouch aside li a {
  text-decoration: none;
  color: #222;
  border-bottom: 1px solid #ddd;
  padding: 14px 16px 14px 0;
  display: block;
}

#page-users-news-entry.isTouch aside li a h4 {
  font-size: 13px;
  line-height: 1.3;
  margin: 0 0 4px;
}

#page-users-news-entry.isTouch aside li a p {
  font-size: 11px;
  line-height: 1;
  color: #666;
  margin: 0;
}

#page-users-reviews.isTouch .widget-catchphrase-author {
  display: none;
}

#page-users-reviews.isTouch #reviews {
  border-top: 1px solid #ddd;
  margin-top: 16px;
  padding-top: 12px;
}

#page-users-reviews.isTouch .heading-level3 {
  font-size: 11px;
  font-weight: 700;
  margin: 0 0 8px;
  padding: 0 16px 8px!important;
  border-bottom: 1px solid #ddd;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  box-sizing: border-box;
  margin-bottom: 0;
  width: 100%!important;
}

#page-users-reviews.isTouch .widget-catchphrase-title {
  line-height: 1.2;
}

#page-explore.isPC #by-searchingConditions h2 {
  margin: 0;
}

#page-explore.isPC #by-searchingConditions .widget-searchingConditions>li:last-child {
  border-bottom: 1px solid #ddd;
}

#page-explore.isPC #by-searchingConditions .widget-searchingConditions p {
  font-size: 12px;
}

#page-explore.isPC #by-searchingConditions .widget-searchingConditions button svg {
  width: 20px;
  height: 20px;
}

#page-explore.isPC #by-genre h3 {
  margin: 1em 0 0;
}

#page-explore.isPC #by-genre ul {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

#page-explore.isPC #by-genre li {
  width: 33.33333%;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-explore.isPC #by-genre li a {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  font-size: 1.3em;
  color: #222;
  display: block;
  background: #f2f1f0;
  text-align: center;
  text-decoration: none;
  line-height: 1.2;
  margin: 0 2px 2px 0;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-explore.isPC #by-genre li a:hover {
  background: #d8d7d6;
}

#page-explore.isPC #by-genre a {
  padding: 1em .5em;
}

#page-explore.isPC #by-others ul {
  margin: 0;
}

#page-explore.isPC #by-others a {
  color: #222;
}

#page-explore.isPC #by-others a:focus,#page-explore.isPC #by-others a:hover {
  color: #0081c2;
}

#page-explore.isTouch #by-others ul {
  margin: 0 0 0 16px;
  padding: 0!important;
}

#page-explore.isTouch #by-searchingConditions h2 {
  margin: 0;
}

#page-explore.isTouch #by-searchingConditions .widget-searchingConditions ul {
  padding: 0 7px 0 0;
}

#page-explore.isTouch #by-searchingConditions .widget-searchingConditions a {
  min-height: 58px;
}

@media screen and (max-width:640px) {
  #page-explore.isTouch #by-searchingConditions .widget-searchingConditions a {
    min-height: auto;
  }
}

#page-explore.isTouch #by-genre ul {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  padding: 0;
  margin: 0 16px;
}

#page-explore.isTouch #by-genre li {
  width: 33.33333%;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-explore.isTouch #by-genre li a {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  color: #222;
  display: block;
  background: #f2f1f0;
  text-align: center;
  text-decoration: none;
  line-height: 1.2;
  margin: 0 2px 2px 0;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  font-size: 1em;
  font-weight: 700;
}

#page-explore.isTouch #by-genre li a:hover {
  background: #d8d7d6;
}

#page-explore.isTouch #by-genre a {
  padding: 1em .5em;
}

#page-explore.isTouch #by-others ul {
  margin: 0 0 0 16px;
}

#page-explore.isTouch #by-others a {
  color: #222;
  display: block;
  padding: 7px 0;
  border-bottom: 1px solid #ddd;
}

#page-explore.isTouch #by-others a:focus,#page-explore.isTouch #by-others a:hover {
  color: #0081c2;
}

#page-tags-tag.isPC #container {
  padding: 0;
}

#page-tags-tag.isPC .ui-tab {
  margin: .5em 0 0;
}

#page-tags-tag.isTouch .widget-catchphrase {
  margin: 0 0 8px;
}

#page-tags-tag.isTouch .widget-work .widget-work-meta .widget-work-status {
  padding-right: 0;
}

#page-tags-tag.isTouch .widget-work .widget-work-meta .widget-work-status:after {
  display: none;
}

#page-tags-tag.isTouch .widget-work .widget-work-characterCount {
  display: none;
}

#page-official #container {
  margin-top: 118px;
}

#page-official #official-introduction {
  font-size: 14px;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  text-align: center;
  letter-spacing: 2px;
  padding: 0 0 0 3px;
  margin: 0 0 16px;
}

#page-official #official-features {
  padding: 0;
  margin: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  width: 820px;
  border-right: 1px solid #ddd;
}

#page-official #official-features li {
  list-style-type: none;
}

#page-official #official-features a {
  color: #222;
  text-decoration: none;
  display: block;
}

#page-official #official-features a:after,#page-official #official-features a:before {
  content: '';
  display: table;
}

#page-official #official-features a:after {
  clear: both;
}

#page-official #official-features a:focus .official-features-title,#page-official #official-features a:hover .official-features-title {
  text-decoration: underline;
}

#page-official #official-features-1 {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-official #official-features-1 a {
  padding: 0 15px 8px 0;
}

#page-official #official-features-2 {
  width: 300px;
  border-left: 1px solid #ddd;
}

#page-official #official-features-2 a {
  padding: 0 15px 8px;
}

#page-official .official-features-image+* {
  margin-top: 16px!important;
}

#page-official .official-features-image {
  position: relative;
}

#page-official .official-features-image img {
  vertical-align: top;
  max-width: 100%;
}

#page-official .official-features-image p {
  position: absolute;
  left: 4px;
  bottom: -9px;
  margin: 0;
  background: #222;
  color: #fff;
  line-height: 1;
  padding: 0 10px;
  font-weight: 700;
  font-size: 10px;
  line-height: 16px;
  height: 16px;
  border-radius: 8px;
  border: 1px solid #fff;
}

#page-official .official-features-catchphrase {
  font-size: 11.5px;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  line-height: 1.5;
  margin: 16px 0 0;
  font-weight: 700;
}

#page-official .official-features-title {
  font-size: 18px;
  line-height: 1.3;
  margin: 4px 0;
  -webkit-font-feature-settings: 'palt';
  font-feature-settings: 'palt';
}

#page-official .official-features-subtitle {
  font-size: 14px;
  line-height: 1.5;
  margin: 0;
  color: #666;
}

#page-official .official-features-catchphrase,#page-official .official-features-subtitle,#page-official .official-features-title {
  margin-left: 8px;
}

#page-official .widget-official-publication {
  background: #f2f1f0;
  padding: 15px;
}

#page-official .widget-official-publication header {
  text-align: center;
  padding: 0 0 16px;
  border-bottom: 1px solid #ddd;
}

#page-official .widget-official-publication header h2,#page-official .widget-official-publication header p {
  margin: 0;
}

#page-official .widget-official-publication header h2 {
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
  font-size: 18px;
  line-height: 1.5;
}

#page-official .widget-official-publication header p {
  font-size: 13px;
}

#page-official .widget-official-publication header a {
  color: #222;
}

#page-official .widget-official-publication header a:hover {
  text-decoration: underline;
}

#page-official .widget-official-publication header a i {
  color: #4baae0;
}

#page-official .widget-official-publication li {
  border-bottom: 1px solid #ccc;
}

#page-official #official-labels {
  margin-top: 30px;
  border-top: 2px solid #ddd;
  padding: 30px 0 0;
}

#page-official #official-labels>header h2,#page-official #official-labels>header p {
  display: inline-block;
  vertical-align: top;
}

#page-official #official-labels-list {
  margin: 30px 0 0;
}

#page-search #container {
  margin-top: 80px;
}

#page-search #searchingConditions {
  margin: 15px 10px 0;
}

#page-search #searchingConditions h4 {
  font-size: .9em;
  margin: 0;
}

#page-search #searchingConditions .widget-searchingConditions div {
  display: block;
}

#page-search #searchingConditions .widget-searchingConditions a {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  padding: 10px 0;
}

#page-search #searchingConditions .widget-searchingConditions p {
  font-size: .85em;
  margin: 0 0 3px;
  line-height: 1.3;
}

#page-search #searchingConditions .widget-searchingConditions ul {
  font-size: 13px;
}

#page-search #searchingConditions .widget-searchingConditions button span {
  margin: 0;
}

#page-search #searchingConditions .widget-searchingConditions button svg {
  width: 16px;
  height: 16px;
}

#page-search #filter-section-contest p {
  margin: 0;
}

#page-search #filter-section-contest template {
  display: none;
}

#page-search.isPC #filter .filter-section {
  background: #f7f6f5;
  border-radius: 4px;
  padding: 10px;
  margin: 15px 0 0;
}

#page-search.isPC #filter .filter-section:first-child {
  margin: 0;
}

#page-search.isPC #filter ul {
  padding: 0;
}

#page-search.isPC #filter li {
  list-style-type: none;
}

#page-search.isPC #filter p {
  margin-bottom: 0;
}

#page-search.isPC #filter section {
  margin: 15px 0 0;
  border-top: 1px solid #ccc;
}

#page-search.isPC #filter section:first-child {
  margin: 0;
  border: none;
}

#page-search.isPC #filter section:first-child h4 {
  margin-top: 0;
}

#page-search.isPC #filter input {
  font-size: 1em;
}

#page-search.isPC #filter h4 {
  font-size: .9em;
  line-height: 1.2;
  margin: 10px 0;
}

#page-search.isPC #filter .filter-section-description h4 {
  margin-bottom: 0;
}

#page-search.isPC #filter .filter-section-description p {
  font-size: 11px;
  color: #666;
  margin: 0 0 8px 1px!important;
}

#page-search.isPC #filter .ui-button-blue {
  font-size: 1em;
  width: 100%;
  padding: .75em 0;
}

#page-search.isPC #filter .ui-checkbox-label,#page-search.isPC #filter .ui-radiobutton-label {
  font-size: 1em;
  -webkit-transform: translateY(.1em);
  transform: translateY(.1em);
}

#page-search.isPC #filter-section-contest select {
  font-size: 1em;
}

#page-search.isPC #filter-section-contest .ui-select {
  display: block;
}

#page-search.isPC #filter-contest-categories {
  margin: 10px 0 0;
}

#page-search.isTouch #filter {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 30000;
}

#page-search.isTouch #filter.isHidden {
  display: none;
}

#page-search.isTouch #filter form {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: calc(100% - 100px);
}

#page-search.isTouch #filter .filter-section-description {
  border-bottom: 1px solid #ddd;
  font-size: 11px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  padding: 0 16px 8px;
  margin: 0 0 1em -16px;
  width: 100%;
}

#page-search.isTouch #filter .filter-section-description h4 {
  margin: 0;
}

#page-search.isTouch #filter .filter-section-description p {
  margin: 0;
  color: #666;
}

#page-search.isTouch #filter-section-inner {
  padding: 0 16px 16px;
  box-sizing: border-box;
  height: calc(100vh - 175px);
  overflow-y: scroll;
  -webkit-overflow-scrolling: touch;
  position: relative;
  background: #fff;
}

#page-search.isTouch #filter-section-inner ul {
  padding: 0;
  margin: 0;
  font-size: 13px;
}

#page-search.isTouch #filter-section-inner ul li {
  list-style-type: none;
}

#page-search.isTouch #filter-section-inner ul:after,#page-search.isTouch #filter-section-inner ul:before {
  content: '';
  display: table;
}

#page-search.isTouch #filter-section-inner ul:after {
  clear: both;
}

#page-search.isTouch #filter-section-inner section {
  margin: 24px auto;
  max-width: 400px;
}

#page-search.isTouch #filter-section-inner input,#page-search.isTouch #filter-section-inner select {
  font-size: 1em;
  height: 33px;
}

#page-search.isTouch #filter-section-contest .ui-select {
  display: block;
}

#page-search.isTouch #filter-contest-categories {
  margin: 8px 0 0!important;
}

#page-rankings.isPC .widget-pager {
  margin: 0;
}

#page-rankings.isTouch .widget-work {
  position: relative;
  padding-left: 56px;
}

#page-rankings.isTouch .widget-work .widget-work-status {
  padding-right: 0;
}

#page-rankings.isTouch .widget-work .widget-work-status:after {
  display: none;
}

#page-rankings.isTouch #rankings-period-links {
  padding: 0;
}

#page-signup .ui-checkbox-label {
  max-width: calc(100% - 40px);
  line-height: 1.3;
}

#page-signup-finished #container {
  text-align: center;
}

#page-signup-finished .ui-message {
  font-size: 1.25em;
  font-weight: 400;
}

#page-settings #account-header {
  line-height: 1;
}

#page-settings #account-header h2 {
  margin: 0;
  font-family: dcsymbols,'Helvetica Neue',Helvetica,Arial,'ヒラギノ角ゴ Pr6N','Hiragino Kaku Gothic Pr6N','ヒラギノ角ゴ ProN','Hiragino Kaku Gothic ProN','ヒラギノ角ゴ StdN','Hiragino Kaku Gothic StdN','Segoe UI',Verdana,'メイリオ',Meiryo,sans-serif;
}

#page-settings #account-header p {
  margin: 8px 0 0;
  font-size: 1.25em;
  color: #666;
}

#page-settings #loyalty,#page-settings #notification,#page-settings #profile,#page-settings #settings {
  margin: 30px 0;
}

#page-settings #loyalty.isHidden,#page-settings #notification.isHidden,#page-settings #profile.isHidden,#page-settings #settings.isHidden {
  display: none;
}

#page-settings #loyalty h4,#page-settings #notification h4,#page-settings #profile h4,#page-settings #settings h4 {
  margin: 0;
}

#page-settings #loyalty p,#page-settings #notification p,#page-settings #profile p,#page-settings #settings p {
  margin: 0;
}

#page-settings #loyalty header h3,#page-settings #notification header h3,#page-settings #profile header h3,#page-settings #settings header h3 {
  font-size: 14px;
  margin: 0;
}

#page-settings #loyalty header p,#page-settings #notification header p,#page-settings #profile header p,#page-settings #settings header p {
  color: #666;
  font-size: 13px;
}

#page-settings #loyalty header span,#page-settings #notification header span,#page-settings #profile header span,#page-settings #settings header span {
  display: inline-block;
}

#page-settings #profile>section {
  padding-top: 30px;
}

#page-settings #no-blocklist-link {
  color: #aaa;
}

#page-settings.isPC #account-header {
  margin: 0 0 30px;
}

#page-settings.isPC #loyalty section,#page-settings.isPC #notification section,#page-settings.isPC #profile section,#page-settings.isPC #settings section {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  border-top: 1px solid #ddd;
  padding: 16px 0;
}

#page-settings.isPC #loyalty section section:first-child,#page-settings.isPC #notification section section:first-child,#page-settings.isPC #profile section section:first-child,#page-settings.isPC #settings section section:first-child {
  border: none;
  padding: 0 0 16px;
}

#page-settings.isPC #loyalty>section:first-child,#page-settings.isPC #notification>section:first-child,#page-settings.isPC #profile>section:first-child,#page-settings.isPC #settings>section:first-child {
  border: none;
  padding-top: 0;
}

#page-settings.isPC #loyalty header,#page-settings.isPC #notification header,#page-settings.isPC #profile header,#page-settings.isPC #settings header {
  padding: 0 0 1em;
  width: 135px;
  margin: 0 30px 0 0;
}

#page-settings.isPC #loyalty header+div,#page-settings.isPC #notification header+div,#page-settings.isPC #profile header+div,#page-settings.isPC #settings header+div {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-settings.isPC #loyalty header p,#page-settings.isPC #notification header p,#page-settings.isPC #profile header p,#page-settings.isPC #settings header p {
  margin: 4px 0 0;
}

#page-settings.isPC #loyalty .section-description,#page-settings.isPC #notification .section-description,#page-settings.isPC #profile .section-description,#page-settings.isPC #settings .section-description {
  margin: 0 0 .75em!important;
}

#page-settings.isPC .updateButton {
  margin: 0 auto 60px!important;
  border-top: 1px solid #ddd;
  padding: 16px 0 0 165px;
}

#page-settings.isPC #account p {
  margin: 0 0 .5em;
}

#page-settings.isPC #notification {
  margin: -100px 0 0;
  padding: 130px 0 0;
}

#page-settings.isPC #notification .section-description {
  border-bottom: 1px solid #ddd;
  padding: 0 0 1em;
}

#page-settings.isPC #notification table {
  width: 100%;
}

#page-settings.isPC #notification tr:first-child td {
  border: none;
  padding-top: 0;
}

#page-settings.isPC #notification tr:last-child td {
  padding-bottom: 0;
}

#page-settings.isPC #notification td {
  padding: 10px 30px 10px 0;
  border-top: 1px solid #ddd;
}

#page-settings.isPC #settings-comments {
  padding: 0;
}

#page-settings.isPC #settings-comments section:last-child {
  padding-bottom: 0;
}

#page-settings.isPC #settings-comments p {
  margin: 0 0 .5em;
}

#page-settings.isTouch #account-header {
  padding: 0 16px;
  text-align: center;
}

#page-settings.isTouch #account-header .heading-level2 {
  line-height: 1;
  font-size: 15px;
  border: none;
  padding: 0!important;
  width: 100%;
  margin: 4px 0 0;
}

#page-settings.isTouch #account-header p {
  font-size: 11px;
  color: #666;
  line-height: 1.2;
}

#page-settings.isTouch .ui-tab {
  width: 100%;
  margin: 16px 0 24px!important;
}

#page-settings.isTouch .ui-tab ul {
  padding: 0;
}

#page-settings.isTouch .ui-input-description {
  margin: 0 0 .5em!important;
}

#page-settings.isTouch #loyalty section,#page-settings.isTouch #notification section,#page-settings.isTouch #profile section,#page-settings.isTouch #settings section {
  margin: 16px 0;
}

#page-settings.isTouch #loyalty>section:first-child,#page-settings.isTouch #notification>section:first-child,#page-settings.isTouch #profile>section:first-child,#page-settings.isTouch #settings>section:first-child {
  padding-top: 0;
}

#page-settings.isTouch #loyalty header h3,#page-settings.isTouch #notification header h3,#page-settings.isTouch #profile header h3,#page-settings.isTouch #settings header h3 {
  border-bottom: 1px solid #ddd;
  padding: 0 16px 8px;
  font-size: 11px;
}

#page-settings.isTouch #loyalty>section>header+div,#page-settings.isTouch #notification>section>header+div,#page-settings.isTouch #profile>section>header+div,#page-settings.isTouch #settings>section>header+div {
  margin: 0 16px;
}

#page-settings.isTouch #loyalty .section-description,#page-settings.isTouch #notification .section-description,#page-settings.isTouch #profile .section-description,#page-settings.isTouch #settings .section-description {
  margin: 8px 0 16px!important;
  font-size: 12px;
  line-height: 1.5;
}

#page-settings.isTouch .updateButton {
  margin: 16px auto 24px!important;
  border-top: 1px solid #ddd;
  padding: 16px 16px 0;
}

#page-settings.isTouch .updateButton button {
  width: 100%;
  box-sizing: border-box;
  text-align: center;
}

#page-settings.isTouch #account div {
  margin: 0 0 0 16px!important;
}

#page-settings.isTouch #account a {
  display: block;
  padding: 10px 0;
  border-bottom: 1px solid #ddd;
}

#page-settings.isTouch #notification {
  margin: -150px 0 0;
  padding: 120px 0 0;
}

#page-settings.isTouch #notification>section {
  padding: 30px 0 0;
}

#page-settings.isTouch #notification>section:first-child {
  padding: 0;
  margin: 36px 0 0;
}

#page-settings.isTouch #notification header {
  margin: 0 0 8px;
}

#page-settings.isTouch #notification table {
  width: 100%;
  display: block;
}

#page-settings.isTouch #notification tr {
  display: block;
}

#page-settings.isTouch #notification tr:first-child td {
  border: none;
  padding-top: 0;
}

#page-settings.isTouch #notification tr:last-child td {
  padding-bottom: 0;
}

#page-settings.isTouch #notification td {
  display: block;
  padding: 4px 0;
}

#page-settings.isTouch #settings>section {
  padding: 30px 0 0;
}

#page-settings.isTouch #settings>section:first-child {
  padding: 0;
}

#page-settings.isTouch #loyalty h3 {
  margin: 0 0 1em;
}

#page-settings.isTouch #blocklist div {
  margin: 16px!important;
}

#page-settings-profile.isPC #container {
  width: auto;
  margin: 50px 0 0;
  padding: 0;
}

#page-settings-profile.isPC #updateButton {
  margin: 0 auto 60px;
  border-top: 1px solid #ddd;
  padding: 16px 0 0 165px;
}

#page-settings-profile.isTouch #container {
  padding-top: 0;
  max-width: 100%;
}

#page-settings-profile.isTouch #updateButton {
  margin: 16px auto 24px;
  border-top: 1px solid #ddd;
  padding: 16px 16px 0;
}

#page-settings-profile.isTouch #updateButton button {
  width: 100%;
  box-sizing: border-box;
  text-align: center;
}

#page-settings-blocklist ul {
  padding: 0;
  line-height: 1.3;
}

#page-settings-blocklist ul li {
  list-style-type: none;
}

#page-settings-blocklist.isPC ul {
  overflow-x: hidden;
  overflow-y: auto;
  -webkit-overflow-scrolling: touch;
  border-top: 1px solid #ddd;
  max-height: 413px;
}

#page-settings-blocklist.isPC ul::-webkit-scrollbar {
  border-right: 5px solid #fff;
  width: 15px;
  background: #fff;
}

#page-settings-blocklist.isPC ul::-webkit-scrollbar:hover {
  border-right-color: #f7f6f5;
}

#page-settings-blocklist.isPC ul::-webkit-scrollbar-thumb {
  border-right: 5px solid #ddd;
  -webkit-transition: all .1s linear;
  transition: all .1s linear;
}

#page-settings-blocklist.isPC ul::-webkit-scrollbar-thumb:hover {
  border-right-color: #bbb;
}

#page-settings-blocklist.isPC li {
  border-bottom: 1px solid #ddd;
  line-height: 1;
}

#page-settings-blocklist.isPC li a {
  text-decoration: none;
  line-height: 1.3;
}

#page-settings-blocklist.isPC li div {
  padding: 10px 0;
}

#page-settings-blocklist.isTouch #container {
  padding: 0;
}

#page-settings-blocklist.isTouch ul {
  border-top: 1px solid #ddd;
  padding: 0;
  margin: 0 0 16px;
}

#page-settings-blocklist.isTouch li {
  border-bottom: 1px solid #ddd;
  margin: 0 0 0 16px;
}

#page-settings-blocklist.isTouch li a {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  text-decoration: none;
  padding: 14px 0;
}

#page-settings-blocklist.isTouch li div {
  min-width: 0;
}

#page-settings-blocklist.isTouch li i {
  color: #ddd;
  margin: 0 16px 0 8px;
}

#page-settings-loyalty-enter.isPC #container {
  height: auto;
  min-height: 100%;
}

@media screen and (max-width:420px) {
  #page-settings-loyalty-entered #container-inner #button {
    display: -webkit-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: reverse;
    -webkit-flex-direction: column-reverse;
    -ms-flex-direction: column-reverse;
    flex-direction: column-reverse;
  }
}

#page-settings-loyalty-entered #container-inner #button a {
  width: 140px;
  margin: 0 4px;
}

@media screen and (max-width:420px) {
  #page-settings-loyalty-entered #container-inner #button a {
    line-height: 1;
    font-size: 1em!important;
    width: 100%;
    padding: 1em 0;
    margin: 0 0 8px;
  }
}

#page-anatanomachi-default .text {
  position: relative;
  background: #f3f7ed;
  overflow: hidden;
  -webkit-transition-property: all;
  transition-property: all;
  -webkit-transition-duration: .35s;
  transition-duration: .35s;
  -webkit-transition-timing-function: ease-out;
  transition-timing-function: ease-out;
  height: 250px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text {
    height: 180px;
  }
}

#page-anatanomachi-default .text.isOpen {
  height: 570px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text.isOpen {
    height: 480px;
  }
}

#page-anatanomachi-default .text.isOpen .text-clear {
  display: none;
}

#page-anatanomachi-default .text-clear {
  display: block;
  position: absolute;
  width: 100%;
  height: 100%;
  z-index: 10;
}

#page-anatanomachi-default .text-container {
  position: absolute;
  right: 0;
  width: 100%;
  overflow-x: scroll;
  -webkit-overflow-scrolling: touch;
  direction: rtl;
  padding-bottom: 58px;
}

@media (min-width:1430px) {
  #page-anatanomachi-default .text-container {
    text-align: center;
    background: url(/images/anatanomachi/paper_bg.png?aRWE6yIkCk3M) center 48px repeat-x;
    overflow-x: auto;
  }
}

#page-anatanomachi-default .text-text {
  position: relative;
  letter-spacing: 5px;
  height: 465px;
  font-family: "Shinsei Kaisho CBSK1","游明朝","Yu Mincho","游明朝体",YuMincho,"ヒラギノ明朝 Pro W3","Hiragino Mincho Pro",HiraMinProN-W3,"HGS明朝E","ＭＳ Ｐ明朝","MS PMincho",Garamond,"Times New Roman",serif;
  font-size: 18px;
  line-height: 33px;
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  direction: ltr;
  text-align: left;
  padding-top: 48px;
  background: url(/images/anatanomachi/paper_bg.png?aRWE6yIkCk3M) right 48px repeat-x;
  min-width: 100%;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text-text {
    height: 373px;
    background: url(/images/anatanomachi/paper_bg_s.png?q_20fEMDMGBO) right 48px repeat-x;
  }
}

@media (min-width:1430px) {
  #page-anatanomachi-default .text-text {
    min-width: auto;
    display: inline-block;
    background: 0 0;
  }
}

#page-anatanomachi-default .text-text p {
  margin: 0;
  padding-top: 4px;
  box-sizing: border-box;
}

#page-anatanomachi-default .text-text p.pr1 {
  position: relative;
}

#page-anatanomachi-default .text-text p.pr1::before {
  display: block;
  content: "";
  width: 431px;
  height: 462px;
  background: url(/images/anatanomachi/kousei.png?eeehm7dYtk6e) center center no-repeat;
  background-size: contain;
  position: absolute;
  margin: -5px 3px 0 0;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text-text p.pr1::before {
    background-image: url(/images/anatanomachi/kousei_s.png?HZiZZ-391zj1);
    width: 559.5px;
    height: 372.5px;
  }
}

#page-anatanomachi-default .text-text p.pr4 {
  padding-left: 495px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text-text p.pr4 {
    padding-left: 396px;
  }
}

#page-anatanomachi-default .text-text .br3-1 {
  display: none;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text-text .br3-1 {
    display: block;
  }
}

#page-anatanomachi-default .text-text .i1 {
  position: absolute;
  top: 406px;
  margin-right: -735px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text-text .i1 {
    top: 350px;
    margin-right: -596px;
  }
}

#page-anatanomachi-default .text-text .i1 img {
  width: 715.5px;
  height: 143px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text-text .i1 img {
    width: 572.4px;
    height: 114.4px;
  }
}

#page-anatanomachi-default .text-title {
  display: block;
  padding-left: 33px;
  padding-right: 99px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text-title {
    padding-right: 33px;
  }
}

#page-anatanomachi-default .text-head {
  position: absolute;
  font-size: 10px;
  line-height: 1;
  color: rgba(0,0,0,.4);
  letter-spacing: 0;
  direction: ltr;
  top: 10px;
  right: 104px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .text-head {
    right: 38px;
  }
}

#page-anatanomachi-default .cover {
  position: relative;
  text-align: center;
  background: url(/images/anatanomachi/japan.png?fv7FdDvKwhpE) center 60px no-repeat;
  background-size: 850px 562.5px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .cover {
    background: url(/images/anatanomachi/japan_min.png?XwV4GGJeeE7y) center 150px no-repeat;
    background-size: 270px 261px;
  }
}

#page-anatanomachi-default .cover-container {
  background: url(/images/anatanomachi/photos.png?A4RPZypreVZH) center 30px no-repeat;
  background-size: 1045px 531.5px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .cover-container {
    background: url(/images/anatanomachi/photos_s.png?8pXAjQhooZa3) center 50px no-repeat;
    background-size: 418.5px 382.5px;
  }
}

#page-anatanomachi-default .cover h1 {
  display: inline-block;
  width: 95%;
  max-width: 980px;
  margin: 14px 0 0;
}

#page-anatanomachi-default .cover h1 a {
  display: block;
  background: url(/images/anatanomachi/kakuyomu.png?rZr22w41UuKL) left center no-repeat;
  width: 102.5px;
  height: 19.5px;
  padding-top: 19.5px;
  overflow: hidden;
  background-size: contain;
  box-sizing: border-box;
}

#page-anatanomachi-default .cover h2 {
  background: url(/images/anatanomachi/anatano_machino_monogatari.png?dIaI6QZg2_Vr) center center no-repeat;
  width: 152px;
  height: 438px;
  padding-top: 438px;
  overflow: hidden;
  margin: 40px auto 0;
  background-size: contain;
  box-sizing: border-box;
}

@media (max-width:600px) {
  #page-anatanomachi-default .cover h2 {
    width: 108.57142857px;
    height: 312.85714286px;
    padding-top: 312.85714286px;
    margin-top: 80px;
  }
}

#page-anatanomachi-default .cover h3 {
  background: url(/images/anatanomachi/message.png?xzZKbilJV07E) center center no-repeat;
  width: 270px;
  height: 83px;
  padding-top: 83px;
  overflow: hidden;
  background-size: contain;
  box-sizing: border-box;
  position: absolute;
  left: 50%;
  top: 230px;
  margin: 0 0 0 -335px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .cover h3 {
    background: #fff url(/images/anatanomachi/message_s.png?m6bUuX9RXCrq) center center no-repeat;
    width: 100%;
    height: 28px;
    padding-top: 28px;
    background-size: 241.5px 12.5px;
    top: 47px;
    left: auto;
    margin: 0;
    border-top: 1px solid #4d4d4d;
    border-bottom: 1px solid #4d4d4d;
  }
}

#page-anatanomachi-default .cover-copy1 {
  background: url(/images/anatanomachi/copy_1.png?9n1QTJXOmaYg) center center no-repeat;
  width: 229px;
  height: 66px;
  padding-top: 66px;
  overflow: hidden;
  background-size: contain;
  box-sizing: border-box;
  position: absolute;
  top: 395px;
  left: 50%;
  margin: 0 0 0 100px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .cover-copy1 {
    background-image: url(/images/anatanomachi/copy_1_s.png?S3Jhrd7fgXLz);
    width: 175px;
    height: 50.5px;
    padding-top: 50.5px;
    position: static;
    top: auto;
    left: auto;
    margin: 25px auto 0;
  }
}

#page-anatanomachi-default .cover-period {
  background: transparent url(/images/anatanomachi/period.png?7gGCzENXfuy7) center center no-repeat;
  height: 30px;
  padding-top: 30px;
  overflow: hidden;
  background-size: 1040px 30px;
  box-sizing: border-box;
  position: relative;
  width: 1044px;
  max-width: 100%;
  margin: 80px auto 16px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .cover-period {
    background-size: 770.37037037px 22.22222222px;
    margin-top: 25px;
  }
}

#page-anatanomachi-default .information {
  width: 980px;
  margin: 24px auto 0;
}

#page-anatanomachi-default .information:after,#page-anatanomachi-default .information:before {
  content: '';
  display: table;
}

#page-anatanomachi-default .information:after {
  clear: both;
}

@media (max-width:980px) {
  #page-anatanomachi-default .information {
    width: 100%;
  }
}

#page-anatanomachi-default .information-container h4 {
  display: inline-block;
  font-weight: 600;
  font-size: 15px;
  margin: 0;
}

#page-anatanomachi-default .information-container h4 span {
  font-size: 10px;
}

#page-anatanomachi-default .information h3 {
  color: #ff1744;
  font-size: 18px;
  font-weight: 600;
  padding-left: 26px;
  margin: 0 0 24px -26px;
}

@media (max-width:980px) {
  #page-anatanomachi-default .information h3 {
    margin-left: -26px;
  }
}

#page-anatanomachi-default .information h3::before {
  content: "";
  position: absolute;
  width: 62px;
  height: 1;
  border-top: 1px solid #ff1744;
  margin-left: -34px;
  -webkit-transform: rotate(-45deg);
  transform: rotate(-45deg);
}

#page-anatanomachi-default .outline {
  margin-top: 32px;
}

@media (max-width:980px) {
  #page-anatanomachi-default .outline {
    padding: 0 16px;
  }
}

#page-anatanomachi-default .outline p {
  font-size: 16px;
  font-weight: 600;
  line-height: 30px;
  -webkit-column-count: 2;
  column-count: 2;
  -webkit-column-gap: 48px;
  column-gap: 48px;
  background: url(/images/anatanomachi/underline.png?obpMrcNMYkvH) 0 0 repeat;
  background-size: 10px 30px;
  padding: 2px 0 3px 0;
  text-align: justify;
  margin: 0;
}

@media (max-width:600px) {
  #page-anatanomachi-default .outline p {
    -webkit-column-count: 1;
    column-count: 1;
    font-size: 14px;
  }
}

#page-anatanomachi-default .top-join {
  text-align: center;
  margin: 32px 0 64px;
  padding: 0 8px;
}

#page-anatanomachi-default .top-join .anatanomachi-nav-result-link {
  display: inline-block;
  border: 2px solid #ff1744;
  padding: 2px;
  border-radius: 29px;
  margin-bottom: 12px;
}

#page-anatanomachi-default .top-join .anatanomachi-nav-result-link a {
  display: inline-block;
  font-size: 24px;
  font-weight: 600;
  color: #fff;
  background: #ff1744;
  padding: 2px 60px;
  line-height: 48px;
  height: 48px;
  border-radius: 25px;
}

@media (max-width:980px) {
  #page-anatanomachi-default .top-join .anatanomachi-nav-result-link a {
    padding-left: 40px;
    padding-right: 40px;
  }
}

#page-anatanomachi-default .information-container {
  margin-top: 70px;
}

#page-anatanomachi-default .information-container:after,#page-anatanomachi-default .information-container:before {
  content: '';
  display: table;
}

#page-anatanomachi-default .information-container:after {
  clear: both;
}

#page-anatanomachi-default .contest-detail {
  float: left;
  width: 640px;
}

@media (max-width:980px) {
  #page-anatanomachi-default .contest-detail {
    float: none;
    width: 100%;
    padding: 0 16px;
    box-sizing: border-box;
  }
}

#page-anatanomachi-default .about {
  margin-bottom: 80px;
}

@media (max-width:980px) {
  #page-anatanomachi-default .news {
    margin-bottom: 80px;
  }
}

#page-anatanomachi-default .about p {
  margin: 0 0 .5em;
  font-size: 13px;
}

#page-anatanomachi-default .about h4 {
  margin-top: 16px;
}

#page-anatanomachi-default .about dd,#page-anatanomachi-default .about dt {
  margin: 0;
  padding: 0;
  line-height: 24px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .about dd,  #page-anatanomachi-default .about dt {
    font-size: 14px;
  }
}

#page-anatanomachi-default .about dt {
  position: absolute;
  padding-right: 2px;
  background: #f2f2f2;
  z-index: 3;
}

#page-anatanomachi-default .about dd {
  color: #ff1744;
  font-weight: 600;
  position: relative;
  padding-left: 128px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .about dd {
    padding-left: 88px;
  }
}

#page-anatanomachi-default .about dd::after {
  content: "";
  border-bottom: 1px solid #ccc;
  width: 126px;
  height: 1px;
  position: absolute;
  left: 0;
  bottom: 6px;
  z-index: 2;
}

@media (max-width:600px) {
  #page-anatanomachi-default .about dd::after {
    width: 86px;
  }
}

#page-anatanomachi-default .news ul {
  margin: 0;
  padding: 0;
}

#page-anatanomachi-default .news li {
  position: relative;
  margin-bottom: 8px;
  padding-left: 136px;
}

@media (max-width:600px) {
  #page-anatanomachi-default .news li {
    padding-left: 96px;
  }
}

#page-anatanomachi-default .news li a {
  display: block;
}

#page-anatanomachi-default .news li a:active span,#page-anatanomachi-default .news li a:hover span {
  color: #ff1744;
}

#page-anatanomachi-default .news li a:active p,#page-anatanomachi-default .news li a:hover p {
  border-color: #ff1744;
}

#page-anatanomachi-default .news li span {
  display: block;
  color: #999;
  font-size: 12px;
  position: absolute;
  left: 0;
  padding-top: 3px;
}

#page-anatanomachi-default .news li p {
  display: inline;
  border-bottom: 1px solid #000;
}

#page-features.isPC #container header {
  line-height: 1.4;
}

#page-features.isPC #container header h1,#page-features.isPC #container header p {
  margin: 0;
}

#page-features.isPC #container header h1 {
  font-size: 14px;
}

#page-features.isPC #container header p {
  color: #666;
  font-size: .95em;
}

#page-features.isPC #container ul {
  padding: 0;
  margin: 30px 0 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

#page-features.isPC #container ul li {
  list-style-type: none;
}

#page-features.isPC #container li {
  width: calc(33.333333% - 20px);
  margin: 0 0 30px 30px;
}

#page-features.isPC #container li:nth-child(3n+3) {
  margin-left: 0;
}

#page-features.isPC #container li:nth-child(1),#page-features.isPC #container li:nth-child(2) {
  width: calc(50% - 15px);
}

#page-features.isPC #container li:nth-child(1) .features-image,#page-features.isPC #container li:nth-child(2) .features-image {
  height: 180px;
  background-size: auto 180px;
}

#page-features.isPC #container li:nth-child(1) {
  margin-left: 0;
}

#page-features.isPC #container li a {
  color: #222;
  text-decoration: none;
}

#page-features.isPC #container li a:focus h2,#page-features.isPC #container li a:hover h2 {
  color: #0990cc;
  text-decoration: underline;
}

#page-features.isPC #container li h2,#page-features.isPC #container li p,#page-features.isPC #container li ul {
  line-height: 1.5;
}

#page-features.isPC #container li h2 {
  font-size: 18px;
  line-height: 1.3;
  margin: 0 0 4px;
}

#page-features.isPC #container li p {
  font-size: 11.5px;
  color: #666;
  margin: 0;
}

#page-features.isPC #container li p:after,#page-features.isPC #container li p:before {
  content: '';
  display: table;
}

#page-features.isPC #container li p:after {
  clear: both;
}

#page-features.isPC #container li p span,#page-features.isPC #container li p time {
  display: block;
  padding: 0 13px 0 0;
  position: relative;
  float: left;
  color: #888;
}

#page-features.isPC #container li p span:after,#page-features.isPC #container li p time:after {
  content: '';
  display: inline-block;
  position: absolute;
  right: 5px;
  top: 50%;
  margin: -2px 0 0;
  width: 4px;
  height: 4px;
  background: #ccc;
  border-radius: 50%;
}

#page-features.isPC #container li p span:last-child:after,#page-features.isPC #container li p time:last-child:after {
  display: none;
  padding: 0;
}

#page-features.isPC .features-image {
  width: 100%;
  height: 116px;
  background-size: auto 116px;
  background-position: center center;
  margin: 0 0 12px;
}

#page-features.isTouch #container header {
  margin: 24px 16px 0;
}

#page-features.isTouch #container header h1 {
  font-size: 11px;
  margin: 0;
}

#page-features.isTouch #container ul {
  padding: 0;
  margin: 16px 16px 0;
}

#page-features.isTouch #container ul li {
  list-style-type: none;
}

#page-features.isTouch #container a {
  color: #222;
  text-decoration: none;
  padding: 0 0 24px;
  display: block;
}

#page-features.isTouch #container a:focus h4,#page-features.isTouch #container a:hover h4 {
  color: #0990cc;
  text-decoration: underline;
}

#page-features.isTouch #container h2,#page-features.isTouch #container p,#page-features.isTouch #container ul {
  line-height: 1.5;
}

#page-features.isTouch #container h2 {
  font-size: 13px;
  line-height: 1.3;
  margin: 0 0 4px;
}

#page-features.isTouch #container p {
  font-size: 11px;
  color: #666;
  margin: 0;
}

#page-features.isTouch #container p:after,#page-features.isTouch #container p:before {
  content: '';
  display: table;
}

#page-features.isTouch #container p:after {
  clear: both;
}

#page-features.isTouch #container p span,#page-features.isTouch #container p time {
  display: block;
  padding: 0 13px 0 0;
  position: relative;
  float: left;
  color: #888;
}

#page-features.isTouch #container p span:after,#page-features.isTouch #container p time:after {
  content: '';
  display: inline-block;
  position: absolute;
  right: 5px;
  top: 50%;
  margin: -2px 0 0;
  width: 4px;
  height: 4px;
  background: #ccc;
  border-radius: 50%;
}

#page-features.isTouch #container p span:last-child:after,#page-features.isTouch #container p time:last-child:after {
  display: none;
  padding: 0;
}

#page-features.isTouch .features-image {
  width: 100%;
  background-size: cover;
  background-position: center center;
  margin: 0 0 12px;
}

#page-features.isTouch .features-image:before {
  content: '';
  display: block;
  padding-top: 32.876712%;
}

#page-guide.isPC #summary {
  width: 1145px;
  margin: 60px auto 0;
  padding: 0 30px;
  box-sizing: border-box;
}

#page-guide.isPC #summary h2 {
  text-align: center;
  font-size: 30px;
  margin: 0 0 30px;
  font-weight: 400;
  letter-spacing: 4px;
}

#page-guide.isPC #summary ul {
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  margin: 0 100px;
}

#page-guide.isPC #summary ul li {
  list-style-type: none;
}

#page-guide.isPC #summary li {
  width: calc(33.333333% - 20px);
  margin: 0 0 15px 30px;
  box-sizing: border-box;
  position: relative;
}

#page-guide.isPC #summary li:first-child {
  margin-left: 0;
}

#page-guide.isPC #summary li h3,#page-guide.isPC #summary li p {
  line-height: 1.6;
  font-size: 15px;
}

#page-guide.isPC #summary li h3 {
  text-align: center;
  margin: 0 0 .5em;
  letter-spacing: 1px;
}

#page-guide.isPC #summary li p {
  margin: 0;
  color: #444;
}

#page-guide.isPC #summary .summary-image {
  width: 200px;
  height: 200px;
  margin: 0 auto 15px;
}

#page-guide.isPC #summary .summary-image img {
  max-width: 200px;
  vertical-align: bottom;
}

#page-guide.isPC #express,#page-guide.isPC #read,#page-guide.isPC #write {
  overflow: hidden;
  min-height: 1060px;
}

#page-guide.isPC #express .section-inner,#page-guide.isPC #read .section-inner,#page-guide.isPC #write .section-inner {
  width: 1145px;
  margin: 100px auto 20px;
  padding: 0 30px 30px 165px;
  box-sizing: border-box;
  position: relative;
}

#page-guide.isPC #express .section-inner h2,#page-guide.isPC #read .section-inner h2,#page-guide.isPC #write .section-inner h2 {
  position: absolute;
  top: 0;
  left: 30px;
  -webkit-writing-mode: vertical-rl;
  -ms-writing-mode: tb-rl;
  writing-mode: vertical-rl;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,serif;
  font-weight: 400;
  font-size: 28px;
  letter-spacing: 30px;
  line-height: 1;
  margin: 0;
}

#page-guide.isPC #express .section-inner h2 span,#page-guide.isPC #read .section-inner h2 span,#page-guide.isPC #write .section-inner h2 span {
  color: #bbb;
}

#page-guide.isPC #express .section-inner h2 i,#page-guide.isPC #read .section-inner h2 i,#page-guide.isPC #write .section-inner h2 i {
  font-style: normal;
  font-size: 18px;
  color: #bbb;
}

#page-guide.isPC #express .section-inner h3,#page-guide.isPC #read .section-inner h3,#page-guide.isPC #write .section-inner h3 {
  font-size: 30px;
  line-height: 1.5;
  position: relative;
  margin: 0;
  letter-spacing: 1px;
}

#page-guide.isPC #express .section-inner h3:before,#page-guide.isPC #read .section-inner h3:before,#page-guide.isPC #write .section-inner h3:before {
  content: '';
  display: block;
  width: 400vw;
  height: 200vh;
  position: absolute;
  top: calc(100% + 15px);
  left: -200vw;
  z-index: -100;
}

#page-guide.isPC #express .section-inner h3>span,#page-guide.isPC #read .section-inner h3>span,#page-guide.isPC #write .section-inner h3>span {
  display: block;
}

#page-guide.isPC #express .section-inner .section-points,#page-guide.isPC #read .section-inner .section-points,#page-guide.isPC #write .section-inner .section-points {
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  width: 465px;
}

#page-guide.isPC #express .section-inner .section-points li,#page-guide.isPC #read .section-inner .section-points li,#page-guide.isPC #write .section-inner .section-points li {
  list-style-type: none;
}

#page-guide.isPC #express .section-inner .section-points li,#page-guide.isPC #read .section-inner .section-points li,#page-guide.isPC #write .section-inner .section-points li {
  width: calc(50% - 3px);
  margin: 0 0 6px 6px;
  padding: 15px 15px 20px 17px;
  box-sizing: border-box;
  background: #fff;
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-guide.isPC #express .section-inner .section-points li:nth-child(2n+1),#page-guide.isPC #read .section-inner .section-points li:nth-child(2n+1),#page-guide.isPC #write .section-inner .section-points li:nth-child(2n+1) {
  margin-left: 0;
}

#page-guide.isPC #express .section-inner .section-points li div,#page-guide.isPC #read .section-inner .section-points li div,#page-guide.isPC #write .section-inner .section-points li div {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  margin: 0 0 0 13px;
}

#page-guide.isPC #express .section-inner .section-points h4,#page-guide.isPC #express .section-inner .section-points p,#page-guide.isPC #read .section-inner .section-points h4,#page-guide.isPC #read .section-inner .section-points p,#page-guide.isPC #write .section-inner .section-points h4,#page-guide.isPC #write .section-inner .section-points p {
  margin: 0;
}

#page-guide.isPC #express .section-inner .section-points h4,#page-guide.isPC #read .section-inner .section-points h4,#page-guide.isPC #write .section-inner .section-points h4 {
  line-height: 1.3;
  margin: 0 0 12px;
  letter-spacing: 1px;
  font-size: 15px;
}

#page-guide.isPC #express .section-inner .section-points .section-points-number,#page-guide.isPC #read .section-inner .section-points .section-points-number,#page-guide.isPC #write .section-inner .section-points .section-points-number {
  color: #4baae0;
  line-height: 1;
  font-weight: 700;
  margin: 3px 0 0;
}

#page-guide.isPC #express .section-inner .section-points .section-points-number span,#page-guide.isPC #read .section-inner .section-points .section-points-number span,#page-guide.isPC #write .section-inner .section-points .section-points-number span {
  display: block;
}

#page-guide.isPC #express .section-inner .section-points .section-points-number-label,#page-guide.isPC #read .section-inner .section-points .section-points-number-label,#page-guide.isPC #write .section-inner .section-points .section-points-number-label {
  font-size: 10px;
  margin: 0 0 2px;
}

#page-guide.isPC #express .section-inner .section-points .section-points-number-text,#page-guide.isPC #read .section-inner .section-points .section-points-number-text,#page-guide.isPC #write .section-inner .section-points .section-points-number-text {
  font-size: 24px;
  letter-spacing: 2px;
}

#page-guide.isPC #express .section-inner .section-points .section-points-text,#page-guide.isPC #read .section-inner .section-points .section-points-text,#page-guide.isPC #write .section-inner .section-points .section-points-text {
  font-size: 13px;
  line-height: 1.5;
}

#page-guide.isPC #express-image,#page-guide.isPC #read-image,#page-guide.isPC #write-image {
  position: absolute;
  top: 45px;
  left: 60%;
  font-size: 11px;
  color: #999;
}

#page-guide.isPC #express-image img,#page-guide.isPC #read-image img,#page-guide.isPC #write-image img {
  vertical-align: bottom;
}

#page-guide.isPC .image-info {
  position: absolute;
  width: 60px;
  height: 60px;
  display: block;
  cursor: help;
  margin: -20px 0 0 -20px;
}

#page-guide.isPC .image-info:after {
  font-size: 16px!important;
  padding: 9px 10px 7px!important;
}

#page-guide.isPC .image-info-point {
  display: block;
  width: 20px;
  height: 20px;
  background: #f23e48;
  border-radius: 10px;
  position: absolute;
  top: 20px;
  left: 20px;
}

@-webkit-keyframes point-scaleout {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }

  100%, 75% {
    -webkit-transform: scale(2.5);
    transform: scale(2.5);
    opacity: 0;
  }
}

@keyframes point-scaleout {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }

  100%, 75% {
    -webkit-transform: scale(2.5);
    transform: scale(2.5);
    opacity: 0;
  }
}

#page-guide.isPC #write h3 {
  color: #4baae0;
}

#page-guide.isPC #write h3:before {
  background: #e5f3f5;
}

#page-guide.isPC #write-image img {
  max-width: 1084px;
  box-shadow: 10px 30px 75px rgba(0,0,0,.2);
}

#page-guide.isPC #write-image-info-1 {
  top: 150px;
  left: 117px;
}

#page-guide.isPC #write-image-info-2 {
  top: 540px;
  left: 290px;
}

#page-guide.isPC #read .section-inner {
  padding: 0 30px 60px 500px;
}

#page-guide.isPC #read .section-points .section-points-number {
  color: #c3b370!important;
}

#page-guide.isPC #read h2 {
  left: auto!important;
  right: 30px;
}

#page-guide.isPC #read h3 {
  color: #c3b370;
}

#page-guide.isPC #read h3:before {
  background: #f5f3e5;
}

#page-guide.isPC #read-image {
  top: 45px;
  left: 60px;
}

#page-guide.isPC #read-image-info-1 {
  top: 107px;
  left: 296px;
}

#page-guide.isPC #express .section-points .section-points-number {
  color: #c370a6!important;
}

#page-guide.isPC #express h3 {
  color: #c370a6;
}

#page-guide.isPC #express h3:before {
  background: #fcf0f9;
}

#page-guide.isPC #express-image img {
  max-height: 800px;
  border-radius: 41px;
  box-shadow: 10px 30px 75px rgba(0,0,0,.2);
}

#page-guide.isPC #express-image-info-1 {
  top: 500px;
  left: 240px;
}

#page-guide.isPC #express-image-info-2 {
  top: 626px;
  left: 180px;
}

#page-guide.isPC #signup {
  margin-top: 0;
}

#page-guide.isTouch #summary {
  margin: 24px auto 0;
  padding: 0 16px;
  box-sizing: border-box;
}

#page-guide.isTouch #summary h2 {
  font-size: 20px;
  margin: 0 0 24px;
  text-align: center;
}

#page-guide.isTouch #summary ul {
  padding: 0;
}

#page-guide.isTouch #summary ul li {
  list-style-type: none;
}

#page-guide.isTouch #summary li {
  margin: 0 0 24px;
  box-sizing: border-box;
  position: relative;
  padding: 0 0 0 116px;
}

#page-guide.isTouch #summary li h3 {
  font-size: 15px;
  margin: 0 0 8px;
  line-height: 1.3;
}

#page-guide.isTouch #summary li h3 br {
  display: none;
}

#page-guide.isTouch #summary li p {
  margin: 0;
  color: #444;
  line-height: 1.6;
}

#page-guide.isTouch #summary .summary-image {
  width: 100px;
  height: 100px;
  position: absolute;
  top: 0;
  left: 0;
}

#page-guide.isTouch #summary .summary-image img {
  max-width: 100px;
  vertical-align: bottom;
}

#page-guide.isTouch #express,#page-guide.isTouch #read,#page-guide.isTouch #write {
  margin: -80px auto 24px;
  padding: 80px 0 0;
}

#page-guide.isTouch #express .section-inner,#page-guide.isTouch #read .section-inner,#page-guide.isTouch #write .section-inner {
  padding: 24px 0;
  margin: 164px 0 0;
  box-sizing: border-box;
}

#page-guide.isTouch #express .section-inner header,#page-guide.isTouch #read .section-inner header,#page-guide.isTouch #write .section-inner header {
  position: relative;
  padding: 0 16px;
}

#page-guide.isTouch #express .section-inner h2,#page-guide.isTouch #read .section-inner h2,#page-guide.isTouch #write .section-inner h2 {
  text-align: center;
  font-family: dcsymbols,'游明朝',YuMincho,'ヒラギノ明朝 Pr6N','Hiragino Mincho Pr6N','ヒラギノ明朝 ProN','Hiragino Mincho ProN','ヒラギノ明朝 StdN','Hiragino Mincho StdN',HiraMinProN-W3,serif;
  font-weight: 400;
  font-size: 11px;
  letter-spacing: 12px;
  line-height: 1;
  margin: 30px 0 10px;
}

#page-guide.isTouch #express .section-inner h2 span,#page-guide.isTouch #read .section-inner h2 span,#page-guide.isTouch #write .section-inner h2 span {
  color: #bbb;
}

#page-guide.isTouch #express .section-inner h2 i,#page-guide.isTouch #read .section-inner h2 i,#page-guide.isTouch #write .section-inner h2 i {
  font-style: normal;
  font-size: 8px;
  color: #bbb;
}

#page-guide.isTouch #express .section-inner h3,#page-guide.isTouch #read .section-inner h3,#page-guide.isTouch #write .section-inner h3 {
  font-size: 22px;
  line-height: 1.3;
  margin: 0;
  text-align: center;
}

#page-guide.isTouch #express .section-inner h3 span,#page-guide.isTouch #read .section-inner h3 span,#page-guide.isTouch #write .section-inner h3 span {
  display: inline-block;
}

#page-guide.isTouch #express .section-inner .section-points,#page-guide.isTouch #read .section-inner .section-points,#page-guide.isTouch #write .section-inner .section-points {
  padding: 0;
  margin: 0 16px;
}

#page-guide.isTouch #express .section-inner .section-points li,#page-guide.isTouch #read .section-inner .section-points li,#page-guide.isTouch #write .section-inner .section-points li {
  list-style-type: none;
}

#page-guide.isTouch #express .section-inner .section-points li,#page-guide.isTouch #read .section-inner .section-points li,#page-guide.isTouch #write .section-inner .section-points li {
  margin: 0 0 6px;
  padding: 15px 15px 20px 17px;
  box-sizing: border-box;
  background: #fff;
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-guide.isTouch #express .section-inner .section-points li div,#page-guide.isTouch #read .section-inner .section-points li div,#page-guide.isTouch #write .section-inner .section-points li div {
  margin: 0 0 0 13px;
}

#page-guide.isTouch #express .section-inner .section-points h4,#page-guide.isTouch #express .section-inner .section-points p,#page-guide.isTouch #read .section-inner .section-points h4,#page-guide.isTouch #read .section-inner .section-points p,#page-guide.isTouch #write .section-inner .section-points h4,#page-guide.isTouch #write .section-inner .section-points p {
  margin: 0;
}

#page-guide.isTouch #express .section-inner .section-points h4,#page-guide.isTouch #read .section-inner .section-points h4,#page-guide.isTouch #write .section-inner .section-points h4 {
  line-height: 1.3;
  margin: 0 0 8px;
  font-size: 15px;
}

#page-guide.isTouch #express .section-inner .section-points .section-points-number,#page-guide.isTouch #read .section-inner .section-points .section-points-number,#page-guide.isTouch #write .section-inner .section-points .section-points-number {
  color: #4baae0;
  line-height: 1;
  font-weight: 700;
  margin: 3px 0 0;
}

#page-guide.isTouch #express .section-inner .section-points .section-points-number span,#page-guide.isTouch #read .section-inner .section-points .section-points-number span,#page-guide.isTouch #write .section-inner .section-points .section-points-number span {
  display: block;
}

#page-guide.isTouch #express .section-inner .section-points .section-points-number-label,#page-guide.isTouch #read .section-inner .section-points .section-points-number-label,#page-guide.isTouch #write .section-inner .section-points .section-points-number-label {
  font-size: 10px;
  margin: 0 0 2px;
}

#page-guide.isTouch #express .section-inner .section-points .section-points-number-text,#page-guide.isTouch #read .section-inner .section-points .section-points-number-text,#page-guide.isTouch #write .section-inner .section-points .section-points-number-text {
  font-size: 24px;
  letter-spacing: 2px;
}

#page-guide.isTouch #express .section-inner .section-points .section-points-text,#page-guide.isTouch #read .section-inner .section-points .section-points-text,#page-guide.isTouch #write .section-inner .section-points .section-points-text {
  font-size: 12px;
  line-height: 1.5;
}

#page-guide.isTouch #express-image,#page-guide.isTouch #read-image,#page-guide.isTouch #write-image {
  font-size: 11px;
  color: #999;
  margin: -140px 16px 0;
  text-align: center;
}

#page-guide.isTouch #express-image img,#page-guide.isTouch #read-image img,#page-guide.isTouch #write-image img {
  vertical-align: bottom;
}

#page-guide.isTouch .image-info {
  display: none;
}

#page-guide.isTouch #write .section-inner {
  background: #e5f3f5;
}

#page-guide.isTouch #write h3 {
  color: #4baae0;
}

#page-guide.isTouch #write-image img {
  max-width: 100%;
  border: 1px solid #ddd;
}

#page-guide.isTouch #read .section-inner {
  background: #f5f3e5;
}

#page-guide.isTouch #read h3 {
  color: #c3b370;
}

#page-guide.isTouch #read .section-points-number {
  color: #c3b370!important;
}

#page-guide.isTouch #express .section-inner {
  background: #fcf0f9;
}

#page-guide.isTouch #express h3 {
  color: #c370a6;
}

#page-guide.isTouch #express .section-points-number {
  color: #c370a6!important;
}

#page-guide.isTouch #express-image img {
  max-height: 400px;
  border: 1px solid #ddd;
  border-radius: 20px;
}

#page-guide.isTouch #signup {
  text-align: center;
  margin: 24px auto 0;
}

#page-guide.isTouch #signup .ui-button-blue,#page-guide.isTouch #signup .ui-button-default {
  box-sizing: border-box;
  padding: 1em;
  display: block;
  font-size: 1.1em;
}

#page-guide-write.isPC .section {
  width: 1125px;
  margin: 60px auto;
  padding: 0 30px;
}

#page-guide-write.isPC .section header h2 {
  line-height: 1.3;
  margin: 0;
  font-size: 30px;
  letter-spacing: 4px;
  font-weight: 400;
}

#page-guide-write.isPC .section header p {
  margin: 8px 0 0;
  font-size: 16px;
  line-height: 1.6;
  color: #666;
  width: calc(45% - 15px);
}

#page-guide-write.isPC #write-functions {
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  margin: 30px 0;
}

#page-guide-write.isPC #write-functions li {
  list-style-type: none;
}

#page-guide-write.isPC #write-functions li {
  width: calc(25% - 22.5px);
  margin: 0 0 30px 30px;
}

#page-guide-write.isPC #write-functions li:nth-child(4n+1) {
  margin-left: 0;
}

#page-guide-write.isPC #write-functions div {
  line-height: 1.6;
}

#page-guide-write.isPC #write-functions div h3,#page-guide-write.isPC #write-functions div p {
  display: inline;
  margin: 0;
  line-height: 1.6;
  font-size: 14px;
}

#page-guide-write.isPC #write-functions div h3 {
  margin: 0 1em 0 0;
}

#page-guide-write.isPC #write-functions div p {
  color: #444;
}

#page-guide-write.isPC #submit {
  background: #f2f1f0;
  margin: 0 auto;
  padding: 30px 30px;
  min-width: 1185px;
}

#page-guide-write.isPC #submit-contents {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  margin: 30px 0 0;
}

#page-guide-write.isPC #submit-contents>div {
  width: 50%;
}

#page-guide-write.isPC #submit-contests ul {
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  margin: 16px 0 0;
}

#page-guide-write.isPC #submit-contests ul li {
  list-style-type: none;
}

#page-guide-write.isPC #submit-contests li {
  width: calc(50% - 5px);
  margin: 0 10px 0 0;
}

#page-guide-write.isPC #submit-contests li:last-child {
  margin: 0;
}

#page-guide-write.isPC #submit-contests img {
  vertical-align: bottom;
}

#page-guide-write.isPC #submit-works {
  width: calc(50% - 60px)!important;
  margin: 0 0 0 60px;
}

#page-guide-write.isPC #submit-works header h3 {
  font-size: 18px;
  margin: 0 0 8px;
}

#page-guide-write.isPC #submit-works header p {
  margin: 0;
  font-size: 15px;
  width: 75%;
}

#page-guide-write.isPC #submit-works ul {
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  margin: 30px 0 0;
}

#page-guide-write.isPC #submit-works ul li {
  list-style-type: none;
}

#page-guide-write.isPC #submit-works li {
  width: 33.333333%;
  margin: 0 0 60px;
}

#page-guide-write.isPC #submit-works img {
  max-width: 70%;
  border: 1px solid #222;
  box-sizing: border-box;
  vertical-align: bottom;
}

#page-guide-write.isTouch .section {
  margin: 24px auto;
  max-width: 640px;
}

#page-guide-write.isTouch .section header {
  text-align: center;
}

#page-guide-write.isTouch .section header h2 {
  line-height: 1.3;
  margin: 0;
  font-size: 18px;
  letter-spacing: 4px;
  font-weight: 400;
}

#page-guide-write.isTouch .section header p {
  margin: 8px auto 0;
  font-size: 11px;
  line-height: 1.6;
  color: #666;
  max-width: 640px;
  padding: 0 32px;
}

#page-guide-write.isTouch #write-functions {
  padding: 0;
  margin: 24px 0 24px 16px;
}

#page-guide-write.isTouch #write-functions li {
  list-style-type: none;
}

#page-guide-write.isTouch #write-functions li {
  padding: 14px 16px 14px 0;
  border-top: 1px solid #ddd;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-guide-write.isTouch #write-functions div {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  line-height: 1.6;
}

#page-guide-write.isTouch #write-functions div h3,#page-guide-write.isTouch #write-functions div p {
  margin: 0;
}

#page-guide-write.isTouch #write-functions div h3 {
  color: #222;
  font-size: 13px;
}

#page-guide-write.isTouch #write-functions div p {
  font-size: 12px;
  color: #444;
}

#page-guide-write.isTouch #write-functions div div p {
  margin: 8px 0;
}

#page-guide-write.isTouch #submit {
  background: #f2f1f0;
  margin: 0 auto;
  padding: 24px 0;
}

#page-guide-write.isTouch #submit-contents {
  margin: 24px 0;
}

#page-guide-write.isTouch #submit-contests ul {
  padding: 0;
  margin: 16px 0 0;
}

#page-guide-write.isTouch #submit-contests ul li {
  list-style-type: none;
}

#page-guide-write.isTouch #submit-contests li {
  margin: 0 0 8px;
}

#page-guide-write.isTouch #submit-contests img {
  vertical-align: bottom;
}

#page-guide-write.isTouch #submit-works {
  background: #fff;
  padding: 24px 16px;
  margin: 24px 16px 0;
  border: 1px solid #ddd;
}

#page-guide-write.isTouch #submit-works header h3 {
  font-size: 18px;
  margin: 0 0 8px;
}

#page-guide-write.isTouch #submit-works header p {
  margin: 0 auto;
  font-size: 12px;
  width: 75%;
}

#page-guide-write.isTouch #submit-works ul {
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  -webkit-box-align: end;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
  margin: 24px 0 0;
}

#page-guide-write.isTouch #submit-works ul li {
  list-style-type: none;
}

#page-guide-write.isTouch #submit-works li {
  width: 33.333333%;
  margin: 0 0 30px;
  text-align: center;
}

#page-guide-write.isTouch #submit-works li:nth-child(3n+1) {
  position: relative;
}

#page-guide-write.isTouch #submit-works li:nth-child(3n+1):before {
  content: '';
  display: block;
  position: absolute;
  bottom: -7px;
  left: 0;
  width: 300%;
  height: 0;
  border-top: 5px solid #ddd;
}

#page-guide-write.isTouch #submit-works img {
  max-width: 70%;
  border: 1px solid #222;
  box-sizing: border-box;
  vertical-align: bottom;
}

#page-guide-read.isPC .section {
  width: 1125px;
  margin: 60px auto;
  padding: 0 30px;
}

#page-guide-read.isPC .section header h2 {
  line-height: 1.3;
  margin: 0;
  font-size: 30px;
  letter-spacing: 4px;
  font-weight: 400;
}

#page-guide-read.isPC .section header p {
  margin: 8px 0 0;
  font-size: 16px;
  line-height: 1.6;
  color: #666;
  width: calc(45% - 15px);
}

#page-guide-read.isPC #read-functions {
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  margin: 30px 0;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-guide-read.isPC #read-functions li {
  list-style-type: none;
}

#page-guide-read.isPC #read-functions li {
  width: 200px;
  margin: 0 0 30px;
  position: relative;
}

#page-guide-read.isPC #read-functions div {
  line-height: 1.6;
}

#page-guide-read.isPC #read-functions div h3,#page-guide-read.isPC #read-functions div p {
  display: inline;
  margin: 0;
  line-height: 1.6;
  font-size: 14px;
}

#page-guide-read.isPC #read-functions div h3 {
  margin: 0 1em 0 0;
}

#page-guide-read.isPC #read-functions div p {
  color: #444;
}

#page-guide-read.isPC #read-history {
  position: relative;
  z-index: 10;
}

#page-guide-read.isPC #writing-direction-vertical {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  margin: 30px auto 80px;
}

#page-guide-read.isPC #writing-direction-vertical header {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-guide-read.isPC #writing-direction-vertical header p {
  width: 100%;
}

#page-guide-read.isPC #writing-direction-vertical-image-container {
  margin: 0 0 0 60px;
  width: 732px;
}

#page-guide-read.isPC #writing-direction-vertical-image {
  margin: 0;
}

#page-guide-read.isPC #writing-direction-vertical-image img {
  max-width: 730px;
  max-height: 500px;
  border: 1px solid #ddd;
  vertical-align: bottom;
}

#page-guide-read.isPC #writing-direction-vertical-display-setting-image {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  font-size: 13px;
  margin: -4em 3em 0 auto;
  width: 380px;
}

#page-guide-read.isPC #writing-direction-vertical-display-setting-image p:first-child {
  margin: 0 16px 0 0;
}

#page-guide-read.isPC #writing-direction-vertical-display-setting-image img {
  max-width: 180px;
  border-radius: 90px;
  border: 1px solid #ddd;
  box-sizing: border-box;
}

#page-guide-read.isPC #find {
  background: #f2f1f0;
  margin: 0 auto;
  padding: 30px 30px;
  min-width: 1185px;
}

#page-guide-read.isPC #official-list {
  margin: 30px 0 0!important;
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  margin: 1px 0 0 1px;
  border-top: 1px solid #ddd;
}

#page-guide-read.isPC #official-list::before {
  content: '';
  display: block;
  border-bottom: 1px solid #ddd;
  position: absolute;
  left: 0;
  bottom: 0;
  width: 100%;
  height: 0;
}

#page-guide-read.isTouch .section {
  margin: 24px auto;
  max-width: 640px;
}

#page-guide-read.isTouch .section header {
  text-align: center;
}

#page-guide-read.isTouch .section header h2 {
  line-height: 1.3;
  margin: 0;
  font-size: 18px;
  letter-spacing: 4px;
  font-weight: 400;
}

#page-guide-read.isTouch .section header p {
  margin: 8px auto 0;
  font-size: 11px;
  line-height: 1.6;
  color: #666;
  max-width: 640px;
  padding: 0 32px;
}

#page-guide-read.isTouch #read-functions {
  padding: 0;
  margin: 24px 0;
}

#page-guide-read.isTouch #read-functions li {
  list-style-type: none;
}

#page-guide-read.isTouch #read-functions li {
  margin: 0 0 0 16px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  font-size: 13px;
  border-top: 1px solid #ddd;
  padding: 14px 16px 14px 0;
}

#page-guide-read.isTouch #read-functions li:last-child {
  border-bottom: 1px solid #ddd;
}

#page-guide-read.isTouch #read-functions div {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
  line-height: 1.6;
}

#page-guide-read.isTouch #read-functions div h3,#page-guide-read.isTouch #read-functions div p {
  margin: 0;
}

#page-guide-read.isTouch #read-functions div h3 {
  color: #222;
  font-size: 13px;
}

#page-guide-read.isTouch #read-functions div p {
  font-size: 12px;
  color: #444;
}

#page-guide-read.isTouch #read-functions div div p {
  margin: 8px 0;
}

#page-guide-read.isTouch #read-history {
  position: relative;
  z-index: 10;
}

#page-guide-read.isTouch #writing-direction-vertical {
  margin: 42px 0 24px;
}

#page-guide-read.isTouch #writing-direction-vertical header p {
  color: #222;
  font-size: 12px;
  text-align: left;
}

#page-guide-read.isTouch #writing-direction-vertical-image {
  margin: 24px 16px 0;
}

#page-guide-read.isTouch #writing-direction-vertical-image img {
  max-width: 100%;
  border: 1px solid #ddd;
  vertical-align: bottom;
}

#page-guide-read.isTouch #writing-direction-vertical-display-setting-image {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  font-size: 11px;
  margin: 1em auto 0;
  padding: 0 28px 0 32px;
  max-width: 400px;
}

#page-guide-read.isTouch #writing-direction-vertical-display-setting-image p:first-child {
  margin: 0 16px 0 0;
}

#page-guide-read.isTouch #writing-direction-vertical-display-setting-image img {
  max-width: 130px;
  border-radius: 65px;
  border: 1px solid #ddd;
  box-sizing: border-box;
}

#page-guide-read.isTouch #find {
  background: #f2f1f0;
  margin: 0 auto;
  padding: 24px 0;
}

#page-guide-read.isTouch #find ul {
  padding: 0;
  margin: 24px 0;
}

#page-guide-read.isTouch #find ul li {
  list-style-type: none;
}

#page-guide-read.isTouch #find ul li {
  margin: 0 0 24px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  padding: 0 16px;
}

#page-guide-read.isTouch #find ul h3 {
  margin: 0;
  font-size: 13px;
  line-height: 1.3;
}

#page-guide-read.isTouch #find ul p {
  margin: 8px 0 0;
  font-size: 12px;
  line-height: 1.6;
}

#page-guide-read.isTouch #find ul div {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-guide-read.isTouch #find .find-image {
  width: 44px;
  margin: 0 16px 0 0;
}

#page-guide-read.isTouch #find .find-image img {
  vertical-align: bottom;
  width: 44px;
  height: 44px;
}

#page-guide-read.isTouch #official-list {
  margin: 24px 0 24px 16px;
  border-top: 1px solid #ddd;
}

@-webkit-keyframes slide {
  0% {
    opacity: 0;
  }

  10% {
    opacity: 1;
  }

  33.333333% {
    opacity: 1;
  }

  44.333333% {
    opacity: 0;
  }
}

@keyframes slide {
  0% {
    opacity: 0;
  }

  10% {
    opacity: 1;
  }

  33.333333% {
    opacity: 1;
  }

  44.333333% {
    opacity: 0;
  }
}

@-webkit-keyframes feature2-animation {
  from {
    -webkit-transform: translateX(0);
    transform: translateX(0);
  }

  to {
    -webkit-transform: translateX(-100%);
    transform: translateX(-100%);
  }
}

@keyframes feature2-animation {
  from {
    -webkit-transform: translateX(0);
    transform: translateX(0);
  }

  to {
    -webkit-transform: translateX(-100%);
    transform: translateX(-100%);
  }
}

#page-guide-app #pager a {
  border-top-color: #fff;
}

#page-guide-app.isPC #container {
  overflow: hidden;
  min-width: 1185px;
}

@-webkit-keyframes novelimage {
  0% {
    opacity: 0;
    top: -100;
  }

  30% {
    opacity: 1;
    top: -280px;
  }

  100% {
    opacity: 1;
    top: -253px;
  }
}

@keyframes novelimage {
  0% {
    opacity: 0;
    top: -100;
  }

  30% {
    opacity: 1;
    top: -280px;
  }

  100% {
    opacity: 1;
    top: -253px;
  }
}

#page-guide-app.isTouch #container {
  overflow: hidden;
  max-width: 100%!important;
}

#page-guide-more.isPC .section {
  width: 1125px;
  margin: 0 auto;
  padding: 45px 30px 15px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  border-bottom: 1px solid #ddd;
}

#page-guide-more.isPC .section header {
  width: 135px;
}

#page-guide-more.isPC .section header h2 {
  margin: 0;
  font-size: 13px;
  letter-spacing: 4px;
  font-weight: 400;
  height: 80px;
  line-height: 80px;
  vertical-align: middle;
}

#page-guide-more.isPC .section header h2 span {
  display: inline-block;
  line-height: 1.3;
}

#page-guide-more.isPC .section ul {
  width: calc(100% - 165px);
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  margin: 0;
}

#page-guide-more.isPC .section ul li {
  list-style-type: none;
}

#page-guide-more.isPC .section ul li {
  width: calc(50% - 15px);
  margin: 0 0 30px 30px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

#page-guide-more.isPC .section ul li:nth-child(2n+1) {
  margin-left: 0;
}

#page-guide-more.isPC .section ul .section-image {
  margin: 0 24px 0 0!important;
}

#page-guide-more.isPC .section ul .section-image img {
  width: 80px;
  height: 80px;
  vertical-align: bottom;
}

#page-guide-more.isPC .section ul div {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-guide-more.isPC .section ul h3 {
  margin: 0;
  font-size: 18px;
  line-height: 1.3;
}

#page-guide-more.isPC .section ul p {
  margin: 8px 0 0;
  font-size: 14px;
  line-height: 1.6;
}

#page-guide-more.isTouch .section {
  margin: 24px auto;
}

#page-guide-more.isTouch .section header h2 {
  margin: 0 0 16px;
  font-size: 11px;
  padding: 0 16px 8px;
  border-bottom: 1px solid #ddd;
}

#page-guide-more.isTouch .section ul {
  padding: 0;
  margin: 0 16px;
}

#page-guide-more.isTouch .section ul li {
  list-style-type: none;
}

#page-guide-more.isTouch .section ul li {
  margin: 0 0 24px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

#page-guide-more.isTouch .section ul .section-image {
  margin: 0 16px 0 0;
}

#page-guide-more.isTouch .section ul .section-image img {
  width: 44px;
  height: 44px;
  vertical-align: bottom;
}

#page-guide-more.isTouch .section ul div {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 0;
}

#page-guide-more.isTouch .section ul div h3 {
  margin: 0;
  font-size: 13px;
  line-height: 1.3;
}

#page-guide-more.isTouch .section ul div p {
  margin: 8px 0 0;
  font-size: 12px;
  line-height: 1.5;
  color: #666;
}

#page-guide-more.isTouch #signup {
  border-top: 1px solid #ddd;
  padding: 24px 16px 0;
}